Class: Google::Apis::DisplayvideoV4::AdGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single ad group associated with a line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdGroup

Returns a new instance of AdGroup.



191
192
193
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_formatString

Required. Immutable. The format of the ads in the ad group. Corresponds to the JSON property adGroupFormat

Returns:

  • (String)


134
135
136
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 134

def ad_group_format
  @ad_group_format
end

#ad_group_idFixnum

Output only. The unique ID of the ad group. Assigned by the system. Corresponds to the JSON property adGroupId

Returns:

  • (Fixnum)


139
140
141
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 139

def ad_group_id
  @ad_group_id
end

#ad_group_inventory_controlGoogle::Apis::DisplayvideoV4::AdGroupInventoryControl

The inventory control of the ad group. Corresponds to the JSON property adGroupInventoryControl



144
145
146
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 144

def ad_group_inventory_control
  @ad_group_inventory_control
end

#advertiser_idFixnum

Output only. The unique ID of the advertiser the ad group belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


149
150
151
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 149

def advertiser_id
  @advertiser_id
end

#bid_strategyGoogle::Apis::DisplayvideoV4::BiddingStrategy

Settings that control the bid strategy. Bid strategy determines the bid price. Corresponds to the JSON property bidStrategy



154
155
156
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 154

def bid_strategy
  @bid_strategy
end

#display_nameString

Required. The display name of the ad group. Must be UTF-8 encoded with a maximum size of 255 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


160
161
162
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 160

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not the ad group can spend its budget and bid on inventory. If the ad group's parent line item is not active, the ad group can' t spend its budget even if its own status is ENTITY_STATUS_ACTIVE. Corresponds to the JSON property entityStatus

Returns:

  • (String)


167
168
169
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 167

def entity_status
  @entity_status
end

#line_item_idFixnum

Required. Immutable. The unique ID of the line item that the ad group belongs to. Corresponds to the JSON property lineItemId

Returns:

  • (Fixnum)


173
174
175
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 173

def line_item_id
  @line_item_id
end

#nameString

Output only. Identifier. The resource name of the ad group. Corresponds to the JSON property name

Returns:

  • (String)


178
179
180
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 178

def name
  @name
end

#product_feed_dataGoogle::Apis::DisplayvideoV4::ProductFeedData

The details of product feed. Corresponds to the JSON property productFeedData



183
184
185
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 183

def product_feed_data
  @product_feed_data
end

#targeting_expansionGoogle::Apis::DisplayvideoV4::TargetingExpansionConfig

Settings that control the optimized targeting settings of the line item. Corresponds to the JSON property targetingExpansion



189
190
191
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 189

def targeting_expansion
  @targeting_expansion
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 196

def update!(**args)
  @ad_group_format = args[:ad_group_format] if args.key?(:ad_group_format)
  @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id)
  @ad_group_inventory_control = args[:ad_group_inventory_control] if args.key?(:ad_group_inventory_control)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @line_item_id = args[:line_item_id] if args.key?(:line_item_id)
  @name = args[:name] if args.key?(:name)
  @product_feed_data = args[:product_feed_data] if args.key?(:product_feed_data)
  @targeting_expansion = args[:targeting_expansion] if args.key?(:targeting_expansion)
end