Class: Google::Apis::DisplayvideoV4::AdGroupAssignedTargetingOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Wrapper object associating an AssignedTargetingOption resource and the ad group it is assigned to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdGroupAssignedTargetingOption

Returns a new instance of AdGroupAssignedTargetingOption.



360
361
362
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 360

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_idFixnum

The ID of the ad group the assigned targeting option is assigned to. Corresponds to the JSON property adGroupId

Returns:

  • (Fixnum)


352
353
354
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 352

def ad_group_id
  @ad_group_id
end

#assigned_targeting_optionGoogle::Apis::DisplayvideoV4::AssignedTargetingOption

A single assigned targeting option, which defines the state of a targeting option for an entity with targeting settings. Corresponds to the JSON property assignedTargetingOption



358
359
360
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 358

def assigned_targeting_option
  @assigned_targeting_option
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



365
366
367
368
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 365

def update!(**args)
  @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id)
  @assigned_targeting_option = args[:assigned_targeting_option] if args.key?(:assigned_targeting_option)
end