Class: Google::Apis::DisplayvideoV4::AdPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single ad policy associated with an ad group ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdPolicy

Returns a new instance of AdPolicy.



425
426
427
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_policy_approval_statusString

The policy approval status of an ad, indicating the approval decision. Corresponds to the JSON property adPolicyApprovalStatus

Returns:

  • (String)


410
411
412
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 410

def ad_policy_approval_status
  @ad_policy_approval_status
end

#ad_policy_review_statusString

The policy review status of an ad, indicating where in the review process the ad is currently. Corresponds to the JSON property adPolicyReviewStatus

Returns:

  • (String)


416
417
418
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 416

def ad_policy_review_status
  @ad_policy_review_status
end

#ad_policy_topic_entryArray<Google::Apis::DisplayvideoV4::AdPolicyTopicEntry>

The entries for each policy topic identified as relating to the ad. Each entry includes the topic, restriction level, and guidance on how to fix policy issues. Corresponds to the JSON property adPolicyTopicEntry



423
424
425
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 423

def ad_policy_topic_entry
  @ad_policy_topic_entry
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



430
431
432
433
434
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 430

def update!(**args)
  @ad_policy_approval_status = args[:ad_policy_approval_status] if args.key?(:ad_policy_approval_status)
  @ad_policy_review_status = args[:ad_policy_review_status] if args.key?(:ad_policy_review_status)
  @ad_policy_topic_entry = args[:ad_policy_topic_entry] if args.key?(:ad_policy_topic_entry)
end