Class: Google::Apis::DisplayvideoV4::AdPolicyTopicAppealInfo
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AdPolicyTopicAppealInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Information on how to appeal a policy decision.
Instance Attribute Summary collapse
-
#appeal_form_link ⇒ String
Only available when appeal_type is
APPEAL_FORM. -
#appeal_type ⇒ String
Whether the decision can be appealed through a self-service appeal or an appeal form.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdPolicyTopicAppealInfo
constructor
A new instance of AdPolicyTopicAppealInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdPolicyTopicAppealInfo
Returns a new instance of AdPolicyTopicAppealInfo.
470 471 472 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#appeal_form_link ⇒ String
Only available when appeal_type is APPEAL_FORM.
Corresponds to the JSON property appealFormLink
462 463 464 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 462 def appeal_form_link @appeal_form_link end |
#appeal_type ⇒ String
Whether the decision can be appealed through a self-service appeal or an
appeal form.
Corresponds to the JSON property appealType
468 469 470 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 468 def appeal_type @appeal_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
475 476 477 478 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 475 def update!(**args) @appeal_form_link = args[:appeal_form_link] if args.key?(:appeal_form_link) @appeal_type = args[:appeal_type] if args.key?(:appeal_type) end |