Class: Google::Apis::DisplayvideoV4::AdPolicyTopicEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

An entry describing how an ad has been identified as relating to an ad policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdPolicyTopicEntry

Returns a new instance of AdPolicyTopicEntry.



659
660
661
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 659

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appeal_infoGoogle::Apis::DisplayvideoV4::AdPolicyTopicAppealInfo

Information on how to appeal a policy decision. Corresponds to the JSON property appealInfo



611
612
613
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 611

def appeal_info
  @appeal_info
end

Ad policy help center link for the policy topic. Corresponds to the JSON property helpCenterLink

Returns:

  • (String)


616
617
618
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 616

def help_center_link
  @help_center_link
end

#policy_decision_typeString

The source of the policy decision. Corresponds to the JSON property policyDecisionType

Returns:

  • (String)


621
622
623
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 621

def policy_decision_type
  @policy_decision_type
end

#policy_enforcement_meansString

The policy enforcement means used in the policy review. Corresponds to the JSON property policyEnforcementMeans

Returns:

  • (String)


626
627
628
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 626

def policy_enforcement_means
  @policy_enforcement_means
end

#policy_labelString

Localized label text for policy. Examples include "Trademarks in text", " Contains Alcohol", etc. Corresponds to the JSON property policyLabel

Returns:

  • (String)


632
633
634
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 632

def policy_label
  @policy_label
end

#policy_topicString

The policy topic. Examples include "TRADEMARKS", "ALCOHOL", etc. Corresponds to the JSON property policyTopic

Returns:

  • (String)


637
638
639
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 637

def policy_topic
  @policy_topic
end

#policy_topic_constraintsArray<Google::Apis::DisplayvideoV4::AdPolicyTopicConstraint>

The serving constraints relevant to the policy decision. Corresponds to the JSON property policyTopicConstraints



642
643
644
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 642

def policy_topic_constraints
  @policy_topic_constraints
end

#policy_topic_descriptionString

A short summary description of the policy topic. Corresponds to the JSON property policyTopicDescription

Returns:

  • (String)


647
648
649
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 647

def policy_topic_description
  @policy_topic_description
end

#policy_topic_evidencesArray<Google::Apis::DisplayvideoV4::AdPolicyTopicEvidence>

The evidence used in the policy decision. Corresponds to the JSON property policyTopicEvidences



652
653
654
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 652

def policy_topic_evidences
  @policy_topic_evidences
end

#policy_topic_typeString

How ad serving will be affected due to the relation to the ad policy topic. Corresponds to the JSON property policyTopicType

Returns:

  • (String)


657
658
659
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 657

def policy_topic_type
  @policy_topic_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



664
665
666
667
668
669
670
671
672
673
674
675
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 664

def update!(**args)
  @appeal_info = args[:appeal_info] if args.key?(:appeal_info)
  @help_center_link = args[:help_center_link] if args.key?(:help_center_link)
  @policy_decision_type = args[:policy_decision_type] if args.key?(:policy_decision_type)
  @policy_enforcement_means = args[:policy_enforcement_means] if args.key?(:policy_enforcement_means)
  @policy_label = args[:policy_label] if args.key?(:policy_label)
  @policy_topic = args[:policy_topic] if args.key?(:policy_topic)
  @policy_topic_constraints = args[:policy_topic_constraints] if args.key?(:policy_topic_constraints)
  @policy_topic_description = args[:policy_topic_description] if args.key?(:policy_topic_description)
  @policy_topic_evidences = args[:policy_topic_evidences] if args.key?(:policy_topic_evidences)
  @policy_topic_type = args[:policy_topic_type] if args.key?(:policy_topic_type)
end