Class: Google::Apis::DisplayvideoV4::AdPolicyTopicEvidenceCounterfeit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details on the counterfeit enforcement that caused a policy violation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdPolicyTopicEvidenceCounterfeit

Returns a new instance of AdPolicyTopicEvidenceCounterfeit.



764
765
766
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 764

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ownersArray<String>

The content or product owners that made a complaint. Corresponds to the JSON property owners

Returns:

  • (Array<String>)


762
763
764
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 762

def owners
  @owners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



769
770
771
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 769

def update!(**args)
  @owners = args[:owners] if args.key?(:owners)
end