Class: Google::Apis::DisplayvideoV4::AdPolicyTopicEvidenceDestinationNotWorking
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AdPolicyTopicEvidenceDestinationNotWorking
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details for on HTTP or DNS errors related to the ad destination.
Instance Attribute Summary collapse
-
#device ⇒ String
The device where visiting the URL resulted in the error.
-
#dns_error_type ⇒ String
The type of DNS error.
-
#expanded_uri ⇒ String
The full URL that didn't work.
-
#http_error_code ⇒ Fixnum
The HTTP error code.
-
#last_checked_time ⇒ String
The last time the error was seen when navigating to URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdPolicyTopicEvidenceDestinationNotWorking
constructor
A new instance of AdPolicyTopicEvidenceDestinationNotWorking.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdPolicyTopicEvidenceDestinationNotWorking
Returns a new instance of AdPolicyTopicEvidenceDestinationNotWorking.
832 833 834 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 832 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device ⇒ String
The device where visiting the URL resulted in the error.
Corresponds to the JSON property device
810 811 812 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 810 def device @device end |
#dns_error_type ⇒ String
The type of DNS error.
Corresponds to the JSON property dnsErrorType
815 816 817 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 815 def dns_error_type @dns_error_type end |
#expanded_uri ⇒ String
The full URL that didn't work.
Corresponds to the JSON property expandedUri
820 821 822 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 820 def @expanded_uri end |
#http_error_code ⇒ Fixnum
The HTTP error code.
Corresponds to the JSON property httpErrorCode
825 826 827 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 825 def http_error_code @http_error_code end |
#last_checked_time ⇒ String
The last time the error was seen when navigating to URL.
Corresponds to the JSON property lastCheckedTime
830 831 832 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 830 def last_checked_time @last_checked_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
837 838 839 840 841 842 843 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 837 def update!(**args) @device = args[:device] if args.key?(:device) @dns_error_type = args[:dns_error_type] if args.key?(:dns_error_type) @expanded_uri = args[:expanded_uri] if args.key?(:expanded_uri) @http_error_code = args[:http_error_code] if args.key?(:http_error_code) @last_checked_time = args[:last_checked_time] if args.key?(:last_checked_time) end |