Class: Google::Apis::DisplayvideoV4::Advertiser
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::Advertiser
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single advertiser in Display & Video 360 (DV360).
Instance Attribute Summary collapse
-
#ad_server_config ⇒ Google::Apis::DisplayvideoV4::AdvertiserAdServerConfig
Ad server related settings of an advertiser.
-
#advertiser_id ⇒ Fixnum
Output only.
-
#billing_config ⇒ Google::Apis::DisplayvideoV4::AdvertiserBillingConfig
Billing related settings of an advertiser.
-
#contains_eu_political_ads ⇒ String
Optional.
-
#creative_config ⇒ Google::Apis::DisplayvideoV4::AdvertiserCreativeConfig
Creatives related settings of an advertiser.
-
#data_access_config ⇒ Google::Apis::DisplayvideoV4::AdvertiserDataAccessConfig
Settings that control how advertiser related data may be accessed.
-
#default_business_name ⇒ String
Optional.
-
#default_logo_asset_id ⇒ Fixnum
Optional.
-
#display_name ⇒ String
Required.
-
#entity_status ⇒ String
Required.
-
#general_config ⇒ Google::Apis::DisplayvideoV4::AdvertiserGeneralConfig
General settings of an advertiser.
-
#integration_details ⇒ Google::Apis::DisplayvideoV4::IntegrationDetails
Integration details of an entry.
-
#name ⇒ String
Output only.
-
#partner_id ⇒ Fixnum
Required.
-
#prisma_enabled ⇒ Boolean
(also: #prisma_enabled?)
Whether integration with Mediaocean (Prisma) is enabled.
-
#serving_config ⇒ Google::Apis::DisplayvideoV4::AdvertiserTargetingConfig
Targeting settings related to ad serving of an advertiser.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Advertiser
constructor
A new instance of Advertiser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Advertiser
Returns a new instance of Advertiser.
1410 1411 1412 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1410 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_server_config ⇒ Google::Apis::DisplayvideoV4::AdvertiserAdServerConfig
Ad server related settings of an advertiser.
Corresponds to the JSON property adServerConfig
1304 1305 1306 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1304 def ad_server_config @ad_server_config end |
#advertiser_id ⇒ Fixnum
Output only. The unique ID of the advertiser. Assigned by the system.
Corresponds to the JSON property advertiserId
1309 1310 1311 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1309 def advertiser_id @advertiser_id end |
#billing_config ⇒ Google::Apis::DisplayvideoV4::AdvertiserBillingConfig
Billing related settings of an advertiser.
Corresponds to the JSON property billingConfig
1314 1315 1316 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1314 def billing_config @billing_config end |
#contains_eu_political_ads ⇒ String
Optional. Whether this advertiser contains line items that serve European
Union political ads. If this field is set to
DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING, then the following will happen: *
Any new line items created under this advertiser will be assigned
DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING if not otherwise specified. * Any
existing line items under this advertiser that do not have a set value be
updated to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING within a day.
Corresponds to the JSON property containsEuPoliticalAds
1325 1326 1327 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1325 def contains_eu_political_ads @contains_eu_political_ads end |
#creative_config ⇒ Google::Apis::DisplayvideoV4::AdvertiserCreativeConfig
Creatives related settings of an advertiser.
Corresponds to the JSON property creativeConfig
1330 1331 1332 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1330 def creative_config @creative_config end |
#data_access_config ⇒ Google::Apis::DisplayvideoV4::AdvertiserDataAccessConfig
Settings that control how advertiser related data may be accessed.
Corresponds to the JSON property dataAccessConfig
1335 1336 1337 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1335 def data_access_config @data_access_config end |
#default_business_name ⇒ String
Optional. The default business name for the advertiser. This is the value used
by YouTube and Demand Gen ads under this advertiser if a business name is not
provided.
Corresponds to the JSON property defaultBusinessName
1342 1343 1344 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1342 def default_business_name @default_business_name end |
#default_logo_asset_id ⇒ Fixnum
Optional. The asset ID of the default logo image for the advertiser. This is
the asset ID that will be used by YouTube and Demand ads under this advertiser
if a logo asset is not provided. You must use advertisers.adAssets.upload to
upload this asset using the API.
Corresponds to the JSON property defaultLogoAssetId
1350 1351 1352 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1350 def default_logo_asset_id @default_logo_asset_id end |
#display_name ⇒ String
Required. The display name of the advertiser. Must be UTF-8 encoded with a
maximum size of 240 bytes.
Corresponds to the JSON property displayName
1356 1357 1358 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1356 def display_name @display_name end |
#entity_status ⇒ String
Required. Controls whether or not insertion orders and line items of the
advertiser can spend their budgets and bid on inventory. * Accepted values are
ENTITY_STATUS_ACTIVE, ENTITY_STATUS_PAUSED and
ENTITY_STATUS_SCHEDULED_FOR_DELETION. * If set to
ENTITY_STATUS_SCHEDULED_FOR_DELETION, the advertiser will be deleted 30 days
from when it was first scheduled for deletion.
Corresponds to the JSON property entityStatus
1366 1367 1368 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1366 def entity_status @entity_status end |
#general_config ⇒ Google::Apis::DisplayvideoV4::AdvertiserGeneralConfig
General settings of an advertiser.
Corresponds to the JSON property generalConfig
1371 1372 1373 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1371 def general_config @general_config end |
#integration_details ⇒ Google::Apis::DisplayvideoV4::IntegrationDetails
Integration details of an entry.
Corresponds to the JSON property integrationDetails
1376 1377 1378 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1376 def integration_details @integration_details end |
#name ⇒ String
Output only. The resource name of the advertiser.
Corresponds to the JSON property name
1381 1382 1383 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1381 def name @name end |
#partner_id ⇒ Fixnum
Required. Immutable. The unique ID of the partner that the advertiser belongs
to.
Corresponds to the JSON property partnerId
1387 1388 1389 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1387 def partner_id @partner_id end |
#prisma_enabled ⇒ Boolean Also known as: prisma_enabled?
Whether integration with Mediaocean (Prisma) is enabled. By enabling this, you
agree to the following: On behalf of my company, I authorize Mediaocean (
Prisma) to send budget segment plans to Google, and I authorize Google to send
corresponding reporting and invoices from DV360 to Mediaocean for the purposes
of budget planning, billing, and reconciliation for this advertiser.
Corresponds to the JSON property prismaEnabled
1396 1397 1398 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1396 def prisma_enabled @prisma_enabled end |
#serving_config ⇒ Google::Apis::DisplayvideoV4::AdvertiserTargetingConfig
Targeting settings related to ad serving of an advertiser.
Corresponds to the JSON property servingConfig
1402 1403 1404 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1402 def serving_config @serving_config end |
#update_time ⇒ String
Output only. The timestamp when the advertiser was last updated. Assigned by
the system.
Corresponds to the JSON property updateTime
1408 1409 1410 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1408 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1415 def update!(**args) @ad_server_config = args[:ad_server_config] if args.key?(:ad_server_config) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @billing_config = args[:billing_config] if args.key?(:billing_config) @contains_eu_political_ads = args[:contains_eu_political_ads] if args.key?(:contains_eu_political_ads) @creative_config = args[:creative_config] if args.key?(:creative_config) @data_access_config = args[:data_access_config] if args.key?(:data_access_config) @default_business_name = args[:default_business_name] if args.key?(:default_business_name) @default_logo_asset_id = args[:default_logo_asset_id] if args.key?(:default_logo_asset_id) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @general_config = args[:general_config] if args.key?(:general_config) @integration_details = args[:integration_details] if args.key?(:integration_details) @name = args[:name] if args.key?(:name) @partner_id = args[:partner_id] if args.key?(:partner_id) @prisma_enabled = args[:prisma_enabled] if args.key?(:prisma_enabled) @serving_config = args[:serving_config] if args.key?(:serving_config) @update_time = args[:update_time] if args.key?(:update_time) end |