Class: Google::Apis::DisplayvideoV4::AdvertiserAdServerConfig
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AdvertiserAdServerConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Ad server related settings of an advertiser.
Instance Attribute Summary collapse
-
#cm_hybrid_config ⇒ Google::Apis::DisplayvideoV4::CmHybridConfig
Settings for advertisers that use both Campaign Manager 360 (CM360) and third- party ad servers.
-
#third_party_only_config ⇒ Google::Apis::DisplayvideoV4::ThirdPartyOnlyConfig
Settings for advertisers that use third-party ad servers only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdvertiserAdServerConfig
constructor
A new instance of AdvertiserAdServerConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdvertiserAdServerConfig
Returns a new instance of AdvertiserAdServerConfig.
1338 1339 1340 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1338 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cm_hybrid_config ⇒ Google::Apis::DisplayvideoV4::CmHybridConfig
Settings for advertisers that use both Campaign Manager 360 (CM360) and third-
party ad servers.
Corresponds to the JSON property cmHybridConfig
1331 1332 1333 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1331 def cm_hybrid_config @cm_hybrid_config end |
#third_party_only_config ⇒ Google::Apis::DisplayvideoV4::ThirdPartyOnlyConfig
Settings for advertisers that use third-party ad servers only.
Corresponds to the JSON property thirdPartyOnlyConfig
1336 1337 1338 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1336 def third_party_only_config @third_party_only_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1343 1344 1345 1346 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1343 def update!(**args) @cm_hybrid_config = args[:cm_hybrid_config] if args.key?(:cm_hybrid_config) @third_party_only_config = args[:third_party_only_config] if args.key?(:third_party_only_config) end |