Class: Google::Apis::DisplayvideoV4::AdvertiserTargetingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Targeting settings related to ad serving of an advertiser.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdvertiserTargetingConfig

Returns a new instance of AdvertiserTargetingConfig.



1644
1645
1646
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exempt_tv_from_viewability_targetingBoolean Also known as: exempt_tv_from_viewability_targeting?

Whether or not connected TV devices are exempt from viewability targeting for all video line items under the advertiser. Corresponds to the JSON property exemptTvFromViewabilityTargeting

Returns:

  • (Boolean)


1641
1642
1643
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1641

def exempt_tv_from_viewability_targeting
  @exempt_tv_from_viewability_targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1649
1650
1651
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1649

def update!(**args)
  @exempt_tv_from_viewability_targeting = args[:exempt_tv_from_viewability_targeting] if args.key?(:exempt_tv_from_viewability_targeting)
end