Class: Google::Apis::DisplayvideoV4::AlgorithmRules

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Rule-based algorithm.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlgorithmRules

Returns a new instance of AlgorithmRules.



1721
1722
1723
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_model_idFixnum

Attribution model for the algorithm. This field is only supported for allowlisted partners. Corresponds to the JSON property attributionModelId

Returns:

  • (Fixnum)


1707
1708
1709
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1707

def attribution_model_id
  @attribution_model_id
end

#impression_signal_rulesetGoogle::Apis::DisplayvideoV4::AlgorithmRulesRuleset

A ruleset consisting of a list of rules and how to aggregate the resulting values. Corresponds to the JSON property impressionSignalRuleset



1713
1714
1715
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1713

def impression_signal_ruleset
  @impression_signal_ruleset
end

#post_impression_signal_rulesetGoogle::Apis::DisplayvideoV4::AlgorithmRulesRuleset

A ruleset consisting of a list of rules and how to aggregate the resulting values. Corresponds to the JSON property postImpressionSignalRuleset



1719
1720
1721
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1719

def post_impression_signal_ruleset
  @post_impression_signal_ruleset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1726
1727
1728
1729
1730
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1726

def update!(**args)
  @attribution_model_id = args[:attribution_model_id] if args.key?(:attribution_model_id)
  @impression_signal_ruleset = args[:impression_signal_ruleset] if args.key?(:impression_signal_ruleset)
  @post_impression_signal_ruleset = args[:post_impression_signal_ruleset] if args.key?(:post_impression_signal_ruleset)
end