Class: Google::Apis::DisplayvideoV4::AlgorithmRulesComparisonValue
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AlgorithmRulesComparisonValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A value to compare the signal to.
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
Boolean value.
-
#content_duration_value ⇒ String
Video content duration value.
-
#content_genre_id_value ⇒ Fixnum
Video genre id value.
-
#content_stream_type_value ⇒ String
Video delivery type value.
-
#creative_dimension_value ⇒ Google::Apis::DisplayvideoV4::Dimensions
Dimensions.
-
#day_and_time_value ⇒ Google::Apis::DisplayvideoV4::DayAndTime
Representation of time defined by day of the week and hour of the day.
-
#device_type_value ⇒ String
Device type value.
-
#double_value ⇒ Float
Double value.
-
#environment_value ⇒ String
Environment value.
-
#exchange_value ⇒ String
Exchange value.
-
#int64_value ⇒ Fixnum
Integer value.
-
#on_screen_position_value ⇒ String
Ad position value.
-
#string_value ⇒ String
String value.
-
#video_player_size_value ⇒ String
Video player size value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AlgorithmRulesComparisonValue
constructor
A new instance of AlgorithmRulesComparisonValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AlgorithmRulesComparisonValue
Returns a new instance of AlgorithmRulesComparisonValue.
1791 1792 1793 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1791 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
Boolean value.
Corresponds to the JSON property boolValue
1723 1724 1725 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1723 def bool_value @bool_value end |
#content_duration_value ⇒ String
Video content duration value.
Corresponds to the JSON property contentDurationValue
1729 1730 1731 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1729 def content_duration_value @content_duration_value end |
#content_genre_id_value ⇒ Fixnum
Video genre id value.
Corresponds to the JSON property contentGenreIdValue
1734 1735 1736 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1734 def content_genre_id_value @content_genre_id_value end |
#content_stream_type_value ⇒ String
Video delivery type value.
Corresponds to the JSON property contentStreamTypeValue
1739 1740 1741 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1739 def content_stream_type_value @content_stream_type_value end |
#creative_dimension_value ⇒ Google::Apis::DisplayvideoV4::Dimensions
Dimensions.
Corresponds to the JSON property creativeDimensionValue
1744 1745 1746 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1744 def creative_dimension_value @creative_dimension_value end |
#day_and_time_value ⇒ Google::Apis::DisplayvideoV4::DayAndTime
Representation of time defined by day of the week and hour of the day.
Corresponds to the JSON property dayAndTimeValue
1749 1750 1751 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1749 def day_and_time_value @day_and_time_value end |
#device_type_value ⇒ String
Device type value.
Corresponds to the JSON property deviceTypeValue
1754 1755 1756 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1754 def device_type_value @device_type_value end |
#double_value ⇒ Float
Double value.
Corresponds to the JSON property doubleValue
1759 1760 1761 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1759 def double_value @double_value end |
#environment_value ⇒ String
Environment value.
Corresponds to the JSON property environmentValue
1764 1765 1766 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1764 def environment_value @environment_value end |
#exchange_value ⇒ String
Exchange value.
Corresponds to the JSON property exchangeValue
1769 1770 1771 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1769 def exchange_value @exchange_value end |
#int64_value ⇒ Fixnum
Integer value.
Corresponds to the JSON property int64Value
1774 1775 1776 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1774 def int64_value @int64_value end |
#on_screen_position_value ⇒ String
Ad position value.
Corresponds to the JSON property onScreenPositionValue
1779 1780 1781 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1779 def on_screen_position_value @on_screen_position_value end |
#string_value ⇒ String
String value.
Corresponds to the JSON property stringValue
1784 1785 1786 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1784 def string_value @string_value end |
#video_player_size_value ⇒ String
Video player size value. This field is only supported for allowlisted partners.
Corresponds to the JSON property videoPlayerSizeValue
1789 1790 1791 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1789 def video_player_size_value @video_player_size_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1796 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @content_duration_value = args[:content_duration_value] if args.key?(:content_duration_value) @content_genre_id_value = args[:content_genre_id_value] if args.key?(:content_genre_id_value) @content_stream_type_value = args[:content_stream_type_value] if args.key?(:content_stream_type_value) @creative_dimension_value = args[:creative_dimension_value] if args.key?(:creative_dimension_value) @day_and_time_value = args[:day_and_time_value] if args.key?(:day_and_time_value) @device_type_value = args[:device_type_value] if args.key?(:device_type_value) @double_value = args[:double_value] if args.key?(:double_value) @environment_value = args[:environment_value] if args.key?(:environment_value) @exchange_value = args[:exchange_value] if args.key?(:exchange_value) @int64_value = args[:int64_value] if args.key?(:int64_value) @on_screen_position_value = args[:on_screen_position_value] if args.key?(:on_screen_position_value) @string_value = args[:string_value] if args.key?(:string_value) @video_player_size_value = args[:video_player_size_value] if args.key?(:video_player_size_value) end |