Class: Google::Apis::DisplayvideoV4::AlgorithmRulesRule
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AlgorithmRulesRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Set of conditions. The return value of the rule is either: * The return value for single met condition or * The defined default return value if no conditions are met.
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Google::Apis::DisplayvideoV4::AlgorithmRulesRuleCondition>
List of conditions in this rule.
-
#default_return_value ⇒ Google::Apis::DisplayvideoV4::AlgorithmRulesSignalValue
Adjusted value of the signal used for rule evaluation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AlgorithmRulesRule
constructor
A new instance of AlgorithmRulesRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AlgorithmRulesRule
Returns a new instance of AlgorithmRulesRule.
1775 1776 1777 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1775 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Array<Google::Apis::DisplayvideoV4::AlgorithmRulesRuleCondition>
List of conditions in this rule. The criteria among conditions should be
mutually exclusive.
Corresponds to the JSON property conditions
1768 1769 1770 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1768 def conditions @conditions end |
#default_return_value ⇒ Google::Apis::DisplayvideoV4::AlgorithmRulesSignalValue
Adjusted value of the signal used for rule evaluation.
Corresponds to the JSON property defaultReturnValue
1773 1774 1775 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1773 def default_return_value @default_return_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1780 1781 1782 1783 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1780 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @default_return_value = args[:default_return_value] if args.key?(:default_return_value) end |