Class: Google::Apis::DisplayvideoV4::AppCategoryTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Represents a targetable collection of apps. A collection lets you target dynamic groups of related apps that are maintained by the platform, for example All Apps/Google Play/Games. This will be populated in the app_category_details field when targeting_type is TARGETING_TYPE_APP_CATEGORY .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppCategoryTargetingOptionDetails

Returns a new instance of AppCategoryTargetingOptionDetails.



2141
2142
2143
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The name of the app collection. Corresponds to the JSON property displayName

Returns:

  • (String)


2139
2140
2141
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2139

def display_name
  @display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2146
2147
2148
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2146

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
end