Class: Google::Apis::DisplayvideoV4::AssignedInventorySource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

An assignment between a targetable inventory source and an inventory source group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AssignedInventorySource

Returns a new instance of AssignedInventorySource.



2227
2228
2229
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2227

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigned_inventory_source_idFixnum

Output only. The unique ID of the assigned inventory source. The ID is only unique within a given inventory source group. It may be reused in other contexts. Corresponds to the JSON property assignedInventorySourceId

Returns:

  • (Fixnum)


2215
2216
2217
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2215

def assigned_inventory_source_id
  @assigned_inventory_source_id
end

#inventory_source_idString

Required. The ID of the inventory source entity being targeted. Corresponds to the JSON property inventorySourceId

Returns:

  • (String)


2220
2221
2222
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2220

def inventory_source_id
  @inventory_source_id
end

#nameString

Output only. The resource name of the assigned inventory source. Corresponds to the JSON property name

Returns:

  • (String)


2225
2226
2227
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2225

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2232
2233
2234
2235
2236
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2232

def update!(**args)
  @assigned_inventory_source_id = args[:assigned_inventory_source_id] if args.key?(:assigned_inventory_source_id)
  @inventory_source_id = args[:inventory_source_id] if args.key?(:inventory_source_id)
  @name = args[:name] if args.key?(:name)
end