Class: Google::Apis::DisplayvideoV4::AssignedUserRole

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single assigned user role, which defines a user's authorized interaction with a specified partner or advertiser.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AssignedUserRole

Returns a new instance of AssignedUserRole.



2770
2771
2772
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2770

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

The ID of the advertiser that the assigend user role applies to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


2753
2754
2755
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2753

def advertiser_id
  @advertiser_id
end

#assigned_user_role_idString

Output only. The ID of the assigned user role. Corresponds to the JSON property assignedUserRoleId

Returns:

  • (String)


2758
2759
2760
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2758

def assigned_user_role_id
  @assigned_user_role_id
end

#partner_idFixnum

The ID of the partner that the assigned user role applies to. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


2763
2764
2765
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2763

def partner_id
  @partner_id
end

#user_roleString

Required. The user role to assign to a user for the entity. Corresponds to the JSON property userRole

Returns:

  • (String)


2768
2769
2770
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2768

def user_role
  @user_role
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2775
2776
2777
2778
2779
2780
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2775

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @assigned_user_role_id = args[:assigned_user_role_id] if args.key?(:assigned_user_role_id)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @user_role = args[:user_role] if args.key?(:user_role)
end