Class: Google::Apis::DisplayvideoV4::AudioVideoOffset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

The length an audio or a video has been played.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AudioVideoOffset

Returns a new instance of AudioVideoOffset.



2925
2926
2927
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2925

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#percentageFixnum

Optional. The offset in percentage of the audio or video duration. Corresponds to the JSON property percentage

Returns:

  • (Fixnum)


2918
2919
2920
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2918

def percentage
  @percentage
end

#secondsFixnum

Optional. The offset in seconds from the start of the audio or video. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


2923
2924
2925
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2923

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2930
2931
2932
2933
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2930

def update!(**args)
  @percentage = args[:percentage] if args.key?(:percentage)
  @seconds = args[:seconds] if args.key?(:seconds)
end