Class: Google::Apis::DisplayvideoV4::AuthorizedSellerStatusAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Represents an assigned authorized seller status. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_AUTHORIZED_SELLER_STATUS. If a resource does not have an TARGETING_TYPE_AUTHORIZED_SELLER_STATUS assigned targeting option, it is using the "Authorized Direct Sellers and Resellers" option.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthorizedSellerStatusAssignedTargetingOptionDetails

Returns a new instance of AuthorizedSellerStatusAssignedTargetingOptionDetails.



2940
2941
2942
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2940

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorized_seller_statusString

Output only. The authorized seller status to target. Corresponds to the JSON property authorizedSellerStatus

Returns:

  • (String)


2932
2933
2934
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2932

def authorized_seller_status
  @authorized_seller_status
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_AUTHORIZED_SELLER_STATUS. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


2938
2939
2940
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2938

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2945
2946
2947
2948
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2945

def update!(**args)
  @authorized_seller_status = args[:authorized_seller_status] if args.key?(:authorized_seller_status)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end