Class: Google::Apis::DisplayvideoV4::BiddingStrategy
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::BiddingStrategy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Settings that control the bid strategy. Bid strategy determines the bid price.
Instance Attribute Summary collapse
-
#demand_gen_bid ⇒ Google::Apis::DisplayvideoV4::DemandGenBiddingStrategy
Settings that control the bid strategy for Demand Gen resources.
-
#fixed_bid ⇒ Google::Apis::DisplayvideoV4::FixedBidStrategy
A strategy that uses a fixed bidding price.
-
#maximize_spend_auto_bid ⇒ Google::Apis::DisplayvideoV4::MaximizeSpendBidStrategy
A strategy that automatically adjusts the bid to optimize a specified performance goal while spending the full budget.
-
#performance_goal_auto_bid ⇒ Google::Apis::DisplayvideoV4::PerformanceGoalBidStrategy
A strategy that automatically adjusts the bid to meet or beat a specified performance goal.
-
#youtube_and_partners_bid ⇒ Google::Apis::DisplayvideoV4::YoutubeAndPartnersBiddingStrategy
Settings that control the bid strategy for YouTube and Partners resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BiddingStrategy
constructor
A new instance of BiddingStrategy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BiddingStrategy
Returns a new instance of BiddingStrategy.
3100 3101 3102 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#demand_gen_bid ⇒ Google::Apis::DisplayvideoV4::DemandGenBiddingStrategy
Settings that control the bid strategy for Demand Gen resources.
Corresponds to the JSON property demandGenBid
3076 3077 3078 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3076 def demand_gen_bid @demand_gen_bid end |
#fixed_bid ⇒ Google::Apis::DisplayvideoV4::FixedBidStrategy
A strategy that uses a fixed bidding price.
Corresponds to the JSON property fixedBid
3081 3082 3083 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3081 def fixed_bid @fixed_bid end |
#maximize_spend_auto_bid ⇒ Google::Apis::DisplayvideoV4::MaximizeSpendBidStrategy
A strategy that automatically adjusts the bid to optimize a specified
performance goal while spending the full budget.
Corresponds to the JSON property maximizeSpendAutoBid
3087 3088 3089 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3087 def maximize_spend_auto_bid @maximize_spend_auto_bid end |
#performance_goal_auto_bid ⇒ Google::Apis::DisplayvideoV4::PerformanceGoalBidStrategy
A strategy that automatically adjusts the bid to meet or beat a specified
performance goal.
Corresponds to the JSON property performanceGoalAutoBid
3093 3094 3095 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3093 def performance_goal_auto_bid @performance_goal_auto_bid end |
#youtube_and_partners_bid ⇒ Google::Apis::DisplayvideoV4::YoutubeAndPartnersBiddingStrategy
Settings that control the bid strategy for YouTube and Partners resources.
Corresponds to the JSON property youtubeAndPartnersBid
3098 3099 3100 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3098 def youtube_and_partners_bid @youtube_and_partners_bid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3105 3106 3107 3108 3109 3110 3111 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3105 def update!(**args) @demand_gen_bid = args[:demand_gen_bid] if args.key?(:demand_gen_bid) @fixed_bid = args[:fixed_bid] if args.key?(:fixed_bid) @maximize_spend_auto_bid = args[:maximize_spend_auto_bid] if args.key?(:maximize_spend_auto_bid) @performance_goal_auto_bid = args[:performance_goal_auto_bid] if args.key?(:performance_goal_auto_bid) @youtube_and_partners_bid = args[:youtube_and_partners_bid] if args.key?(:youtube_and_partners_bid) end |