Class: Google::Apis::DisplayvideoV4::BudgetSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Summarized information of an individual campaign budget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BudgetSummary

Returns a new instance of BudgetSummary.



3207
3208
3209
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_budget_idString

Corresponds to the external_budget_id of a campaign budget. If the value is not set in the campaign budget, this field will be empty. Corresponds to the JSON property externalBudgetId

Returns:

  • (String)


3178
3179
3180
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3178

def external_budget_id
  @external_budget_id
end

#pre_tax_amount_microsFixnum

The sum of charges made under this budget before taxes, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property preTaxAmountMicros

Returns:

  • (Fixnum)


3185
3186
3187
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3185

def pre_tax_amount_micros
  @pre_tax_amount_micros
end

#prisma_cpe_codeGoogle::Apis::DisplayvideoV4::PrismaCpeCode

Google Payments Center supports searching and filtering on the component fields of this code. Corresponds to the JSON property prismaCpeCode



3191
3192
3193
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3191

def prisma_cpe_code
  @prisma_cpe_code
end

#tax_amount_microsFixnum

The amount of tax applied to charges under this budget, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property taxAmountMicros

Returns:

  • (Fixnum)


3198
3199
3200
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3198

def tax_amount_micros
  @tax_amount_micros
end

#total_amount_microsFixnum

The total sum of charges made under this budget, including tax, in micros of the invoice's currency. For example, if currency_code is USD, then 1000000 represents one US dollar. Corresponds to the JSON property totalAmountMicros

Returns:

  • (Fixnum)


3205
3206
3207
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3205

def total_amount_micros
  @total_amount_micros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3212
3213
3214
3215
3216
3217
3218
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3212

def update!(**args)
  @external_budget_id = args[:external_budget_id] if args.key?(:external_budget_id)
  @pre_tax_amount_micros = args[:pre_tax_amount_micros] if args.key?(:pre_tax_amount_micros)
  @prisma_cpe_code = args[:prisma_cpe_code] if args.key?(:prisma_cpe_code)
  @tax_amount_micros = args[:tax_amount_micros] if args.key?(:tax_amount_micros)
  @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros)
end