Class: Google::Apis::DisplayvideoV4::BulkEditAdGroupAssignedTargetingOptionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for BulkEditAdGroupAssignedTargetingOptions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkEditAdGroupAssignedTargetingOptionsRequest

Returns a new instance of BulkEditAdGroupAssignedTargetingOptionsRequest.



3199
3200
3201
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3199

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_idsArray<Fixnum>

Required. The IDs of the ad groups the assigned targeting options will belong to. A maximum of 25 ad group IDs can be specified. Corresponds to the JSON property adGroupIds

Returns:

  • (Array<Fixnum>)


3171
3172
3173
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3171

def ad_group_ids
  @ad_group_ids
end

#create_requestsArray<Google::Apis::DisplayvideoV4::CreateAssignedTargetingOptionsRequest>

Optional. The assigned targeting options to create in batch, specified as a list of CreateAssignedTargetingOptionRequest. Supported targeting types: * TARGETING_TYPE_AGE_RANGE * TARGETING_TYPE_APP * TARGETING_TYPE_APP_CATEGORY * TARGETING_TYPE_AUDIENCE_GROUP * TARGETING_TYPE_CATEGORY * TARGETING_TYPE_GENDER * TARGETING_TYPE_GEO_REGION * TARGETING_TYPE_HOUSEHOLD_INCOME * TARGETING_TYPE_KEYWORD * TARGETING_TYPE_LANGUAGE * TARGETING_TYPE_PARENTAL_STATUS * TARGETING_TYPE_URL * TARGETING_TYPE_YOUTUBE_CHANNEL * TARGETING_TYPE_YOUTUBE_VIDEO Corresponds to the JSON property createRequests



3184
3185
3186
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3184

def create_requests
  @create_requests
end

#delete_requestsArray<Google::Apis::DisplayvideoV4::DeleteAssignedTargetingOptionsRequest>

Optional. The assigned targeting options to delete in batch, specified as a list of DeleteAssignedTargetingOptionsRequest. Supported targeting types: * TARGETING_TYPE_AGE_RANGE * TARGETING_TYPE_APP * TARGETING_TYPE_APP_CATEGORY * TARGETING_TYPE_AUDIENCE_GROUP * TARGETING_TYPE_CATEGORY * TARGETING_TYPE_GENDER * TARGETING_TYPE_GEO_REGION * TARGETING_TYPE_HOUSEHOLD_INCOME * TARGETING_TYPE_KEYWORD * TARGETING_TYPE_LANGUAGE * TARGETING_TYPE_PARENTAL_STATUS * TARGETING_TYPE_URL * TARGETING_TYPE_YOUTUBE_CHANNEL * TARGETING_TYPE_YOUTUBE_VIDEO Corresponds to the JSON property deleteRequests



3197
3198
3199
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3197

def delete_requests
  @delete_requests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3204
3205
3206
3207
3208
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3204

def update!(**args)
  @ad_group_ids = args[:ad_group_ids] if args.key?(:ad_group_ids)
  @create_requests = args[:create_requests] if args.key?(:create_requests)
  @delete_requests = args[:delete_requests] if args.key?(:delete_requests)
end