Class: Google::Apis::DisplayvideoV4::BulkEditAdGroupAssignedTargetingOptionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::BulkEditAdGroupAssignedTargetingOptionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Response message for BulkEditAssignedTargetingOptions.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::DisplayvideoV4::Status>
Output only.
-
#failed_ad_group_ids ⇒ Array<Fixnum>
Output only.
-
#updated_ad_group_ids ⇒ Array<Fixnum>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkEditAdGroupAssignedTargetingOptionsResponse
constructor
A new instance of BulkEditAdGroupAssignedTargetingOptionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkEditAdGroupAssignedTargetingOptionsResponse
Returns a new instance of BulkEditAdGroupAssignedTargetingOptionsResponse.
3238 3239 3240 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3238 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::DisplayvideoV4::Status>
Output only. The error information for each ad group that failed to update.
Corresponds to the JSON property errors
3226 3227 3228 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3226 def errors @errors end |
#failed_ad_group_ids ⇒ Array<Fixnum>
Output only. The IDs of the ad groups which failed to update.
Corresponds to the JSON property failedAdGroupIds
3231 3232 3233 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3231 def failed_ad_group_ids @failed_ad_group_ids end |
#updated_ad_group_ids ⇒ Array<Fixnum>
Output only. The IDs of the ad groups which were successfully updated.
Corresponds to the JSON property updatedAdGroupIds
3236 3237 3238 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3236 def updated_ad_group_ids @updated_ad_group_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3243 3244 3245 3246 3247 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3243 def update!(**args) @errors = args[:errors] if args.key?(:errors) @failed_ad_group_ids = args[:failed_ad_group_ids] if args.key?(:failed_ad_group_ids) @updated_ad_group_ids = args[:updated_ad_group_ids] if args.key?(:updated_ad_group_ids) end |