Class: Google::Apis::DisplayvideoV4::BulkEditAssignedLocationsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for AssignedLocationService.BulkEditAssignedLocations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkEditAssignedLocationsRequest

Returns a new instance of BulkEditAssignedLocationsRequest.



3372
3373
3374
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#created_assigned_locationsArray<Google::Apis::DisplayvideoV4::AssignedLocation>

The assigned locations to create in bulk, specified as a list of AssignedLocation resources. Corresponds to the JSON property createdAssignedLocations



3364
3365
3366
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3364

def created_assigned_locations
  @created_assigned_locations
end

#deleted_assigned_locationsArray<Fixnum>

The IDs of the assigned locations to delete in bulk, specified as a list of assignedLocationId values. Corresponds to the JSON property deletedAssignedLocations

Returns:

  • (Array<Fixnum>)


3370
3371
3372
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3370

def deleted_assigned_locations
  @deleted_assigned_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3377
3378
3379
3380
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3377

def update!(**args)
  @created_assigned_locations = args[:created_assigned_locations] if args.key?(:created_assigned_locations)
  @deleted_assigned_locations = args[:deleted_assigned_locations] if args.key?(:deleted_assigned_locations)
end