Class: Google::Apis::DisplayvideoV4::BulkEditAssignedLocationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::BulkEditAssignedLocationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#assigned_locations ⇒ Array<Google::Apis::DisplayvideoV4::AssignedLocation>
The list of assigned locations that have been successfully created.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkEditAssignedLocationsResponse
constructor
A new instance of BulkEditAssignedLocationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkEditAssignedLocationsResponse
Returns a new instance of BulkEditAssignedLocationsResponse.
3393 3394 3395 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3393 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assigned_locations ⇒ Array<Google::Apis::DisplayvideoV4::AssignedLocation>
The list of assigned locations that have been successfully created. This list
will be absent if empty.
Corresponds to the JSON property assignedLocations
3391 3392 3393 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3391 def assigned_locations @assigned_locations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3398 3399 3400 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3398 def update!(**args) @assigned_locations = args[:assigned_locations] if args.key?(:assigned_locations) end |