Class: Google::Apis::DisplayvideoV4::BulkEditNegativeKeywordsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for NegativeKeywordService.BulkEditNegativeKeywords.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkEditNegativeKeywordsRequest

Returns a new instance of BulkEditNegativeKeywordsRequest.



3678
3679
3680
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#created_negative_keywordsArray<Google::Apis::DisplayvideoV4::NegativeKeyword>

The negative keywords to create in batch, specified as a list of NegativeKeywords. Corresponds to the JSON property createdNegativeKeywords



3670
3671
3672
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3670

def created_negative_keywords
  @created_negative_keywords
end

#deleted_negative_keywordsArray<String>

The negative keywords to delete in batch, specified as a list of keyword_values. Corresponds to the JSON property deletedNegativeKeywords

Returns:

  • (Array<String>)


3676
3677
3678
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3676

def deleted_negative_keywords
  @deleted_negative_keywords
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3683
3684
3685
3686
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3683

def update!(**args)
  @created_negative_keywords = args[:created_negative_keywords] if args.key?(:created_negative_keywords)
  @deleted_negative_keywords = args[:deleted_negative_keywords] if args.key?(:deleted_negative_keywords)
end