Class: Google::Apis::DisplayvideoV4::BulkEditPartnerAssignedTargetingOptionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for BulkEditPartnerAssignedTargetingOptions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkEditPartnerAssignedTargetingOptionsRequest

Returns a new instance of BulkEditPartnerAssignedTargetingOptionsRequest.



3727
3728
3729
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3727

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_requestsArray<Google::Apis::DisplayvideoV4::CreateAssignedTargetingOptionsRequest>

The assigned targeting options to create in batch, specified as a list of CreateAssignedTargetingOptionsRequest. Supported targeting types: * TARGETING_TYPE_CHANNEL Corresponds to the JSON property createRequests



3718
3719
3720
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3718

def create_requests
  @create_requests
end

#delete_requestsArray<Google::Apis::DisplayvideoV4::DeleteAssignedTargetingOptionsRequest>

The assigned targeting options to delete in batch, specified as a list of DeleteAssignedTargetingOptionsRequest. Supported targeting types: * TARGETING_TYPE_CHANNEL Corresponds to the JSON property deleteRequests



3725
3726
3727
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3725

def delete_requests
  @delete_requests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3732
3733
3734
3735
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3732

def update!(**args)
  @create_requests = args[:create_requests] if args.key?(:create_requests)
  @delete_requests = args[:delete_requests] if args.key?(:delete_requests)
end