Class: Google::Apis::DisplayvideoV4::Campaign

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Campaign

Returns a new instance of Campaign.



4183
4184
4185
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The unique ID of the advertiser the campaign belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


4129
4130
4131
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4129

def advertiser_id
  @advertiser_id
end

#campaign_budgetsArray<Google::Apis::DisplayvideoV4::CampaignBudget>

The list of budgets available to this campaign. If this field is not set, the campaign uses an unlimited budget. Corresponds to the JSON property campaignBudgets



4135
4136
4137
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4135

def campaign_budgets
  @campaign_budgets
end

#campaign_flightGoogle::Apis::DisplayvideoV4::CampaignFlight

Settings that track the planned spend and duration of a campaign. Corresponds to the JSON property campaignFlight



4140
4141
4142
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4140

def campaign_flight
  @campaign_flight
end

#campaign_goalGoogle::Apis::DisplayvideoV4::CampaignGoal

Settings that control the goal of a campaign. Corresponds to the JSON property campaignGoal



4145
4146
4147
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4145

def campaign_goal
  @campaign_goal
end

#campaign_idFixnum

Output only. The unique ID of the campaign. Assigned by the system. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


4150
4151
4152
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4150

def campaign_id
  @campaign_id
end

#display_nameString

Required. The display name of the campaign. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


4156
4157
4158
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4156

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not the insertion orders under this campaign can spend their budgets and bid on inventory. * Accepted values are ENTITY_STATUS_ACTIVE, ENTITY_STATUS_ARCHIVED, and ENTITY_STATUS_PAUSED. * For CreateCampaign method, ENTITY_STATUS_ARCHIVED is not allowed. Corresponds to the JSON property entityStatus

Returns:

  • (String)


4164
4165
4166
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4164

def entity_status
  @entity_status
end

#frequency_capGoogle::Apis::DisplayvideoV4::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property frequencyCap



4170
4171
4172
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4170

def frequency_cap
  @frequency_cap
end

#nameString

Output only. The resource name of the campaign. Corresponds to the JSON property name

Returns:

  • (String)


4175
4176
4177
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4175

def name
  @name
end

#update_timeString

Output only. The timestamp when the campaign was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


4181
4182
4183
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4181

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4188
4189
4190
4191
4192
4193
4194
4195
4196
4197
4198
4199
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4188

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @campaign_budgets = args[:campaign_budgets] if args.key?(:campaign_budgets)
  @campaign_flight = args[:campaign_flight] if args.key?(:campaign_flight)
  @campaign_goal = args[:campaign_goal] if args.key?(:campaign_goal)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end