Class: Google::Apis::DisplayvideoV4::CarouselCard

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen carousel card.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CarouselCard

Returns a new instance of CarouselCard.



4402
4403
4404
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_to_actionString

Required. The text on the call-to-action button shown on the card. Must use 10 characters or less. Corresponds to the JSON property callToAction

Returns:

  • (String)


4368
4369
4370
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4368

def call_to_action
  @call_to_action
end

#final_mobile_urlString

Optional. The URL address of the webpage that people reach after they click the card on a mobile device. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


4374
4375
4376
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4374

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the card. Corresponds to the JSON property finalUrl

Returns:

  • (String)


4380
4381
4382
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4380

def final_url
  @final_url
end

#headlineString

Required. The headline of the card. Corresponds to the JSON property headline

Returns:

  • (String)


4385
4386
4387
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4385

def headline
  @headline
end

#marketing_imageGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property marketingImage



4390
4391
4392
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4390

def marketing_image
  @marketing_image
end

#portrait_marketing_imageGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property portraitMarketingImage



4395
4396
4397
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4395

def portrait_marketing_image
  @portrait_marketing_image
end

#square_marketing_imageGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property squareMarketingImage



4400
4401
4402
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4400

def square_marketing_image
  @square_marketing_image
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4407
4408
4409
4410
4411
4412
4413
4414
4415
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4407

def update!(**args)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @headline = args[:headline] if args.key?(:headline)
  @marketing_image = args[:marketing_image] if args.key?(:marketing_image)
  @portrait_marketing_image = args[:portrait_marketing_image] if args.key?(:portrait_marketing_image)
  @square_marketing_image = args[:square_marketing_image] if args.key?(:square_marketing_image)
end