Class: Google::Apis::DisplayvideoV4::CombinedAudienceGroup
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::CombinedAudienceGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details of combined audience group. All combined audience targeting settings are logically ‘OR’ of each other.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ CombinedAudienceGroup
constructor
A new instance of CombinedAudienceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CombinedAudienceGroup
Returns a new instance of CombinedAudienceGroup.
4768 4769 4770 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4768 def initialize(**args) update!(**args) end |
Instance Attribute Details
#settings ⇒ Array<Google::Apis::DisplayvideoV4::CombinedAudienceTargetingSetting>
Required. All combined audience targeting settings in combined audience group.
Repeated settings with the same id will be ignored. The number of combined
audience settings should be no more than five, error will be thrown otherwise.
Corresponds to the JSON property settings
4766 4767 4768 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4766 def settings @settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4773 4774 4775 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4773 def update!(**args) @settings = args[:settings] if args.key?(:settings) end |