Class: Google::Apis::DisplayvideoV4::CommonInStreamAttribute
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::CommonInStreamAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Common attributes for in-stream, non-skippable and bumper ads.
Instance Attribute Summary collapse
-
#action_button_label ⇒ String
The text on the call-to-action button.
-
#action_headline ⇒ String
The headline of the call-to-action banner.
-
#companion_banner ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
-
#display_url ⇒ String
The webpage address that appears with the ad.
-
#final_url ⇒ String
The URL address of the webpage that people reach after they click the ad.
-
#tracking_url ⇒ String
The URL address loaded in the background for tracking purposes.
-
#video ⇒ Google::Apis::DisplayvideoV4::YoutubeVideoDetails
Details of a YouTube video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommonInStreamAttribute
constructor
A new instance of CommonInStreamAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommonInStreamAttribute
Returns a new instance of CommonInStreamAttribute.
4836 4837 4838 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4836 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_button_label ⇒ String
The text on the call-to-action button.
Corresponds to the JSON property actionButtonLabel
4804 4805 4806 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4804 def @action_button_label end |
#action_headline ⇒ String
The headline of the call-to-action banner.
Corresponds to the JSON property actionHeadline
4809 4810 4811 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4809 def action_headline @action_headline end |
#companion_banner ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
Corresponds to the JSON property companionBanner
4814 4815 4816 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4814 def @companion_banner end |
#display_url ⇒ String
The webpage address that appears with the ad.
Corresponds to the JSON property displayUrl
4819 4820 4821 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4819 def display_url @display_url end |
#final_url ⇒ String
The URL address of the webpage that people reach after they click the ad.
Corresponds to the JSON property finalUrl
4824 4825 4826 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4824 def final_url @final_url end |
#tracking_url ⇒ String
The URL address loaded in the background for tracking purposes.
Corresponds to the JSON property trackingUrl
4829 4830 4831 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4829 def tracking_url @tracking_url end |
#video ⇒ Google::Apis::DisplayvideoV4::YoutubeVideoDetails
Details of a YouTube video.
Corresponds to the JSON property video
4834 4835 4836 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4834 def video @video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4841 4842 4843 4844 4845 4846 4847 4848 4849 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4841 def update!(**args) @action_button_label = args[:action_button_label] if args.key?(:action_button_label) @action_headline = args[:action_headline] if args.key?(:action_headline) @companion_banner = args[:companion_banner] if args.key?(:companion_banner) @display_url = args[:display_url] if args.key?(:display_url) @final_url = args[:final_url] if args.key?(:final_url) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @video = args[:video] if args.key?(:video) end |