Class: Google::Apis::DisplayvideoV4::CreateAssignedTargetingOptionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A request listing which assigned targeting options of a given targeting type should be created and added.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateAssignedTargetingOptionsRequest

Returns a new instance of CreateAssignedTargetingOptionsRequest.



5405
5406
5407
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5405

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigned_targeting_optionsArray<Google::Apis::DisplayvideoV4::AssignedTargetingOption>

Required. The assigned targeting options to create and add. Corresponds to the JSON property assignedTargetingOptions



5398
5399
5400
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5398

def assigned_targeting_options
  @assigned_targeting_options
end

#targeting_typeString

Required. Identifies the type of this assigned targeting option. Corresponds to the JSON property targetingType

Returns:

  • (String)


5403
5404
5405
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5403

def targeting_type
  @targeting_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5410
5411
5412
5413
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5410

def update!(**args)
  @assigned_targeting_options = args[:assigned_targeting_options] if args.key?(:assigned_targeting_options)
  @targeting_type = args[:targeting_type] if args.key?(:targeting_type)
end