Class: Google::Apis::DisplayvideoV4::CustomBiddingScript

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single custom bidding script.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomBiddingScript

Returns a new instance of CustomBiddingScript.



6224
6225
6226
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Output only. Whether the script is currently being used for scoring by the parent algorithm. Corresponds to the JSON property active

Returns:

  • (Boolean)


6184
6185
6186
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6184

def active
  @active
end

#create_timeString

Output only. The time when the script was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6190
6191
6192
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6190

def create_time
  @create_time
end

#custom_bidding_algorithm_idFixnum

Output only. The unique ID of the custom bidding algorithm the script belongs to. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


6196
6197
6198
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6196

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#custom_bidding_script_idFixnum

Output only. The unique ID of the custom bidding script. Corresponds to the JSON property customBiddingScriptId

Returns:

  • (Fixnum)


6201
6202
6203
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6201

def custom_bidding_script_id
  @custom_bidding_script_id
end

#errorsArray<Google::Apis::DisplayvideoV4::ScriptError>

Output only. Error details of a rejected custom bidding script. This field will only be populated when state is REJECTED. Corresponds to the JSON property errors



6207
6208
6209
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6207

def errors
  @errors
end

#nameString

Output only. The resource name of the custom bidding script. Corresponds to the JSON property name

Returns:

  • (String)


6212
6213
6214
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6212

def name
  @name
end

#scriptGoogle::Apis::DisplayvideoV4::CustomBiddingScriptRef

The reference to the uploaded custom bidding script file. Corresponds to the JSON property script



6217
6218
6219
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6217

def script
  @script
end

#stateString

Output only. The state of the custom bidding script. Corresponds to the JSON property state

Returns:

  • (String)


6222
6223
6224
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6222

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6229
6230
6231
6232
6233
6234
6235
6236
6237
6238
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6229

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @custom_bidding_script_id = args[:custom_bidding_script_id] if args.key?(:custom_bidding_script_id)
  @errors = args[:errors] if args.key?(:errors)
  @name = args[:name] if args.key?(:name)
  @script = args[:script] if args.key?(:script)
  @state = args[:state] if args.key?(:state)
end