Class: Google::Apis::DisplayvideoV4::DemandGenCarouselAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen carousel ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenCarouselAd

Returns a new instance of DemandGenCarouselAd.



6678
6679
6680
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Optional. The business name shown on the ad. This setting is required unless a default value is set at the advertiser level. If left unset, the default value will be applied. Corresponds to the JSON property businessName

Returns:

  • (String)


6629
6630
6631
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6629

def business_name
  @business_name
end

#cardsArray<Google::Apis::DisplayvideoV4::CarouselCard>

Required. The list of cards shown on the ad. Corresponds to the JSON property cards



6634
6635
6636
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6634

def cards
  @cards
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6640
6641
6642
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6640

def custom_parameters
  @custom_parameters
end

#descriptionString

Required. The description of the ad. Corresponds to the JSON property description

Returns:

  • (String)


6645
6646
6647
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6645

def description
  @description
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6651
6652
6653
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6651

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6656
6657
6658
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6656

def final_url_suffix
  @final_url_suffix
end

#headlineString

Required. The headline of the ad. Corresponds to the JSON property headline

Returns:

  • (String)


6661
6662
6663
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6661

def headline
  @headline
end

#logoGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property logo



6666
6667
6668
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6666

def 
  @logo
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


6671
6672
6673
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6671

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


6676
6677
6678
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6676

def user_specified_tracking_url
  @user_specified_tracking_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6683
6684
6685
6686
6687
6688
6689
6690
6691
6692
6693
6694
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6683

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @cards = args[:cards] if args.key?(:cards)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @description = args[:description] if args.key?(:description)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headline = args[:headline] if args.key?(:headline)
  @logo = args[:logo] if args.key?(:logo)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
end