Class: Google::Apis::DisplayvideoV4::DemandGenProductAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen product ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenProductAd

Returns a new instance of DemandGenProductAd.



6857
6858
6859
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Optional. The business name shown on the ad. This setting is required unless a default value is set at the advertiser level. If left unset, the default value will be applied. Corresponds to the JSON property businessName

Returns:

  • (String)


6796
6797
6798
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6796

def business_name
  @business_name
end

#call_to_actionString

Required. The call-to-action button shown on the ad. The supported values are:

  • AUTOMATED * APPLY_NOW * BOOK_NOW * CONTACT_US * DOWNLOAD * GET_QUOTE * LEARN_MORE * SHOP_NOW * SIGN_UP * SUBSCRIBE Corresponds to the JSON property callToAction

Returns:

  • (String)


6803
6804
6805
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6803

def call_to_action
  @call_to_action
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6809
6810
6811
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6809

def custom_parameters
  @custom_parameters
end

#descriptionString

Required. The description of the ad. Corresponds to the JSON property description

Returns:

  • (String)


6814
6815
6816
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6814

def description
  @description
end

#display_url_breadcrumb1String

Optional. The first piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb1

Returns:

  • (String)


6819
6820
6821
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6819

def display_url_breadcrumb1
  @display_url_breadcrumb1
end

#display_url_breadcrumb2String

Optional. The second piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb2

Returns:

  • (String)


6824
6825
6826
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6824

def display_url_breadcrumb2
  @display_url_breadcrumb2
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6830
6831
6832
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6830

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6835
6836
6837
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6835

def final_url_suffix
  @final_url_suffix
end

#headlineString

Required. The headline of the ad. Corresponds to the JSON property headline

Returns:

  • (String)


6840
6841
6842
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6840

def headline
  @headline
end

#logoGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property logo



6845
6846
6847
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6845

def 
  @logo
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


6850
6851
6852
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6850

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


6855
6856
6857
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6855

def user_specified_tracking_url
  @user_specified_tracking_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6862
6863
6864
6865
6866
6867
6868
6869
6870
6871
6872
6873
6874
6875
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6862

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @description = args[:description] if args.key?(:description)
  @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1)
  @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headline = args[:headline] if args.key?(:headline)
  @logo = args[:logo] if args.key?(:logo)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
end