Class: Google::Apis::DisplayvideoV4::DuplicateLineItemRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for LineItemService.DuplicateLineItem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DuplicateLineItemRequest

Returns a new instance of DuplicateLineItemRequest.



7448
7449
7450
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7448

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contains_eu_political_adsString

Whether this line item will serve European Union political ads. If contains_eu_political_ads has been set to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING in the parent advertiser, then this field will be assigned DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING if not otherwise specified. This field can then be updated using the UI, API, or Structured Data Files. This field must be assigned when creating a new line item. Otherwise, the advertisers.lineItems.create request will fail. Corresponds to the JSON property containsEuPoliticalAds

Returns:

  • (String)


7440
7441
7442
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7440

def contains_eu_political_ads
  @contains_eu_political_ads
end

#target_display_nameString

The display name of the new line item. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property targetDisplayName

Returns:

  • (String)


7446
7447
7448
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7446

def target_display_name
  @target_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7453
7454
7455
7456
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7453

def update!(**args)
  @contains_eu_political_ads = args[:contains_eu_political_ads] if args.key?(:contains_eu_political_ads)
  @target_display_name = args[:target_display_name] if args.key?(:target_display_name)
end