Class: Google::Apis::DisplayvideoV4::EditCustomerMatchMembersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for FirstPartyAndPartnerAudienceService. EditCustomerMatchMembers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EditCustomerMatchMembersRequest

Returns a new instance of EditCustomerMatchMembersRequest.



7513
7514
7515
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7513

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#added_contact_info_listGoogle::Apis::DisplayvideoV4::ContactInfoList

Wrapper message for a list of contact information defining Customer Match audience members. Corresponds to the JSON property addedContactInfoList



7487
7488
7489
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7487

def added_contact_info_list
  @added_contact_info_list
end

#added_mobile_device_id_listGoogle::Apis::DisplayvideoV4::MobileDeviceIdList

Wrapper message for a list of mobile device IDs defining Customer Match audience members. Corresponds to the JSON property addedMobileDeviceIdList



7493
7494
7495
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7493

def added_mobile_device_id_list
  @added_mobile_device_id_list
end

#advertiser_idFixnum

Required. The ID of the owner advertiser of the updated Customer Match FirstAndThirdPartyAudience. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


7499
7500
7501
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7499

def advertiser_id
  @advertiser_id
end

#removed_contact_info_listGoogle::Apis::DisplayvideoV4::ContactInfoList

Wrapper message for a list of contact information defining Customer Match audience members. Corresponds to the JSON property removedContactInfoList



7505
7506
7507
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7505

def removed_contact_info_list
  @removed_contact_info_list
end

#removed_mobile_device_id_listGoogle::Apis::DisplayvideoV4::MobileDeviceIdList

Wrapper message for a list of mobile device IDs defining Customer Match audience members. Corresponds to the JSON property removedMobileDeviceIdList



7511
7512
7513
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7511

def removed_mobile_device_id_list
  @removed_mobile_device_id_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7518
7519
7520
7521
7522
7523
7524
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7518

def update!(**args)
  @added_contact_info_list = args[:added_contact_info_list] if args.key?(:added_contact_info_list)
  @added_mobile_device_id_list = args[:added_mobile_device_id_list] if args.key?(:added_mobile_device_id_list)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @removed_contact_info_list = args[:removed_contact_info_list] if args.key?(:removed_contact_info_list)
  @removed_mobile_device_id_list = args[:removed_mobile_device_id_list] if args.key?(:removed_mobile_device_id_list)
end