Class: Google::Apis::DisplayvideoV4::FixedBidStrategy
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::FixedBidStrategy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A strategy that uses a fixed bidding price.
Instance Attribute Summary collapse
-
#bid_amount_micros ⇒ Fixnum
The fixed bid amount, in micros of the advertiser's currency.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FixedBidStrategy
constructor
A new instance of FixedBidStrategy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FixedBidStrategy
Returns a new instance of FixedBidStrategy.
7970 7971 7972 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7970 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bid_amount_micros ⇒ Fixnum
The fixed bid amount, in micros of the advertiser's currency. For insertion
order entity, bid_amount_micros should be set as 0. For line item entity,
bid_amount_micros must be greater than or equal to billable unit of the given
currency and smaller than or equal to the upper limit 1000000000. For example,
1500000 represents 1.5 standard units of the currency.
Corresponds to the JSON property bidAmountMicros
7968 7969 7970 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7968 def bid_amount_micros @bid_amount_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7975 7976 7977 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7975 def update!(**args) @bid_amount_micros = args[:bid_amount_micros] if args.key?(:bid_amount_micros) end |