Class: Google::Apis::DisplayvideoV4::FloodlightGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single Floodlight group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FloodlightGroup

Returns a new instance of FloodlightGroup.



8261
8262
8263
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_view_configGoogle::Apis::DisplayvideoV4::ActiveViewVideoViewabilityMetricConfig

Configuration for custom Active View video viewability metrics. Corresponds to the JSON property activeViewConfig



8216
8217
8218
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8216

def active_view_config
  @active_view_config
end

#custom_variablesHash<String,Object>

User-defined custom variables owned by the Floodlight group. Use custom Floodlight variables to create reporting data that is tailored to your unique business needs. Custom Floodlight variables use the keys U1=, U2=, and so on, and can take any values that you choose to pass to them. You can use them to track virtually any type of data that you collect about your customers, such as the genre of movie that a customer purchases, the country to which the item is shipped, and so on. Custom Floodlight variables may not be used to pass any data that could be used or recognized as personally identifiable information (PII). Example: custom_variables fields "U1": value number_value: 123.4 , "U2": value string_value: "MyVariable2" , "U3": value string_value: "MyVariable3" `Acceptable values for keys are "U1" through "U100", inclusive. String values must be less than 64 characters long, and cannot contain the following characters:"<>. Corresponds to the JSON propertycustomVariables`

Returns:

  • (Hash<String,Object>)


8233
8234
8235
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8233

def custom_variables
  @custom_variables
end

#display_nameString

Required. The display name of the Floodlight group. Corresponds to the JSON property displayName

Returns:

  • (String)


8238
8239
8240
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8238

def display_name
  @display_name
end

#floodlight_group_idFixnum

Output only. The unique ID of the Floodlight group. Assigned by the system. Corresponds to the JSON property floodlightGroupId

Returns:

  • (Fixnum)


8243
8244
8245
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8243

def floodlight_group_id
  @floodlight_group_id
end

#lookback_windowGoogle::Apis::DisplayvideoV4::LookbackWindow

Specifies how many days into the past to look when determining whether to record a conversion. Corresponds to the JSON property lookbackWindow



8249
8250
8251
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8249

def lookback_window
  @lookback_window
end

#nameString

Output only. The resource name of the Floodlight group. Corresponds to the JSON property name

Returns:

  • (String)


8254
8255
8256
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8254

def name
  @name
end

#web_tag_typeString

Required. The web tag type enabled for the Floodlight group. Corresponds to the JSON property webTagType

Returns:

  • (String)


8259
8260
8261
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8259

def web_tag_type
  @web_tag_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8266
8267
8268
8269
8270
8271
8272
8273
8274
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8266

def update!(**args)
  @active_view_config = args[:active_view_config] if args.key?(:active_view_config)
  @custom_variables = args[:custom_variables] if args.key?(:custom_variables)
  @display_name = args[:display_name] if args.key?(:display_name)
  @floodlight_group_id = args[:floodlight_group_id] if args.key?(:floodlight_group_id)
  @lookback_window = args[:lookback_window] if args.key?(:lookback_window)
  @name = args[:name] if args.key?(:name)
  @web_tag_type = args[:web_tag_type] if args.key?(:web_tag_type)
end