Class: Google::Apis::DisplayvideoV4::GenerateReachForecastRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for ReachForecastService.GenerateReachForecast.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateReachForecastRequest

Returns a new instance of GenerateReachForecastRequest.



8393
8394
8395
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#campaign_durationGoogle::Apis::DisplayvideoV4::CampaignDuration

The duration of the reach plan. Corresponds to the JSON property campaignDuration



8368
8369
8370
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8368

def campaign_duration
  @campaign_duration
end

#currency_codeString

Required. The currency code for the plan in ISO 4217 format. Corresponds to the JSON property currencyCode

Returns:

  • (String)


8373
8374
8375
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8373

def currency_code
  @currency_code
end

#min_effective_frequencyFixnum

Optional. The minimum effective frequency for the reported reach metrics. This is the smallest number of times a customer must be exposed to the ad for it to be considered effective. This setting only impacts reporting. Must be between 1 and 10, inclusive. If not specified, a default of 1 is applied. Corresponds to the JSON property minEffectiveFrequency

Returns:

  • (Fixnum)


8381
8382
8383
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8381

def min_effective_frequency
  @min_effective_frequency
end

#planned_productsArray<Google::Apis::DisplayvideoV4::PlannedProduct>

Required. The list of line items to include in the forecast. Corresponds to the JSON property plannedProducts



8386
8387
8388
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8386

def planned_products
  @planned_products
end

#targetingGoogle::Apis::DisplayvideoV4::Targeting

Targeting settings for a planned campaign. Corresponds to the JSON property targeting



8391
8392
8393
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8391

def targeting
  @targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8398
8399
8400
8401
8402
8403
8404
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8398

def update!(**args)
  @campaign_duration = args[:campaign_duration] if args.key?(:campaign_duration)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @min_effective_frequency = args[:min_effective_frequency] if args.key?(:min_effective_frequency)
  @planned_products = args[:planned_products] if args.key?(:planned_products)
  @targeting = args[:targeting] if args.key?(:targeting)
end