Class: Google::Apis::DisplayvideoV4::GoogleAudienceGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details of Google audience group. All Google audience targeting settings are logically ‘OR’ of each other.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAudienceGroup

Returns a new instance of GoogleAudienceGroup.



8349
8350
8351
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#settingsArray<Google::Apis::DisplayvideoV4::GoogleAudienceTargetingSetting>

Required. All Google audience targeting settings in Google audience group. Repeated settings with the same id will be ignored. Corresponds to the JSON property settings



8347
8348
8349
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8347

def settings
  @settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8354
8355
8356
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8354

def update!(**args)
  @settings = args[:settings] if args.key?(:settings)
end