Class: Google::Apis::DisplayvideoV4::GuaranteedOrder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A guaranteed order. Guaranteed orders are parent entity of guaranteed inventory sources. When creating a guaranteed inventory source, a guaranteed order ID must be assigned to the inventory source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GuaranteedOrder

Returns a new instance of GuaranteedOrder.



8725
8726
8727
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8725

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_advertiser_idFixnum

Output only. The ID of default advertiser of the guaranteed order. The default advertiser is either the read_write_advertiser_id or, if that is not set, the first advertiser listed in read_advertiser_ids. Otherwise, there is no default advertiser. Corresponds to the JSON property defaultAdvertiserId

Returns:

  • (Fixnum)


8644
8645
8646
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8644

def default_advertiser_id
  @default_advertiser_id
end

#default_campaign_idFixnum

The ID of the default campaign that is assigned to the guaranteed order. The default campaign must belong to the default advertiser. Corresponds to the JSON property defaultCampaignId

Returns:

  • (Fixnum)


8650
8651
8652
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8650

def default_campaign_id
  @default_campaign_id
end

#display_nameString

Required. The display name of the guaranteed order. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


8656
8657
8658
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8656

def display_name
  @display_name
end

#exchangeString

Required. Immutable. The exchange where the guaranteed order originated. Corresponds to the JSON property exchange

Returns:

  • (String)


8661
8662
8663
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8661

def exchange
  @exchange
end

#guaranteed_order_idString

Output only. The unique identifier of the guaranteed order. The guaranteed order IDs have the format exchange`-`legacy_guaranteed_order_id. Corresponds to the JSON property guaranteedOrderId

Returns:

  • (String)


8667
8668
8669
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8667

def guaranteed_order_id
  @guaranteed_order_id
end

#legacy_guaranteed_order_idString

Output only. The legacy ID of the guaranteed order. Assigned by the original exchange. The legacy ID is unique within one exchange, but is not guaranteed to be unique across all guaranteed orders. This ID is used in SDF and UI. Corresponds to the JSON property legacyGuaranteedOrderId

Returns:

  • (String)


8674
8675
8676
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8674

def legacy_guaranteed_order_id
  @legacy_guaranteed_order_id
end

#nameString

Output only. The resource name of the guaranteed order. Corresponds to the JSON property name

Returns:

  • (String)


8679
8680
8681
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8679

def name
  @name
end

#publisher_nameString

Required. The publisher name of the guaranteed order. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property publisherName

Returns:

  • (String)


8685
8686
8687
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8685

def publisher_name
  @publisher_name
end

#read_access_inheritedBoolean Also known as: read_access_inherited?

Whether all advertisers of read_write_partner_id have read access to the guaranteed order. Only applicable if read_write_partner_id is set. If True, overrides read_advertiser_ids. Corresponds to the JSON property readAccessInherited

Returns:

  • (Boolean)


8692
8693
8694
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8692

def read_access_inherited
  @read_access_inherited
end

#read_advertiser_idsArray<Fixnum>

The IDs of advertisers with read access to the guaranteed order. This field must not include the advertiser assigned to read_write_advertiser_id if it is set. All advertisers in this field must belong to read_write_partner_id or the same partner as read_write_advertiser_id. Corresponds to the JSON property readAdvertiserIds

Returns:

  • (Array<Fixnum>)


8701
8702
8703
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8701

def read_advertiser_ids
  @read_advertiser_ids
end

#read_write_advertiser_idFixnum

The advertiser with read/write access to the guaranteed order. This is also the default advertiser of the guaranteed order. Corresponds to the JSON property readWriteAdvertiserId

Returns:

  • (Fixnum)


8707
8708
8709
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8707

def read_write_advertiser_id
  @read_write_advertiser_id
end

#read_write_partner_idFixnum

The partner with read/write access to the guaranteed order. Corresponds to the JSON property readWritePartnerId

Returns:

  • (Fixnum)


8712
8713
8714
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8712

def read_write_partner_id
  @read_write_partner_id
end

#statusGoogle::Apis::DisplayvideoV4::GuaranteedOrderStatus

The status settings of the guaranteed order. Corresponds to the JSON property status



8717
8718
8719
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8717

def status
  @status
end

#update_timeString

Output only. The timestamp when the guaranteed order was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


8723
8724
8725
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8723

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8730
8731
8732
8733
8734
8735
8736
8737
8738
8739
8740
8741
8742
8743
8744
8745
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8730

def update!(**args)
  @default_advertiser_id = args[:default_advertiser_id] if args.key?(:default_advertiser_id)
  @default_campaign_id = args[:default_campaign_id] if args.key?(:default_campaign_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @exchange = args[:exchange] if args.key?(:exchange)
  @guaranteed_order_id = args[:guaranteed_order_id] if args.key?(:guaranteed_order_id)
  @legacy_guaranteed_order_id = args[:legacy_guaranteed_order_id] if args.key?(:legacy_guaranteed_order_id)
  @name = args[:name] if args.key?(:name)
  @publisher_name = args[:publisher_name] if args.key?(:publisher_name)
  @read_access_inherited = args[:read_access_inherited] if args.key?(:read_access_inherited)
  @read_advertiser_ids = args[:read_advertiser_ids] if args.key?(:read_advertiser_ids)
  @read_write_advertiser_id = args[:read_write_advertiser_id] if args.key?(:read_write_advertiser_id)
  @read_write_partner_id = args[:read_write_partner_id] if args.key?(:read_write_partner_id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
end