Class: Google::Apis::DisplayvideoV4::InsertionOrderBudgetSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Settings that control the budget of a single budget segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertionOrderBudgetSegment

Returns a new instance of InsertionOrderBudgetSegment.



9123
9124
9125
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9123

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_amount_microsFixnum

Required. The budget amount the insertion order will spend for the given date_range. The amount is in micros. Must be greater than 0. For example, 500000000 represents 500 standard units of the currency. Corresponds to the JSON property budgetAmountMicros

Returns:

  • (Fixnum)


9103
9104
9105
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9103

def budget_amount_micros
  @budget_amount_micros
end

#campaign_budget_idFixnum

Optional. The budget_id of the campaign budget that this insertion order budget segment is a part of. Corresponds to the JSON property campaignBudgetId

Returns:

  • (Fixnum)


9109
9110
9111
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9109

def campaign_budget_id
  @campaign_budget_id
end

#date_rangeGoogle::Apis::DisplayvideoV4::DateRange

A date range. Corresponds to the JSON property dateRange



9114
9115
9116
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9114

def date_range
  @date_range
end

#descriptionString

Optional. The budget segment description. It can be used to enter Purchase Order information for each budget segment and have that information printed on the invoices. Must be UTF-8 encoded. Corresponds to the JSON property description

Returns:

  • (String)


9121
9122
9123
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9121

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9128
9129
9130
9131
9132
9133
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9128

def update!(**args)
  @budget_amount_micros = args[:budget_amount_micros] if args.key?(:budget_amount_micros)
  @campaign_budget_id = args[:campaign_budget_id] if args.key?(:campaign_budget_id)
  @date_range = args[:date_range] if args.key?(:date_range)
  @description = args[:description] if args.key?(:description)
end