Class: Google::Apis::DisplayvideoV4::InventorySource
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::InventorySource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
An inventory source.
Instance Attribute Summary collapse
-
#commitment ⇒ String
Whether the inventory source has a guaranteed or non-guaranteed delivery.
-
#creative_configs ⇒ Array<Google::Apis::DisplayvideoV4::CreativeConfig>
The creative requirements of the inventory source.
-
#deal_id ⇒ String
The ID in the exchange space that uniquely identifies the inventory source.
-
#delivery_method ⇒ String
The delivery method of the inventory source.
-
#display_name ⇒ String
The display name of the inventory source.
-
#exchange ⇒ String
The exchange to which the inventory source belongs.
-
#guaranteed_order_id ⇒ String
Immutable.
-
#inventory_source_id ⇒ Fixnum
Output only.
-
#inventory_source_product_type ⇒ String
Output only.
-
#inventory_source_type ⇒ String
Denotes the type of the inventory source.
-
#name ⇒ String
Output only.
-
#publisher_name ⇒ String
The publisher/seller name of the inventory source.
-
#rate_details ⇒ Google::Apis::DisplayvideoV4::RateDetails
The rate related settings of the inventory source.
-
#read_advertiser_ids ⇒ Array<Fixnum>
Output only.
-
#read_partner_ids ⇒ Array<Fixnum>
Output only.
-
#read_write_accessors ⇒ Google::Apis::DisplayvideoV4::InventorySourceAccessors
The partner or advertisers with access to the inventory source.
-
#status ⇒ Google::Apis::DisplayvideoV4::InventorySourceStatus
The status related settings of the inventory source.
-
#time_range ⇒ Google::Apis::DisplayvideoV4::TimeRange
A time range.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InventorySource
constructor
A new instance of InventorySource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InventorySource
Returns a new instance of InventorySource.
9414 9415 9416 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9414 def initialize(**args) update!(**args) end |
Instance Attribute Details
#commitment ⇒ String
Whether the inventory source has a guaranteed or non-guaranteed delivery.
Corresponds to the JSON property commitment
9307 9308 9309 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9307 def commitment @commitment end |
#creative_configs ⇒ Array<Google::Apis::DisplayvideoV4::CreativeConfig>
The creative requirements of the inventory source. Not applicable for auction
packages.
Corresponds to the JSON property creativeConfigs
9313 9314 9315 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9313 def creative_configs @creative_configs end |
#deal_id ⇒ String
The ID in the exchange space that uniquely identifies the inventory source.
Must be unique across buyers within each exchange but not necessarily unique
across exchanges.
Corresponds to the JSON property dealId
9320 9321 9322 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9320 def deal_id @deal_id end |
#delivery_method ⇒ String
The delivery method of the inventory source. * For non-guaranteed inventory
sources, the only acceptable value is
INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC. * For guaranteed inventory
sources, acceptable values are INVENTORY_SOURCE_DELIVERY_METHOD_TAG and
INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC.
Corresponds to the JSON property deliveryMethod
9329 9330 9331 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9329 def delivery_method @delivery_method end |
#display_name ⇒ String
The display name of the inventory source. Must be UTF-8 encoded with a maximum
size of 240 bytes.
Corresponds to the JSON property displayName
9335 9336 9337 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9335 def display_name @display_name end |
#exchange ⇒ String
The exchange to which the inventory source belongs.
Corresponds to the JSON property exchange
9340 9341 9342 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9340 def exchange @exchange end |
#guaranteed_order_id ⇒ String
Immutable. The ID of the guaranteed order that this inventory source belongs
to. Only applicable when commitment is INVENTORY_SOURCE_COMMITMENT_GUARANTEED
.
Corresponds to the JSON property guaranteedOrderId
9347 9348 9349 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9347 def guaranteed_order_id @guaranteed_order_id end |
#inventory_source_id ⇒ Fixnum
Output only. The unique ID of the inventory source. Assigned by the system.
Corresponds to the JSON property inventorySourceId
9352 9353 9354 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9352 def inventory_source_id @inventory_source_id end |
#inventory_source_product_type ⇒ String
Output only. The product type of the inventory source, denoting the way
through which it sells inventory.
Corresponds to the JSON property inventorySourceProductType
9358 9359 9360 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9358 def inventory_source_product_type @inventory_source_product_type end |
#inventory_source_type ⇒ String
Denotes the type of the inventory source.
Corresponds to the JSON property inventorySourceType
9363 9364 9365 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9363 def inventory_source_type @inventory_source_type end |
#name ⇒ String
Output only. The resource name of the inventory source.
Corresponds to the JSON property name
9368 9369 9370 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9368 def name @name end |
#publisher_name ⇒ String
The publisher/seller name of the inventory source.
Corresponds to the JSON property publisherName
9373 9374 9375 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9373 def publisher_name @publisher_name end |
#rate_details ⇒ Google::Apis::DisplayvideoV4::RateDetails
The rate related settings of the inventory source.
Corresponds to the JSON property rateDetails
9378 9379 9380 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9378 def rate_details @rate_details end |
#read_advertiser_ids ⇒ Array<Fixnum>
Output only. The IDs of advertisers with read-only access to the inventory
source.
Corresponds to the JSON property readAdvertiserIds
9384 9385 9386 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9384 def read_advertiser_ids @read_advertiser_ids end |
#read_partner_ids ⇒ Array<Fixnum>
Output only. The IDs of partners with read-only access to the inventory source.
All advertisers of partners in this field inherit read-only access to the
inventory source.
Corresponds to the JSON property readPartnerIds
9391 9392 9393 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9391 def read_partner_ids @read_partner_ids end |
#read_write_accessors ⇒ Google::Apis::DisplayvideoV4::InventorySourceAccessors
The partner or advertisers with access to the inventory source.
Corresponds to the JSON property readWriteAccessors
9396 9397 9398 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9396 def read_write_accessors @read_write_accessors end |
#status ⇒ Google::Apis::DisplayvideoV4::InventorySourceStatus
The status related settings of the inventory source.
Corresponds to the JSON property status
9401 9402 9403 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9401 def status @status end |
#time_range ⇒ Google::Apis::DisplayvideoV4::TimeRange
A time range.
Corresponds to the JSON property timeRange
9406 9407 9408 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9406 def time_range @time_range end |
#update_time ⇒ String
Output only. The timestamp when the inventory source was last updated.
Assigned by the system.
Corresponds to the JSON property updateTime
9412 9413 9414 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9412 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9419 def update!(**args) @commitment = args[:commitment] if args.key?(:commitment) @creative_configs = args[:creative_configs] if args.key?(:creative_configs) @deal_id = args[:deal_id] if args.key?(:deal_id) @delivery_method = args[:delivery_method] if args.key?(:delivery_method) @display_name = args[:display_name] if args.key?(:display_name) @exchange = args[:exchange] if args.key?(:exchange) @guaranteed_order_id = args[:guaranteed_order_id] if args.key?(:guaranteed_order_id) @inventory_source_id = args[:inventory_source_id] if args.key?(:inventory_source_id) @inventory_source_product_type = args[:inventory_source_product_type] if args.key?(:inventory_source_product_type) @inventory_source_type = args[:inventory_source_type] if args.key?(:inventory_source_type) @name = args[:name] if args.key?(:name) @publisher_name = args[:publisher_name] if args.key?(:publisher_name) @rate_details = args[:rate_details] if args.key?(:rate_details) @read_advertiser_ids = args[:read_advertiser_ids] if args.key?(:read_advertiser_ids) @read_partner_ids = args[:read_partner_ids] if args.key?(:read_partner_ids) @read_write_accessors = args[:read_write_accessors] if args.key?(:read_write_accessors) @status = args[:status] if args.key?(:status) @time_range = args[:time_range] if args.key?(:time_range) @update_time = args[:update_time] if args.key?(:update_time) end |