Class: Google::Apis::DisplayvideoV4::LineItemAssignedTargetingOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Wrapper object associating an assigned_targeting_option resource and the line item it is assigned to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LineItemAssignedTargetingOption

Returns a new instance of LineItemAssignedTargetingOption.



10025
10026
10027
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigned_targeting_optionGoogle::Apis::DisplayvideoV4::AssignedTargetingOption

A single assigned targeting option, which defines the state of a targeting option for an entity with targeting settings. Corresponds to the JSON property assignedTargetingOption



10018
10019
10020
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10018

def assigned_targeting_option
  @assigned_targeting_option
end

#line_item_idFixnum

The ID of the line item the assigned targeting option is assigned to. Corresponds to the JSON property lineItemId

Returns:

  • (Fixnum)


10023
10024
10025
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10023

def line_item_id
  @line_item_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10030
10031
10032
10033
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10030

def update!(**args)
  @assigned_targeting_option = args[:assigned_targeting_option] if args.key?(:assigned_targeting_option)
  @line_item_id = args[:line_item_id] if args.key?(:line_item_id)
end