Class: Google::Apis::DisplayvideoV4::ListAdAssetsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A response message for ListAdAssets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAdAssetsResponse

Returns a new instance of ListAdAssetsResponse.



10113
10114
10115
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10113

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_assetsArray<Google::Apis::DisplayvideoV4::AdAsset>

The list of ad assets. The list will only contain assets of AdAssetType AD_ASSET_TYPE_YOUTUBE_VIDEO. This list will be absent if empty. Corresponds to the JSON property adAssets



10104
10105
10106
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10104

def ad_assets
  @ad_assets
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListAdAssets method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10111
10112
10113
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10111

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10118
10119
10120
10121
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10118

def update!(**args)
  @ad_assets = args[:ad_assets] if args.key?(:ad_assets)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end