Class: Google::Apis::DisplayvideoV4::ListAdGroupAdsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAdGroupAdsResponse

Returns a new instance of ListAdGroupAdsResponse.



10373
10374
10375
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_adsArray<Google::Apis::DisplayvideoV4::AdGroupAd>

The list of ads. This list will be absent if empty. Corresponds to the JSON property adGroupAds



10364
10365
10366
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10364

def ad_group_ads
  @ad_group_ads
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListAdGroupAds method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10371
10372
10373
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10371

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10378
10379
10380
10381
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10378

def update!(**args)
  @ad_group_ads = args[:ad_group_ads] if args.key?(:ad_group_ads)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end