Class: Google::Apis::DisplayvideoV4::ListAdGroupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAdGroupsResponse

Returns a new instance of ListAdGroupsResponse.



10415
10416
10417
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10415

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_groupsArray<Google::Apis::DisplayvideoV4::AdGroup>

The list of ad groups. This list will be absent if empty. Corresponds to the JSON property adGroups



10406
10407
10408
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10406

def ad_groups
  @ad_groups
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListAdGroups method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10413
10414
10415
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10413

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10420
10421
10422
10423
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10420

def update!(**args)
  @ad_groups = args[:ad_groups] if args.key?(:ad_groups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end