Class: Google::Apis::DisplayvideoV4::ListAdvertisersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAdvertisersResponse

Returns a new instance of ListAdvertisersResponse.



10483
10484
10485
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10483

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertisersArray<Google::Apis::DisplayvideoV4::Advertiser>

The list of advertisers. This list will be absent if empty. Corresponds to the JSON property advertisers



10474
10475
10476
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10474

def advertisers
  @advertisers
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListAdvertisers method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10481
10482
10483
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10481

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10488
10489
10490
10491
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10488

def update!(**args)
  @advertisers = args[:advertisers] if args.key?(:advertisers)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end