Class: Google::Apis::DisplayvideoV4::ListAssignedLocationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Response message for AssignedLocationService.ListAssignedLocations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAssignedLocationsResponse

Returns a new instance of ListAssignedLocationsResponse.



10305
10306
10307
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigned_locationsArray<Google::Apis::DisplayvideoV4::AssignedLocation>

The list of assigned locations. This list will be absent if empty. Corresponds to the JSON property assignedLocations



10296
10297
10298
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10296

def assigned_locations
  @assigned_locations
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListAssignedLocations method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10303
10304
10305
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10303

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10310
10311
10312
10313
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10310

def update!(**args)
  @assigned_locations = args[:assigned_locations] if args.key?(:assigned_locations)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end