Class: Google::Apis::DisplayvideoV4::ListCampaignsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListCampaignsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#campaigns ⇒ Array<Google::Apis::DisplayvideoV4::Campaign>
The list of campaigns.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCampaignsResponse
constructor
A new instance of ListCampaignsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCampaignsResponse
Returns a new instance of ListCampaignsResponse.
10552 10553 10554 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaigns ⇒ Array<Google::Apis::DisplayvideoV4::Campaign>
The list of campaigns. This list will be absent if empty.
Corresponds to the JSON property campaigns
10543 10544 10545 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10543 def campaigns @campaigns end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListCampaigns method to retrieve
the next page of results.
Corresponds to the JSON property nextPageToken
10550 10551 10552 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10550 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10557 10558 10559 10560 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10557 def update!(**args) @campaigns = args[:campaigns] if args.key?(:campaigns) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |