Class: Google::Apis::DisplayvideoV4::ListChannelsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListChannelsResponse

Returns a new instance of ListChannelsResponse.



10562
10563
10564
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channelsArray<Google::Apis::DisplayvideoV4::Channel>

The list of channels. This list will be absent if empty. Corresponds to the JSON property channels



10553
10554
10555
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10553

def channels
  @channels
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListChannels method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10560
10561
10562
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10560

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10567
10568
10569
10570
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10567

def update!(**args)
  @channels = args[:channels] if args.key?(:channels)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end