Class: Google::Apis::DisplayvideoV4::ListCombinedAudiencesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListCombinedAudiencesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#combined_audiences ⇒ Array<Google::Apis::DisplayvideoV4::CombinedAudience>
The list of combined audiences.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCombinedAudiencesResponse
constructor
A new instance of ListCombinedAudiencesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCombinedAudiencesResponse
Returns a new instance of ListCombinedAudiencesResponse.
10386 10387 10388 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10386 def initialize(**args) update!(**args) end |
Instance Attribute Details
#combined_audiences ⇒ Array<Google::Apis::DisplayvideoV4::CombinedAudience>
The list of combined audiences. This list will be absent if empty.
Corresponds to the JSON property combinedAudiences
10377 10378 10379 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10377 def combined_audiences @combined_audiences end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListCombinedAudiences method to
retrieve the next page of results.
Corresponds to the JSON property nextPageToken
10384 10385 10386 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10384 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10391 10392 10393 10394 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10391 def update!(**args) @combined_audiences = args[:combined_audiences] if args.key?(:combined_audiences) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |