Class: Google::Apis::DisplayvideoV4::ListCreativesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCreativesResponse

Returns a new instance of ListCreativesResponse.



10647
10648
10649
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10647

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creativesArray<Google::Apis::DisplayvideoV4::Creative>

The list of creatives. This list will be absent if empty. Corresponds to the JSON property creatives



10637
10638
10639
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10637

def creatives
  @creatives
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListCreativesRequest method to retrieve the next page of results. If this field is null, it means this is the last page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10645
10646
10647
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10645

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10652
10653
10654
10655
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10652

def update!(**args)
  @creatives = args[:creatives] if args.key?(:creatives)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end