Class: Google::Apis::DisplayvideoV4::ListCustomBiddingAlgorithmRulesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListCustomBiddingAlgorithmRulesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#custom_bidding_rules ⇒ Array<Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRules>
The list of CustomBiddingAlgorithmRules resources.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCustomBiddingAlgorithmRulesResponse
constructor
A new instance of ListCustomBiddingAlgorithmRulesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCustomBiddingAlgorithmRulesResponse
Returns a new instance of ListCustomBiddingAlgorithmRulesResponse.
10677 10678 10679 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10677 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_bidding_rules ⇒ Array<Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRules>
The list of CustomBiddingAlgorithmRules resources. This list will be absent if
empty.
Corresponds to the JSON property customBiddingRules
10667 10668 10669 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10667 def custom_bidding_rules @custom_bidding_rules end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to
ListCustomBiddingAlgorithmRulesRequest method to retrieve the next page of
results. If this field is null, it means this is the last page.
Corresponds to the JSON property nextPageToken
10675 10676 10677 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10675 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10682 10683 10684 10685 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10682 def update!(**args) @custom_bidding_rules = args[:custom_bidding_rules] if args.key?(:custom_bidding_rules) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |