Class: Google::Apis::DisplayvideoV4::ListCustomListsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListCustomListsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#custom_lists ⇒ Array<Google::Apis::DisplayvideoV4::CustomList>
The list of custom lists.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCustomListsResponse
constructor
A new instance of ListCustomListsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCustomListsResponse
Returns a new instance of ListCustomListsResponse.
10746 10747 10748 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10746 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_lists ⇒ Array<Google::Apis::DisplayvideoV4::CustomList>
The list of custom lists. This list will be absent if empty.
Corresponds to the JSON property customLists
10737 10738 10739 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10737 def custom_lists @custom_lists end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListCustomLists method to
retrieve the next page of results.
Corresponds to the JSON property nextPageToken
10744 10745 10746 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10744 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10751 10752 10753 10754 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10751 def update!(**args) @custom_lists = args[:custom_lists] if args.key?(:custom_lists) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |