Class: Google::Apis::DisplayvideoV4::ListFloodlightActivitiesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListFloodlightActivitiesResponse

Returns a new instance of ListFloodlightActivitiesResponse.



10581
10582
10583
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#floodlight_activitiesArray<Google::Apis::DisplayvideoV4::FloodlightActivity>

The list of Floodlight activities. This list will be absent if empty. Corresponds to the JSON property floodlightActivities



10572
10573
10574
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10572

def floodlight_activities
  @floodlight_activities
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListFloodlightActivities method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10579
10580
10581
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10579

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10586
10587
10588
10589
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10586

def update!(**args)
  @floodlight_activities = args[:floodlight_activities] if args.key?(:floodlight_activities)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end