Class: Google::Apis::DisplayvideoV4::ListGoogleAudiencesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGoogleAudiencesResponse

Returns a new instance of ListGoogleAudiencesResponse.



10841
10842
10843
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10841

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_audiencesArray<Google::Apis::DisplayvideoV4::GoogleAudience>

The list of Google audiences. This list will be absent if empty. Corresponds to the JSON property googleAudiences



10832
10833
10834
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10832

def google_audiences
  @google_audiences
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListGoogleAudiences method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10839
10840
10841
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10839

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10846
10847
10848
10849
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10846

def update!(**args)
  @google_audiences = args[:google_audiences] if args.key?(:google_audiences)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end