Class: Google::Apis::DisplayvideoV4::ListGuaranteedOrdersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGuaranteedOrdersResponse

Returns a new instance of ListGuaranteedOrdersResponse.



10838
10839
10840
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10838

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#guaranteed_ordersArray<Google::Apis::DisplayvideoV4::GuaranteedOrder>

The list of guaranteed orders. This list will be absent if empty. Corresponds to the JSON property guaranteedOrders



10829
10830
10831
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10829

def guaranteed_orders
  @guaranteed_orders
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListGuaranteedOrders method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10836
10837
10838
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10836

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10843
10844
10845
10846
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10843

def update!(**args)
  @guaranteed_orders = args[:guaranteed_orders] if args.key?(:guaranteed_orders)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end