Class: Google::Apis::DisplayvideoV4::ListInsertionOrdersResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListInsertionOrdersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#insertion_orders ⇒ Array<Google::Apis::DisplayvideoV4::InsertionOrder>
The list of insertion orders.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInsertionOrdersResponse
constructor
A new instance of ListInsertionOrdersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInsertionOrdersResponse
Returns a new instance of ListInsertionOrdersResponse.
10662 10663 10664 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10662 def initialize(**args) update!(**args) end |
Instance Attribute Details
#insertion_orders ⇒ Array<Google::Apis::DisplayvideoV4::InsertionOrder>
The list of insertion orders. This list will be absent if empty.
Corresponds to the JSON property insertionOrders
10653 10654 10655 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10653 def insertion_orders @insertion_orders end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListInsertionOrders method to
retrieve the next page of results.
Corresponds to the JSON property nextPageToken
10660 10661 10662 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10660 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10667 10668 10669 10670 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10667 def update!(**args) @insertion_orders = args[:insertion_orders] if args.key?(:insertion_orders) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |