Class: Google::Apis::DisplayvideoV4::ListInventorySourceGroupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListInventorySourceGroupsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Response message for InventorySourceGroupService.ListInventorySourceGroups.
Instance Attribute Summary collapse
-
#inventory_source_groups ⇒ Array<Google::Apis::DisplayvideoV4::InventorySourceGroup>
The list of inventory source groups.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInventorySourceGroupsResponse
constructor
A new instance of ListInventorySourceGroupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInventorySourceGroupsResponse
Returns a new instance of ListInventorySourceGroupsResponse.
10689 10690 10691 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10689 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inventory_source_groups ⇒ Array<Google::Apis::DisplayvideoV4::InventorySourceGroup>
The list of inventory source groups. This list will be absent if empty.
Corresponds to the JSON property inventorySourceGroups
10680 10681 10682 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10680 def inventory_source_groups @inventory_source_groups end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListInventorySourceGroups method
to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
10687 10688 10689 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10687 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10694 10695 10696 10697 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10694 def update!(**args) @inventory_source_groups = args[:inventory_source_groups] if args.key?(:inventory_source_groups) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |