Class: Google::Apis::DisplayvideoV4::ListLineItemsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListLineItemsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#line_items ⇒ Array<Google::Apis::DisplayvideoV4::LineItem>
The list of line items.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLineItemsResponse
constructor
A new instance of ListLineItemsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLineItemsResponse
Returns a new instance of ListLineItemsResponse.
10799 10800 10801 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#line_items ⇒ Array<Google::Apis::DisplayvideoV4::LineItem>
The list of line items. This list will be absent if empty.
Corresponds to the JSON property lineItems
10790 10791 10792 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10790 def line_items @line_items end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListLineItems method to retrieve
the next page of results.
Corresponds to the JSON property nextPageToken
10797 10798 10799 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10797 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10804 10805 10806 10807 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10804 def update!(**args) @line_items = args[:line_items] if args.key?(:line_items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |