Class: Google::Apis::DisplayvideoV4::ListLocationListsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListLocationListsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#location_lists ⇒ Array<Google::Apis::DisplayvideoV4::LocationList>
The list of location lists.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLocationListsResponse
constructor
A new instance of ListLocationListsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLocationListsResponse
Returns a new instance of ListLocationListsResponse.
11029 11030 11031 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11029 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location_lists ⇒ Array<Google::Apis::DisplayvideoV4::LocationList>
The list of location lists. This list will be absent if empty.
Corresponds to the JSON property locationLists
11020 11021 11022 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11020 def location_lists @location_lists end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListLocationLists method to
retrieve the next page of results.
Corresponds to the JSON property nextPageToken
11027 11028 11029 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11027 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11034 11035 11036 11037 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11034 def update!(**args) @location_lists = args[:location_lists] if args.key?(:location_lists) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |