Class: Google::Apis::DisplayvideoV4::ListNegativeKeywordListsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Response message for NegativeKeywordListService.ListNegativeKeywordLists.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListNegativeKeywordListsResponse

Returns a new instance of ListNegativeKeywordListsResponse.



10853
10854
10855
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10853

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#negative_keyword_listsArray<Google::Apis::DisplayvideoV4::NegativeKeywordList>

The list of negative keyword lists. This list will be absent if empty. Corresponds to the JSON property negativeKeywordLists



10844
10845
10846
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10844

def negative_keyword_lists
  @negative_keyword_lists
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListNegativeKeywordLists method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10851
10852
10853
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10851

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10858
10859
10860
10861
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10858

def update!(**args)
  @negative_keyword_lists = args[:negative_keyword_lists] if args.key?(:negative_keyword_lists)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end