Class: Google::Apis::DisplayvideoV4::ListNegativeKeywordsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Response message for NegativeKeywordService.ListNegativeKeywords.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListNegativeKeywordsResponse

Returns a new instance of ListNegativeKeywordsResponse.



10880
10881
10882
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10880

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#negative_keywordsArray<Google::Apis::DisplayvideoV4::NegativeKeyword>

The list of negative keywords. This list will be absent if empty. Corresponds to the JSON property negativeKeywords



10871
10872
10873
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10871

def negative_keywords
  @negative_keywords
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListNegativeKeywords method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10878
10879
10880
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10878

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10885
10886
10887
10888
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10885

def update!(**args)
  @negative_keywords = args[:negative_keywords] if args.key?(:negative_keywords)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end