Class: Google::Apis::DisplayvideoV4::ListPartnersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPartnersResponse

Returns a new instance of ListPartnersResponse.



10944
10945
10946
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListPartners method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10937
10938
10939
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10937

def next_page_token
  @next_page_token
end

#partnersArray<Google::Apis::DisplayvideoV4::Partner>

The list of partners. This list will be absent if empty. Corresponds to the JSON property partners



10942
10943
10944
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10942

def partners
  @partners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10949
10950
10951
10952
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10949

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @partners = args[:partners] if args.key?(:partners)
end