Class: Google::Apis::DisplayvideoV4::LocationList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A list of locations used for targeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocationList

Returns a new instance of LocationList.



11088
11089
11090
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11088

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Required. Immutable. The unique ID of the advertiser the location list belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


11064
11065
11066
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11064

def advertiser_id
  @advertiser_id
end

#display_nameString

Required. The display name of the location list. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


11070
11071
11072
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11070

def display_name
  @display_name
end

#location_list_idFixnum

Output only. The unique ID of the location list. Assigned by the system. Corresponds to the JSON property locationListId

Returns:

  • (Fixnum)


11075
11076
11077
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11075

def location_list_id
  @location_list_id
end

#location_typeString

Required. Immutable. The type of location. All locations in the list will share this type. Corresponds to the JSON property locationType

Returns:

  • (String)


11081
11082
11083
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11081

def location_type
  @location_type
end

#nameString

Output only. The resource name of the location list. Corresponds to the JSON property name

Returns:

  • (String)


11086
11087
11088
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11086

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11093
11094
11095
11096
11097
11098
11099
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11093

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @location_list_id = args[:location_list_id] if args.key?(:location_list_id)
  @location_type = args[:location_type] if args.key?(:location_type)
  @name = args[:name] if args.key?(:name)
end