Class: Google::Apis::DisplayvideoV4::NonSkippableAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::NonSkippableAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details for a non-skippable ad.
Instance Attribute Summary collapse
-
#common_in_stream_attribute ⇒ Google::Apis::DisplayvideoV4::CommonInStreamAttribute
Common attributes for in-stream, non-skippable and bumper ads.
-
#custom_parameters ⇒ Hash<String,String>
The custom parameters and accompanying values to add to the tracking URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NonSkippableAd
constructor
A new instance of NonSkippableAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NonSkippableAd
Returns a new instance of NonSkippableAd.
11575 11576 11577 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common_in_stream_attribute ⇒ Google::Apis::DisplayvideoV4::CommonInStreamAttribute
Common attributes for in-stream, non-skippable and bumper ads.
Corresponds to the JSON property commonInStreamAttribute
11568 11569 11570 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11568 def common_in_stream_attribute @common_in_stream_attribute end |
#custom_parameters ⇒ Hash<String,String>
The custom parameters and accompanying values to add to the tracking URL.
Corresponds to the JSON property customParameters
11573 11574 11575 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11573 def custom_parameters @custom_parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11580 11581 11582 11583 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11580 def update!(**args) @common_in_stream_attribute = args[:common_in_stream_attribute] if args.key?(:common_in_stream_attribute) @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters) end |