Class: Google::Apis::DisplayvideoV4::OnTargetAudienceMetrics
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::OnTargetAudienceMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Estimated audience sizes for a targeted geography.
Instance Attribute Summary collapse
-
#census_audience_size ⇒ Fixnum
Size of the audience based on the census data of the targeted geography.
-
#youtube_audience_size ⇒ Fixnum
Estimated size of the YouTube audience.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OnTargetAudienceMetrics
constructor
A new instance of OnTargetAudienceMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OnTargetAudienceMetrics
Returns a new instance of OnTargetAudienceMetrics.
11978 11979 11980 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#census_audience_size ⇒ Fixnum
Size of the audience based on the census data of the targeted geography.
Corresponds to the JSON property censusAudienceSize
11971 11972 11973 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11971 def census_audience_size @census_audience_size end |
#youtube_audience_size ⇒ Fixnum
Estimated size of the YouTube audience.
Corresponds to the JSON property youtubeAudienceSize
11976 11977 11978 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11976 def youtube_audience_size @youtube_audience_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11983 11984 11985 11986 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11983 def update!(**args) @census_audience_size = args[:census_audience_size] if args.key?(:census_audience_size) @youtube_audience_size = args[:youtube_audience_size] if args.key?(:youtube_audience_size) end |