Class: Google::Apis::DisplayvideoV4::ParentEntityFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A filtering option that filters on selected file types belonging to a chosen set of filter entities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ParentEntityFilter

Returns a new instance of ParentEntityFilter.



11944
11945
11946
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_typeArray<String>

Required. File types that will be returned. Corresponds to the JSON property fileType

Returns:

  • (Array<String>)


11931
11932
11933
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11931

def file_type
  @file_type
end

#filter_idsArray<Fixnum>

The IDs of the specified filter type. This is used to filter entities to fetch. If filter type is not FILTER_TYPE_NONE, at least one ID must be specified. Corresponds to the JSON property filterIds

Returns:

  • (Array<Fixnum>)


11937
11938
11939
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11937

def filter_ids
  @filter_ids
end

#filter_typeString

Required. Filter type used to filter fetched entities. Corresponds to the JSON property filterType

Returns:

  • (String)


11942
11943
11944
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11942

def filter_type
  @filter_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11949
11950
11951
11952
11953
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11949

def update!(**args)
  @file_type = args[:file_type] if args.key?(:file_type)
  @filter_ids = args[:filter_ids] if args.key?(:filter_ids)
  @filter_type = args[:filter_type] if args.key?(:filter_type)
end