Class: Google::Apis::DisplayvideoV4::Partner

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single partner in Display & Video 360 (DV360).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Partner

Returns a new instance of Partner.



12290
12291
12292
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_server_configGoogle::Apis::DisplayvideoV4::PartnerAdServerConfig

Ad server related settings of a partner. Corresponds to the JSON property adServerConfig



12241
12242
12243
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12241

def ad_server_config
  @ad_server_config
end

#billing_configGoogle::Apis::DisplayvideoV4::PartnerBillingConfig

Billing related settings of a partner. Corresponds to the JSON property billingConfig



12246
12247
12248
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12246

def billing_config
  @billing_config
end

#data_access_configGoogle::Apis::DisplayvideoV4::PartnerDataAccessConfig

Settings that control how partner related data may be accessed. Corresponds to the JSON property dataAccessConfig



12251
12252
12253
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12251

def data_access_config
  @data_access_config
end

#display_nameString

The display name of the partner. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


12257
12258
12259
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12257

def display_name
  @display_name
end

#entity_statusString

Output only. The status of the partner. Corresponds to the JSON property entityStatus

Returns:

  • (String)


12262
12263
12264
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12262

def entity_status
  @entity_status
end

#exchange_configGoogle::Apis::DisplayvideoV4::ExchangeConfig

Settings that control which exchanges are enabled for a partner. Corresponds to the JSON property exchangeConfig



12267
12268
12269
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12267

def exchange_config
  @exchange_config
end

#general_configGoogle::Apis::DisplayvideoV4::PartnerGeneralConfig

General settings of a partner. Corresponds to the JSON property generalConfig



12272
12273
12274
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12272

def general_config
  @general_config
end

#nameString

Output only. The resource name of the partner. Corresponds to the JSON property name

Returns:

  • (String)


12277
12278
12279
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12277

def name
  @name
end

#partner_idFixnum

Output only. The unique ID of the partner. Assigned by the system. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


12282
12283
12284
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12282

def partner_id
  @partner_id
end

#update_timeString

Output only. The timestamp when the partner was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


12288
12289
12290
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12288

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12295
12296
12297
12298
12299
12300
12301
12302
12303
12304
12305
12306
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12295

def update!(**args)
  @ad_server_config = args[:ad_server_config] if args.key?(:ad_server_config)
  @billing_config = args[:billing_config] if args.key?(:billing_config)
  @data_access_config = args[:data_access_config] if args.key?(:data_access_config)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @exchange_config = args[:exchange_config] if args.key?(:exchange_config)
  @general_config = args[:general_config] if args.key?(:general_config)
  @name = args[:name] if args.key?(:name)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end