Class: Google::Apis::DisplayvideoV4::PartnerRevenueModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Settings that control how partner revenue is calculated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartnerRevenueModel

Returns a new instance of PartnerRevenueModel.



12237
12238
12239
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#markup_amountFixnum

Required. The markup amount of the partner revenue model. Must be greater than or equal to 0. * When the markup_type is set to be PARTNER_REVENUE_MODEL_MARKUP_TYPE_CPM, this field represents the CPM markup in micros of advertiser's currency. For example, 1500000 represents 1.5 standard units of the currency. * When the markup_type is set to be PARTNER_REVENUE_MODEL_MARKUP_TYPE_MEDIA_COST_MARKUP, this field represents the media cost percent markup in millis. For example, 100 represents 0.1% ( decimal 0.001). * When the markup_type is set to be PARTNER_REVENUE_MODEL_MARKUP_TYPE_TOTAL_MEDIA_COST_MARKUP, this field represents the total media cost percent markup in millis. For example, 100 represents 0.1% (decimal 0.001). Corresponds to the JSON property markupAmount

Returns:

  • (Fixnum)


12228
12229
12230
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12228

def markup_amount
  @markup_amount
end

#markup_typeString

Required. The markup type of the partner revenue model. This field must be set to PARTNER_REVENUE_MODEL_MARKUP_TYPE_TOTAL_MEDIA_COST_MARKUP for Demand Gen line items. Corresponds to the JSON property markupType

Returns:

  • (String)


12235
12236
12237
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12235

def markup_type
  @markup_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12242
12243
12244
12245
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12242

def update!(**args)
  @markup_amount = args[:markup_amount] if args.key?(:markup_amount)
  @markup_type = args[:markup_type] if args.key?(:markup_type)
end