Class: Google::Apis::DisplayvideoV4::PerformanceGoalBidStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A strategy that automatically adjusts the bid to meet or beat a specified performance goal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PerformanceGoalBidStrategy

Returns a new instance of PerformanceGoalBidStrategy.



12352
12353
12354
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12352

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_bidding_algorithm_idFixnum

The ID of the Custom Bidding Algorithm used by this strategy. Only applicable when performance_goal_type is set to BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CUSTOM_ALGO. Assigning a custom bidding algorithm that uses floodlight activities not identified in floodlightActivityConfigs will return an error. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


12309
12310
12311
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12309

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#max_average_cpm_bid_amount_microsFixnum

The maximum average CPM that may be bid, in micros of the advertiser's currency. Must be greater than or equal to a billable unit of the given currency. Not applicable when performance_goal_type is set to BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM. For example, 1500000 represents 1.5 standard units of the currency. Corresponds to the JSON property maxAverageCpmBidAmountMicros

Returns:

  • (Fixnum)


12318
12319
12320
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12318

def max_average_cpm_bid_amount_micros
  @max_average_cpm_bid_amount_micros
end

#performance_goal_amount_microsFixnum

Required. The performance goal the bidding strategy will attempt to meet or beat, in micros of the advertiser's currency or in micro of the ROAS (Return On Advertising Spend) value which is also based on advertiser's currency. Must be greater than or equal to a billable unit of the given currency and smaller or equal to upper bounds. Each performance_goal_type has its upper bound: * when performance_goal_type is BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPA, upper bound is 10000.00 USD. * when performance_goal_type is BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPC, upper bound is 1000.00 USD. * when performance_goal_type is BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM, upper bound is 1000.00 USD. * when performance_goal_type is BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CUSTOM_ALGO, upper bound is 1000.00 and lower bound is 0.01. Example: If set to BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM, the bid price will be based on the probability that each available impression will be viewable. For example, if viewable CPM target is $2 and an impression is 40% likely to be viewable, the bid price will be $0.80 CPM (40% of $2). For example, 1500000 represents 1.5 standard units of the currency or ROAS value. Corresponds to the JSON property performanceGoalAmountMicros

Returns:

  • (Fixnum)


12340
12341
12342
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12340

def performance_goal_amount_micros
  @performance_goal_amount_micros
end

#performance_goal_typeString

Required. The type of the performance goal that the bidding strategy will try to meet or beat. For line item level usage, the value must be one of: * BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPA * BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CPC * BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM * BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CUSTOM_ALGO. Corresponds to the JSON property performanceGoalType

Returns:

  • (String)


12350
12351
12352
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12350

def performance_goal_type
  @performance_goal_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12357
12358
12359
12360
12361
12362
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12357

def update!(**args)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @max_average_cpm_bid_amount_micros = args[:max_average_cpm_bid_amount_micros] if args.key?(:max_average_cpm_bid_amount_micros)
  @performance_goal_amount_micros = args[:performance_goal_amount_micros] if args.key?(:performance_goal_amount_micros)
  @performance_goal_type = args[:performance_goal_type] if args.key?(:performance_goal_type)
end