Class: Google::Apis::DisplayvideoV4::ProductMatchDimension
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ProductMatchDimension
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A dimension used to match products.
Instance Attribute Summary collapse
-
#custom_label ⇒ Google::Apis::DisplayvideoV4::CustomLabel
The key and value of a custom label.
-
#product_offer_id ⇒ String
The ID of the product offer to match with a product with the same offer ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductMatchDimension
constructor
A new instance of ProductMatchDimension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductMatchDimension
Returns a new instance of ProductMatchDimension.
12594 12595 12596 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_label ⇒ Google::Apis::DisplayvideoV4::CustomLabel
The key and value of a custom label.
Corresponds to the JSON property customLabel
12587 12588 12589 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12587 def custom_label @custom_label end |
#product_offer_id ⇒ String
The ID of the product offer to match with a product with the same offer ID.
Corresponds to the JSON property productOfferId
12592 12593 12594 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12592 def product_offer_id @product_offer_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12599 12600 12601 12602 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12599 def update!(**args) @custom_label = args[:custom_label] if args.key?(:custom_label) @product_offer_id = args[:product_offer_id] if args.key?(:product_offer_id) end |