Class: Google::Apis::DisplayvideoV4::ProximityLocationListAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Targeting details for proximity location list. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_PROXIMITY_LOCATION_LIST.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProximityLocationListAssignedTargetingOptionDetails

Returns a new instance of ProximityLocationListAssignedTargetingOptionDetails.



12621
12622
12623
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#proximity_location_list_idFixnum

Required. ID of the proximity location list. Should refer to the location_list_id field of a LocationList resource whose type is TARGETING_LOCATION_TYPE_PROXIMITY. Corresponds to the JSON property proximityLocationListId

Returns:

  • (Fixnum)


12607
12608
12609
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12607

def proximity_location_list_id
  @proximity_location_list_id
end

#proximity_radiusFloat

Required. Radius expressed in the distance units set in proximity_radius_unit. This represents the size of the area around a chosen location that will be targeted. Radius should be between 1 and 500 miles or 800 kilometers. Corresponds to the JSON property proximityRadius

Returns:

  • (Float)


12614
12615
12616
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12614

def proximity_radius
  @proximity_radius
end

#proximity_radius_unitString

Required. Radius distance units. Corresponds to the JSON property proximityRadiusUnit

Returns:

  • (String)


12619
12620
12621
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12619

def proximity_radius_unit
  @proximity_radius_unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12626
12627
12628
12629
12630
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12626

def update!(**args)
  @proximity_location_list_id = args[:proximity_location_list_id] if args.key?(:proximity_location_list_id)
  @proximity_radius = args[:proximity_radius] if args.key?(:proximity_radius)
  @proximity_radius_unit = args[:proximity_radius_unit] if args.key?(:proximity_radius_unit)
end