Class: Google::Apis::DisplayvideoV4::RemarketingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Settings that control the whether remarketing is enabled for the given identified advertiser.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemarketingConfig

Returns a new instance of RemarketingConfig.



13420
13421
13422
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13420

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The ID of the advertiser. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


13411
13412
13413
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13411

def advertiser_id
  @advertiser_id
end

#remarketing_enabledBoolean Also known as: remarketing_enabled?

Output only. Whether the Floodlight activity remarketing user list is available to the identified advertiser. Corresponds to the JSON property remarketingEnabled

Returns:

  • (Boolean)


13417
13418
13419
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13417

def remarketing_enabled
  @remarketing_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13425
13426
13427
13428
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13425

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @remarketing_enabled = args[:remarketing_enabled] if args.key?(:remarketing_enabled)
end