Class: Google::Apis::DisplayvideoV4::ReplaceNegativeKeywordsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for NegativeKeywordService.ReplaceNegativeKeywords.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplaceNegativeKeywordsRequest

Returns a new instance of ReplaceNegativeKeywordsRequest.



13403
13404
13405
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13403

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_negative_keywordsArray<Google::Apis::DisplayvideoV4::NegativeKeyword>

The negative keywords that will replace the existing keywords in the negative keyword list, specified as a list of NegativeKeywords. Corresponds to the JSON property newNegativeKeywords



13401
13402
13403
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13401

def new_negative_keywords
  @new_negative_keywords
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13408
13409
13410
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13408

def update!(**args)
  @new_negative_keywords = args[:new_negative_keywords] if args.key?(:new_negative_keywords)
end