Class: Google::Apis::DisplayvideoV4::ReplaceSitesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for SiteService.ReplaceSites.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplaceSitesRequest

Returns a new instance of ReplaceSitesRequest.



13435
13436
13437
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13435

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

The ID of the advertiser that owns the parent channel. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


13422
13423
13424
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13422

def advertiser_id
  @advertiser_id
end

#new_sitesArray<Google::Apis::DisplayvideoV4::Site>

The sites that will replace the existing sites assigned to the channel, specified as a list of Sites. Corresponds to the JSON property newSites



13428
13429
13430
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13428

def new_sites
  @new_sites
end

#partner_idFixnum

The ID of the partner that owns the parent channel. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


13433
13434
13435
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13433

def partner_id
  @partner_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13440
13441
13442
13443
13444
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13440

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @new_sites = args[:new_sites] if args.key?(:new_sites)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
end