Class: Google::Apis::DisplayvideoV4::ReplaceSitesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ReplaceSitesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Response message for SiteService.ReplaceSites.
Instance Attribute Summary collapse
-
#sites ⇒ Array<Google::Apis::DisplayvideoV4::Site>
The list of sites in the channel after replacing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplaceSitesResponse
constructor
A new instance of ReplaceSitesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplaceSitesResponse
Returns a new instance of ReplaceSitesResponse.
13456 13457 13458 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13456 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sites ⇒ Array<Google::Apis::DisplayvideoV4::Site>
The list of sites in the channel after replacing.
Corresponds to the JSON property sites
13454 13455 13456 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13454 def sites @sites end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13461 13462 13463 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13461 def update!(**args) @sites = args[:sites] if args.key?(:sites) end |