Class: Google::Apis::DisplayvideoV4::ReviewStatusInfo
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ReviewStatusInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Review statuses for the creative.
Instance Attribute Summary collapse
-
#approval_status ⇒ String
Represents the basic approval needed for a creative to begin serving.
-
#content_and_policy_review_status ⇒ String
Content and policy review status for the creative.
-
#creative_and_landing_page_review_status ⇒ String
Creative and landing page review status for the creative.
-
#exchange_review_statuses ⇒ Array<Google::Apis::DisplayvideoV4::ExchangeReviewStatus>
Exchange review statuses for the creative.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReviewStatusInfo
constructor
A new instance of ReviewStatusInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReviewStatusInfo
Returns a new instance of ReviewStatusInfo.
12846 12847 12848 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12846 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approval_status ⇒ String
Represents the basic approval needed for a creative to begin serving. Summary
of creative_and_landing_page_review_status and
content_and_policy_review_status.
Corresponds to the JSON property approvalStatus
12829 12830 12831 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12829 def approval_status @approval_status end |
#content_and_policy_review_status ⇒ String
Content and policy review status for the creative.
Corresponds to the JSON property contentAndPolicyReviewStatus
12834 12835 12836 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12834 def content_and_policy_review_status @content_and_policy_review_status end |
#creative_and_landing_page_review_status ⇒ String
Creative and landing page review status for the creative.
Corresponds to the JSON property creativeAndLandingPageReviewStatus
12839 12840 12841 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12839 def creative_and_landing_page_review_status @creative_and_landing_page_review_status end |
#exchange_review_statuses ⇒ Array<Google::Apis::DisplayvideoV4::ExchangeReviewStatus>
Exchange review statuses for the creative.
Corresponds to the JSON property exchangeReviewStatuses
12844 12845 12846 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12844 def exchange_review_statuses @exchange_review_statuses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12851 12852 12853 12854 12855 12856 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12851 def update!(**args) @approval_status = args[:approval_status] if args.key?(:approval_status) @content_and_policy_review_status = args[:content_and_policy_review_status] if args.key?(:content_and_policy_review_status) @creative_and_landing_page_review_status = args[:creative_and_landing_page_review_status] if args.key?(:creative_and_landing_page_review_status) @exchange_review_statuses = args[:exchange_review_statuses] if args.key?(:exchange_review_statuses) end |