Class: Google::Apis::DisplayvideoV4::ScriptError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

An error message for a custom bidding script.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScriptError

Returns a new instance of ScriptError.



13611
13612
13613
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnFixnum

The column number in the script where the error was thrown. Corresponds to the JSON property column

Returns:

  • (Fixnum)


13594
13595
13596
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13594

def column
  @column
end

#error_codeString

The type of error. Corresponds to the JSON property errorCode

Returns:

  • (String)


13599
13600
13601
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13599

def error_code
  @error_code
end

#error_messageString

The detailed error message. Corresponds to the JSON property errorMessage

Returns:

  • (String)


13604
13605
13606
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13604

def error_message
  @error_message
end

#lineFixnum

The line number in the script where the error was thrown. Corresponds to the JSON property line

Returns:

  • (Fixnum)


13609
13610
13611
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13609

def line
  @line
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13616
13617
13618
13619
13620
13621
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13616

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @error_code = args[:error_code] if args.key?(:error_code)
  @error_message = args[:error_message] if args.key?(:error_message)
  @line = args[:line] if args.key?(:line)
end