Class: Google::Apis::DisplayvideoV4::SearchTargetingOptionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for SearchTargetingOptions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchTargetingOptionsRequest

Returns a new instance of SearchTargetingOptionsRequest.



13798
13799
13800
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Required. The Advertiser this request is being made in the context of. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


13765
13766
13767
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13765

def advertiser_id
  @advertiser_id
end

#business_chain_search_termsGoogle::Apis::DisplayvideoV4::BusinessChainSearchTerms

Search terms for Business Chain targeting options. At least one of the field should be populated. Corresponds to the JSON property businessChainSearchTerms



13771
13772
13773
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13771

def business_chain_search_terms
  @business_chain_search_terms
end

#geo_region_search_termsGoogle::Apis::DisplayvideoV4::GeoRegionSearchTerms

Search terms for geo region targeting options. Corresponds to the JSON property geoRegionSearchTerms



13776
13777
13778
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13776

def geo_region_search_terms
  @geo_region_search_terms
end

#page_sizeFixnum

Requested page size. Must be between 1 and 200. If unspecified will default to 100. Returns error code INVALID_ARGUMENT if an invalid value is specified. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


13783
13784
13785
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13783

def page_size
  @page_size
end

#page_tokenString

A token identifying a page of results the server should return. Typically, this is the value of next_page_token returned from the previous call to SearchTargetingOptions method. If not specified, the first page of results will be returned. Corresponds to the JSON property pageToken

Returns:

  • (String)


13791
13792
13793
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13791

def page_token
  @page_token
end

#poi_search_termsGoogle::Apis::DisplayvideoV4::PoiSearchTerms

Search terms for POI targeting options. Corresponds to the JSON property poiSearchTerms



13796
13797
13798
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13796

def poi_search_terms
  @poi_search_terms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13803
13804
13805
13806
13807
13808
13809
13810
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13803

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @business_chain_search_terms = args[:business_chain_search_terms] if args.key?(:business_chain_search_terms)
  @geo_region_search_terms = args[:geo_region_search_terms] if args.key?(:geo_region_search_terms)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @poi_search_terms = args[:poi_search_terms] if args.key?(:poi_search_terms)
end