Class: Google::Apis::DisplayvideoV4::ThirdPartyUrl
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ThirdPartyUrl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Tracking URLs from third parties to track interactions with an audio or a video creative.
Instance Attribute Summary collapse
-
#type ⇒ String
Optional.
-
#url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ThirdPartyUrl
constructor
A new instance of ThirdPartyUrl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ThirdPartyUrl
Returns a new instance of ThirdPartyUrl.
14662 14663 14664 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14662 def initialize(**args) update!(**args) end |
Instance Attribute Details
#type ⇒ String
Optional. The type of interaction needs to be tracked by the tracking URL
Corresponds to the JSON property type
14653 14654 14655 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14653 def type @type end |
#url ⇒ String
Optional. Tracking URL used to track the interaction. Provide a URL with
optional path or query string, beginning with https:. For example, https://
www.example.com/path
Corresponds to the JSON property url
14660 14661 14662 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14660 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14667 14668 14669 14670 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14667 def update!(**args) @type = args[:type] if args.key?(:type) @url = args[:url] if args.key?(:url) end |