Class: Google::Apis::DisplayvideoV4::TrackingFloodlightActivityConfig
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::TrackingFloodlightActivityConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Settings that control the behavior of a single Floodlight activity config.
Instance Attribute Summary collapse
-
#floodlight_activity_id ⇒ Fixnum
Required.
-
#post_click_lookback_window_days ⇒ Fixnum
Required.
-
#post_view_lookback_window_days ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TrackingFloodlightActivityConfig
constructor
A new instance of TrackingFloodlightActivityConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TrackingFloodlightActivityConfig
Returns a new instance of TrackingFloodlightActivityConfig.
14764 14765 14766 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14764 def initialize(**args) update!(**args) end |
Instance Attribute Details
#floodlight_activity_id ⇒ Fixnum
Required. The ID of the Floodlight activity.
Corresponds to the JSON property floodlightActivityId
14750 14751 14752 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14750 def floodlight_activity_id @floodlight_activity_id end |
#post_click_lookback_window_days ⇒ Fixnum
Required. The number of days after an ad has been clicked in which a
conversion may be counted. Must be between 0 and 90 inclusive.
Corresponds to the JSON property postClickLookbackWindowDays
14756 14757 14758 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14756 def post_click_lookback_window_days @post_click_lookback_window_days end |
#post_view_lookback_window_days ⇒ Fixnum
Required. The number of days after an ad has been viewed in which a conversion
may be counted. Must be between 0 and 90 inclusive.
Corresponds to the JSON property postViewLookbackWindowDays
14762 14763 14764 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14762 def post_view_lookback_window_days @post_view_lookback_window_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14769 14770 14771 14772 14773 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14769 def update!(**args) @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id) @post_click_lookback_window_days = args[:post_click_lookback_window_days] if args.key?(:post_click_lookback_window_days) @post_view_lookback_window_days = args[:post_view_lookback_window_days] if args.key?(:post_view_lookback_window_days) end |