Class: Google::Apis::DisplayvideoV4::UploadAdAssetRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A request message for UploadAdAsset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UploadAdAssetRequest

Returns a new instance of UploadAdAssetRequest.



14933
14934
14935
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14933

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_asset_typeString

Required. The type of the ad asset. Only AD_ASSET_TYPE_IMAGE is supported. Corresponds to the JSON property adAssetType

Returns:

  • (String)


14919
14920
14921
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14919

def ad_asset_type
  @ad_asset_type
end

#filenameString

Required. The filename of the ad asset, including the file extension. The filename must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property filename

Returns:

  • (String)


14925
14926
14927
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14925

def filename
  @filename
end

#synthetic_content_attestation_statusString

Optional. Whether to add a label to the asset as created or edited using AI when served in regions with local AI labeling regulations. Corresponds to the JSON property syntheticContentAttestationStatus

Returns:

  • (String)


14931
14932
14933
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14931

def synthetic_content_attestation_status
  @synthetic_content_attestation_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14938
14939
14940
14941
14942
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14938

def update!(**args)
  @ad_asset_type = args[:ad_asset_type] if args.key?(:ad_asset_type)
  @filename = args[:filename] if args.key?(:filename)
  @synthetic_content_attestation_status = args[:synthetic_content_attestation_status] if args.key?(:synthetic_content_attestation_status)
end