Class: Google::Apis::DisplayvideoV4::VideoAdSequenceStep
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::VideoAdSequenceStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
The detail of a single step in a VideoAdSequence.
Instance Attribute Summary collapse
-
#ad_group_id ⇒ Fixnum
The ID of the corresponding ad group of the step.
-
#interaction_type ⇒ String
The interaction on the previous step that will lead the viewer to this step.
-
#previous_step_id ⇒ Fixnum
The ID of the previous step.
-
#step_id ⇒ Fixnum
The ID of the step.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoAdSequenceStep
constructor
A new instance of VideoAdSequenceStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoAdSequenceStep
Returns a new instance of VideoAdSequenceStep.
15215 15216 15217 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15215 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_id ⇒ Fixnum
The ID of the corresponding ad group of the step.
Corresponds to the JSON property adGroupId
15197 15198 15199 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15197 def ad_group_id @ad_group_id end |
#interaction_type ⇒ String
The interaction on the previous step that will lead the viewer to this step.
The first step does not have interaction_type.
Corresponds to the JSON property interactionType
15203 15204 15205 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15203 def interaction_type @interaction_type end |
#previous_step_id ⇒ Fixnum
The ID of the previous step. The first step does not have previous step.
Corresponds to the JSON property previousStepId
15208 15209 15210 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15208 def previous_step_id @previous_step_id end |
#step_id ⇒ Fixnum
The ID of the step.
Corresponds to the JSON property stepId
15213 15214 15215 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15213 def step_id @step_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15220 15221 15222 15223 15224 15225 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15220 def update!(**args) @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id) @interaction_type = args[:interaction_type] if args.key?(:interaction_type) @previous_step_id = args[:previous_step_id] if args.key?(:previous_step_id) @step_id = args[:step_id] if args.key?(:step_id) end |