Class: Google::Apis::DisplayvideoV4::VideoPerformanceAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a video performance ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoPerformanceAd

Returns a new instance of VideoPerformanceAd.



15335
15336
15337
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15335

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_button_labelsArray<String>

The list of text assets shown on the call-to-action button. Corresponds to the JSON property actionButtonLabels

Returns:

  • (Array<String>)


15278
15279
15280
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15278

def action_button_labels
  @action_button_labels
end

#companion_bannersArray<Google::Apis::DisplayvideoV4::ImageAsset>

The list of companion banners used by this ad. Corresponds to the JSON property companionBanners



15283
15284
15285
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15283

def companion_banners
  @companion_banners
end

#custom_parametersHash<String,String>

The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


15288
15289
15290
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15288

def custom_parameters
  @custom_parameters
end

#descriptionsArray<String>

The list of descriptions shown on the call-to-action banner. Corresponds to the JSON property descriptions

Returns:

  • (Array<String>)


15293
15294
15295
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15293

def descriptions
  @descriptions
end

#display_url_breadcrumb1String

The first piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb1

Returns:

  • (String)


15298
15299
15300
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15298

def display_url_breadcrumb1
  @display_url_breadcrumb1
end

#display_url_breadcrumb2String

The second piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb2

Returns:

  • (String)


15303
15304
15305
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15303

def display_url_breadcrumb2
  @display_url_breadcrumb2
end

#domainString

The domain of the display URL. Corresponds to the JSON property domain

Returns:

  • (String)


15308
15309
15310
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15308

def domain
  @domain
end

#final_urlString

The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


15313
15314
15315
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15313

def final_url
  @final_url
end

#headlinesArray<String>

The list of headlines shown on the call-to-action banner. Corresponds to the JSON property headlines

Returns:

  • (Array<String>)


15318
15319
15320
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15318

def headlines
  @headlines
end

#long_headlinesArray<String>

The list of long headlines shown on the call-to-action banner. Corresponds to the JSON property longHeadlines

Returns:

  • (Array<String>)


15323
15324
15325
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15323

def long_headlines
  @long_headlines
end

#tracking_urlString

The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


15328
15329
15330
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15328

def tracking_url
  @tracking_url
end

#videosArray<Google::Apis::DisplayvideoV4::YoutubeVideoDetails>

The list of YouTube video assets used by this ad. Corresponds to the JSON property videos



15333
15334
15335
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15333

def videos
  @videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15340
15341
15342
15343
15344
15345
15346
15347
15348
15349
15350
15351
15352
15353
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15340

def update!(**args)
  @action_button_labels = args[:action_button_labels] if args.key?(:action_button_labels)
  @companion_banners = args[:companion_banners] if args.key?(:companion_banners)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1)
  @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2)
  @domain = args[:domain] if args.key?(:domain)
  @final_url = args[:final_url] if args.key?(:final_url)
  @headlines = args[:headlines] if args.key?(:headlines)
  @long_headlines = args[:long_headlines] if args.key?(:long_headlines)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @videos = args[:videos] if args.key?(:videos)
end