Class: Google::Apis::DisplayvideoV4::YoutubeAndPartnersBiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Settings that control the bid strategy for YouTube and Partners resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAndPartnersBiddingStrategy

Returns a new instance of YoutubeAndPartnersBiddingStrategy.



14564
14565
14566
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_effective_target_cpa_sourceString

Output only. Source of the effective target CPA value for ad group. Corresponds to the JSON property adGroupEffectiveTargetCpaSource

Returns:

  • (String)


14534
14535
14536
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14534

def ad_group_effective_target_cpa_source
  @ad_group_effective_target_cpa_source
end

#ad_group_effective_target_cpa_valueFixnum

Output only. The effective target CPA for ad group, in micros of advertiser's currency. Corresponds to the JSON property adGroupEffectiveTargetCpaValue

Returns:

  • (Fixnum)


14540
14541
14542
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14540

def ad_group_effective_target_cpa_value
  @ad_group_effective_target_cpa_value
end

#typeString

The type of the bidding strategy. Corresponds to the JSON property type

Returns:

  • (String)


14545
14546
14547
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14545

def type
  @type
end

#valueFixnum

The value used by the bidding strategy. When the bidding strategy is assigned at the line item level, this field is only applicable for the following strategy types: * YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_TARGET_CPA * YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_TARGET_ROAS When the bidding strategy is assigned at the ad group level, this field is only applicable for the following strategy types: * YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_MANUAL_CPM * YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_MANUAL_CPV * YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_TARGET_CPA * YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_TARGET_CPM * YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_RESERVE_CPM * YOUTUBE_AND_PARTNERS_BIDDING_STRATEGY_TYPE_TARGET_ROAS If not using an applicable strategy, the value of this field will be 0. Corresponds to the JSON property value

Returns:

  • (Fixnum)


14562
14563
14564
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14562

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14569
14570
14571
14572
14573
14574
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14569

def update!(**args)
  @ad_group_effective_target_cpa_source = args[:ad_group_effective_target_cpa_source] if args.key?(:ad_group_effective_target_cpa_source)
  @ad_group_effective_target_cpa_value = args[:ad_group_effective_target_cpa_value] if args.key?(:ad_group_effective_target_cpa_value)
  @type = args[:type] if args.key?(:type)
  @value = args[:value] if args.key?(:value)
end