Class: Google::Apis::DisplayvideoV4::YoutubeAssetAssociation
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::YoutubeAssetAssociation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
An association between a resource and a YouTube asset.
Instance Attribute Summary collapse
-
#linked_youtube_asset ⇒ Google::Apis::DisplayvideoV4::YoutubeAssetAssociationLinkedYouTubeAsset
A YouTube asset linked to a resource in a YoutubeAssetAssociation.
-
#name ⇒ String
Identifier.
-
#youtube_asset_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ YoutubeAssetAssociation
constructor
A new instance of YoutubeAssetAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ YoutubeAssetAssociation
Returns a new instance of YoutubeAssetAssociation.
14724 14725 14726 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14724 def initialize(**args) update!(**args) end |
Instance Attribute Details
#linked_youtube_asset ⇒ Google::Apis::DisplayvideoV4::YoutubeAssetAssociationLinkedYouTubeAsset
A YouTube asset linked to a resource in a YoutubeAssetAssociation.
Corresponds to the JSON property linkedYoutubeAsset
14701 14702 14703 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14701 def linked_youtube_asset @linked_youtube_asset end |
#name ⇒ String
Identifier. The resource name of the association. For line item-level
associations: The name pattern is advertisers/advertiser_id/lineItems/
line_item_id/youtubeAssetTypes/youtube_asset_type/youtubeAssetAssociations/
youtube_asset_association_id. For ad group-level associations: The name
pattern is `advertisers/`advertiser_id`/adGroups/`ad_group_id`/
youtubeAssetTypes/`youtube_asset_type`/youtubeAssetAssociations/`
youtube_asset_association_id. For YOUTUBE_ASSET_TYPE_LOCATION and
YOUTUBE_ASSET_TYPE_AFFILIATE_LOCATION associations:
youtube_asset_association_id is the ID of the asset set linked, or 0 if the
location_matching_type or affiliate_location_matching_type is DISABLED. For
YOUTUBE_ASSET_TYPE_SITELINK associations: youtube_asset_association_id is
be the ID of the sitelink asset linked.
Corresponds to the JSON property name
14717 14718 14719 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14717 def name @name end |
#youtube_asset_type ⇒ String
Required. The type of YouTube asset associated with the resource.
Corresponds to the JSON property youtubeAssetType
14722 14723 14724 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14722 def youtube_asset_type @youtube_asset_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14729 14730 14731 14732 14733 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14729 def update!(**args) @linked_youtube_asset = args[:linked_youtube_asset] if args.key?(:linked_youtube_asset) @name = args[:name] if args.key?(:name) @youtube_asset_type = args[:youtube_asset_type] if args.key?(:youtube_asset_type) end |