Class: Google::Apis::DisplayvideoV4::YoutubeAssetAssociationAffiliateLocationAssetFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

An asset filter that matches eligible affiliate location assets for serving.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAssetAssociationAffiliateLocationAssetFilter

Returns a new instance of YoutubeAssetAssociationAffiliateLocationAssetFilter.



15723
15724
15725
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affiliate_location_matching_functionGoogle::Apis::DisplayvideoV4::YoutubeAssetAssociationAffiliateLocationAssetFilterAffiliateLocationMatchingFunction

The matching function for an affiliate location asset filter. Corresponds to the JSON property affiliateLocationMatchingFunction



15710
15711
15712
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15710

def affiliate_location_matching_function
  @affiliate_location_matching_function
end

#affiliate_location_matching_typeString

Required. The matching type of this affiliate location asset filter. Corresponds to the JSON property affiliateLocationMatchingType

Returns:

  • (String)


15715
15716
15717
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15715

def affiliate_location_matching_type
  @affiliate_location_matching_type
end

#asset_set_idFixnum

Output only. The ID of the asset set that matches the affiliate location assets eligible for serving. Corresponds to the JSON property assetSetId

Returns:

  • (Fixnum)


15721
15722
15723
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15721

def asset_set_id
  @asset_set_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15728
15729
15730
15731
15732
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15728

def update!(**args)
  @affiliate_location_matching_function = args[:affiliate_location_matching_function] if args.key?(:affiliate_location_matching_function)
  @affiliate_location_matching_type = args[:affiliate_location_matching_type] if args.key?(:affiliate_location_matching_type)
  @asset_set_id = args[:asset_set_id] if args.key?(:asset_set_id)
end