Class: Google::Apis::DisplayvideoV4::YoutubeAssetAssociationLinkedYouTubeAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A YouTube asset linked to a resource in a YoutubeAssetAssociation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAssetAssociationLinkedYouTubeAsset

Returns a new instance of YoutubeAssetAssociationLinkedYouTubeAsset.



15793
15794
15795
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affiliate_location_asset_filterGoogle::Apis::DisplayvideoV4::YoutubeAssetAssociationAffiliateLocationAssetFilter

An asset filter that matches eligible affiliate location assets for serving. Corresponds to the JSON property affiliateLocationAssetFilter



15781
15782
15783
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15781

def affiliate_location_asset_filter
  @affiliate_location_asset_filter
end

#location_asset_filterGoogle::Apis::DisplayvideoV4::YoutubeAssetAssociationLocationAssetFilter

An asset filter that matches eligible location assets for serving. Corresponds to the JSON property locationAssetFilter



15786
15787
15788
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15786

def location_asset_filter
  @location_asset_filter
end

A sitelink asset. Corresponds to the JSON property sitelinkAsset



15791
15792
15793
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15791

def sitelink_asset
  @sitelink_asset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15798
15799
15800
15801
15802
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15798

def update!(**args)
  @affiliate_location_asset_filter = args[:affiliate_location_asset_filter] if args.key?(:affiliate_location_asset_filter)
  @location_asset_filter = args[:location_asset_filter] if args.key?(:location_asset_filter)
  @sitelink_asset = args[:sitelink_asset] if args.key?(:sitelink_asset)
end