Class: Google::Apis::DisplayvideoV4::YoutubeAssetAssociationLocationAssetFilterLocationMatchingFunction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

The matching function for a location asset filter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAssetAssociationLocationAssetFilterLocationMatchingFunction

Returns a new instance of YoutubeAssetAssociationLocationAssetFilterLocationMatchingFunction.



15859
15860
15861
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15859

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#businessString

Optional. The business name to match with. This field is optional and can only be set if location_matching_type is FILTER. Corresponds to the JSON property business

Returns:

  • (String)


15845
15846
15847
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15845

def business
  @business
end

#labelsArray<String>

Optional. The labels to match with. Labels are logically OR'ed together. This field is optional and can only be set if location_matching_type is FILTER. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


15851
15852
15853
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15851

def labels
  @labels
end

#location_asset_idsArray<Fixnum>

Optional. The selected location asset IDs. This field is required if location_matching_type is SELECTED_ASSETS. Corresponds to the JSON property locationAssetIds

Returns:

  • (Array<Fixnum>)


15857
15858
15859
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15857

def location_asset_ids
  @location_asset_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15864
15865
15866
15867
15868
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15864

def update!(**args)
  @business = args[:business] if args.key?(:business)
  @labels = args[:labels] if args.key?(:labels)
  @location_asset_ids = args[:location_asset_ids] if args.key?(:location_asset_ids)
end