Class: Google::Apis::DisplayvideoV4::YoutubeVideoDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::YoutubeVideoDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details of a YouTube video.
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#unavailable_reason ⇒ String
The reason why the video data is not available.
-
#video_asset_id ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ YoutubeVideoDetails
constructor
A new instance of YoutubeVideoDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ YoutubeVideoDetails
Returns a new instance of YoutubeVideoDetails.
15019 15020 15021 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. The YouTube video ID which can be searched on YouTube webpage.
Corresponds to the JSON property id
15006 15007 15008 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15006 def id @id end |
#unavailable_reason ⇒ String
The reason why the video data is not available.
Corresponds to the JSON property unavailableReason
15011 15012 15013 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15011 def unavailable_reason @unavailable_reason end |
#video_asset_id ⇒ Fixnum
Required. The YouTube video asset id. This is the adAssetId of an AdAsset
resource.
Corresponds to the JSON property videoAssetId
15017 15018 15019 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15017 def video_asset_id @video_asset_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15024 15025 15026 15027 15028 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15024 def update!(**args) @id = args[:id] if args.key?(:id) @unavailable_reason = args[:unavailable_reason] if args.key?(:unavailable_reason) @video_asset_id = args[:video_asset_id] if args.key?(:video_asset_id) end |