Class: Google::Apis::DisplayvideoV4::AdGroupAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AdGroupAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single ad associated with an ad group.
Instance Attribute Summary collapse
-
#ad_group_ad_id ⇒ Fixnum
Output only.
-
#ad_group_id ⇒ Fixnum
Required.
-
#ad_policy ⇒ Google::Apis::DisplayvideoV4::AdPolicy
A single ad policy associated with an ad group ad.
-
#ad_urls ⇒ Array<Google::Apis::DisplayvideoV4::AdUrl>
Output only.
-
#advertiser_id ⇒ Fixnum
Output only.
-
#audio_ad ⇒ Google::Apis::DisplayvideoV4::AudioAd
Details for an audio ad.
-
#bumper_ad ⇒ Google::Apis::DisplayvideoV4::BumperAd
Details for a bumper ad.
-
#dcm_tracking_info ⇒ Google::Apis::DisplayvideoV4::DcmTrackingInfo
Details on the DCM tracking.
-
#demand_gen_carousel_ad ⇒ Google::Apis::DisplayvideoV4::DemandGenCarouselAd
Details for a Demand Gen carousel ad.
-
#demand_gen_image_ad ⇒ Google::Apis::DisplayvideoV4::DemandGenImageAd
Details for a Demand Gen image ad.
-
#demand_gen_product_ad ⇒ Google::Apis::DisplayvideoV4::DemandGenProductAd
Details for a Demand Gen product ad.
-
#demand_gen_video_ad ⇒ Google::Apis::DisplayvideoV4::DemandGenVideoAd
Details for a Demand Gen video ad.
-
#display_name ⇒ String
Required.
-
#display_video_source_ad ⇒ Google::Apis::DisplayvideoV4::DisplayVideoSourceAd
The ad sourced from a DV360 creative.
-
#entity_status ⇒ String
Required.
-
#in_stream_ad ⇒ Google::Apis::DisplayvideoV4::InStreamAd
Details for an in-stream ad.
-
#masthead_ad ⇒ Google::Apis::DisplayvideoV4::MastheadAd
Details for a Masthead Ad.
-
#name ⇒ String
Output only.
-
#non_skippable_ad ⇒ Google::Apis::DisplayvideoV4::NonSkippableAd
Details for a non-skippable ad.
-
#video_discover_ad ⇒ Google::Apis::DisplayvideoV4::VideoDiscoveryAd
Details for a video discovery ad.
-
#video_performance_ad ⇒ Google::Apis::DisplayvideoV4::VideoPerformanceAd
Details for a video performance ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdGroupAd
constructor
A new instance of AdGroupAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdGroupAd
Returns a new instance of AdGroupAd.
320 321 322 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 320 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_ad_id ⇒ Fixnum
Output only. The unique ID of the ad. Assigned by the system.
Corresponds to the JSON property adGroupAdId
217 218 219 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 217 def ad_group_ad_id @ad_group_ad_id end |
#ad_group_id ⇒ Fixnum
Required. Immutable. The unique ID of the ad group that the ad belongs to.
Corresponds to the JSON property adGroupId
222 223 224 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 222 def ad_group_id @ad_group_id end |
#ad_policy ⇒ Google::Apis::DisplayvideoV4::AdPolicy
A single ad policy associated with an ad group ad.
Corresponds to the JSON property adPolicy
227 228 229 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 227 def ad_policy @ad_policy end |
#ad_urls ⇒ Array<Google::Apis::DisplayvideoV4::AdUrl>
Output only. List of URLs used by the ad.
Corresponds to the JSON property adUrls
232 233 234 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 232 def ad_urls @ad_urls end |
#advertiser_id ⇒ Fixnum
Output only. The unique ID of the advertiser the ad belongs to.
Corresponds to the JSON property advertiserId
237 238 239 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 237 def advertiser_id @advertiser_id end |
#audio_ad ⇒ Google::Apis::DisplayvideoV4::AudioAd
Details for an audio ad.
Corresponds to the JSON property audioAd
242 243 244 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 242 def audio_ad @audio_ad end |
#bumper_ad ⇒ Google::Apis::DisplayvideoV4::BumperAd
Details for a bumper ad.
Corresponds to the JSON property bumperAd
247 248 249 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 247 def bumper_ad @bumper_ad end |
#dcm_tracking_info ⇒ Google::Apis::DisplayvideoV4::DcmTrackingInfo
Details on the DCM tracking.
Corresponds to the JSON property dcmTrackingInfo
252 253 254 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 252 def dcm_tracking_info @dcm_tracking_info end |
#demand_gen_carousel_ad ⇒ Google::Apis::DisplayvideoV4::DemandGenCarouselAd
Details for a Demand Gen carousel ad.
Corresponds to the JSON property demandGenCarouselAd
257 258 259 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 257 def demand_gen_carousel_ad @demand_gen_carousel_ad end |
#demand_gen_image_ad ⇒ Google::Apis::DisplayvideoV4::DemandGenImageAd
Details for a Demand Gen image ad.
Corresponds to the JSON property demandGenImageAd
262 263 264 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 262 def demand_gen_image_ad @demand_gen_image_ad end |
#demand_gen_product_ad ⇒ Google::Apis::DisplayvideoV4::DemandGenProductAd
Details for a Demand Gen product ad.
Corresponds to the JSON property demandGenProductAd
267 268 269 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 267 def demand_gen_product_ad @demand_gen_product_ad end |
#demand_gen_video_ad ⇒ Google::Apis::DisplayvideoV4::DemandGenVideoAd
Details for a Demand Gen video ad.
Corresponds to the JSON property demandGenVideoAd
272 273 274 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 272 def demand_gen_video_ad @demand_gen_video_ad end |
#display_name ⇒ String
Required. The display name of the ad. Must be UTF-8 encoded with a maximum
size of 255 bytes.
Corresponds to the JSON property displayName
278 279 280 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 278 def display_name @display_name end |
#display_video_source_ad ⇒ Google::Apis::DisplayvideoV4::DisplayVideoSourceAd
The ad sourced from a DV360 creative.
Corresponds to the JSON property displayVideoSourceAd
283 284 285 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 283 def display_video_source_ad @display_video_source_ad end |
#entity_status ⇒ String
Required. The entity status of the ad.
Corresponds to the JSON property entityStatus
288 289 290 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 288 def entity_status @entity_status end |
#in_stream_ad ⇒ Google::Apis::DisplayvideoV4::InStreamAd
Details for an in-stream ad.
Corresponds to the JSON property inStreamAd
293 294 295 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 293 def in_stream_ad @in_stream_ad end |
#masthead_ad ⇒ Google::Apis::DisplayvideoV4::MastheadAd
Details for a Masthead Ad.
Corresponds to the JSON property mastheadAd
298 299 300 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 298 def masthead_ad @masthead_ad end |
#name ⇒ String
Output only. The resource name of the ad.
Corresponds to the JSON property name
303 304 305 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 303 def name @name end |
#non_skippable_ad ⇒ Google::Apis::DisplayvideoV4::NonSkippableAd
Details for a non-skippable ad.
Corresponds to the JSON property nonSkippableAd
308 309 310 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 308 def non_skippable_ad @non_skippable_ad end |
#video_discover_ad ⇒ Google::Apis::DisplayvideoV4::VideoDiscoveryAd
Details for a video discovery ad.
Corresponds to the JSON property videoDiscoverAd
313 314 315 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 313 def video_discover_ad @video_discover_ad end |
#video_performance_ad ⇒ Google::Apis::DisplayvideoV4::VideoPerformanceAd
Details for a video performance ad.
Corresponds to the JSON property videoPerformanceAd
318 319 320 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 318 def video_performance_ad @video_performance_ad end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 325 def update!(**args) @ad_group_ad_id = args[:ad_group_ad_id] if args.key?(:ad_group_ad_id) @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id) @ad_policy = args[:ad_policy] if args.key?(:ad_policy) @ad_urls = args[:ad_urls] if args.key?(:ad_urls) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @audio_ad = args[:audio_ad] if args.key?(:audio_ad) @bumper_ad = args[:bumper_ad] if args.key?(:bumper_ad) @dcm_tracking_info = args[:dcm_tracking_info] if args.key?(:dcm_tracking_info) @demand_gen_carousel_ad = args[:demand_gen_carousel_ad] if args.key?(:demand_gen_carousel_ad) @demand_gen_image_ad = args[:demand_gen_image_ad] if args.key?(:demand_gen_image_ad) @demand_gen_product_ad = args[:demand_gen_product_ad] if args.key?(:demand_gen_product_ad) @demand_gen_video_ad = args[:demand_gen_video_ad] if args.key?(:demand_gen_video_ad) @display_name = args[:display_name] if args.key?(:display_name) @display_video_source_ad = args[:display_video_source_ad] if args.key?(:display_video_source_ad) @entity_status = args[:entity_status] if args.key?(:entity_status) @in_stream_ad = args[:in_stream_ad] if args.key?(:in_stream_ad) @masthead_ad = args[:masthead_ad] if args.key?(:masthead_ad) @name = args[:name] if args.key?(:name) @non_skippable_ad = args[:non_skippable_ad] if args.key?(:non_skippable_ad) @video_discover_ad = args[:video_discover_ad] if args.key?(:video_discover_ad) @video_performance_ad = args[:video_performance_ad] if args.key?(:video_performance_ad) end |