Class: Google::Apis::DisplayvideoV4::AdGroupAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single ad associated with an ad group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdGroupAd

Returns a new instance of AdGroupAd.



314
315
316
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 314

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_ad_idFixnum

Output only. The unique ID of the ad. Assigned by the system. Corresponds to the JSON property adGroupAdId

Returns:

  • (Fixnum)


211
212
213
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 211

def ad_group_ad_id
  @ad_group_ad_id
end

#ad_group_idFixnum

Required. Immutable. The unique ID of the ad group that the ad belongs to. Corresponds to the JSON property adGroupId

Returns:

  • (Fixnum)


216
217
218
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 216

def ad_group_id
  @ad_group_id
end

#ad_policyGoogle::Apis::DisplayvideoV4::AdPolicy

A single ad policy associated with an ad group ad. Corresponds to the JSON property adPolicy



221
222
223
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 221

def ad_policy
  @ad_policy
end

#ad_urlsArray<Google::Apis::DisplayvideoV4::AdUrl>

Output only. List of URLs used by the ad. Corresponds to the JSON property adUrls



226
227
228
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 226

def ad_urls
  @ad_urls
end

#advertiser_idFixnum

Output only. The unique ID of the advertiser the ad belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


231
232
233
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 231

def advertiser_id
  @advertiser_id
end

#audio_adGoogle::Apis::DisplayvideoV4::AudioAd

Details for an audio ad. Corresponds to the JSON property audioAd



236
237
238
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 236

def audio_ad
  @audio_ad
end

#bumper_adGoogle::Apis::DisplayvideoV4::BumperAd

Details for a bumper ad. Corresponds to the JSON property bumperAd



241
242
243
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 241

def bumper_ad
  @bumper_ad
end

#dcm_tracking_infoGoogle::Apis::DisplayvideoV4::DcmTrackingInfo

Details on the DCM tracking. Corresponds to the JSON property dcmTrackingInfo



246
247
248
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 246

def dcm_tracking_info
  @dcm_tracking_info
end

Details for a Demand Gen carousel ad. Corresponds to the JSON property demandGenCarouselAd



251
252
253
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 251

def demand_gen_carousel_ad
  @demand_gen_carousel_ad
end

#demand_gen_image_adGoogle::Apis::DisplayvideoV4::DemandGenImageAd

Details for a Demand Gen image ad. Corresponds to the JSON property demandGenImageAd



256
257
258
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 256

def demand_gen_image_ad
  @demand_gen_image_ad
end

#demand_gen_product_adGoogle::Apis::DisplayvideoV4::DemandGenProductAd

Details for a Demand Gen product ad. Corresponds to the JSON property demandGenProductAd



261
262
263
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 261

def demand_gen_product_ad
  @demand_gen_product_ad
end

#demand_gen_video_adGoogle::Apis::DisplayvideoV4::DemandGenVideoAd

Details for a Demand Gen video ad. Corresponds to the JSON property demandGenVideoAd



266
267
268
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 266

def demand_gen_video_ad
  @demand_gen_video_ad
end

#display_nameString

Required. The display name of the ad. Must be UTF-8 encoded with a maximum size of 255 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


272
273
274
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 272

def display_name
  @display_name
end

#display_video_source_adGoogle::Apis::DisplayvideoV4::DisplayVideoSourceAd

The ad sourced from a DV360 creative. Corresponds to the JSON property displayVideoSourceAd



277
278
279
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 277

def display_video_source_ad
  @display_video_source_ad
end

#entity_statusString

Required. The entity status of the ad. Corresponds to the JSON property entityStatus

Returns:

  • (String)


282
283
284
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 282

def entity_status
  @entity_status
end

#in_stream_adGoogle::Apis::DisplayvideoV4::InStreamAd

Details for an in-stream ad. Corresponds to the JSON property inStreamAd



287
288
289
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 287

def in_stream_ad
  @in_stream_ad
end

#masthead_adGoogle::Apis::DisplayvideoV4::MastheadAd

Details for a Masthead Ad. Corresponds to the JSON property mastheadAd



292
293
294
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 292

def masthead_ad
  @masthead_ad
end

#nameString

Output only. The resource name of the ad. Corresponds to the JSON property name

Returns:

  • (String)


297
298
299
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 297

def name
  @name
end

#non_skippable_adGoogle::Apis::DisplayvideoV4::NonSkippableAd

Details for a non-skippable ad. Corresponds to the JSON property nonSkippableAd



302
303
304
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 302

def non_skippable_ad
  @non_skippable_ad
end

#video_discover_adGoogle::Apis::DisplayvideoV4::VideoDiscoveryAd

Details for a video discovery ad. Corresponds to the JSON property videoDiscoverAd



307
308
309
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 307

def video_discover_ad
  @video_discover_ad
end

#video_performance_adGoogle::Apis::DisplayvideoV4::VideoPerformanceAd

Details for a video performance ad. Corresponds to the JSON property videoPerformanceAd



312
313
314
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 312

def video_performance_ad
  @video_performance_ad
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 319

def update!(**args)
  @ad_group_ad_id = args[:ad_group_ad_id] if args.key?(:ad_group_ad_id)
  @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id)
  @ad_policy = args[:ad_policy] if args.key?(:ad_policy)
  @ad_urls = args[:ad_urls] if args.key?(:ad_urls)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @audio_ad = args[:audio_ad] if args.key?(:audio_ad)
  @bumper_ad = args[:bumper_ad] if args.key?(:bumper_ad)
  @dcm_tracking_info = args[:dcm_tracking_info] if args.key?(:dcm_tracking_info)
  @demand_gen_carousel_ad = args[:demand_gen_carousel_ad] if args.key?(:demand_gen_carousel_ad)
  @demand_gen_image_ad = args[:demand_gen_image_ad] if args.key?(:demand_gen_image_ad)
  @demand_gen_product_ad = args[:demand_gen_product_ad] if args.key?(:demand_gen_product_ad)
  @demand_gen_video_ad = args[:demand_gen_video_ad] if args.key?(:demand_gen_video_ad)
  @display_name = args[:display_name] if args.key?(:display_name)
  @display_video_source_ad = args[:display_video_source_ad] if args.key?(:display_video_source_ad)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @in_stream_ad = args[:in_stream_ad] if args.key?(:in_stream_ad)
  @masthead_ad = args[:masthead_ad] if args.key?(:masthead_ad)
  @name = args[:name] if args.key?(:name)
  @non_skippable_ad = args[:non_skippable_ad] if args.key?(:non_skippable_ad)
  @video_discover_ad = args[:video_discover_ad] if args.key?(:video_discover_ad)
  @video_performance_ad = args[:video_performance_ad] if args.key?(:video_performance_ad)
end