Class: Google::Apis::DisplayvideoV4::AdPolicy
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AdPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single ad policy associated with an ad group ad.
Instance Attribute Summary collapse
-
#ad_policy_approval_status ⇒ String
The policy approval status of an ad, indicating the approval decision.
-
#ad_policy_review_status ⇒ String
The policy review status of an ad, indicating where in the review process the ad is currently.
-
#ad_policy_topic_entry ⇒ Array<Google::Apis::DisplayvideoV4::AdPolicyTopicEntry>
The entries for each policy topic identified as relating to the ad.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdPolicy
constructor
A new instance of AdPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdPolicy
Returns a new instance of AdPolicy.
424 425 426 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_policy_approval_status ⇒ String
The policy approval status of an ad, indicating the approval decision.
Corresponds to the JSON property adPolicyApprovalStatus
409 410 411 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 409 def ad_policy_approval_status @ad_policy_approval_status end |
#ad_policy_review_status ⇒ String
The policy review status of an ad, indicating where in the review process the
ad is currently.
Corresponds to the JSON property adPolicyReviewStatus
415 416 417 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 415 def ad_policy_review_status @ad_policy_review_status end |
#ad_policy_topic_entry ⇒ Array<Google::Apis::DisplayvideoV4::AdPolicyTopicEntry>
The entries for each policy topic identified as relating to the ad. Each entry
includes the topic, restriction level, and guidance on how to fix policy
issues.
Corresponds to the JSON property adPolicyTopicEntry
422 423 424 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 422 def ad_policy_topic_entry @ad_policy_topic_entry end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
429 430 431 432 433 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 429 def update!(**args) @ad_policy_approval_status = args[:ad_policy_approval_status] if args.key?(:ad_policy_approval_status) @ad_policy_review_status = args[:ad_policy_review_status] if args.key?(:ad_policy_review_status) @ad_policy_topic_entry = args[:ad_policy_topic_entry] if args.key?(:ad_policy_topic_entry) end |