Class: Google::Apis::DisplayvideoV4::AdPolicyTopicConstraint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details on ad serving constraints.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdPolicyTopicConstraint

Returns a new instance of AdPolicyTopicConstraint.



522
523
524
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_domain_mismatch_country_listGoogle::Apis::DisplayvideoV4::AdPolicyTopicConstraintAdPolicyCountryConstraintList

A list of countries where the ad cannot serve due to policy constraints. Corresponds to the JSON property certificateDomainMismatchCountryList



488
489
490
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 488

def certificate_domain_mismatch_country_list
  @certificate_domain_mismatch_country_list
end

#certificate_missing_country_listGoogle::Apis::DisplayvideoV4::AdPolicyTopicConstraintAdPolicyCountryConstraintList

A list of countries where the ad cannot serve due to policy constraints. Corresponds to the JSON property certificateMissingCountryList



493
494
495
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 493

def certificate_missing_country_list
  @certificate_missing_country_list
end

#country_constraintGoogle::Apis::DisplayvideoV4::AdPolicyTopicConstraintAdPolicyCountryConstraintList

A list of countries where the ad cannot serve due to policy constraints. Corresponds to the JSON property countryConstraint



498
499
500
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 498

def country_constraint
  @country_constraint
end

#global_certificate_domain_mismatchGoogle::Apis::DisplayvideoV4::AdPolicyTopicConstraintAdPolicyGlobalCertificateDomainMismatchConstraint

Certificate is required to serve in any country and the existing certificate does not cover the ad's domain. Corresponds to the JSON property globalCertificateDomainMismatch



504
505
506
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 504

def global_certificate_domain_mismatch
  @global_certificate_domain_mismatch
end

#global_certificate_missingGoogle::Apis::DisplayvideoV4::AdPolicyTopicConstraintAdPolicyGlobalCertificateMissingConstraint

Certificate is required to serve in any country. Corresponds to the JSON property globalCertificateMissing



509
510
511
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 509

def global_certificate_missing
  @global_certificate_missing
end

Link to the form to request a certificate for the constraint. Corresponds to the JSON property requestCertificateFormLink

Returns:

  • (String)


514
515
516
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 514

def request_certificate_form_link
  @request_certificate_form_link
end

#reseller_constraintGoogle::Apis::DisplayvideoV4::AdPolicyTopicConstraintAdPolicyResellerConstraint

Policy topic was constrained due to disapproval of the website for reseller purposes. Corresponds to the JSON property resellerConstraint



520
521
522
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 520

def reseller_constraint
  @reseller_constraint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



527
528
529
530
531
532
533
534
535
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 527

def update!(**args)
  @certificate_domain_mismatch_country_list = args[:certificate_domain_mismatch_country_list] if args.key?(:certificate_domain_mismatch_country_list)
  @certificate_missing_country_list = args[:certificate_missing_country_list] if args.key?(:certificate_missing_country_list)
  @country_constraint = args[:country_constraint] if args.key?(:country_constraint)
  @global_certificate_domain_mismatch = args[:global_certificate_domain_mismatch] if args.key?(:global_certificate_domain_mismatch)
  @global_certificate_missing = args[:global_certificate_missing] if args.key?(:global_certificate_missing)
  @request_certificate_form_link = args[:request_certificate_form_link] if args.key?(:request_certificate_form_link)
  @reseller_constraint = args[:reseller_constraint] if args.key?(:reseller_constraint)
end