Class: Google::Apis::DisplayvideoV4::AdPolicyTopicEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

An entry describing how an ad has been identified as relating to an ad policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdPolicyTopicEntry

Returns a new instance of AdPolicyTopicEntry.



653
654
655
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appeal_infoGoogle::Apis::DisplayvideoV4::AdPolicyTopicAppealInfo

Information on how to appeal a policy decision. Corresponds to the JSON property appealInfo



605
606
607
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 605

def appeal_info
  @appeal_info
end

Ad policy help center link for the policy topic. Corresponds to the JSON property helpCenterLink

Returns:

  • (String)


610
611
612
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 610

def help_center_link
  @help_center_link
end

#policy_decision_typeString

The source of the policy decision. Corresponds to the JSON property policyDecisionType

Returns:

  • (String)


615
616
617
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 615

def policy_decision_type
  @policy_decision_type
end

#policy_enforcement_meansString

The policy enforcement means used in the policy review. Corresponds to the JSON property policyEnforcementMeans

Returns:

  • (String)


620
621
622
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 620

def policy_enforcement_means
  @policy_enforcement_means
end

#policy_labelString

Localized label text for policy. Examples include "Trademarks in text", " Contains Alcohol", etc. Corresponds to the JSON property policyLabel

Returns:

  • (String)


626
627
628
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 626

def policy_label
  @policy_label
end

#policy_topicString

The policy topic. Examples include "TRADEMARKS", "ALCOHOL", etc. Corresponds to the JSON property policyTopic

Returns:

  • (String)


631
632
633
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 631

def policy_topic
  @policy_topic
end

#policy_topic_constraintsArray<Google::Apis::DisplayvideoV4::AdPolicyTopicConstraint>

The serving constraints relevant to the policy decision. Corresponds to the JSON property policyTopicConstraints



636
637
638
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 636

def policy_topic_constraints
  @policy_topic_constraints
end

#policy_topic_descriptionString

A short summary description of the policy topic. Corresponds to the JSON property policyTopicDescription

Returns:

  • (String)


641
642
643
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 641

def policy_topic_description
  @policy_topic_description
end

#policy_topic_evidencesArray<Google::Apis::DisplayvideoV4::AdPolicyTopicEvidence>

The evidence used in the policy decision. Corresponds to the JSON property policyTopicEvidences



646
647
648
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 646

def policy_topic_evidences
  @policy_topic_evidences
end

#policy_topic_typeString

How ad serving will be affected due to the relation to the ad policy topic. Corresponds to the JSON property policyTopicType

Returns:

  • (String)


651
652
653
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 651

def policy_topic_type
  @policy_topic_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



658
659
660
661
662
663
664
665
666
667
668
669
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 658

def update!(**args)
  @appeal_info = args[:appeal_info] if args.key?(:appeal_info)
  @help_center_link = args[:help_center_link] if args.key?(:help_center_link)
  @policy_decision_type = args[:policy_decision_type] if args.key?(:policy_decision_type)
  @policy_enforcement_means = args[:policy_enforcement_means] if args.key?(:policy_enforcement_means)
  @policy_label = args[:policy_label] if args.key?(:policy_label)
  @policy_topic = args[:policy_topic] if args.key?(:policy_topic)
  @policy_topic_constraints = args[:policy_topic_constraints] if args.key?(:policy_topic_constraints)
  @policy_topic_description = args[:policy_topic_description] if args.key?(:policy_topic_description)
  @policy_topic_evidences = args[:policy_topic_evidences] if args.key?(:policy_topic_evidences)
  @policy_topic_type = args[:policy_topic_type] if args.key?(:policy_topic_type)
end