Class: Google::Apis::DisplayvideoV4::AdPolicyTopicEvidence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Evidence information used in the policy decision.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdPolicyTopicEvidence

Returns a new instance of AdPolicyTopicEvidence.



735
736
737
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#counterfeitGoogle::Apis::DisplayvideoV4::AdPolicyTopicEvidenceCounterfeit

Details on the counterfeit enforcement that caused a policy violation. Corresponds to the JSON property counterfeit



679
680
681
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 679

def counterfeit
  @counterfeit
end

#destination_mismatchGoogle::Apis::DisplayvideoV4::AdPolicyTopicEvidenceDestinationMismatch

Details on a mismatch between destination URL types. Corresponds to the JSON property destinationMismatch



684
685
686
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 684

def destination_mismatch
  @destination_mismatch
end

#destination_not_workingGoogle::Apis::DisplayvideoV4::AdPolicyTopicEvidenceDestinationNotWorking

Details for on HTTP or DNS errors related to the ad destination. Corresponds to the JSON property destinationNotWorking



689
690
691
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 689

def destination_not_working
  @destination_not_working
end

#destination_text_listGoogle::Apis::DisplayvideoV4::AdPolicyTopicEvidenceDestinationTextList

A list of destination text that violated the policy. Corresponds to the JSON property destinationTextList



694
695
696
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 694

def destination_text_list
  @destination_text_list
end

#http_codeFixnum

HTTP code returned when the final URL was crawled. Corresponds to the JSON property httpCode

Returns:

  • (Fixnum)


699
700
701
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 699

def http_code
  @http_code
end

#language_codeString

The language the ad was detected to be written in. This field uses IETF language tags, such as "en-US". Corresponds to the JSON property languageCode

Returns:

  • (String)


705
706
707
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 705

def language_code
  @language_code
end

Legal related regulation enforcement, either from DMCA or local legal regulation. Corresponds to the JSON property legalRemoval



711
712
713
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 711

def legal_removal
  @legal_removal
end

#regional_requirementsGoogle::Apis::DisplayvideoV4::AdPolicyTopicEvidenceRegionalRequirements

Trust & Safety (T&S) proactive enforcement for policies meant to address regional requirements. This is considered a Google-owned investigation instead of a regulation notice since it's proactive T&S enforcement. Corresponds to the JSON property regionalRequirements



718
719
720
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 718

def regional_requirements
  @regional_requirements
end

#text_listGoogle::Apis::DisplayvideoV4::AdPolicyTopicEvidenceTextList

A list of fragments of text that violated the policy. Corresponds to the JSON property textList



723
724
725
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 723

def text_list
  @text_list
end

#trademarkGoogle::Apis::DisplayvideoV4::AdPolicyTopicEvidenceTrademark

Trademark terms that caused a policy violation. Corresponds to the JSON property trademark



728
729
730
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 728

def trademark
  @trademark
end

#website_listGoogle::Apis::DisplayvideoV4::AdPolicyTopicEvidenceWebsiteList

A list of websites that violated the policy. Corresponds to the JSON property websiteList



733
734
735
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 733

def website_list
  @website_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



740
741
742
743
744
745
746
747
748
749
750
751
752
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 740

def update!(**args)
  @counterfeit = args[:counterfeit] if args.key?(:counterfeit)
  @destination_mismatch = args[:destination_mismatch] if args.key?(:destination_mismatch)
  @destination_not_working = args[:destination_not_working] if args.key?(:destination_not_working)
  @destination_text_list = args[:destination_text_list] if args.key?(:destination_text_list)
  @http_code = args[:http_code] if args.key?(:http_code)
  @language_code = args[:language_code] if args.key?(:language_code)
  @legal_removal = args[:legal_removal] if args.key?(:legal_removal)
  @regional_requirements = args[:regional_requirements] if args.key?(:regional_requirements)
  @text_list = args[:text_list] if args.key?(:text_list)
  @trademark = args[:trademark] if args.key?(:trademark)
  @website_list = args[:website_list] if args.key?(:website_list)
end