Class: Google::Apis::DisplayvideoV4::AdPolicyTopicEvidenceDestinationMismatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details on a mismatch between destination URL types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdPolicyTopicEvidenceDestinationMismatch

Returns a new instance of AdPolicyTopicEvidenceDestinationMismatch.



786
787
788
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 786

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#uri_typesArray<String>

The set of URLs that do not match. The list can include single or multiple uri types. Example 1: [DISPLAY_URL, FINAL_URL] means ad display URL does not match with the ad final URL. Example 2: [FINAL_URL] means ad final URL did not match the crawled url, which is also considered as destination mismatch. Corresponds to the JSON property uriTypes

Returns:

  • (Array<String>)


784
785
786
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 784

def uri_types
  @uri_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



791
792
793
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 791

def update!(**args)
  @uri_types = args[:uri_types] if args.key?(:uri_types)
end