Class: Google::Apis::DisplayvideoV4::AdPolicyTopicEvidenceTextList
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AdPolicyTopicEvidenceTextList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A list of fragments of text that violated the policy.
Instance Attribute Summary collapse
-
#texts ⇒ Array<String>
The fragments of text from the resource that caused the policy finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdPolicyTopicEvidenceTextList
constructor
A new instance of AdPolicyTopicEvidenceTextList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdPolicyTopicEvidenceTextList
Returns a new instance of AdPolicyTopicEvidenceTextList.
995 996 997 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#texts ⇒ Array<String>
The fragments of text from the resource that caused the policy finding.
Corresponds to the JSON property texts
993 994 995 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 993 def texts @texts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1000 1001 1002 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1000 def update!(**args) @texts = args[:texts] if args.key?(:texts) end |