Class: Google::Apis::DisplayvideoV4::AdvancedProductTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Product-specific targeting overrides.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdvancedProductTargeting

Returns a new instance of AdvancedProductTargeting.



1269
1270
1271
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1269

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_rangeString

Optional. The age range to target. Corresponds to the JSON property ageRange

Returns:

  • (String)


1208
1209
1210
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1208

def age_range
  @age_range
end

#date_rangeGoogle::Apis::DisplayvideoV4::DateRange

A date range. Corresponds to the JSON property dateRange



1213
1214
1215
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1213

def date_range
  @date_range
end

#devicesArray<String>

Optional. The devices to target. Corresponds to the JSON property devices

Returns:

  • (Array<String>)


1218
1219
1220
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1218

def devices
  @devices
end

#frequency_capGoogle::Apis::DisplayvideoV4::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property frequencyCap



1224
1225
1226
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1224

def frequency_cap
  @frequency_cap
end

#gendersArray<String>

Optional. The gender options to target. Corresponds to the JSON property genders

Returns:

  • (Array<String>)


1229
1230
1231
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1229

def genders
  @genders
end

#networkString

Optional. The network to target. Corresponds to the JSON property network

Returns:

  • (String)


1234
1235
1236
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1234

def network
  @network
end

#plannable_location_idsArray<Fixnum>

Optional. Plannable location IDs to target. Corresponds to the JSON property plannableLocationIds

Returns:

  • (Array<Fixnum>)


1239
1240
1241
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1239

def plannable_location_ids
  @plannable_location_ids
end

#surface_targeting_settingsGoogle::Apis::DisplayvideoV4::SurfaceTargetingSettings

Surface targeting selection. Corresponds to the JSON property surfaceTargetingSettings



1244
1245
1246
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1244

def surface_targeting_settings
  @surface_targeting_settings
end

#target_frequencyGoogle::Apis::DisplayvideoV4::TargetFrequency

Setting that controls the average number of times the ads will show to the same person over a certain period of time. Corresponds to the JSON property targetFrequency



1250
1251
1252
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1250

def target_frequency
  @target_frequency
end

#user_interest_idsArray<String>

Optional. The user interest IDs to target. Plannable user interests can be retrieved using the RetrievePlannableUserInterests method. Corresponds to the JSON property userInterestIds

Returns:

  • (Array<String>)


1256
1257
1258
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1256

def user_interest_ids
  @user_interest_ids
end

#user_list_idsArray<String>

Optional. The user list IDs to target. Plannable user lists can be retrieved using the RetrievePlannableUserInterests method. Corresponds to the JSON property userListIds

Returns:

  • (Array<String>)


1262
1263
1264
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1262

def user_list_ids
  @user_list_ids
end

#youtube_select_settingsGoogle::Apis::DisplayvideoV4::YouTubeSelectSettings

Settings for YouTube Select Lineups. Corresponds to the JSON property youtubeSelectSettings



1267
1268
1269
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1267

def youtube_select_settings
  @youtube_select_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1274

def update!(**args)
  @age_range = args[:age_range] if args.key?(:age_range)
  @date_range = args[:date_range] if args.key?(:date_range)
  @devices = args[:devices] if args.key?(:devices)
  @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap)
  @genders = args[:genders] if args.key?(:genders)
  @network = args[:network] if args.key?(:network)
  @plannable_location_ids = args[:plannable_location_ids] if args.key?(:plannable_location_ids)
  @surface_targeting_settings = args[:surface_targeting_settings] if args.key?(:surface_targeting_settings)
  @target_frequency = args[:target_frequency] if args.key?(:target_frequency)
  @user_interest_ids = args[:user_interest_ids] if args.key?(:user_interest_ids)
  @user_list_ids = args[:user_list_ids] if args.key?(:user_list_ids)
  @youtube_select_settings = args[:youtube_select_settings] if args.key?(:youtube_select_settings)
end