Class: Google::Apis::DisplayvideoV4::Advertiser

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single advertiser in Display & Video 360 (DV360).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Advertiser

Returns a new instance of Advertiser.



1409
1410
1411
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_server_configGoogle::Apis::DisplayvideoV4::AdvertiserAdServerConfig

Ad server related settings of an advertiser. Corresponds to the JSON property adServerConfig



1303
1304
1305
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1303

def ad_server_config
  @ad_server_config
end

#advertiser_idFixnum

Output only. The unique ID of the advertiser. Assigned by the system. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


1308
1309
1310
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1308

def advertiser_id
  @advertiser_id
end

#billing_configGoogle::Apis::DisplayvideoV4::AdvertiserBillingConfig

Billing related settings of an advertiser. Corresponds to the JSON property billingConfig



1313
1314
1315
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1313

def billing_config
  @billing_config
end

#contains_eu_political_adsString

Optional. Whether this advertiser contains line items that serve European Union political ads. If this field is set to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING, then the following will happen: * Any new line items created under this advertiser will be assigned DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING if not otherwise specified. * Any existing line items under this advertiser that do not have a set value be updated to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING within a day. Corresponds to the JSON property containsEuPoliticalAds

Returns:

  • (String)


1324
1325
1326
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1324

def contains_eu_political_ads
  @contains_eu_political_ads
end

#creative_configGoogle::Apis::DisplayvideoV4::AdvertiserCreativeConfig

Creatives related settings of an advertiser. Corresponds to the JSON property creativeConfig



1329
1330
1331
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1329

def creative_config
  @creative_config
end

#data_access_configGoogle::Apis::DisplayvideoV4::AdvertiserDataAccessConfig

Settings that control how advertiser related data may be accessed. Corresponds to the JSON property dataAccessConfig



1334
1335
1336
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1334

def data_access_config
  @data_access_config
end

#default_business_nameString

Optional. The default business name for the advertiser. This is the value used by YouTube and Demand Gen ads under this advertiser if a business name is not provided. Corresponds to the JSON property defaultBusinessName

Returns:

  • (String)


1341
1342
1343
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1341

def default_business_name
  @default_business_name
end

#default_logo_asset_idFixnum

Optional. The asset ID of the default logo image for the advertiser. This is the asset ID that will be used by YouTube and Demand ads under this advertiser if a logo asset is not provided. You must use advertisers.adAssets.upload to upload this asset using the API. Corresponds to the JSON property defaultLogoAssetId

Returns:

  • (Fixnum)


1349
1350
1351
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1349

def default_logo_asset_id
  @default_logo_asset_id
end

#display_nameString

Required. The display name of the advertiser. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


1355
1356
1357
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1355

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not insertion orders and line items of the advertiser can spend their budgets and bid on inventory. * Accepted values are ENTITY_STATUS_ACTIVE, ENTITY_STATUS_PAUSED and ENTITY_STATUS_SCHEDULED_FOR_DELETION. * If set to ENTITY_STATUS_SCHEDULED_FOR_DELETION, the advertiser will be deleted 30 days from when it was first scheduled for deletion. Corresponds to the JSON property entityStatus

Returns:

  • (String)


1365
1366
1367
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1365

def entity_status
  @entity_status
end

#general_configGoogle::Apis::DisplayvideoV4::AdvertiserGeneralConfig

General settings of an advertiser. Corresponds to the JSON property generalConfig



1370
1371
1372
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1370

def general_config
  @general_config
end

#integration_detailsGoogle::Apis::DisplayvideoV4::IntegrationDetails

Integration details of an entry. Corresponds to the JSON property integrationDetails



1375
1376
1377
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1375

def integration_details
  @integration_details
end

#nameString

Output only. The resource name of the advertiser. Corresponds to the JSON property name

Returns:

  • (String)


1380
1381
1382
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1380

def name
  @name
end

#partner_idFixnum

Required. Immutable. The unique ID of the partner that the advertiser belongs to. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


1386
1387
1388
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1386

def partner_id
  @partner_id
end

#prisma_enabledBoolean Also known as: prisma_enabled?

Whether integration with Mediaocean (Prisma) is enabled. By enabling this, you agree to the following: On behalf of my company, I authorize Mediaocean ( Prisma) to send budget segment plans to Google, and I authorize Google to send corresponding reporting and invoices from DV360 to Mediaocean for the purposes of budget planning, billing, and reconciliation for this advertiser. Corresponds to the JSON property prismaEnabled

Returns:

  • (Boolean)


1395
1396
1397
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1395

def prisma_enabled
  @prisma_enabled
end

#serving_configGoogle::Apis::DisplayvideoV4::AdvertiserTargetingConfig

Targeting settings related to ad serving of an advertiser. Corresponds to the JSON property servingConfig



1401
1402
1403
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1401

def serving_config
  @serving_config
end

#update_timeString

Output only. The timestamp when the advertiser was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


1407
1408
1409
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1407

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1414

def update!(**args)
  @ad_server_config = args[:ad_server_config] if args.key?(:ad_server_config)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @billing_config = args[:billing_config] if args.key?(:billing_config)
  @contains_eu_political_ads = args[:contains_eu_political_ads] if args.key?(:contains_eu_political_ads)
  @creative_config = args[:creative_config] if args.key?(:creative_config)
  @data_access_config = args[:data_access_config] if args.key?(:data_access_config)
  @default_business_name = args[:default_business_name] if args.key?(:default_business_name)
  @default_logo_asset_id = args[:default_logo_asset_id] if args.key?(:default_logo_asset_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @general_config = args[:general_config] if args.key?(:general_config)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @name = args[:name] if args.key?(:name)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @prisma_enabled = args[:prisma_enabled] if args.key?(:prisma_enabled)
  @serving_config = args[:serving_config] if args.key?(:serving_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end