Class: Google::Apis::DisplayvideoV4::Advertiser

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single advertiser in Display & Video 360 (DV360).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Advertiser

Returns a new instance of Advertiser.



1299
1300
1301
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_server_configGoogle::Apis::DisplayvideoV4::AdvertiserAdServerConfig

Ad server related settings of an advertiser. Corresponds to the JSON property adServerConfig



1208
1209
1210
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1208

def ad_server_config
  @ad_server_config
end

#advertiser_idFixnum

Output only. The unique ID of the advertiser. Assigned by the system. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


1213
1214
1215
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1213

def advertiser_id
  @advertiser_id
end

#billing_configGoogle::Apis::DisplayvideoV4::AdvertiserBillingConfig

Billing related settings of an advertiser. Corresponds to the JSON property billingConfig



1218
1219
1220
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1218

def billing_config
  @billing_config
end

#contains_eu_political_adsString

Optional. Whether this advertiser contains line items that serve European Union political ads. If this field is set to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING, then the following will happen: * Any new line items created under this advertiser will be assigned DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING if not otherwise specified. * Any existing line items under this advertiser that do not have a set value be updated to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING within a day. Corresponds to the JSON property containsEuPoliticalAds

Returns:

  • (String)


1229
1230
1231
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1229

def contains_eu_political_ads
  @contains_eu_political_ads
end

#creative_configGoogle::Apis::DisplayvideoV4::AdvertiserCreativeConfig

Creatives related settings of an advertiser. Corresponds to the JSON property creativeConfig



1234
1235
1236
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1234

def creative_config
  @creative_config
end

#data_access_configGoogle::Apis::DisplayvideoV4::AdvertiserDataAccessConfig

Settings that control how advertiser related data may be accessed. Corresponds to the JSON property dataAccessConfig



1239
1240
1241
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1239

def data_access_config
  @data_access_config
end

#display_nameString

Required. The display name of the advertiser. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


1245
1246
1247
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1245

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not insertion orders and line items of the advertiser can spend their budgets and bid on inventory. * Accepted values are ENTITY_STATUS_ACTIVE, ENTITY_STATUS_PAUSED and ENTITY_STATUS_SCHEDULED_FOR_DELETION. * If set to ENTITY_STATUS_SCHEDULED_FOR_DELETION, the advertiser will be deleted 30 days from when it was first scheduled for deletion. Corresponds to the JSON property entityStatus

Returns:

  • (String)


1255
1256
1257
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1255

def entity_status
  @entity_status
end

#general_configGoogle::Apis::DisplayvideoV4::AdvertiserGeneralConfig

General settings of an advertiser. Corresponds to the JSON property generalConfig



1260
1261
1262
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1260

def general_config
  @general_config
end

#integration_detailsGoogle::Apis::DisplayvideoV4::IntegrationDetails

Integration details of an entry. Corresponds to the JSON property integrationDetails



1265
1266
1267
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1265

def integration_details
  @integration_details
end

#nameString

Output only. The resource name of the advertiser. Corresponds to the JSON property name

Returns:

  • (String)


1270
1271
1272
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1270

def name
  @name
end

#partner_idFixnum

Required. Immutable. The unique ID of the partner that the advertiser belongs to. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


1276
1277
1278
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1276

def partner_id
  @partner_id
end

#prisma_enabledBoolean Also known as: prisma_enabled?

Whether integration with Mediaocean (Prisma) is enabled. By enabling this, you agree to the following: On behalf of my company, I authorize Mediaocean ( Prisma) to send budget segment plans to Google, and I authorize Google to send corresponding reporting and invoices from DV360 to Mediaocean for the purposes of budget planning, billing, and reconciliation for this advertiser. Corresponds to the JSON property prismaEnabled

Returns:

  • (Boolean)


1285
1286
1287
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1285

def prisma_enabled
  @prisma_enabled
end

#serving_configGoogle::Apis::DisplayvideoV4::AdvertiserTargetingConfig

Targeting settings related to ad serving of an advertiser. Corresponds to the JSON property servingConfig



1291
1292
1293
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1291

def serving_config
  @serving_config
end

#update_timeString

Output only. The timestamp when the advertiser was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


1297
1298
1299
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1297

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1304

def update!(**args)
  @ad_server_config = args[:ad_server_config] if args.key?(:ad_server_config)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @billing_config = args[:billing_config] if args.key?(:billing_config)
  @contains_eu_political_ads = args[:contains_eu_political_ads] if args.key?(:contains_eu_political_ads)
  @creative_config = args[:creative_config] if args.key?(:creative_config)
  @data_access_config = args[:data_access_config] if args.key?(:data_access_config)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @general_config = args[:general_config] if args.key?(:general_config)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @name = args[:name] if args.key?(:name)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @prisma_enabled = args[:prisma_enabled] if args.key?(:prisma_enabled)
  @serving_config = args[:serving_config] if args.key?(:serving_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end