Class: Google::Apis::DisplayvideoV4::AdvertiserCreativeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Creatives related settings of an advertiser.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AdvertiserCreativeConfig

Returns a new instance of AdvertiserCreativeConfig.



1416
1417
1418
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dynamic_creative_enabledBoolean Also known as: dynamic_creative_enabled?

Whether or not the advertiser is enabled for dynamic creatives. Corresponds to the JSON property dynamicCreativeEnabled

Returns:

  • (Boolean)


1375
1376
1377
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1375

def dynamic_creative_enabled
  @dynamic_creative_enabled
end

#ias_client_idFixnum

An ID for configuring campaign monitoring provided by Integral Ad Service (IAS) . The DV360 system will append an IAS "Campaign Monitor" tag containing this ID to the creative tag. Corresponds to the JSON property iasClientId

Returns:

  • (Fixnum)


1383
1384
1385
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1383

def ias_client_id
  @ias_client_id
end

#oba_compliance_disabledBoolean Also known as: oba_compliance_disabled?

Whether or not to disable Google's About this Ad feature that adds badging (to identify the content as an ad) and transparency information (on interaction with About this Ad) to your ads for Online Behavioral Advertising (OBA) and regulatory requirements. About this Ad gives users greater control over the ads they see and helps you explain why they're seeing your ad. Learn more. If you choose to set this field to true, note that ads served through Display & Video 360 must comply to the following: * Be Online Behavioral Advertising (OBA) compliant, as per your contract with Google Marketing Platform. * In the European Economic Area ( EEA), include transparency information and a mechanism for users to report illegal content in ads. If using an alternative ad badging, transparency, and reporting solution, you must ensure it includes the required transparency information and illegal content flagging mechanism and that you notify Google of any illegal content reports using the appropriate form. Corresponds to the JSON property obaComplianceDisabled

Returns:

  • (Boolean)


1403
1404
1405
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1403

def oba_compliance_disabled
  @oba_compliance_disabled
end

#video_creative_data_sharing_authorizedBoolean Also known as: video_creative_data_sharing_authorized?

By setting this field to true, you, on behalf of your company, authorize Google to use video creatives associated with this Display & Video 360 advertiser to provide reporting and features related to the advertiser's television campaigns. Applicable only when the advertiser has a CM360 hybrid ad server configuration. Corresponds to the JSON property videoCreativeDataSharingAuthorized

Returns:

  • (Boolean)


1413
1414
1415
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1413

def video_creative_data_sharing_authorized
  @video_creative_data_sharing_authorized
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1421
1422
1423
1424
1425
1426
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1421

def update!(**args)
  @dynamic_creative_enabled = args[:dynamic_creative_enabled] if args.key?(:dynamic_creative_enabled)
  @ias_client_id = args[:ias_client_id] if args.key?(:ias_client_id)
  @oba_compliance_disabled = args[:oba_compliance_disabled] if args.key?(:oba_compliance_disabled)
  @video_creative_data_sharing_authorized = args[:video_creative_data_sharing_authorized] if args.key?(:video_creative_data_sharing_authorized)
end