Class: Google::Apis::DisplayvideoV4::AlgorithmRules

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Rule-based algorithm.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlgorithmRules

Returns a new instance of AlgorithmRules.



1615
1616
1617
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1615

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_model_idFixnum

Attribution model for the algorithm. This field is only supported for allowlisted partners. Corresponds to the JSON property attributionModelId

Returns:

  • (Fixnum)


1601
1602
1603
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1601

def attribution_model_id
  @attribution_model_id
end

#impression_signal_rulesetGoogle::Apis::DisplayvideoV4::AlgorithmRulesRuleset

A ruleset consisting of a list of rules and how to aggregate the resulting values. Corresponds to the JSON property impressionSignalRuleset



1607
1608
1609
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1607

def impression_signal_ruleset
  @impression_signal_ruleset
end

#post_impression_signal_rulesetGoogle::Apis::DisplayvideoV4::AlgorithmRulesRuleset

A ruleset consisting of a list of rules and how to aggregate the resulting values. Corresponds to the JSON property postImpressionSignalRuleset



1613
1614
1615
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1613

def post_impression_signal_ruleset
  @post_impression_signal_ruleset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1620
1621
1622
1623
1624
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1620

def update!(**args)
  @attribution_model_id = args[:attribution_model_id] if args.key?(:attribution_model_id)
  @impression_signal_ruleset = args[:impression_signal_ruleset] if args.key?(:impression_signal_ruleset)
  @post_impression_signal_ruleset = args[:post_impression_signal_ruleset] if args.key?(:post_impression_signal_ruleset)
end