Class: Google::Apis::DisplayvideoV4::AlgorithmRulesFloodlightActivityConversionSignal
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AlgorithmRulesFloodlightActivityConversionSignal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
The rule to score impressions based on Floodlight conversion events.
Instance Attribute Summary collapse
-
#conversion_counting ⇒ String
Required.
-
#counting_method ⇒ String
Required.
-
#floodlight_activity_id ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AlgorithmRulesFloodlightActivityConversionSignal
constructor
A new instance of AlgorithmRulesFloodlightActivityConversionSignal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AlgorithmRulesFloodlightActivityConversionSignal
Returns a new instance of AlgorithmRulesFloodlightActivityConversionSignal.
1746 1747 1748 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1746 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversion_counting ⇒ String
Required. The type of conversions to be used in impression value computation,
for example, post-click conversions.
Corresponds to the JSON property conversionCounting
1733 1734 1735 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1733 def conversion_counting @conversion_counting end |
#counting_method ⇒ String
Required. The way to acquire value from the floodlight activity, for example,
count of the conversion.
Corresponds to the JSON property countingMethod
1739 1740 1741 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1739 def counting_method @counting_method end |
#floodlight_activity_id ⇒ Fixnum
Required. Id of the floodlight activity.
Corresponds to the JSON property floodlightActivityId
1744 1745 1746 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1744 def floodlight_activity_id @floodlight_activity_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1751 1752 1753 1754 1755 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1751 def update!(**args) @conversion_counting = args[:conversion_counting] if args.key?(:conversion_counting) @counting_method = args[:counting_method] if args.key?(:counting_method) @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id) end |