Class: Google::Apis::DisplayvideoV4::AlgorithmRulesRuleCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Set of signal comparisons. Equivalent of an if statement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AlgorithmRulesRuleCondition

Returns a new instance of AlgorithmRulesRuleCondition.



1907
1908
1909
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#return_valueGoogle::Apis::DisplayvideoV4::AlgorithmRulesSignalValue

Adjusted value of the signal used for rule evaluation. Corresponds to the JSON property returnValue



1899
1900
1901
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1899

def return_value
  @return_value
end

#signal_comparisonsArray<Google::Apis::DisplayvideoV4::AlgorithmRulesSignalComparison>

List of comparisons that build if statement condition. The comparisons are combined into a single condition with AND logical operators. Corresponds to the JSON property signalComparisons



1905
1906
1907
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1905

def signal_comparisons
  @signal_comparisons
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1912
1913
1914
1915
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1912

def update!(**args)
  @return_value = args[:return_value] if args.key?(:return_value)
  @signal_comparisons = args[:signal_comparisons] if args.key?(:signal_comparisons)
end