Class: Google::Apis::DisplayvideoV4::AlgorithmRulesRuleCondition
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AlgorithmRulesRuleCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Set of signal comparisons. Equivalent of an if statement.
Instance Attribute Summary collapse
-
#return_value ⇒ Google::Apis::DisplayvideoV4::AlgorithmRulesSignalValue
Adjusted value of the signal used for rule evaluation.
-
#signal_comparisons ⇒ Array<Google::Apis::DisplayvideoV4::AlgorithmRulesSignalComparison>
List of comparisons that build
ifstatement condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AlgorithmRulesRuleCondition
constructor
A new instance of AlgorithmRulesRuleCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AlgorithmRulesRuleCondition
Returns a new instance of AlgorithmRulesRuleCondition.
1801 1802 1803 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1801 def initialize(**args) update!(**args) end |
Instance Attribute Details
#return_value ⇒ Google::Apis::DisplayvideoV4::AlgorithmRulesSignalValue
Adjusted value of the signal used for rule evaluation.
Corresponds to the JSON property returnValue
1793 1794 1795 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1793 def return_value @return_value end |
#signal_comparisons ⇒ Array<Google::Apis::DisplayvideoV4::AlgorithmRulesSignalComparison>
List of comparisons that build if statement condition. The comparisons are
combined into a single condition with AND logical operators.
Corresponds to the JSON property signalComparisons
1799 1800 1801 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1799 def signal_comparisons @signal_comparisons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1806 1807 1808 1809 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1806 def update!(**args) @return_value = args[:return_value] if args.key?(:return_value) @signal_comparisons = args[:signal_comparisons] if args.key?(:signal_comparisons) end |