Class: Google::Apis::DisplayvideoV4::AppAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AppAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details for assigned app targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_APP.
Instance Attribute Summary collapse
-
#app_id ⇒ String
Required.
-
#app_platform ⇒ String
Indicates the platform of the targeted app.
-
#display_name ⇒ String
Output only.
-
#negative ⇒ Boolean
(also: #negative?)
Indicates if this option is being negatively targeted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AppAssignedTargetingOptionDetails
constructor
A new instance of AppAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AppAssignedTargetingOptionDetails
Returns a new instance of AppAssignedTargetingOptionDetails.
2080 2081 2082 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
Required. The ID of the app. Android's Play store app uses bundle ID, for
example com.google.android.gm. Apple's App store app ID uses 9 digit string,
for example 422689480.
Corresponds to the JSON property appId
2060 2061 2062 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2060 def app_id @app_id end |
#app_platform ⇒ String
Indicates the platform of the targeted app. If this field is not specified,
the app platform will be assumed to be mobile (i.e., Android or iOS), and we
will derive the appropriate mobile platform from the app ID.
Corresponds to the JSON property appPlatform
2067 2068 2069 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2067 def app_platform @app_platform end |
#display_name ⇒ String
Output only. The display name of the app.
Corresponds to the JSON property displayName
2072 2073 2074 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2072 def display_name @display_name end |
#negative ⇒ Boolean Also known as: negative?
Indicates if this option is being negatively targeted.
Corresponds to the JSON property negative
2077 2078 2079 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2077 def negative @negative end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2085 2086 2087 2088 2089 2090 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2085 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @app_platform = args[:app_platform] if args.key?(:app_platform) @display_name = args[:display_name] if args.key?(:display_name) @negative = args[:negative] if args.key?(:negative) end |