Class: Google::Apis::DisplayvideoV4::AppAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for assigned app targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_APP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppAssignedTargetingOptionDetails

Returns a new instance of AppAssignedTargetingOptionDetails.



1974
1975
1976
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

Required. The ID of the app. Android's Play store app uses bundle ID, for example com.google.android.gm. Apple's App store app ID uses 9 digit string, for example 422689480. Corresponds to the JSON property appId

Returns:

  • (String)


1954
1955
1956
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1954

def app_id
  @app_id
end

#app_platformString

Indicates the platform of the targeted app. If this field is not specified, the app platform will be assumed to be mobile (i.e., Android or iOS), and we will derive the appropriate mobile platform from the app ID. Corresponds to the JSON property appPlatform

Returns:

  • (String)


1961
1962
1963
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1961

def app_platform
  @app_platform
end

#display_nameString

Output only. The display name of the app. Corresponds to the JSON property displayName

Returns:

  • (String)


1966
1967
1968
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1966

def display_name
  @display_name
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. Corresponds to the JSON property negative

Returns:

  • (Boolean)


1971
1972
1973
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1971

def negative
  @negative
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1979
1980
1981
1982
1983
1984
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 1979

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @app_platform = args[:app_platform] if args.key?(:app_platform)
  @display_name = args[:display_name] if args.key?(:display_name)
  @negative = args[:negative] if args.key?(:negative)
end