Class: Google::Apis::DisplayvideoV4::AssignedLocation
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AssignedLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
An assignment between a location list and a relevant targeting option.
Instance Attribute Summary collapse
-
#assigned_location_id ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#targeting_option_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AssignedLocation
constructor
A new instance of AssignedLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AssignedLocation
Returns a new instance of AssignedLocation.
2153 2154 2155 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2153 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assigned_location_id ⇒ Fixnum
Output only. The unique ID of the assigned location. The ID is only unique
within a location list. It may be reused in other contexts.
Corresponds to the JSON property assignedLocationId
2141 2142 2143 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2141 def assigned_location_id @assigned_location_id end |
#name ⇒ String
Output only. The resource name of the assigned location.
Corresponds to the JSON property name
2146 2147 2148 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2146 def name @name end |
#targeting_option_id ⇒ String
Required. The ID of the targeting option assigned to the location list.
Corresponds to the JSON property targetingOptionId
2151 2152 2153 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2151 def targeting_option_id @targeting_option_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2158 2159 2160 2161 2162 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2158 def update!(**args) @assigned_location_id = args[:assigned_location_id] if args.key?(:assigned_location_id) @name = args[:name] if args.key?(:name) @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id) end |