Class: Google::Apis::DisplayvideoV4::AssignedTargetingOption
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AssignedTargetingOption
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single assigned targeting option, which defines the state of a targeting option for an entity with targeting settings.
Instance Attribute Summary collapse
-
#age_range_details ⇒ Google::Apis::DisplayvideoV4::AgeRangeAssignedTargetingOptionDetails
Represents a targetable age range.
-
#app_category_details ⇒ Google::Apis::DisplayvideoV4::AppCategoryAssignedTargetingOptionDetails
Details for assigned app category targeting option.
-
#app_details ⇒ Google::Apis::DisplayvideoV4::AppAssignedTargetingOptionDetails
Details for assigned app targeting option.
-
#assigned_targeting_option_id ⇒ String
Output only.
-
#assigned_targeting_option_id_alias ⇒ String
Output only.
-
#audience_group_details ⇒ Google::Apis::DisplayvideoV4::AudienceGroupAssignedTargetingOptionDetails
Assigned audience group targeting option details.
-
#audio_content_type_details ⇒ Google::Apis::DisplayvideoV4::AudioContentTypeAssignedTargetingOptionDetails
Details for audio content type assigned targeting option.
-
#authorized_seller_status_details ⇒ Google::Apis::DisplayvideoV4::AuthorizedSellerStatusAssignedTargetingOptionDetails
Represents an assigned authorized seller status.
-
#browser_details ⇒ Google::Apis::DisplayvideoV4::BrowserAssignedTargetingOptionDetails
Details for assigned browser targeting option.
-
#business_chain_details ⇒ Google::Apis::DisplayvideoV4::BusinessChainAssignedTargetingOptionDetails
Details for assigned Business chain targeting option.
-
#carrier_and_isp_details ⇒ Google::Apis::DisplayvideoV4::CarrierAndIspAssignedTargetingOptionDetails
Details for assigned carrier and ISP targeting option.
-
#category_details ⇒ Google::Apis::DisplayvideoV4::CategoryAssignedTargetingOptionDetails
Assigned category targeting option details.
-
#channel_details ⇒ Google::Apis::DisplayvideoV4::ChannelAssignedTargetingOptionDetails
Details for assigned channel targeting option.
-
#content_duration_details ⇒ Google::Apis::DisplayvideoV4::ContentDurationAssignedTargetingOptionDetails
Details for content duration assigned targeting option.
-
#content_genre_details ⇒ Google::Apis::DisplayvideoV4::ContentGenreAssignedTargetingOptionDetails
Details for content genre assigned targeting option.
-
#content_instream_position_details ⇒ Google::Apis::DisplayvideoV4::ContentInstreamPositionAssignedTargetingOptionDetails
Assigned content instream position targeting option details.
-
#content_outstream_position_details ⇒ Google::Apis::DisplayvideoV4::ContentOutstreamPositionAssignedTargetingOptionDetails
Assigned content outstream position targeting option details.
-
#content_stream_type_details ⇒ Google::Apis::DisplayvideoV4::ContentStreamTypeAssignedTargetingOptionDetails
Details for content stream type assigned targeting option.
-
#content_theme_exclusion_details ⇒ Google::Apis::DisplayvideoV4::ContentThemeAssignedTargetingOptionDetails
Targeting details for content theme.
-
#day_and_time_details ⇒ Google::Apis::DisplayvideoV4::DayAndTimeAssignedTargetingOptionDetails
Representation of a segment of time defined on a specific day of the week and with a start and end time.
-
#device_make_model_details ⇒ Google::Apis::DisplayvideoV4::DeviceMakeModelAssignedTargetingOptionDetails
Assigned device make and model targeting option details.
-
#device_type_details ⇒ Google::Apis::DisplayvideoV4::DeviceTypeAssignedTargetingOptionDetails
Targeting details for device type.
-
#digital_content_label_exclusion_details ⇒ Google::Apis::DisplayvideoV4::DigitalContentLabelAssignedTargetingOptionDetails
Targeting details for digital content label.
-
#environment_details ⇒ Google::Apis::DisplayvideoV4::EnvironmentAssignedTargetingOptionDetails
Assigned environment targeting option details.
-
#exchange_details ⇒ Google::Apis::DisplayvideoV4::ExchangeAssignedTargetingOptionDetails
Details for assigned exchange targeting option.
-
#gender_details ⇒ Google::Apis::DisplayvideoV4::GenderAssignedTargetingOptionDetails
Details for assigned gender targeting option.
-
#geo_region_details ⇒ Google::Apis::DisplayvideoV4::GeoRegionAssignedTargetingOptionDetails
Details for assigned geographic region targeting option.
-
#household_income_details ⇒ Google::Apis::DisplayvideoV4::HouseholdIncomeAssignedTargetingOptionDetails
Details for assigned household income targeting option.
-
#inheritance ⇒ String
Output only.
-
#inventory_source_details ⇒ Google::Apis::DisplayvideoV4::InventorySourceAssignedTargetingOptionDetails
Targeting details for inventory source.
-
#inventory_source_group_details ⇒ Google::Apis::DisplayvideoV4::InventorySourceGroupAssignedTargetingOptionDetails
Targeting details for inventory source group.
-
#keyword_details ⇒ Google::Apis::DisplayvideoV4::KeywordAssignedTargetingOptionDetails
Details for assigned keyword targeting option.
-
#language_details ⇒ Google::Apis::DisplayvideoV4::LanguageAssignedTargetingOptionDetails
Details for assigned language targeting option.
-
#name ⇒ String
Output only.
-
#native_content_position_details ⇒ Google::Apis::DisplayvideoV4::NativeContentPositionAssignedTargetingOptionDetails
Details for native content position assigned targeting option.
-
#negative_keyword_list_details ⇒ Google::Apis::DisplayvideoV4::NegativeKeywordListAssignedTargetingOptionDetails
Targeting details for negative keyword list.
-
#omid_details ⇒ Google::Apis::DisplayvideoV4::OmidAssignedTargetingOptionDetails
Represents a targetable Open Measurement enabled inventory type.
-
#on_screen_position_details ⇒ Google::Apis::DisplayvideoV4::OnScreenPositionAssignedTargetingOptionDetails
On screen position targeting option details.
-
#operating_system_details ⇒ Google::Apis::DisplayvideoV4::OperatingSystemAssignedTargetingOptionDetails
Assigned operating system targeting option details.
-
#parental_status_details ⇒ Google::Apis::DisplayvideoV4::ParentalStatusAssignedTargetingOptionDetails
Details for assigned parental status targeting option.
-
#poi_details ⇒ Google::Apis::DisplayvideoV4::PoiAssignedTargetingOptionDetails
Details for assigned POI targeting option.
-
#proximity_location_list_details ⇒ Google::Apis::DisplayvideoV4::ProximityLocationListAssignedTargetingOptionDetails
Targeting details for proximity location list.
-
#regional_location_list_details ⇒ Google::Apis::DisplayvideoV4::RegionalLocationListAssignedTargetingOptionDetails
Targeting details for regional location list.
-
#sensitive_category_exclusion_details ⇒ Google::Apis::DisplayvideoV4::SensitiveCategoryAssignedTargetingOptionDetails
Targeting details for sensitive category.
-
#session_position_details ⇒ Google::Apis::DisplayvideoV4::SessionPositionAssignedTargetingOptionDetails
Details for session position assigned targeting option.
-
#sub_exchange_details ⇒ Google::Apis::DisplayvideoV4::SubExchangeAssignedTargetingOptionDetails
Details for assigned sub-exchange targeting option.
-
#targeting_type ⇒ String
Output only.
-
#third_party_verifier_details ⇒ Google::Apis::DisplayvideoV4::ThirdPartyVerifierAssignedTargetingOptionDetails
Assigned third party verifier targeting option details.
-
#url_details ⇒ Google::Apis::DisplayvideoV4::UrlAssignedTargetingOptionDetails
Details for assigned URL targeting option.
-
#user_rewarded_content_details ⇒ Google::Apis::DisplayvideoV4::UserRewardedContentAssignedTargetingOptionDetails
User rewarded content targeting option details.
-
#video_player_size_details ⇒ Google::Apis::DisplayvideoV4::VideoPlayerSizeAssignedTargetingOptionDetails
Video player size targeting option details.
-
#viewability_details ⇒ Google::Apis::DisplayvideoV4::ViewabilityAssignedTargetingOptionDetails
Assigned viewability targeting option details.
-
#youtube_channel_details ⇒ Google::Apis::DisplayvideoV4::YoutubeChannelAssignedTargetingOptionDetails
Details for YouTube channel assigned targeting option.
-
#youtube_video_details ⇒ Google::Apis::DisplayvideoV4::YoutubeVideoAssignedTargetingOptionDetails
Details for YouTube video assigned targeting option.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AssignedTargetingOption
constructor
A new instance of AssignedTargetingOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AssignedTargetingOption
Returns a new instance of AssignedTargetingOption.
2568 2569 2570 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2568 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age_range_details ⇒ Google::Apis::DisplayvideoV4::AgeRangeAssignedTargetingOptionDetails
Represents a targetable age range. This will be populated in the details field
of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_AGE_RANGE
.
Corresponds to the JSON property ageRangeDetails
2175 2176 2177 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2175 def age_range_details @age_range_details end |
#app_category_details ⇒ Google::Apis::DisplayvideoV4::AppCategoryAssignedTargetingOptionDetails
Details for assigned app category targeting option. This will be populated in
the app_category_details field of an AssignedTargetingOption when
targeting_type is TARGETING_TYPE_APP_CATEGORY.
Corresponds to the JSON property appCategoryDetails
2182 2183 2184 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2182 def app_category_details @app_category_details end |
#app_details ⇒ Google::Apis::DisplayvideoV4::AppAssignedTargetingOptionDetails
Details for assigned app targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_APP.
Corresponds to the JSON property appDetails
2189 2190 2191 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2189 def app_details @app_details end |
#assigned_targeting_option_id ⇒ String
Output only. The unique ID of the assigned targeting option. The ID is only
unique within a given resource and targeting type. It may be reused in other
contexts.
Corresponds to the JSON property assignedTargetingOptionId
2196 2197 2198 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2196 def assigned_targeting_option_id @assigned_targeting_option_id end |
#assigned_targeting_option_id_alias ⇒ String
Output only. An alias for the assigned_targeting_option_id. This value can be
used in place of assignedTargetingOptionId when retrieving or deleting
existing targeting. This field will only be supported for all assigned
targeting options of the following targeting types: *
TARGETING_TYPE_AGE_RANGE * TARGETING_TYPE_DEVICE_TYPE *
TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION * TARGETING_TYPE_ENVIRONMENT
TARGETING_TYPE_EXCHANGE*TARGETING_TYPE_GENDER*TARGETING_TYPE_HOUSEHOLD_INCOME*TARGETING_TYPE_NATIVE_CONTENT_POSITION*TARGETING_TYPE_OMID*TARGETING_TYPE_PARENTAL_STATUS*TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION*TARGETING_TYPE_VIDEO_PLAYER_SIZE*TARGETING_TYPE_VIEWABILITYThis field is also supported for line item assigned targeting options of the following targeting types: *TARGETING_TYPE_CONTENT_INSTREAM_POSITION*TARGETING_TYPE_CONTENT_OUTSTREAM_POSITIONCorresponds to the JSON propertyassignedTargetingOptionIdAlias
2214 2215 2216 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2214 def assigned_targeting_option_id_alias @assigned_targeting_option_id_alias end |
#audience_group_details ⇒ Google::Apis::DisplayvideoV4::AudienceGroupAssignedTargetingOptionDetails
Assigned audience group targeting option details. This will be populated in
the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_AUDIENCE_GROUP. The relation between each group is UNION,
except for excluded_first_and_third_party_audience_group and
excluded_google_audience_group, of which COMPLEMENT is used as an INTERSECTION
with other groups.
Corresponds to the JSON property audienceGroupDetails
2224 2225 2226 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2224 def audience_group_details @audience_group_details end |
#audio_content_type_details ⇒ Google::Apis::DisplayvideoV4::AudioContentTypeAssignedTargetingOptionDetails
Details for audio content type assigned targeting option. This will be
populated in the audio_content_type_details field when targeting_type is
TARGETING_TYPE_AUDIO_CONTENT_TYPE. Explicitly targeting all options is not
supported. Remove all audio content type targeting options to achieve this
effect.
Corresponds to the JSON property audioContentTypeDetails
2233 2234 2235 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2233 def audio_content_type_details @audio_content_type_details end |
#authorized_seller_status_details ⇒ Google::Apis::DisplayvideoV4::AuthorizedSellerStatusAssignedTargetingOptionDetails
Represents an assigned authorized seller status. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_AUTHORIZED_SELLER_STATUS. If a resource does not have an
TARGETING_TYPE_AUTHORIZED_SELLER_STATUS assigned targeting option, it is
using the "Authorized Direct Sellers and Resellers" option.
Corresponds to the JSON property authorizedSellerStatusDetails
2242 2243 2244 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2242 def @authorized_seller_status_details end |
#browser_details ⇒ Google::Apis::DisplayvideoV4::BrowserAssignedTargetingOptionDetails
Details for assigned browser targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_BROWSER.
Corresponds to the JSON property browserDetails
2249 2250 2251 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2249 def browser_details @browser_details end |
#business_chain_details ⇒ Google::Apis::DisplayvideoV4::BusinessChainAssignedTargetingOptionDetails
Details for assigned Business chain targeting option. This will be populated
in the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_BUSINESS_CHAIN.
Corresponds to the JSON property businessChainDetails
2256 2257 2258 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2256 def business_chain_details @business_chain_details end |
#carrier_and_isp_details ⇒ Google::Apis::DisplayvideoV4::CarrierAndIspAssignedTargetingOptionDetails
Details for assigned carrier and ISP targeting option. This will be populated
in the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_CARRIER_AND_ISP.
Corresponds to the JSON property carrierAndIspDetails
2263 2264 2265 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2263 def carrier_and_isp_details @carrier_and_isp_details end |
#category_details ⇒ Google::Apis::DisplayvideoV4::CategoryAssignedTargetingOptionDetails
Assigned category targeting option details. This will be populated in the
category_details field when targeting_type is TARGETING_TYPE_CATEGORY.
Corresponds to the JSON property categoryDetails
2269 2270 2271 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2269 def category_details @category_details end |
#channel_details ⇒ Google::Apis::DisplayvideoV4::ChannelAssignedTargetingOptionDetails
Details for assigned channel targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_CHANNEL.
Corresponds to the JSON property channelDetails
2276 2277 2278 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2276 def channel_details @channel_details end |
#content_duration_details ⇒ Google::Apis::DisplayvideoV4::ContentDurationAssignedTargetingOptionDetails
Details for content duration assigned targeting option. This will be populated
in the content_duration_details field when targeting_type is
TARGETING_TYPE_CONTENT_DURATION. Explicitly targeting all options is not
supported. Remove all content duration targeting options to achieve this
effect.
Corresponds to the JSON property contentDurationDetails
2285 2286 2287 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2285 def content_duration_details @content_duration_details end |
#content_genre_details ⇒ Google::Apis::DisplayvideoV4::ContentGenreAssignedTargetingOptionDetails
Details for content genre assigned targeting option. This will be populated in
the content_genre_details field when targeting_type is
TARGETING_TYPE_CONTENT_GENRE. Explicitly targeting all options is not
supported. Remove all content genre targeting options to achieve this effect.
Corresponds to the JSON property contentGenreDetails
2293 2294 2295 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2293 def content_genre_details @content_genre_details end |
#content_instream_position_details ⇒ Google::Apis::DisplayvideoV4::ContentInstreamPositionAssignedTargetingOptionDetails
Assigned content instream position targeting option details. This will be
populated in the content_instream_position_details field when targeting_type
is TARGETING_TYPE_CONTENT_INSTREAM_POSITION.
Corresponds to the JSON property contentInstreamPositionDetails
2300 2301 2302 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2300 def content_instream_position_details @content_instream_position_details end |
#content_outstream_position_details ⇒ Google::Apis::DisplayvideoV4::ContentOutstreamPositionAssignedTargetingOptionDetails
Assigned content outstream position targeting option details. This will be
populated in the content_outstream_position_details field when targeting_type
is TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION.
Corresponds to the JSON property contentOutstreamPositionDetails
2307 2308 2309 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2307 def content_outstream_position_details @content_outstream_position_details end |
#content_stream_type_details ⇒ Google::Apis::DisplayvideoV4::ContentStreamTypeAssignedTargetingOptionDetails
Details for content stream type assigned targeting option. This will be
populated in the content_stream_type_details field when targeting_type is
TARGETING_TYPE_CONTENT_STREAM_TYPE. Explicitly targeting all options is not
supported. Remove all content stream type targeting options to achieve this
effect.
Corresponds to the JSON property contentStreamTypeDetails
2316 2317 2318 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2316 def content_stream_type_details @content_stream_type_details end |
#content_theme_exclusion_details ⇒ Google::Apis::DisplayvideoV4::ContentThemeAssignedTargetingOptionDetails
Targeting details for content theme. This will be populated in the details
field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_CONTENT_THEME_EXCLUSION.
Corresponds to the JSON property contentThemeExclusionDetails
2323 2324 2325 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2323 def content_theme_exclusion_details @content_theme_exclusion_details end |
#day_and_time_details ⇒ Google::Apis::DisplayvideoV4::DayAndTimeAssignedTargetingOptionDetails
Representation of a segment of time defined on a specific day of the week and
with a start and end time. The time represented by start_hour must be before
the time represented by end_hour.
Corresponds to the JSON property dayAndTimeDetails
2330 2331 2332 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2330 def day_and_time_details @day_and_time_details end |
#device_make_model_details ⇒ Google::Apis::DisplayvideoV4::DeviceMakeModelAssignedTargetingOptionDetails
Assigned device make and model targeting option details. This will be
populated in the device_make_model_details field when targeting_type is
TARGETING_TYPE_DEVICE_MAKE_MODEL.
Corresponds to the JSON property deviceMakeModelDetails
2337 2338 2339 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2337 def device_make_model_details @device_make_model_details end |
#device_type_details ⇒ Google::Apis::DisplayvideoV4::DeviceTypeAssignedTargetingOptionDetails
Targeting details for device type. This will be populated in the details field
of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_DEVICE_TYPE.
Corresponds to the JSON property deviceTypeDetails
2344 2345 2346 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2344 def device_type_details @device_type_details end |
#digital_content_label_exclusion_details ⇒ Google::Apis::DisplayvideoV4::DigitalContentLabelAssignedTargetingOptionDetails
Targeting details for digital content label. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION.
Corresponds to the JSON property digitalContentLabelExclusionDetails
2351 2352 2353 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2351 def digital_content_label_exclusion_details @digital_content_label_exclusion_details end |
#environment_details ⇒ Google::Apis::DisplayvideoV4::EnvironmentAssignedTargetingOptionDetails
Assigned environment targeting option details. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_ENVIRONMENT.
Corresponds to the JSON property environmentDetails
2358 2359 2360 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2358 def environment_details @environment_details end |
#exchange_details ⇒ Google::Apis::DisplayvideoV4::ExchangeAssignedTargetingOptionDetails
Details for assigned exchange targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_EXCHANGE.
Corresponds to the JSON property exchangeDetails
2365 2366 2367 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2365 def exchange_details @exchange_details end |
#gender_details ⇒ Google::Apis::DisplayvideoV4::GenderAssignedTargetingOptionDetails
Details for assigned gender targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_GENDER.
Corresponds to the JSON property genderDetails
2372 2373 2374 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2372 def gender_details @gender_details end |
#geo_region_details ⇒ Google::Apis::DisplayvideoV4::GeoRegionAssignedTargetingOptionDetails
Details for assigned geographic region targeting option. This will be
populated in the details field of an AssignedTargetingOption when
targeting_type is TARGETING_TYPE_GEO_REGION.
Corresponds to the JSON property geoRegionDetails
2379 2380 2381 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2379 def geo_region_details @geo_region_details end |
#household_income_details ⇒ Google::Apis::DisplayvideoV4::HouseholdIncomeAssignedTargetingOptionDetails
Details for assigned household income targeting option. This will be populated
in the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_HOUSEHOLD_INCOME.
Corresponds to the JSON property householdIncomeDetails
2386 2387 2388 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2386 def household_income_details @household_income_details end |
#inheritance ⇒ String
Output only. The inheritance status of the assigned targeting option.
Corresponds to the JSON property inheritance
2391 2392 2393 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2391 def inheritance @inheritance end |
#inventory_source_details ⇒ Google::Apis::DisplayvideoV4::InventorySourceAssignedTargetingOptionDetails
Targeting details for inventory source. This will be populated in the details
field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_INVENTORY_SOURCE.
Corresponds to the JSON property inventorySourceDetails
2398 2399 2400 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2398 def inventory_source_details @inventory_source_details end |
#inventory_source_group_details ⇒ Google::Apis::DisplayvideoV4::InventorySourceGroupAssignedTargetingOptionDetails
Targeting details for inventory source group. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_INVENTORY_SOURCE_GROUP.
Corresponds to the JSON property inventorySourceGroupDetails
2405 2406 2407 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2405 def inventory_source_group_details @inventory_source_group_details end |
#keyword_details ⇒ Google::Apis::DisplayvideoV4::KeywordAssignedTargetingOptionDetails
Details for assigned keyword targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_KEYWORD.
Corresponds to the JSON property keywordDetails
2412 2413 2414 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2412 def keyword_details @keyword_details end |
#language_details ⇒ Google::Apis::DisplayvideoV4::LanguageAssignedTargetingOptionDetails
Details for assigned language targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_LANGUAGE.
Corresponds to the JSON property languageDetails
2419 2420 2421 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2419 def language_details @language_details end |
#name ⇒ String
Output only. The resource name for this assigned targeting option.
Corresponds to the JSON property name
2424 2425 2426 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2424 def name @name end |
#native_content_position_details ⇒ Google::Apis::DisplayvideoV4::NativeContentPositionAssignedTargetingOptionDetails
Details for native content position assigned targeting option. This will be
populated in the native_content_position_details field when targeting_type is
TARGETING_TYPE_NATIVE_CONTENT_POSITION. Explicitly targeting all options is
not supported. Remove all native content position targeting options to achieve
this effect.
Corresponds to the JSON property nativeContentPositionDetails
2433 2434 2435 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2433 def native_content_position_details @native_content_position_details end |
#negative_keyword_list_details ⇒ Google::Apis::DisplayvideoV4::NegativeKeywordListAssignedTargetingOptionDetails
Targeting details for negative keyword list. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_NEGATIVE_KEYWORD_LIST.
Corresponds to the JSON property negativeKeywordListDetails
2440 2441 2442 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2440 def negative_keyword_list_details @negative_keyword_list_details end |
#omid_details ⇒ Google::Apis::DisplayvideoV4::OmidAssignedTargetingOptionDetails
Represents a targetable Open Measurement enabled inventory type. This will be
populated in the details field of an AssignedTargetingOption when
targeting_type is TARGETING_TYPE_OMID.
Corresponds to the JSON property omidDetails
2447 2448 2449 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2447 def omid_details @omid_details end |
#on_screen_position_details ⇒ Google::Apis::DisplayvideoV4::OnScreenPositionAssignedTargetingOptionDetails
On screen position targeting option details. This will be populated in the
on_screen_position_details field when targeting_type is
TARGETING_TYPE_ON_SCREEN_POSITION.
Corresponds to the JSON property onScreenPositionDetails
2454 2455 2456 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2454 def on_screen_position_details @on_screen_position_details end |
#operating_system_details ⇒ Google::Apis::DisplayvideoV4::OperatingSystemAssignedTargetingOptionDetails
Assigned operating system targeting option details. This will be populated in
the operating_system_details field when targeting_type is
TARGETING_TYPE_OPERATING_SYSTEM.
Corresponds to the JSON property operatingSystemDetails
2461 2462 2463 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2461 def @operating_system_details end |
#parental_status_details ⇒ Google::Apis::DisplayvideoV4::ParentalStatusAssignedTargetingOptionDetails
Details for assigned parental status targeting option. This will be populated
in the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_PARENTAL_STATUS.
Corresponds to the JSON property parentalStatusDetails
2468 2469 2470 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2468 def parental_status_details @parental_status_details end |
#poi_details ⇒ Google::Apis::DisplayvideoV4::PoiAssignedTargetingOptionDetails
Details for assigned POI targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_POI.
Corresponds to the JSON property poiDetails
2475 2476 2477 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2475 def poi_details @poi_details end |
#proximity_location_list_details ⇒ Google::Apis::DisplayvideoV4::ProximityLocationListAssignedTargetingOptionDetails
Targeting details for proximity location list. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_PROXIMITY_LOCATION_LIST.
Corresponds to the JSON property proximityLocationListDetails
2482 2483 2484 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2482 def proximity_location_list_details @proximity_location_list_details end |
#regional_location_list_details ⇒ Google::Apis::DisplayvideoV4::RegionalLocationListAssignedTargetingOptionDetails
Targeting details for regional location list. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_REGIONAL_LOCATION_LIST.
Corresponds to the JSON property regionalLocationListDetails
2489 2490 2491 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2489 def regional_location_list_details @regional_location_list_details end |
#sensitive_category_exclusion_details ⇒ Google::Apis::DisplayvideoV4::SensitiveCategoryAssignedTargetingOptionDetails
Targeting details for sensitive category. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION.
Corresponds to the JSON property sensitiveCategoryExclusionDetails
2496 2497 2498 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2496 def sensitive_category_exclusion_details @sensitive_category_exclusion_details end |
#session_position_details ⇒ Google::Apis::DisplayvideoV4::SessionPositionAssignedTargetingOptionDetails
Details for session position assigned targeting option. This will be populated
in the session_position_details field when targeting_type is
TARGETING_TYPE_SESSION_POSITION.
Corresponds to the JSON property sessionPositionDetails
2503 2504 2505 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2503 def session_position_details @session_position_details end |
#sub_exchange_details ⇒ Google::Apis::DisplayvideoV4::SubExchangeAssignedTargetingOptionDetails
Details for assigned sub-exchange targeting option. This will be populated in
the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_SUB_EXCHANGE.
Corresponds to the JSON property subExchangeDetails
2510 2511 2512 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2510 def sub_exchange_details @sub_exchange_details end |
#targeting_type ⇒ String
Output only. Identifies the type of this assigned targeting option.
Corresponds to the JSON property targetingType
2515 2516 2517 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2515 def targeting_type @targeting_type end |
#third_party_verifier_details ⇒ Google::Apis::DisplayvideoV4::ThirdPartyVerifierAssignedTargetingOptionDetails
Assigned third party verifier targeting option details. This will be populated
in the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_THIRD_PARTY_VERIFIER.
Corresponds to the JSON property thirdPartyVerifierDetails
2522 2523 2524 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2522 def third_party_verifier_details @third_party_verifier_details end |
#url_details ⇒ Google::Apis::DisplayvideoV4::UrlAssignedTargetingOptionDetails
Details for assigned URL targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_URL.
Corresponds to the JSON property urlDetails
2529 2530 2531 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2529 def url_details @url_details end |
#user_rewarded_content_details ⇒ Google::Apis::DisplayvideoV4::UserRewardedContentAssignedTargetingOptionDetails
User rewarded content targeting option details. This will be populated in the
user_rewarded_content_details field when targeting_type is
TARGETING_TYPE_USER_REWARDED_CONTENT.
Corresponds to the JSON property userRewardedContentDetails
2536 2537 2538 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2536 def user_rewarded_content_details @user_rewarded_content_details end |
#video_player_size_details ⇒ Google::Apis::DisplayvideoV4::VideoPlayerSizeAssignedTargetingOptionDetails
Video player size targeting option details. This will be populated in the
video_player_size_details field when targeting_type is
TARGETING_TYPE_VIDEO_PLAYER_SIZE. Explicitly targeting all options is not
supported. Remove all video player size targeting options to achieve this
effect.
Corresponds to the JSON property videoPlayerSizeDetails
2545 2546 2547 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2545 def video_player_size_details @video_player_size_details end |
#viewability_details ⇒ Google::Apis::DisplayvideoV4::ViewabilityAssignedTargetingOptionDetails
Assigned viewability targeting option details. This will be populated in the
viewability_details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_VIEWABILITY.
Corresponds to the JSON property viewabilityDetails
2552 2553 2554 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2552 def viewability_details @viewability_details end |
#youtube_channel_details ⇒ Google::Apis::DisplayvideoV4::YoutubeChannelAssignedTargetingOptionDetails
Details for YouTube channel assigned targeting option. This will be populated
in the youtube_channel_details field when targeting_type is
TARGETING_TYPE_YOUTUBE_CHANNEL.
Corresponds to the JSON property youtubeChannelDetails
2559 2560 2561 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2559 def youtube_channel_details @youtube_channel_details end |
#youtube_video_details ⇒ Google::Apis::DisplayvideoV4::YoutubeVideoAssignedTargetingOptionDetails
Details for YouTube video assigned targeting option. This will be populated in
the youtube_video_details field when targeting_type is
TARGETING_TYPE_YOUTUBE_VIDEO.
Corresponds to the JSON property youtubeVideoDetails
2566 2567 2568 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2566 def youtube_video_details @youtube_video_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 2620 2621 2622 2623 2624 2625 2626 2627 2628 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2573 def update!(**args) @age_range_details = args[:age_range_details] if args.key?(:age_range_details) @app_category_details = args[:app_category_details] if args.key?(:app_category_details) @app_details = args[:app_details] if args.key?(:app_details) @assigned_targeting_option_id = args[:assigned_targeting_option_id] if args.key?(:assigned_targeting_option_id) @assigned_targeting_option_id_alias = args[:assigned_targeting_option_id_alias] if args.key?(:assigned_targeting_option_id_alias) @audience_group_details = args[:audience_group_details] if args.key?(:audience_group_details) @audio_content_type_details = args[:audio_content_type_details] if args.key?(:audio_content_type_details) @authorized_seller_status_details = args[:authorized_seller_status_details] if args.key?(:authorized_seller_status_details) @browser_details = args[:browser_details] if args.key?(:browser_details) @business_chain_details = args[:business_chain_details] if args.key?(:business_chain_details) @carrier_and_isp_details = args[:carrier_and_isp_details] if args.key?(:carrier_and_isp_details) @category_details = args[:category_details] if args.key?(:category_details) @channel_details = args[:channel_details] if args.key?(:channel_details) @content_duration_details = args[:content_duration_details] if args.key?(:content_duration_details) @content_genre_details = args[:content_genre_details] if args.key?(:content_genre_details) @content_instream_position_details = args[:content_instream_position_details] if args.key?(:content_instream_position_details) @content_outstream_position_details = args[:content_outstream_position_details] if args.key?(:content_outstream_position_details) @content_stream_type_details = args[:content_stream_type_details] if args.key?(:content_stream_type_details) @content_theme_exclusion_details = args[:content_theme_exclusion_details] if args.key?(:content_theme_exclusion_details) @day_and_time_details = args[:day_and_time_details] if args.key?(:day_and_time_details) @device_make_model_details = args[:device_make_model_details] if args.key?(:device_make_model_details) @device_type_details = args[:device_type_details] if args.key?(:device_type_details) @digital_content_label_exclusion_details = args[:digital_content_label_exclusion_details] if args.key?(:digital_content_label_exclusion_details) @environment_details = args[:environment_details] if args.key?(:environment_details) @exchange_details = args[:exchange_details] if args.key?(:exchange_details) @gender_details = args[:gender_details] if args.key?(:gender_details) @geo_region_details = args[:geo_region_details] if args.key?(:geo_region_details) @household_income_details = args[:household_income_details] if args.key?(:household_income_details) @inheritance = args[:inheritance] if args.key?(:inheritance) @inventory_source_details = args[:inventory_source_details] if args.key?(:inventory_source_details) @inventory_source_group_details = args[:inventory_source_group_details] if args.key?(:inventory_source_group_details) @keyword_details = args[:keyword_details] if args.key?(:keyword_details) @language_details = args[:language_details] if args.key?(:language_details) @name = args[:name] if args.key?(:name) @native_content_position_details = args[:native_content_position_details] if args.key?(:native_content_position_details) @negative_keyword_list_details = args[:negative_keyword_list_details] if args.key?(:negative_keyword_list_details) @omid_details = args[:omid_details] if args.key?(:omid_details) @on_screen_position_details = args[:on_screen_position_details] if args.key?(:on_screen_position_details) @operating_system_details = args[:operating_system_details] if args.key?(:operating_system_details) @parental_status_details = args[:parental_status_details] if args.key?(:parental_status_details) @poi_details = args[:poi_details] if args.key?(:poi_details) @proximity_location_list_details = args[:proximity_location_list_details] if args.key?(:proximity_location_list_details) @regional_location_list_details = args[:regional_location_list_details] if args.key?(:regional_location_list_details) @sensitive_category_exclusion_details = args[:sensitive_category_exclusion_details] if args.key?(:sensitive_category_exclusion_details) @session_position_details = args[:session_position_details] if args.key?(:session_position_details) @sub_exchange_details = args[:sub_exchange_details] if args.key?(:sub_exchange_details) @targeting_type = args[:targeting_type] if args.key?(:targeting_type) @third_party_verifier_details = args[:third_party_verifier_details] if args.key?(:third_party_verifier_details) @url_details = args[:url_details] if args.key?(:url_details) @user_rewarded_content_details = args[:user_rewarded_content_details] if args.key?(:user_rewarded_content_details) @video_player_size_details = args[:video_player_size_details] if args.key?(:video_player_size_details) @viewability_details = args[:viewability_details] if args.key?(:viewability_details) @youtube_channel_details = args[:youtube_channel_details] if args.key?(:youtube_channel_details) @youtube_video_details = args[:youtube_video_details] if args.key?(:youtube_video_details) end |