Class: Google::Apis::DisplayvideoV4::AudienceGroupAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AudienceGroupAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Assigned audience group targeting option details. This will be populated in
the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_AUDIENCE_GROUP. The relation between each group is UNION,
except for excluded_first_and_third_party_audience_group and
excluded_google_audience_group, of which COMPLEMENT is used as an INTERSECTION
with other groups.
Instance Attribute Summary collapse
-
#excluded_first_party_and_partner_audience_group ⇒ Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceGroup
Details of first party and partner audience group.
-
#excluded_google_audience_group ⇒ Google::Apis::DisplayvideoV4::GoogleAudienceGroup
Details of Google audience group.
-
#included_combined_audience_group ⇒ Google::Apis::DisplayvideoV4::CombinedAudienceGroup
Details of combined audience group.
-
#included_custom_list_group ⇒ Google::Apis::DisplayvideoV4::CustomListGroup
Details of custom list group.
-
#included_first_party_and_partner_audience_groups ⇒ Array<Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceGroup>
Optional.
-
#included_google_audience_group ⇒ Google::Apis::DisplayvideoV4::GoogleAudienceGroup
Details of Google audience group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AudienceGroupAssignedTargetingOptionDetails
constructor
A new instance of AudienceGroupAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AudienceGroupAssignedTargetingOptionDetails
Returns a new instance of AudienceGroupAssignedTargetingOptionDetails.
2839 2840 2841 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#excluded_first_party_and_partner_audience_group ⇒ Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceGroup
Details of first party and partner audience group. All first party and partner
audience targeting settings are logically ‘OR’ of each other.
Corresponds to the JSON property excludedFirstPartyAndPartnerAudienceGroup
2803 2804 2805 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2803 def excluded_first_party_and_partner_audience_group @excluded_first_party_and_partner_audience_group end |
#excluded_google_audience_group ⇒ Google::Apis::DisplayvideoV4::GoogleAudienceGroup
Details of Google audience group. All Google audience targeting settings are
logically ‘OR’ of each other.
Corresponds to the JSON property excludedGoogleAudienceGroup
2809 2810 2811 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2809 def excluded_google_audience_group @excluded_google_audience_group end |
#included_combined_audience_group ⇒ Google::Apis::DisplayvideoV4::CombinedAudienceGroup
Details of combined audience group. All combined audience targeting settings
are logically ‘OR’ of each other.
Corresponds to the JSON property includedCombinedAudienceGroup
2815 2816 2817 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2815 def included_combined_audience_group @included_combined_audience_group end |
#included_custom_list_group ⇒ Google::Apis::DisplayvideoV4::CustomListGroup
Details of custom list group. All custom list targeting settings are logically
‘OR’ of each other.
Corresponds to the JSON property includedCustomListGroup
2821 2822 2823 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2821 def included_custom_list_group @included_custom_list_group end |
#included_first_party_and_partner_audience_groups ⇒ Array<Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceGroup>
Optional. The first party and partner audience ids and recencies of included
first party and partner audience groups. Each first party and partner audience
group contains first party and partner audience ids only. The relation between
each first party and partner audience group is INTERSECTION, and the result is
UNION'ed with other audience groups. Repeated groups with the same settings
will be ignored.
Corresponds to the JSON property includedFirstPartyAndPartnerAudienceGroups
2831 2832 2833 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2831 def included_first_party_and_partner_audience_groups @included_first_party_and_partner_audience_groups end |
#included_google_audience_group ⇒ Google::Apis::DisplayvideoV4::GoogleAudienceGroup
Details of Google audience group. All Google audience targeting settings are
logically ‘OR’ of each other.
Corresponds to the JSON property includedGoogleAudienceGroup
2837 2838 2839 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2837 def included_google_audience_group @included_google_audience_group end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2844 2845 2846 2847 2848 2849 2850 2851 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2844 def update!(**args) @excluded_first_party_and_partner_audience_group = args[:excluded_first_party_and_partner_audience_group] if args.key?(:excluded_first_party_and_partner_audience_group) @excluded_google_audience_group = args[:excluded_google_audience_group] if args.key?(:excluded_google_audience_group) @included_combined_audience_group = args[:included_combined_audience_group] if args.key?(:included_combined_audience_group) @included_custom_list_group = args[:included_custom_list_group] if args.key?(:included_custom_list_group) @included_first_party_and_partner_audience_groups = args[:included_first_party_and_partner_audience_groups] if args.key?(:included_first_party_and_partner_audience_groups) @included_google_audience_group = args[:included_google_audience_group] if args.key?(:included_google_audience_group) end |