Class: Google::Apis::DisplayvideoV4::AudioAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for an audio ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AudioAd

Returns a new instance of AudioAd.



2757
2758
2759
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2757

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_urlString

The webpage address that appears with the ad. Corresponds to the JSON property displayUrl

Returns:

  • (String)


2740
2741
2742
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2740

def display_url
  @display_url
end

#final_urlString

The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


2745
2746
2747
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2745

def final_url
  @final_url
end

#tracking_urlString

The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


2750
2751
2752
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2750

def tracking_url
  @tracking_url
end

#videoGoogle::Apis::DisplayvideoV4::YoutubeVideoDetails

Details of a YouTube video. Corresponds to the JSON property video



2755
2756
2757
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2755

def video
  @video
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2762
2763
2764
2765
2766
2767
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2762

def update!(**args)
  @display_url = args[:display_url] if args.key?(:display_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @video = args[:video] if args.key?(:video)
end