Class: Google::Apis::DisplayvideoV4::AuditAdvertiserResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::AuditAdvertiserResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Response message for AdvertiserService.AuditAdvertiser.
Instance Attribute Summary collapse
-
#ad_group_criteria_count ⇒ Fixnum
The number of individual targeting options from the following targeting types that are assigned to a line item under this advertiser.
-
#campaign_criteria_count ⇒ Fixnum
The number of individual targeting options from the following targeting types that are assigned to a line item under this advertiser.
-
#channels_count ⇒ Fixnum
The number of channels created under this advertiser.
-
#negative_keyword_lists_count ⇒ Fixnum
The number of negative keyword lists created under this advertiser.
-
#negatively_targeted_channels_count ⇒ Fixnum
The number of negatively targeted channels created under this advertiser.
-
#used_campaigns_count ⇒ Fixnum
The number of ACTIVE and PAUSED campaigns under this advertiser.
-
#used_insertion_orders_count ⇒ Fixnum
The number of ACTIVE, PAUSED and DRAFT insertion orders under this advertiser.
-
#used_line_items_count ⇒ Fixnum
The number of ACTIVE, PAUSED, and DRAFT line items under this advertiser.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuditAdvertiserResponse
constructor
A new instance of AuditAdvertiserResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuditAdvertiserResponse
Returns a new instance of AuditAdvertiserResponse.
3024 3025 3026 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3024 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_group_criteria_count ⇒ Fixnum
The number of individual targeting options from the following targeting types
that are assigned to a line item under this advertiser. These individual
targeting options count towards the limit of 4500000 ad group targeting
options per advertiser. Qualifying Targeting types: * Channels, URLs, apps,
and collections * Demographic * Google Audiences, including Affinity, Custom
Affinity, and In-market audiences * Inventory source * Keyword * Mobile app
category * User lists * Video targeting * Viewability
Corresponds to the JSON property adGroupCriteriaCount
2972 2973 2974 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2972 def ad_group_criteria_count @ad_group_criteria_count end |
#campaign_criteria_count ⇒ Fixnum
The number of individual targeting options from the following targeting types
that are assigned to a line item under this advertiser. These individual
targeting options count towards the limit of 900000 campaign targeting options
per advertiser. Qualifying Targeting types: * Position * Browser * Connection
speed * Day and time * Device and operating system * Digital content label *
Sensitive categories * Environment * Geography, including business chains and
proximity * ISP * Language * Third-party verification
Corresponds to the JSON property campaignCriteriaCount
2983 2984 2985 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2983 def campaign_criteria_count @campaign_criteria_count end |
#channels_count ⇒ Fixnum
The number of channels created under this advertiser. These channels count
towards the limit of 1000 channels per advertiser.
Corresponds to the JSON property channelsCount
2989 2990 2991 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2989 def channels_count @channels_count end |
#negative_keyword_lists_count ⇒ Fixnum
The number of negative keyword lists created under this advertiser. These
negative keyword lists count towards the limit of 20 negative keyword lists
per advertiser.
Corresponds to the JSON property negativeKeywordListsCount
2996 2997 2998 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2996 def negative_keyword_lists_count @negative_keyword_lists_count end |
#negatively_targeted_channels_count ⇒ Fixnum
The number of negatively targeted channels created under this advertiser.
These negatively targeted channels count towards the limit of 5 negatively
targeted channels per advertiser.
Corresponds to the JSON property negativelyTargetedChannelsCount
3003 3004 3005 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3003 def negatively_targeted_channels_count @negatively_targeted_channels_count end |
#used_campaigns_count ⇒ Fixnum
The number of ACTIVE and PAUSED campaigns under this advertiser. These
campaigns count towards the limit of 9999 campaigns per advertiser.
Corresponds to the JSON property usedCampaignsCount
3009 3010 3011 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3009 def used_campaigns_count @used_campaigns_count end |
#used_insertion_orders_count ⇒ Fixnum
The number of ACTIVE, PAUSED and DRAFT insertion orders under this advertiser.
These insertion orders count towards the limit of 9999 insertion orders per
advertiser.
Corresponds to the JSON property usedInsertionOrdersCount
3016 3017 3018 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3016 def used_insertion_orders_count @used_insertion_orders_count end |
#used_line_items_count ⇒ Fixnum
The number of ACTIVE, PAUSED, and DRAFT line items under this advertiser.
These line items count towards the limit of 9999 line items per advertiser.
Corresponds to the JSON property usedLineItemsCount
3022 3023 3024 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3022 def used_line_items_count @used_line_items_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3029 def update!(**args) @ad_group_criteria_count = args[:ad_group_criteria_count] if args.key?(:ad_group_criteria_count) @campaign_criteria_count = args[:campaign_criteria_count] if args.key?(:campaign_criteria_count) @channels_count = args[:channels_count] if args.key?(:channels_count) @negative_keyword_lists_count = args[:negative_keyword_lists_count] if args.key?(:negative_keyword_lists_count) @negatively_targeted_channels_count = args[:negatively_targeted_channels_count] if args.key?(:negatively_targeted_channels_count) @used_campaigns_count = args[:used_campaigns_count] if args.key?(:used_campaigns_count) @used_insertion_orders_count = args[:used_insertion_orders_count] if args.key?(:used_insertion_orders_count) @used_line_items_count = args[:used_line_items_count] if args.key?(:used_line_items_count) end |