Class: Google::Apis::DisplayvideoV4::BiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Settings that control the bid strategy. Bid strategy determines the bid price.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BiddingStrategy

Returns a new instance of BiddingStrategy.



3011
3012
3013
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3011

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#demand_gen_bidGoogle::Apis::DisplayvideoV4::DemandGenBiddingStrategy

Settings that control the bid strategy for Demand Gen resources. Corresponds to the JSON property demandGenBid



2987
2988
2989
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2987

def demand_gen_bid
  @demand_gen_bid
end

#fixed_bidGoogle::Apis::DisplayvideoV4::FixedBidStrategy

A strategy that uses a fixed bidding price. Corresponds to the JSON property fixedBid



2992
2993
2994
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2992

def fixed_bid
  @fixed_bid
end

#maximize_spend_auto_bidGoogle::Apis::DisplayvideoV4::MaximizeSpendBidStrategy

A strategy that automatically adjusts the bid to optimize a specified performance goal while spending the full budget. Corresponds to the JSON property maximizeSpendAutoBid



2998
2999
3000
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2998

def maximize_spend_auto_bid
  @maximize_spend_auto_bid
end

#performance_goal_auto_bidGoogle::Apis::DisplayvideoV4::PerformanceGoalBidStrategy

A strategy that automatically adjusts the bid to meet or beat a specified performance goal. Corresponds to the JSON property performanceGoalAutoBid



3004
3005
3006
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3004

def performance_goal_auto_bid
  @performance_goal_auto_bid
end

#youtube_and_partners_bidGoogle::Apis::DisplayvideoV4::YoutubeAndPartnersBiddingStrategy

Settings that control the bid strategy for YouTube and Partners resources. Corresponds to the JSON property youtubeAndPartnersBid



3009
3010
3011
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3009

def youtube_and_partners_bid
  @youtube_and_partners_bid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3016
3017
3018
3019
3020
3021
3022
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3016

def update!(**args)
  @demand_gen_bid = args[:demand_gen_bid] if args.key?(:demand_gen_bid)
  @fixed_bid = args[:fixed_bid] if args.key?(:fixed_bid)
  @maximize_spend_auto_bid = args[:maximize_spend_auto_bid] if args.key?(:maximize_spend_auto_bid)
  @performance_goal_auto_bid = args[:performance_goal_auto_bid] if args.key?(:performance_goal_auto_bid)
  @youtube_and_partners_bid = args[:youtube_and_partners_bid] if args.key?(:youtube_and_partners_bid)
end