Class: Google::Apis::DisplayvideoV4::BiddingStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Settings that control the bid strategy. Bid strategy determines the bid price.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BiddingStrategy

Returns a new instance of BiddingStrategy.



3003
3004
3005
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#demand_gen_bidGoogle::Apis::DisplayvideoV4::DemandGenBiddingStrategy

Settings that control the bid strategy for Demand Gen resources. Corresponds to the JSON property demandGenBid



2979
2980
2981
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2979

def demand_gen_bid
  @demand_gen_bid
end

#fixed_bidGoogle::Apis::DisplayvideoV4::FixedBidStrategy

A strategy that uses a fixed bidding price. Corresponds to the JSON property fixedBid



2984
2985
2986
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2984

def fixed_bid
  @fixed_bid
end

#maximize_spend_auto_bidGoogle::Apis::DisplayvideoV4::MaximizeSpendBidStrategy

A strategy that automatically adjusts the bid to optimize a specified performance goal while spending the full budget. Corresponds to the JSON property maximizeSpendAutoBid



2990
2991
2992
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2990

def maximize_spend_auto_bid
  @maximize_spend_auto_bid
end

#performance_goal_auto_bidGoogle::Apis::DisplayvideoV4::PerformanceGoalBidStrategy

A strategy that automatically adjusts the bid to meet or beat a specified performance goal. Corresponds to the JSON property performanceGoalAutoBid



2996
2997
2998
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 2996

def performance_goal_auto_bid
  @performance_goal_auto_bid
end

#youtube_and_partners_bidGoogle::Apis::DisplayvideoV4::YoutubeAndPartnersBiddingStrategy

Settings that control the bid strategy for YouTube and Partners resources. Corresponds to the JSON property youtubeAndPartnersBid



3001
3002
3003
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3001

def youtube_and_partners_bid
  @youtube_and_partners_bid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3008
3009
3010
3011
3012
3013
3014
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3008

def update!(**args)
  @demand_gen_bid = args[:demand_gen_bid] if args.key?(:demand_gen_bid)
  @fixed_bid = args[:fixed_bid] if args.key?(:fixed_bid)
  @maximize_spend_auto_bid = args[:maximize_spend_auto_bid] if args.key?(:maximize_spend_auto_bid)
  @performance_goal_auto_bid = args[:performance_goal_auto_bid] if args.key?(:performance_goal_auto_bid)
  @youtube_and_partners_bid = args[:youtube_and_partners_bid] if args.key?(:youtube_and_partners_bid)
end