Class: Google::Apis::DisplayvideoV4::BrowserAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for assigned browser targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_BROWSER.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BrowserAssignedTargetingOptionDetails

Returns a new instance of BrowserAssignedTargetingOptionDetails.



3155
3156
3157
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the browser. Corresponds to the JSON property displayName

Returns:

  • (String)


3140
3141
3142
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3140

def display_name
  @display_name
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. All assigned browser targeting options on the same resource must have the same value for this field. Corresponds to the JSON property negative

Returns:

  • (Boolean)


3146
3147
3148
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3146

def negative
  @negative
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_BROWSER. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


3153
3154
3155
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3153

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3160
3161
3162
3163
3164
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3160

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @negative = args[:negative] if args.key?(:negative)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end