Class: Google::Apis::DisplayvideoV4::BulkEditAdGroupAssignedTargetingOptionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::BulkEditAdGroupAssignedTargetingOptionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Response message for BulkEditAssignedTargetingOptions.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::DisplayvideoV4::Status>
Output only.
-
#failed_ad_group_ids ⇒ Array<Fixnum>
Output only.
-
#updated_ad_group_ids ⇒ Array<Fixnum>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkEditAdGroupAssignedTargetingOptionsResponse
constructor
A new instance of BulkEditAdGroupAssignedTargetingOptionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkEditAdGroupAssignedTargetingOptionsResponse
Returns a new instance of BulkEditAdGroupAssignedTargetingOptionsResponse.
3230 3231 3232 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3230 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::DisplayvideoV4::Status>
Output only. The error information for each ad group that failed to update.
Corresponds to the JSON property errors
3218 3219 3220 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3218 def errors @errors end |
#failed_ad_group_ids ⇒ Array<Fixnum>
Output only. The IDs of the ad groups which failed to update.
Corresponds to the JSON property failedAdGroupIds
3223 3224 3225 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3223 def failed_ad_group_ids @failed_ad_group_ids end |
#updated_ad_group_ids ⇒ Array<Fixnum>
Output only. The IDs of the ad groups which were successfully updated.
Corresponds to the JSON property updatedAdGroupIds
3228 3229 3230 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3228 def updated_ad_group_ids @updated_ad_group_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3235 3236 3237 3238 3239 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3235 def update!(**args) @errors = args[:errors] if args.key?(:errors) @failed_ad_group_ids = args[:failed_ad_group_ids] if args.key?(:failed_ad_group_ids) @updated_ad_group_ids = args[:updated_ad_group_ids] if args.key?(:updated_ad_group_ids) end |