Class: Google::Apis::DisplayvideoV4::BulkEditAssignedInventorySourcesRequest
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::BulkEditAssignedInventorySourcesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Request message for AssignedInventorySourceService.BulkEdit.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
The ID of the advertiser that owns the parent inventory source group.
-
#created_assigned_inventory_sources ⇒ Array<Google::Apis::DisplayvideoV4::AssignedInventorySource>
The assigned inventory sources to create in bulk, specified as a list of AssignedInventorySources.
-
#deleted_assigned_inventory_sources ⇒ Array<Fixnum>
The IDs of the assigned inventory sources to delete in bulk, specified as a list of assigned_inventory_source_ids.
-
#partner_id ⇒ Fixnum
The ID of the partner that owns the inventory source group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkEditAssignedInventorySourcesRequest
constructor
A new instance of BulkEditAssignedInventorySourcesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkEditAssignedInventorySourcesRequest
Returns a new instance of BulkEditAssignedInventorySourcesRequest.
3331 3332 3333 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
The ID of the advertiser that owns the parent inventory source group. The
parent partner does not have access to these assigned inventory sources.
Corresponds to the JSON property advertiserId
3311 3312 3313 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3311 def advertiser_id @advertiser_id end |
#created_assigned_inventory_sources ⇒ Array<Google::Apis::DisplayvideoV4::AssignedInventorySource>
The assigned inventory sources to create in bulk, specified as a list of
AssignedInventorySources.
Corresponds to the JSON property createdAssignedInventorySources
3317 3318 3319 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3317 def created_assigned_inventory_sources @created_assigned_inventory_sources end |
#deleted_assigned_inventory_sources ⇒ Array<Fixnum>
The IDs of the assigned inventory sources to delete in bulk, specified as a
list of assigned_inventory_source_ids.
Corresponds to the JSON property deletedAssignedInventorySources
3323 3324 3325 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3323 def deleted_assigned_inventory_sources @deleted_assigned_inventory_sources end |
#partner_id ⇒ Fixnum
The ID of the partner that owns the inventory source group. Only this partner
has write access to these assigned inventory sources.
Corresponds to the JSON property partnerId
3329 3330 3331 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3329 def partner_id @partner_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3336 3337 3338 3339 3340 3341 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3336 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @created_assigned_inventory_sources = args[:created_assigned_inventory_sources] if args.key?(:created_assigned_inventory_sources) @deleted_assigned_inventory_sources = args[:deleted_assigned_inventory_sources] if args.key?(:deleted_assigned_inventory_sources) @partner_id = args[:partner_id] if args.key?(:partner_id) end |