Class: Google::Apis::DisplayvideoV4::BulkEditAssignedInventorySourcesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for AssignedInventorySourceService.BulkEdit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkEditAssignedInventorySourcesRequest

Returns a new instance of BulkEditAssignedInventorySourcesRequest.



3323
3324
3325
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3323

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

The ID of the advertiser that owns the parent inventory source group. The parent partner does not have access to these assigned inventory sources. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


3303
3304
3305
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3303

def advertiser_id
  @advertiser_id
end

#created_assigned_inventory_sourcesArray<Google::Apis::DisplayvideoV4::AssignedInventorySource>

The assigned inventory sources to create in bulk, specified as a list of AssignedInventorySources. Corresponds to the JSON property createdAssignedInventorySources



3309
3310
3311
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3309

def created_assigned_inventory_sources
  @created_assigned_inventory_sources
end

#deleted_assigned_inventory_sourcesArray<Fixnum>

The IDs of the assigned inventory sources to delete in bulk, specified as a list of assigned_inventory_source_ids. Corresponds to the JSON property deletedAssignedInventorySources

Returns:

  • (Array<Fixnum>)


3315
3316
3317
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3315

def deleted_assigned_inventory_sources
  @deleted_assigned_inventory_sources
end

#partner_idFixnum

The ID of the partner that owns the inventory source group. Only this partner has write access to these assigned inventory sources. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


3321
3322
3323
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3321

def partner_id
  @partner_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3328
3329
3330
3331
3332
3333
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3328

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @created_assigned_inventory_sources = args[:created_assigned_inventory_sources] if args.key?(:created_assigned_inventory_sources)
  @deleted_assigned_inventory_sources = args[:deleted_assigned_inventory_sources] if args.key?(:deleted_assigned_inventory_sources)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
end