Class: Google::Apis::DisplayvideoV4::BulkEditNegativeKeywordsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for NegativeKeywordService.BulkEditNegativeKeywords.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkEditNegativeKeywordsRequest

Returns a new instance of BulkEditNegativeKeywordsRequest.



3589
3590
3591
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#created_negative_keywordsArray<Google::Apis::DisplayvideoV4::NegativeKeyword>

The negative keywords to create in batch, specified as a list of NegativeKeywords. Corresponds to the JSON property createdNegativeKeywords



3581
3582
3583
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3581

def created_negative_keywords
  @created_negative_keywords
end

#deleted_negative_keywordsArray<String>

The negative keywords to delete in batch, specified as a list of keyword_values. Corresponds to the JSON property deletedNegativeKeywords

Returns:

  • (Array<String>)


3587
3588
3589
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3587

def deleted_negative_keywords
  @deleted_negative_keywords
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3594
3595
3596
3597
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3594

def update!(**args)
  @created_negative_keywords = args[:created_negative_keywords] if args.key?(:created_negative_keywords)
  @deleted_negative_keywords = args[:deleted_negative_keywords] if args.key?(:deleted_negative_keywords)
end