Class: Google::Apis::DisplayvideoV4::BulkListAdGroupAssignedTargetingOptionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkListAdGroupAssignedTargetingOptionsResponse

Returns a new instance of BulkListAdGroupAssignedTargetingOptionsResponse.



3851
3852
3853
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_assigned_targeting_optionsArray<Google::Apis::DisplayvideoV4::AdGroupAssignedTargetingOption>

The list of wrapper objects, each providing an assigned targeting option and the ad group it is assigned to. This list will be absent if empty. Corresponds to the JSON property adGroupAssignedTargetingOptions



3840
3841
3842
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3840

def ad_group_assigned_targeting_options
  @ad_group_assigned_targeting_options
end

#next_page_tokenString

A token identifying the next page of results. This value should be specified as the pageToken in a subsequent call to BulkListAdGroupAssignedTargetingOptions to fetch the next page of results. This token will be absent if there are no more AdGroupAssignedTargetingOption resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3849
3850
3851
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3849

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3856
3857
3858
3859
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3856

def update!(**args)
  @ad_group_assigned_targeting_options = args[:ad_group_assigned_targeting_options] if args.key?(:ad_group_assigned_targeting_options)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end