Class: Google::Apis::DisplayvideoV4::BulkListAssignedTargetingOptionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::BulkListAssignedTargetingOptionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#line_item_assigned_targeting_options ⇒ Array<Google::Apis::DisplayvideoV4::LineItemAssignedTargetingOption>
The list of wrapper objects, each providing an assigned targeting option and the line item it is assigned to.
-
#next_page_token ⇒ String
A token identifying the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkListAssignedTargetingOptionsResponse
constructor
A new instance of BulkListAssignedTargetingOptionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkListAssignedTargetingOptionsResponse
Returns a new instance of BulkListAssignedTargetingOptionsResponse.
3915 3916 3917 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3915 def initialize(**args) update!(**args) end |
Instance Attribute Details
#line_item_assigned_targeting_options ⇒ Array<Google::Apis::DisplayvideoV4::LineItemAssignedTargetingOption>
The list of wrapper objects, each providing an assigned targeting option and
the line item it is assigned to. This list will be absent if empty.
Corresponds to the JSON property lineItemAssignedTargetingOptions
3905 3906 3907 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3905 def @line_item_assigned_targeting_options end |
#next_page_token ⇒ String
A token identifying the next page of results. This value should be specified
as the pageToken in a subsequent call to BulkListAssignedTargetingOptions to
fetch the next page of results. This token will be absent if there are no more
line_item_assigned_targeting_options to return.
Corresponds to the JSON property nextPageToken
3913 3914 3915 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3913 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3920 3921 3922 3923 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3920 def update!(**args) @line_item_assigned_targeting_options = args[:line_item_assigned_targeting_options] if args.key?(:line_item_assigned_targeting_options) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |