Class: Google::Apis::DisplayvideoV4::BulkListAssignedTargetingOptionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::BulkListAssignedTargetingOptionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#line_item_assigned_targeting_options ⇒ Array<Google::Apis::DisplayvideoV4::LineItemAssignedTargetingOption>
The list of wrapper objects, each providing an assigned targeting option and the line item it is assigned to.
-
#next_page_token ⇒ String
A token identifying the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkListAssignedTargetingOptionsResponse
constructor
A new instance of BulkListAssignedTargetingOptionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkListAssignedTargetingOptionsResponse
Returns a new instance of BulkListAssignedTargetingOptionsResponse.
3909 3910 3911 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3909 def initialize(**args) update!(**args) end |
Instance Attribute Details
#line_item_assigned_targeting_options ⇒ Array<Google::Apis::DisplayvideoV4::LineItemAssignedTargetingOption>
The list of wrapper objects, each providing an assigned targeting option and
the line item it is assigned to. This list will be absent if empty.
Corresponds to the JSON property lineItemAssignedTargetingOptions
3899 3900 3901 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3899 def @line_item_assigned_targeting_options end |
#next_page_token ⇒ String
A token identifying the next page of results. This value should be specified
as the pageToken in a subsequent call to BulkListAssignedTargetingOptions to
fetch the next page of results. This token will be absent if there are no more
line_item_assigned_targeting_options to return.
Corresponds to the JSON property nextPageToken
3907 3908 3909 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3907 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3914 3915 3916 3917 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3914 def update!(**args) @line_item_assigned_targeting_options = args[:line_item_assigned_targeting_options] if args.key?(:line_item_assigned_targeting_options) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |