Class: Google::Apis::DisplayvideoV4::BulkListAssignedTargetingOptionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkListAssignedTargetingOptionsResponse

Returns a new instance of BulkListAssignedTargetingOptionsResponse.



3803
3804
3805
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#line_item_assigned_targeting_optionsArray<Google::Apis::DisplayvideoV4::LineItemAssignedTargetingOption>

The list of wrapper objects, each providing an assigned targeting option and the line item it is assigned to. This list will be absent if empty. Corresponds to the JSON property lineItemAssignedTargetingOptions



3793
3794
3795
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3793

def line_item_assigned_targeting_options
  @line_item_assigned_targeting_options
end

#next_page_tokenString

A token identifying the next page of results. This value should be specified as the pageToken in a subsequent call to BulkListAssignedTargetingOptions to fetch the next page of results. This token will be absent if there are no more line_item_assigned_targeting_options to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3801
3802
3803
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3801

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3808
3809
3810
3811
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3808

def update!(**args)
  @line_item_assigned_targeting_options = args[:line_item_assigned_targeting_options] if args.key?(:line_item_assigned_targeting_options)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end