Class: Google::Apis::DisplayvideoV4::BulkUpdateLineItemsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::BulkUpdateLineItemsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Response message for LineItemService.BulkUpdateLineItems.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::DisplayvideoV4::Status>
Errors returned by line items that failed to update.
-
#failed_line_item_ids ⇒ Array<Fixnum>
The IDs of line items that failed to update.
-
#skipped_line_item_ids ⇒ Array<Fixnum>
The IDs of line items that are skipped for updates.
-
#updated_line_item_ids ⇒ Array<Fixnum>
The IDs of successfully updated line items.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkUpdateLineItemsResponse
constructor
A new instance of BulkUpdateLineItemsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkUpdateLineItemsResponse
Returns a new instance of BulkUpdateLineItemsResponse.
3984 3985 3986 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3984 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::DisplayvideoV4::Status>
Errors returned by line items that failed to update.
Corresponds to the JSON property errors
3965 3966 3967 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3965 def errors @errors end |
#failed_line_item_ids ⇒ Array<Fixnum>
The IDs of line items that failed to update.
Corresponds to the JSON property failedLineItemIds
3970 3971 3972 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3970 def failed_line_item_ids @failed_line_item_ids end |
#skipped_line_item_ids ⇒ Array<Fixnum>
The IDs of line items that are skipped for updates. For example, unnecessary
mutates that will result in effectively no changes to line items will be
skipped and corresponding line item IDs can be tracked here.
Corresponds to the JSON property skippedLineItemIds
3977 3978 3979 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3977 def skipped_line_item_ids @skipped_line_item_ids end |
#updated_line_item_ids ⇒ Array<Fixnum>
The IDs of successfully updated line items.
Corresponds to the JSON property updatedLineItemIds
3982 3983 3984 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3982 def updated_line_item_ids @updated_line_item_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3989 3990 3991 3992 3993 3994 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3989 def update!(**args) @errors = args[:errors] if args.key?(:errors) @failed_line_item_ids = args[:failed_line_item_ids] if args.key?(:failed_line_item_ids) @skipped_line_item_ids = args[:skipped_line_item_ids] if args.key?(:skipped_line_item_ids) @updated_line_item_ids = args[:updated_line_item_ids] if args.key?(:updated_line_item_ids) end |