Class: Google::Apis::DisplayvideoV4::BusinessChainAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::BusinessChainAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details for assigned Business chain targeting option. This will be populated
in the details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_BUSINESS_CHAIN.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#proximity_radius_amount ⇒ Float
Required.
-
#proximity_radius_unit ⇒ String
Required.
-
#targeting_option_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BusinessChainAssignedTargetingOptionDetails
constructor
A new instance of BusinessChainAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BusinessChainAssignedTargetingOptionDetails
Returns a new instance of BusinessChainAssignedTargetingOptionDetails.
3937 3938 3939 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. The display name of a business chain, e.g. "KFC", "Chase Bank".
Corresponds to the JSON property displayName
3913 3914 3915 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3913 def display_name @display_name end |
#proximity_radius_amount ⇒ Float
Required. The radius of the area around the business chain that will be
targeted. The units of the radius are specified by proximity_radius_unit. Must
be 1 to 800 if unit is DISTANCE_UNIT_KILOMETERS and 1 to 500 if unit is
DISTANCE_UNIT_MILES. The minimum increment for both cases is 0.1. Inputs will
be rounded to the nearest acceptable value if it is too granular, e.g. 15.57
will become 15.6.
Corresponds to the JSON property proximityRadiusAmount
3923 3924 3925 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3923 def proximity_radius_amount @proximity_radius_amount end |
#proximity_radius_unit ⇒ String
Required. The unit of distance by which the targeting radius is measured.
Corresponds to the JSON property proximityRadiusUnit
3928 3929 3930 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3928 def proximity_radius_unit @proximity_radius_unit end |
#targeting_option_id ⇒ String
Required. The targeting_option_id of a TargetingOption of type
TARGETING_TYPE_BUSINESS_CHAIN. Accepted business chain targeting option IDs
can be retrieved using SearchTargetingOptions.
Corresponds to the JSON property targetingOptionId
3935 3936 3937 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3935 def targeting_option_id @targeting_option_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3942 3943 3944 3945 3946 3947 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 3942 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @proximity_radius_amount = args[:proximity_radius_amount] if args.key?(:proximity_radius_amount) @proximity_radius_unit = args[:proximity_radius_unit] if args.key?(:proximity_radius_unit) @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id) end |