Class: Google::Apis::DisplayvideoV4::Campaign
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::Campaign
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single campaign.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Output only.
-
#campaign_budgets ⇒ Array<Google::Apis::DisplayvideoV4::CampaignBudget>
The list of budgets available to this campaign.
-
#campaign_flight ⇒ Google::Apis::DisplayvideoV4::CampaignFlight
Settings that track the planned spend and duration of a campaign.
-
#campaign_goal ⇒ Google::Apis::DisplayvideoV4::CampaignGoal
Settings that control the goal of a campaign.
-
#campaign_id ⇒ Fixnum
Output only.
-
#display_name ⇒ String
Required.
-
#entity_status ⇒ String
Required.
-
#frequency_cap ⇒ Google::Apis::DisplayvideoV4::FrequencyCap
Settings that control the number of times a user may be shown with the same ad during a given time period.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Campaign
constructor
A new instance of Campaign.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Campaign
Returns a new instance of Campaign.
4071 4072 4073 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4071 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Output only. The unique ID of the advertiser the campaign belongs to.
Corresponds to the JSON property advertiserId
4017 4018 4019 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4017 def advertiser_id @advertiser_id end |
#campaign_budgets ⇒ Array<Google::Apis::DisplayvideoV4::CampaignBudget>
The list of budgets available to this campaign. If this field is not set, the
campaign uses an unlimited budget.
Corresponds to the JSON property campaignBudgets
4023 4024 4025 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4023 def campaign_budgets @campaign_budgets end |
#campaign_flight ⇒ Google::Apis::DisplayvideoV4::CampaignFlight
Settings that track the planned spend and duration of a campaign.
Corresponds to the JSON property campaignFlight
4028 4029 4030 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4028 def campaign_flight @campaign_flight end |
#campaign_goal ⇒ Google::Apis::DisplayvideoV4::CampaignGoal
Settings that control the goal of a campaign.
Corresponds to the JSON property campaignGoal
4033 4034 4035 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4033 def campaign_goal @campaign_goal end |
#campaign_id ⇒ Fixnum
Output only. The unique ID of the campaign. Assigned by the system.
Corresponds to the JSON property campaignId
4038 4039 4040 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4038 def campaign_id @campaign_id end |
#display_name ⇒ String
Required. The display name of the campaign. Must be UTF-8 encoded with a
maximum size of 240 bytes.
Corresponds to the JSON property displayName
4044 4045 4046 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4044 def display_name @display_name end |
#entity_status ⇒ String
Required. Controls whether or not the insertion orders under this campaign can
spend their budgets and bid on inventory. * Accepted values are
ENTITY_STATUS_ACTIVE, ENTITY_STATUS_ARCHIVED, and ENTITY_STATUS_PAUSED. *
For CreateCampaign method, ENTITY_STATUS_ARCHIVED is not allowed.
Corresponds to the JSON property entityStatus
4052 4053 4054 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4052 def entity_status @entity_status end |
#frequency_cap ⇒ Google::Apis::DisplayvideoV4::FrequencyCap
Settings that control the number of times a user may be shown with the same ad
during a given time period.
Corresponds to the JSON property frequencyCap
4058 4059 4060 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4058 def frequency_cap @frequency_cap end |
#name ⇒ String
Output only. The resource name of the campaign.
Corresponds to the JSON property name
4063 4064 4065 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4063 def name @name end |
#update_time ⇒ String
Output only. The timestamp when the campaign was last updated. Assigned by the
system.
Corresponds to the JSON property updateTime
4069 4070 4071 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4069 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4076 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @campaign_budgets = args[:campaign_budgets] if args.key?(:campaign_budgets) @campaign_flight = args[:campaign_flight] if args.key?(:campaign_flight) @campaign_goal = args[:campaign_goal] if args.key?(:campaign_goal) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |