Class: Google::Apis::DisplayvideoV4::Campaign

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single campaign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Campaign

Returns a new instance of Campaign.



4063
4064
4065
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The unique ID of the advertiser the campaign belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


4009
4010
4011
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4009

def advertiser_id
  @advertiser_id
end

#campaign_budgetsArray<Google::Apis::DisplayvideoV4::CampaignBudget>

The list of budgets available to this campaign. If this field is not set, the campaign uses an unlimited budget. Corresponds to the JSON property campaignBudgets



4015
4016
4017
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4015

def campaign_budgets
  @campaign_budgets
end

#campaign_flightGoogle::Apis::DisplayvideoV4::CampaignFlight

Settings that track the planned spend and duration of a campaign. Corresponds to the JSON property campaignFlight



4020
4021
4022
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4020

def campaign_flight
  @campaign_flight
end

#campaign_goalGoogle::Apis::DisplayvideoV4::CampaignGoal

Settings that control the goal of a campaign. Corresponds to the JSON property campaignGoal



4025
4026
4027
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4025

def campaign_goal
  @campaign_goal
end

#campaign_idFixnum

Output only. The unique ID of the campaign. Assigned by the system. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


4030
4031
4032
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4030

def campaign_id
  @campaign_id
end

#display_nameString

Required. The display name of the campaign. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


4036
4037
4038
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4036

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not the insertion orders under this campaign can spend their budgets and bid on inventory. * Accepted values are ENTITY_STATUS_ACTIVE, ENTITY_STATUS_ARCHIVED, and ENTITY_STATUS_PAUSED. * For CreateCampaign method, ENTITY_STATUS_ARCHIVED is not allowed. Corresponds to the JSON property entityStatus

Returns:

  • (String)


4044
4045
4046
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4044

def entity_status
  @entity_status
end

#frequency_capGoogle::Apis::DisplayvideoV4::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property frequencyCap



4050
4051
4052
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4050

def frequency_cap
  @frequency_cap
end

#nameString

Output only. The resource name of the campaign. Corresponds to the JSON property name

Returns:

  • (String)


4055
4056
4057
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4055

def name
  @name
end

#update_timeString

Output only. The timestamp when the campaign was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


4061
4062
4063
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4061

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4068

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @campaign_budgets = args[:campaign_budgets] if args.key?(:campaign_budgets)
  @campaign_flight = args[:campaign_flight] if args.key?(:campaign_flight)
  @campaign_goal = args[:campaign_goal] if args.key?(:campaign_goal)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end