Class: Google::Apis::DisplayvideoV4::CampaignBudget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Settings that control how the campaign budget is allocated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CampaignBudget

Returns a new instance of CampaignBudget.



4257
4258
4259
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_amount_microsFixnum

Required. The total amount the linked insertion order segments can budget. The amount is in micros. Must be greater than 0. For example, 500000000 represents 500 standard units of the currency. Corresponds to the JSON property budgetAmountMicros

Returns:

  • (Fixnum)


4205
4206
4207
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4205

def budget_amount_micros
  @budget_amount_micros
end

#budget_idFixnum

The unique ID of the campaign budget. Assigned by the system. Do not set for new budgets. Must be included when updating or adding budgets to campaign_budgets. Otherwise, a new ID will be generated and assigned. Corresponds to the JSON property budgetId

Returns:

  • (Fixnum)


4212
4213
4214
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4212

def budget_id
  @budget_id
end

#budget_unitString

Required. Immutable. Specifies whether the budget is measured in currency or impressions. Corresponds to the JSON property budgetUnit

Returns:

  • (String)


4218
4219
4220
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4218

def budget_unit
  @budget_unit
end

#date_rangeGoogle::Apis::DisplayvideoV4::DateRange

A date range. Corresponds to the JSON property dateRange



4223
4224
4225
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4223

def date_range
  @date_range
end

#display_nameString

Required. The display name of the budget. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


4229
4230
4231
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4229

def display_name
  @display_name
end

#external_budget_idString

Immutable. The ID identifying this budget to the external source. If this field is set and the invoice detail level of the corresponding billing profile is set to "Budget level PO", all impressions served against this budget will include this ID on the invoice. Must be unique under the campaign. Corresponds to the JSON property externalBudgetId

Returns:

  • (String)


4237
4238
4239
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4237

def external_budget_id
  @external_budget_id
end

#external_budget_sourceString

Required. The external source of the budget. Corresponds to the JSON property externalBudgetSource

Returns:

  • (String)


4242
4243
4244
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4242

def external_budget_source
  @external_budget_source
end

#invoice_grouping_idString

Immutable. The ID used to group budgets to be included the same invoice. If this field is set and the invoice level of the corresponding billing profile is set to "Budget invoice grouping ID", all external_budget_id sharing the same invoice_grouping_id will be grouped in the same invoice. Corresponds to the JSON property invoiceGroupingId

Returns:

  • (String)


4250
4251
4252
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4250

def invoice_grouping_id
  @invoice_grouping_id
end

#prisma_configGoogle::Apis::DisplayvideoV4::PrismaConfig

Settings specific to the Mediaocean Prisma tool. Corresponds to the JSON property prismaConfig



4255
4256
4257
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4255

def prisma_config
  @prisma_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4262

def update!(**args)
  @budget_amount_micros = args[:budget_amount_micros] if args.key?(:budget_amount_micros)
  @budget_id = args[:budget_id] if args.key?(:budget_id)
  @budget_unit = args[:budget_unit] if args.key?(:budget_unit)
  @date_range = args[:date_range] if args.key?(:date_range)
  @display_name = args[:display_name] if args.key?(:display_name)
  @external_budget_id = args[:external_budget_id] if args.key?(:external_budget_id)
  @external_budget_source = args[:external_budget_source] if args.key?(:external_budget_source)
  @invoice_grouping_id = args[:invoice_grouping_id] if args.key?(:invoice_grouping_id)
  @prisma_config = args[:prisma_config] if args.key?(:prisma_config)
end