Class: Google::Apis::DisplayvideoV4::CampaignFlight
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::CampaignFlight
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Settings that track the planned spend and duration of a campaign.
Instance Attribute Summary collapse
-
#planned_dates ⇒ Google::Apis::DisplayvideoV4::DateRange
A date range.
-
#planned_spend_amount_micros ⇒ Fixnum
The amount the campaign is expected to spend for its given planned_dates.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CampaignFlight
constructor
A new instance of CampaignFlight.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CampaignFlight
Returns a new instance of CampaignFlight.
4178 4179 4180 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#planned_dates ⇒ Google::Apis::DisplayvideoV4::DateRange
A date range.
Corresponds to the JSON property plannedDates
4168 4169 4170 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4168 def planned_dates @planned_dates end |
#planned_spend_amount_micros ⇒ Fixnum
The amount the campaign is expected to spend for its given planned_dates. This
will not limit serving, but will be used for tracking spend in the DV360 UI.
The amount is in micros. Must be greater than or equal to 0. For example,
500000000 represents 500 standard units of the currency.
Corresponds to the JSON property plannedSpendAmountMicros
4176 4177 4178 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4176 def planned_spend_amount_micros @planned_spend_amount_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4183 4184 4185 4186 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4183 def update!(**args) @planned_dates = args[:planned_dates] if args.key?(:planned_dates) @planned_spend_amount_micros = args[:planned_spend_amount_micros] if args.key?(:planned_spend_amount_micros) end |