Class: Google::Apis::DisplayvideoV4::CarouselCard

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen carousel card.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CarouselCard

Returns a new instance of CarouselCard.



4395
4396
4397
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_to_actionString

Required. The text on the call-to-action button shown on the card. Must use 10 characters or less. Corresponds to the JSON property callToAction

Returns:

  • (String)


4361
4362
4363
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4361

def call_to_action
  @call_to_action
end

#final_mobile_urlString

Optional. The URL address of the webpage that people reach after they click the card on a mobile device. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


4367
4368
4369
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4367

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the card. Corresponds to the JSON property finalUrl

Returns:

  • (String)


4373
4374
4375
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4373

def final_url
  @final_url
end

#headlineString

Required. The headline of the card. Corresponds to the JSON property headline

Returns:

  • (String)


4378
4379
4380
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4378

def headline
  @headline
end

#marketing_imageGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property marketingImage



4383
4384
4385
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4383

def marketing_image
  @marketing_image
end

#portrait_marketing_imageGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property portraitMarketingImage



4388
4389
4390
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4388

def portrait_marketing_image
  @portrait_marketing_image
end

#square_marketing_imageGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property squareMarketingImage



4393
4394
4395
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4393

def square_marketing_image
  @square_marketing_image
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4400
4401
4402
4403
4404
4405
4406
4407
4408
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4400

def update!(**args)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @headline = args[:headline] if args.key?(:headline)
  @marketing_image = args[:marketing_image] if args.key?(:marketing_image)
  @portrait_marketing_image = args[:portrait_marketing_image] if args.key?(:portrait_marketing_image)
  @square_marketing_image = args[:square_marketing_image] if args.key?(:square_marketing_image)
end