Class: Google::Apis::DisplayvideoV4::CarouselCard

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen carousel card.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CarouselCard

Returns a new instance of CarouselCard.



4378
4379
4380
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_to_actionString

Required. The text on the call-to-action button shown on the card. Must use 10 characters or less. Corresponds to the JSON property callToAction

Returns:

  • (String)


4344
4345
4346
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4344

def call_to_action
  @call_to_action
end

#final_mobile_urlString

Optional. The URL address of the webpage that people reach after they click the card on a mobile device. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


4350
4351
4352
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4350

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the card. Corresponds to the JSON property finalUrl

Returns:

  • (String)


4356
4357
4358
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4356

def final_url
  @final_url
end

#headlineString

Required. The headline of the card. Corresponds to the JSON property headline

Returns:

  • (String)


4361
4362
4363
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4361

def headline
  @headline
end

#marketing_imageGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property marketingImage



4366
4367
4368
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4366

def marketing_image
  @marketing_image
end

#portrait_marketing_imageGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property portraitMarketingImage



4371
4372
4373
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4371

def portrait_marketing_image
  @portrait_marketing_image
end

#square_marketing_imageGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property squareMarketingImage



4376
4377
4378
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4376

def square_marketing_image
  @square_marketing_image
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4383
4384
4385
4386
4387
4388
4389
4390
4391
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4383

def update!(**args)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @headline = args[:headline] if args.key?(:headline)
  @marketing_image = args[:marketing_image] if args.key?(:marketing_image)
  @portrait_marketing_image = args[:portrait_marketing_image] if args.key?(:portrait_marketing_image)
  @square_marketing_image = args[:square_marketing_image] if args.key?(:square_marketing_image)
end