Class: Google::Apis::DisplayvideoV4::CarouselCard

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen carousel card.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CarouselCard

Returns a new instance of CarouselCard.



4256
4257
4258
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_to_actionString

Required. The text on the call-to-action button shown on the card. Must use 10 characters or less. Corresponds to the JSON property callToAction

Returns:

  • (String)


4222
4223
4224
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4222

def call_to_action
  @call_to_action
end

#final_mobile_urlString

Optional. The URL address of the webpage that people reach after they click the card on a mobile device. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


4228
4229
4230
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4228

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the card. Corresponds to the JSON property finalUrl

Returns:

  • (String)


4234
4235
4236
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4234

def final_url
  @final_url
end

#headlineString

Required. The headline of the card. Corresponds to the JSON property headline

Returns:

  • (String)


4239
4240
4241
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4239

def headline
  @headline
end

#marketing_imageGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property marketingImage



4244
4245
4246
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4244

def marketing_image
  @marketing_image
end

#portrait_marketing_imageGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property portraitMarketingImage



4249
4250
4251
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4249

def portrait_marketing_image
  @portrait_marketing_image
end

#square_marketing_imageGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property squareMarketingImage



4254
4255
4256
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4254

def square_marketing_image
  @square_marketing_image
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4261
4262
4263
4264
4265
4266
4267
4268
4269
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4261

def update!(**args)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @headline = args[:headline] if args.key?(:headline)
  @marketing_image = args[:marketing_image] if args.key?(:marketing_image)
  @portrait_marketing_image = args[:portrait_marketing_image] if args.key?(:portrait_marketing_image)
  @square_marketing_image = args[:square_marketing_image] if args.key?(:square_marketing_image)
end