Class: Google::Apis::DisplayvideoV4::CarrierAndIspAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for assigned carrier and ISP targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_CARRIER_AND_ISP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CarrierAndIspAssignedTargetingOptionDetails

Returns a new instance of CarrierAndIspAssignedTargetingOptionDetails.



4419
4420
4421
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the carrier or ISP. Corresponds to the JSON property displayName

Returns:

  • (String)


4403
4404
4405
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4403

def display_name
  @display_name
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. All assigned carrier and ISP targeting options on the same resource must have the same value for this field. Corresponds to the JSON property negative

Returns:

  • (Boolean)


4410
4411
4412
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4410

def negative
  @negative
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_CARRIER_AND_ISP. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


4417
4418
4419
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4417

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4424
4425
4426
4427
4428
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4424

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @negative = args[:negative] if args.key?(:negative)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end