Class: Google::Apis::DisplayvideoV4::Channel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single channel. Channels are custom groups of related websites and apps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Channel

Returns a new instance of Channel.



4441
4442
4443
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

The ID of the advertiser that owns the channel. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


4406
4407
4408
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4406

def advertiser_id
  @advertiser_id
end

#channel_idFixnum

Output only. The unique ID of the channel. Assigned by the system. Corresponds to the JSON property channelId

Returns:

  • (Fixnum)


4411
4412
4413
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4411

def channel_id
  @channel_id
end

#display_nameString

Required. The display name of the channel. Must be UTF-8 encoded with a maximum length of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


4417
4418
4419
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4417

def display_name
  @display_name
end

#nameString

Output only. The resource name of the channel. Corresponds to the JSON property name

Returns:

  • (String)


4422
4423
4424
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4422

def name
  @name
end

#negatively_targeted_line_item_countFixnum

Output only. Number of line items that are directly targeting this channel negatively. Corresponds to the JSON property negativelyTargetedLineItemCount

Returns:

  • (Fixnum)


4428
4429
4430
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4428

def negatively_targeted_line_item_count
  @negatively_targeted_line_item_count
end

#partner_idFixnum

The ID of the partner that owns the channel. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


4433
4434
4435
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4433

def partner_id
  @partner_id
end

#positively_targeted_line_item_countFixnum

Output only. Number of line items that are directly targeting this channel positively. Corresponds to the JSON property positivelyTargetedLineItemCount

Returns:

  • (Fixnum)


4439
4440
4441
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4439

def positively_targeted_line_item_count
  @positively_targeted_line_item_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4446
4447
4448
4449
4450
4451
4452
4453
4454
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4446

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @negatively_targeted_line_item_count = args[:negatively_targeted_line_item_count] if args.key?(:negatively_targeted_line_item_count)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @positively_targeted_line_item_count = args[:positively_targeted_line_item_count] if args.key?(:positively_targeted_line_item_count)
end