Class: Google::Apis::DisplayvideoV4::CmHybridConfig
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::CmHybridConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Settings for advertisers that use both Campaign Manager 360 (CM360) and third- party ad servers.
Instance Attribute Summary collapse
-
#cm_account_id ⇒ Fixnum
Required.
-
#cm_advertiser_ids ⇒ Array<Fixnum>
Output only.
-
#cm_floodlight_config_id ⇒ Fixnum
Required.
-
#cm_floodlight_linking_authorized ⇒ Boolean
(also: #cm_floodlight_linking_authorized?)
Required.
-
#cm_syncable_site_ids ⇒ Array<Fixnum>
A list of CM360 sites whose placements will be synced to DV360 as creatives.
-
#dv360_to_cm_cost_reporting_enabled ⇒ Boolean
(also: #dv360_to_cm_cost_reporting_enabled?)
Whether or not to report DV360 cost to CM360.
-
#dv360_to_cm_data_sharing_enabled ⇒ Boolean
(also: #dv360_to_cm_data_sharing_enabled?)
Whether or not to include DV360 data in CM360 data transfer reports.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CmHybridConfig
constructor
A new instance of CmHybridConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CmHybridConfig
Returns a new instance of CmHybridConfig.
4532 4533 4534 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4532 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cm_account_id ⇒ Fixnum
Required. Immutable. Account ID of the CM360 Floodlight configuration linked
with the DV360 advertiser.
Corresponds to the JSON property cmAccountId
4490 4491 4492 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4490 def cm_account_id @cm_account_id end |
#cm_advertiser_ids ⇒ Array<Fixnum>
Output only. The set of CM360 Advertiser IDs sharing the CM360 Floodlight
configuration.
Corresponds to the JSON property cmAdvertiserIds
4496 4497 4498 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4496 def cm_advertiser_ids @cm_advertiser_ids end |
#cm_floodlight_config_id ⇒ Fixnum
Required. Immutable. ID of the CM360 Floodlight configuration linked with the
DV360 advertiser.
Corresponds to the JSON property cmFloodlightConfigId
4502 4503 4504 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4502 def cm_floodlight_config_id @cm_floodlight_config_id end |
#cm_floodlight_linking_authorized ⇒ Boolean Also known as:
Required. Immutable. By setting this field to true, you, on behalf of your
company, authorize the sharing of information from the given Floodlight
configuration to this Display & Video 360 advertiser.
Corresponds to the JSON property cmFloodlightLinkingAuthorized
4509 4510 4511 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4509 def @cm_floodlight_linking_authorized end |
#cm_syncable_site_ids ⇒ Array<Fixnum>
A list of CM360 sites whose placements will be synced to DV360 as creatives.
If absent or empty in CreateAdvertiser method, the system will automatically
create a CM360 site. Removing sites from this list may cause DV360 creatives
synced from CM360 to be deleted. At least one site must be specified.
Corresponds to the JSON property cmSyncableSiteIds
4518 4519 4520 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4518 def cm_syncable_site_ids @cm_syncable_site_ids end |
#dv360_to_cm_cost_reporting_enabled ⇒ Boolean Also known as: dv360_to_cm_cost_reporting_enabled?
Whether or not to report DV360 cost to CM360.
Corresponds to the JSON property dv360ToCmCostReportingEnabled
4523 4524 4525 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4523 def dv360_to_cm_cost_reporting_enabled @dv360_to_cm_cost_reporting_enabled end |
#dv360_to_cm_data_sharing_enabled ⇒ Boolean Also known as: dv360_to_cm_data_sharing_enabled?
Whether or not to include DV360 data in CM360 data transfer reports.
Corresponds to the JSON property dv360ToCmDataSharingEnabled
4529 4530 4531 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4529 def dv360_to_cm_data_sharing_enabled @dv360_to_cm_data_sharing_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4537 4538 4539 4540 4541 4542 4543 4544 4545 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4537 def update!(**args) @cm_account_id = args[:cm_account_id] if args.key?(:cm_account_id) @cm_advertiser_ids = args[:cm_advertiser_ids] if args.key?(:cm_advertiser_ids) @cm_floodlight_config_id = args[:cm_floodlight_config_id] if args.key?(:cm_floodlight_config_id) @cm_floodlight_linking_authorized = args[:cm_floodlight_linking_authorized] if args.key?(:cm_floodlight_linking_authorized) @cm_syncable_site_ids = args[:cm_syncable_site_ids] if args.key?(:cm_syncable_site_ids) @dv360_to_cm_cost_reporting_enabled = args[:dv360_to_cm_cost_reporting_enabled] if args.key?(:dv360_to_cm_cost_reporting_enabled) @dv360_to_cm_data_sharing_enabled = args[:dv360_to_cm_data_sharing_enabled] if args.key?(:dv360_to_cm_data_sharing_enabled) end |