Class: Google::Apis::DisplayvideoV4::CombinedAudienceGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details of combined audience group. All combined audience targeting settings are logically ‘OR’ of each other.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CombinedAudienceGroup

Returns a new instance of CombinedAudienceGroup.



4630
4631
4632
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4630

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#settingsArray<Google::Apis::DisplayvideoV4::CombinedAudienceTargetingSetting>

Required. All combined audience targeting settings in combined audience group. Repeated settings with the same id will be ignored. The number of combined audience settings should be no more than five, error will be thrown otherwise. Corresponds to the JSON property settings



4628
4629
4630
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4628

def settings
  @settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4635
4636
4637
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4635

def update!(**args)
  @settings = args[:settings] if args.key?(:settings)
end