Class: Google::Apis::DisplayvideoV4::CommonInStreamAttribute
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::CommonInStreamAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Common attributes for in-stream, non-skippable and bumper ads.
Instance Attribute Summary collapse
-
#action_button_label ⇒ String
The text on the call-to-action button.
-
#action_headline ⇒ String
The headline of the call-to-action banner.
-
#companion_banner ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
-
#display_url ⇒ String
The webpage address that appears with the ad.
-
#final_url ⇒ String
The URL address of the webpage that people reach after they click the ad.
-
#tracking_url ⇒ String
The URL address loaded in the background for tracking purposes.
-
#video ⇒ Google::Apis::DisplayvideoV4::YoutubeVideoDetails
Details of a YouTube video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommonInStreamAttribute
constructor
A new instance of CommonInStreamAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommonInStreamAttribute
Returns a new instance of CommonInStreamAttribute.
4813 4814 4815 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4813 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_button_label ⇒ String
The text on the call-to-action button.
Corresponds to the JSON property actionButtonLabel
4781 4782 4783 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4781 def @action_button_label end |
#action_headline ⇒ String
The headline of the call-to-action banner.
Corresponds to the JSON property actionHeadline
4786 4787 4788 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4786 def action_headline @action_headline end |
#companion_banner ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
Corresponds to the JSON property companionBanner
4791 4792 4793 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4791 def @companion_banner end |
#display_url ⇒ String
The webpage address that appears with the ad.
Corresponds to the JSON property displayUrl
4796 4797 4798 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4796 def display_url @display_url end |
#final_url ⇒ String
The URL address of the webpage that people reach after they click the ad.
Corresponds to the JSON property finalUrl
4801 4802 4803 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4801 def final_url @final_url end |
#tracking_url ⇒ String
The URL address loaded in the background for tracking purposes.
Corresponds to the JSON property trackingUrl
4806 4807 4808 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4806 def tracking_url @tracking_url end |
#video ⇒ Google::Apis::DisplayvideoV4::YoutubeVideoDetails
Details of a YouTube video.
Corresponds to the JSON property video
4811 4812 4813 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4811 def video @video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4818 4819 4820 4821 4822 4823 4824 4825 4826 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4818 def update!(**args) @action_button_label = args[:action_button_label] if args.key?(:action_button_label) @action_headline = args[:action_headline] if args.key?(:action_headline) @companion_banner = args[:companion_banner] if args.key?(:companion_banner) @display_url = args[:display_url] if args.key?(:display_url) @final_url = args[:final_url] if args.key?(:final_url) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @video = args[:video] if args.key?(:video) end |