Class: Google::Apis::DisplayvideoV4::CommonInStreamAttribute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Common attributes for in-stream, non-skippable and bumper ads.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommonInStreamAttribute

Returns a new instance of CommonInStreamAttribute.



4699
4700
4701
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_button_labelString

The text on the call-to-action button. Corresponds to the JSON property actionButtonLabel

Returns:

  • (String)


4667
4668
4669
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4667

def action_button_label
  @action_button_label
end

#action_headlineString

The headline of the call-to-action banner. Corresponds to the JSON property actionHeadline

Returns:

  • (String)


4672
4673
4674
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4672

def action_headline
  @action_headline
end

#companion_bannerGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property companionBanner



4677
4678
4679
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4677

def companion_banner
  @companion_banner
end

#display_urlString

The webpage address that appears with the ad. Corresponds to the JSON property displayUrl

Returns:

  • (String)


4682
4683
4684
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4682

def display_url
  @display_url
end

#final_urlString

The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


4687
4688
4689
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4687

def final_url
  @final_url
end

#tracking_urlString

The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


4692
4693
4694
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4692

def tracking_url
  @tracking_url
end

#videoGoogle::Apis::DisplayvideoV4::YoutubeVideoDetails

Details of a YouTube video. Corresponds to the JSON property video



4697
4698
4699
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4697

def video
  @video
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4704
4705
4706
4707
4708
4709
4710
4711
4712
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4704

def update!(**args)
  @action_button_label = args[:action_button_label] if args.key?(:action_button_label)
  @action_headline = args[:action_headline] if args.key?(:action_headline)
  @companion_banner = args[:companion_banner] if args.key?(:companion_banner)
  @display_url = args[:display_url] if args.key?(:display_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @video = args[:video] if args.key?(:video)
end