Class: Google::Apis::DisplayvideoV4::CommonInStreamAttribute
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::CommonInStreamAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Common attributes for in-stream, non-skippable and bumper ads.
Instance Attribute Summary collapse
-
#action_button_label ⇒ String
The text on the call-to-action button.
-
#action_headline ⇒ String
The headline of the call-to-action banner.
-
#companion_banner ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
-
#display_url ⇒ String
The webpage address that appears with the ad.
-
#final_url ⇒ String
The URL address of the webpage that people reach after they click the ad.
-
#tracking_url ⇒ String
The URL address loaded in the background for tracking purposes.
-
#video ⇒ Google::Apis::DisplayvideoV4::YoutubeVideoDetails
Details of a YouTube video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommonInStreamAttribute
constructor
A new instance of CommonInStreamAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommonInStreamAttribute
Returns a new instance of CommonInStreamAttribute.
4691 4692 4693 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4691 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_button_label ⇒ String
The text on the call-to-action button.
Corresponds to the JSON property actionButtonLabel
4659 4660 4661 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4659 def @action_button_label end |
#action_headline ⇒ String
The headline of the call-to-action banner.
Corresponds to the JSON property actionHeadline
4664 4665 4666 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4664 def action_headline @action_headline end |
#companion_banner ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
Corresponds to the JSON property companionBanner
4669 4670 4671 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4669 def @companion_banner end |
#display_url ⇒ String
The webpage address that appears with the ad.
Corresponds to the JSON property displayUrl
4674 4675 4676 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4674 def display_url @display_url end |
#final_url ⇒ String
The URL address of the webpage that people reach after they click the ad.
Corresponds to the JSON property finalUrl
4679 4680 4681 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4679 def final_url @final_url end |
#tracking_url ⇒ String
The URL address loaded in the background for tracking purposes.
Corresponds to the JSON property trackingUrl
4684 4685 4686 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4684 def tracking_url @tracking_url end |
#video ⇒ Google::Apis::DisplayvideoV4::YoutubeVideoDetails
Details of a YouTube video.
Corresponds to the JSON property video
4689 4690 4691 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4689 def video @video end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4696 4697 4698 4699 4700 4701 4702 4703 4704 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4696 def update!(**args) @action_button_label = args[:action_button_label] if args.key?(:action_button_label) @action_headline = args[:action_headline] if args.key?(:action_headline) @companion_banner = args[:companion_banner] if args.key?(:companion_banner) @display_url = args[:display_url] if args.key?(:display_url) @final_url = args[:final_url] if args.key?(:final_url) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @video = args[:video] if args.key?(:video) end |