Class: Google::Apis::DisplayvideoV4::ContactInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Contact information defining a Customer Match audience member.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContactInfo

Returns a new instance of ContactInfo.



4920
4921
4922
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4920

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Optional. Country code of the member. Must also be set with the following fields: * country_code * hashed_first_name * hashed_last_name * zip_codes Corresponds to the JSON property countryCode

Returns:

  • (String)


4885
4886
4887
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4885

def country_code
  @country_code
end

#hashed_emailsArray<String>

Optional. A list of SHA256 hashed email of the member. Before hashing, remove all whitespace and make sure the string is all lowercase. Corresponds to the JSON property hashedEmails

Returns:

  • (Array<String>)


4891
4892
4893
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4891

def hashed_emails
  @hashed_emails
end

#hashed_first_nameString

Optional. SHA256 hashed first name of the member. Before hashing, remove all whitespace and make sure the string is all lowercase. Must also be set with the following fields: * country_code * hashed_last_name * zip_codes Corresponds to the JSON property hashedFirstName

Returns:

  • (String)


4898
4899
4900
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4898

def hashed_first_name
  @hashed_first_name
end

#hashed_last_nameString

Optional. SHA256 hashed last name of the member. Before hashing, remove all whitespace and make sure the string is all lowercase. Must also be set with the following fields: * country_code * hashed_first_name * zip_codes Corresponds to the JSON property hashedLastName

Returns:

  • (String)


4905
4906
4907
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4905

def hashed_last_name
  @hashed_last_name
end

#hashed_phone_numbersArray<String>

Optional. A list of SHA256 hashed phone numbers of the member. Before hashing, all phone numbers must be formatted using the E.164 format and include the country calling code. Corresponds to the JSON property hashedPhoneNumbers

Returns:

  • (Array<String>)


4912
4913
4914
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4912

def hashed_phone_numbers
  @hashed_phone_numbers
end

#zip_codesArray<String>

Optional. A list of zip codes of the member. Must also be set with the following fields: * country_code * hashed_first_name * hashed_last_name Corresponds to the JSON property zipCodes

Returns:

  • (Array<String>)


4918
4919
4920
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4918

def zip_codes
  @zip_codes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4925
4926
4927
4928
4929
4930
4931
4932
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4925

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @hashed_emails = args[:hashed_emails] if args.key?(:hashed_emails)
  @hashed_first_name = args[:hashed_first_name] if args.key?(:hashed_first_name)
  @hashed_last_name = args[:hashed_last_name] if args.key?(:hashed_last_name)
  @hashed_phone_numbers = args[:hashed_phone_numbers] if args.key?(:hashed_phone_numbers)
  @zip_codes = args[:zip_codes] if args.key?(:zip_codes)
end