Class: Google::Apis::DisplayvideoV4::ContactInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Contact information defining a Customer Match audience member.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContactInfo

Returns a new instance of ContactInfo.



4775
4776
4777
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4775

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#country_codeString

Country code of the member. Must also be set with the following fields: * hashed_first_name * hashed_last_name * zip_codes Corresponds to the JSON property countryCode

Returns:

  • (String)


4740
4741
4742
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4740

def country_code
  @country_code
end

#hashed_emailsArray<String>

A list of SHA256 hashed email of the member. Before hashing, remove all whitespace and make sure the string is all lowercase. Corresponds to the JSON property hashedEmails

Returns:

  • (Array<String>)


4746
4747
4748
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4746

def hashed_emails
  @hashed_emails
end

#hashed_first_nameString

SHA256 hashed first name of the member. Before hashing, remove all whitespace and make sure the string is all lowercase. Must also be set with the following fields: * country_code * hashed_last_name * zip_codes Corresponds to the JSON property hashedFirstName

Returns:

  • (String)


4753
4754
4755
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4753

def hashed_first_name
  @hashed_first_name
end

#hashed_last_nameString

SHA256 hashed last name of the member. Before hashing, remove all whitespace and make sure the string is all lowercase. Must also be set with the following fields: * country_code * hashed_first_name * zip_codes Corresponds to the JSON property hashedLastName

Returns:

  • (String)


4760
4761
4762
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4760

def hashed_last_name
  @hashed_last_name
end

#hashed_phone_numbersArray<String>

A list of SHA256 hashed phone numbers of the member. Before hashing, all phone numbers must be formatted using the E.164 format and include the country calling code. Corresponds to the JSON property hashedPhoneNumbers

Returns:

  • (Array<String>)


4767
4768
4769
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4767

def hashed_phone_numbers
  @hashed_phone_numbers
end

#zip_codesArray<String>

A list of zip codes of the member. Must also be set with the following fields:

  • country_code * hashed_first_name * hashed_last_name Corresponds to the JSON property zipCodes

Returns:

  • (Array<String>)


4773
4774
4775
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4773

def zip_codes
  @zip_codes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4780
4781
4782
4783
4784
4785
4786
4787
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 4780

def update!(**args)
  @country_code = args[:country_code] if args.key?(:country_code)
  @hashed_emails = args[:hashed_emails] if args.key?(:hashed_emails)
  @hashed_first_name = args[:hashed_first_name] if args.key?(:hashed_first_name)
  @hashed_last_name = args[:hashed_last_name] if args.key?(:hashed_last_name)
  @hashed_phone_numbers = args[:hashed_phone_numbers] if args.key?(:hashed_phone_numbers)
  @zip_codes = args[:zip_codes] if args.key?(:zip_codes)
end