Class: Google::Apis::DisplayvideoV4::ContentInstreamPositionAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ContentInstreamPositionAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Assigned content instream position targeting option details. This will be
populated in the content_instream_position_details field when targeting_type
is TARGETING_TYPE_CONTENT_INSTREAM_POSITION.
Instance Attribute Summary collapse
-
#ad_type ⇒ String
Output only.
-
#content_instream_position ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContentInstreamPositionAssignedTargetingOptionDetails
constructor
A new instance of ContentInstreamPositionAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContentInstreamPositionAssignedTargetingOptionDetails
Returns a new instance of ContentInstreamPositionAssignedTargetingOptionDetails.
5087 5088 5089 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_type ⇒ String
Output only. The ad type to target. Only applicable to insertion order
targeting and new line items supporting the specified ad type will inherit
this targeting option by default. Possible values are: * AD_TYPE_VIDEO, the
setting will be inherited by new line item when line_item_type is
LINE_ITEM_TYPE_VIDEO_DEFAULT. * AD_TYPE_AUDIO, the setting will be
inherited by new line item when line_item_type is
LINE_ITEM_TYPE_AUDIO_DEFAULT.
Corresponds to the JSON property adType
5080 5081 5082 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5080 def ad_type @ad_type end |
#content_instream_position ⇒ String
Required. The content instream position for video or audio ads.
Corresponds to the JSON property contentInstreamPosition
5085 5086 5087 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5085 def content_instream_position @content_instream_position end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5092 5093 5094 5095 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5092 def update!(**args) @ad_type = args[:ad_type] if args.key?(:ad_type) @content_instream_position = args[:content_instream_position] if args.key?(:content_instream_position) end |