Class: Google::Apis::DisplayvideoV4::ContentOutstreamPositionAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ContentOutstreamPositionAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Assigned content outstream position targeting option details. This will be
populated in the content_outstream_position_details field when targeting_type
is TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION.
Instance Attribute Summary collapse
-
#ad_type ⇒ String
Output only.
-
#content_outstream_position ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContentOutstreamPositionAssignedTargetingOptionDetails
constructor
A new instance of ContentOutstreamPositionAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContentOutstreamPositionAssignedTargetingOptionDetails
Returns a new instance of ContentOutstreamPositionAssignedTargetingOptionDetails.
5125 5126 5127 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5125 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_type ⇒ String
Output only. The ad type to target. Only applicable to insertion order
targeting and new line items supporting the specified ad type will inherit
this targeting option by default. Possible values are: * AD_TYPE_DISPLAY,
the setting will be inherited by new line item when line_item_type is
LINE_ITEM_TYPE_DISPLAY_DEFAULT. * AD_TYPE_VIDEO, the setting will be
inherited by new line item when line_item_type is
LINE_ITEM_TYPE_VIDEO_DEFAULT.
Corresponds to the JSON property adType
5118 5119 5120 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5118 def ad_type @ad_type end |
#content_outstream_position ⇒ String
Required. The content outstream position.
Corresponds to the JSON property contentOutstreamPosition
5123 5124 5125 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5123 def content_outstream_position @content_outstream_position end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5130 5131 5132 5133 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5130 def update!(**args) @ad_type = args[:ad_type] if args.key?(:ad_type) @content_outstream_position = args[:content_outstream_position] if args.key?(:content_outstream_position) end |