Class: Google::Apis::DisplayvideoV4::ContentOutstreamPositionAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ContentOutstreamPositionAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Assigned content outstream position targeting option details. This will be
populated in the content_outstream_position_details field when targeting_type
is TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION.
Instance Attribute Summary collapse
-
#ad_type ⇒ String
Output only.
-
#content_outstream_position ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContentOutstreamPositionAssignedTargetingOptionDetails
constructor
A new instance of ContentOutstreamPositionAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContentOutstreamPositionAssignedTargetingOptionDetails
Returns a new instance of ContentOutstreamPositionAssignedTargetingOptionDetails.
5011 5012 5013 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_type ⇒ String
Output only. The ad type to target. Only applicable to insertion order
targeting and new line items supporting the specified ad type will inherit
this targeting option by default. Possible values are: * AD_TYPE_DISPLAY,
the setting will be inherited by new line item when line_item_type is
LINE_ITEM_TYPE_DISPLAY_DEFAULT. * AD_TYPE_VIDEO, the setting will be
inherited by new line item when line_item_type is
LINE_ITEM_TYPE_VIDEO_DEFAULT.
Corresponds to the JSON property adType
5004 5005 5006 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5004 def ad_type @ad_type end |
#content_outstream_position ⇒ String
Required. The content outstream position.
Corresponds to the JSON property contentOutstreamPosition
5009 5010 5011 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5009 def content_outstream_position @content_outstream_position end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5016 5017 5018 5019 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5016 def update!(**args) @ad_type = args[:ad_type] if args.key?(:ad_type) @content_outstream_position = args[:content_outstream_position] if args.key?(:content_outstream_position) end |