Class: Google::Apis::DisplayvideoV4::ConversionCountingConfig
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ConversionCountingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Settings that control how conversions are counted. All post-click conversions will be counted. A percentage value can be set for post-view conversions counting.
Instance Attribute Summary collapse
-
#floodlight_activity_configs ⇒ Array<Google::Apis::DisplayvideoV4::TrackingFloodlightActivityConfig>
The Floodlight activity configs used to track conversions.
-
#post_view_count_percentage_millis ⇒ Fixnum
The percentage of post-view conversions to count, in millis (1/1000 of a percent).
-
#primary_attribution_model_id ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConversionCountingConfig
constructor
A new instance of ConversionCountingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConversionCountingConfig
Returns a new instance of ConversionCountingConfig.
5174 5175 5176 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#floodlight_activity_configs ⇒ Array<Google::Apis::DisplayvideoV4::TrackingFloodlightActivityConfig>
The Floodlight activity configs used to track conversions. The number of
conversions counted is the sum of all of the conversions counted by all of the
Floodlight activity IDs specified in this field. This field can't be updated
if a custom bidding algorithm is assigned to the line item. If you set this
field and assign a custom bidding algorithm in the same request, the
floodlight activities must match the ones used by the custom bidding algorithm.
Corresponds to the JSON property floodlightActivityConfigs
5155 5156 5157 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5155 def floodlight_activity_configs @floodlight_activity_configs end |
#post_view_count_percentage_millis ⇒ Fixnum
The percentage of post-view conversions to count, in millis (1/1000 of a
percent). Must be between 0 and 100000 inclusive. For example, to track 50% of
the post-click conversions, set a value of 50000.
Corresponds to the JSON property postViewCountPercentageMillis
5162 5163 5164 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5162 def post_view_count_percentage_millis @post_view_count_percentage_millis end |
#primary_attribution_model_id ⇒ Fixnum
Optional. The attribution model to use for conversion measurement. This
attribution model will determine how conversions are counted. The Primary
model can be set by you for a floodlight config or group. More details here. Only applicable to
Demand Gen line items. Retrieval and management of Demand Gen resources is
currently in beta. This field is only available to allowlisted users.
Corresponds to the JSON property primaryAttributionModelId
5172 5173 5174 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5172 def primary_attribution_model_id @primary_attribution_model_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5179 5180 5181 5182 5183 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5179 def update!(**args) @floodlight_activity_configs = args[:floodlight_activity_configs] if args.key?(:floodlight_activity_configs) @post_view_count_percentage_millis = args[:post_view_count_percentage_millis] if args.key?(:post_view_count_percentage_millis) @primary_attribution_model_id = args[:primary_attribution_model_id] if args.key?(:primary_attribution_model_id) end |