Class: Google::Apis::DisplayvideoV4::CreateSdfDownloadTaskRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for [SdfDownloadTaskService.CreateSdfDownloadTask].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateSdfDownloadTaskRequest

Returns a new instance of CreateSdfDownloadTaskRequest.



5333
5334
5335
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

The ID of the advertiser to download SDF for. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


5302
5303
5304
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5302

def advertiser_id
  @advertiser_id
end

#id_filterGoogle::Apis::DisplayvideoV4::IdFilter

A filtering option that filters entities by their entity IDs. Corresponds to the JSON property idFilter



5307
5308
5309
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5307

def id_filter
  @id_filter
end

#inventory_source_filterGoogle::Apis::DisplayvideoV4::InventorySourceFilter

A filtering option for filtering on Inventory Source entities. Corresponds to the JSON property inventorySourceFilter



5312
5313
5314
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5312

def inventory_source_filter
  @inventory_source_filter
end

#parent_entity_filterGoogle::Apis::DisplayvideoV4::ParentEntityFilter

A filtering option that filters on selected file types belonging to a chosen set of filter entities. Corresponds to the JSON property parentEntityFilter



5318
5319
5320
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5318

def parent_entity_filter
  @parent_entity_filter
end

#partner_idFixnum

The ID of the partner to download SDF for. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


5323
5324
5325
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5323

def partner_id
  @partner_id
end

#versionString

Required. The SDF version of the downloaded file. If set to SDF_VERSION_UNSPECIFIED, this will default to the version specified by the advertiser or partner identified by root_id. An advertiser inherits its SDF version from its partner unless configured otherwise. Corresponds to the JSON property version

Returns:

  • (String)


5331
5332
5333
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5331

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5338
5339
5340
5341
5342
5343
5344
5345
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5338

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @id_filter = args[:id_filter] if args.key?(:id_filter)
  @inventory_source_filter = args[:inventory_source_filter] if args.key?(:inventory_source_filter)
  @parent_entity_filter = args[:parent_entity_filter] if args.key?(:parent_entity_filter)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @version = args[:version] if args.key?(:version)
end