Class: Google::Apis::DisplayvideoV4::Creative
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::Creative
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single Creative.
Instance Attribute Summary collapse
-
#additional_dimensions ⇒ Array<Google::Apis::DisplayvideoV4::Dimensions>
Optional.
-
#advertiser_id ⇒ Fixnum
Output only.
-
#appended_tag ⇒ String
Optional.
-
#assets ⇒ Array<Google::Apis::DisplayvideoV4::AssetAssociation>
Required.
-
#cm_placement_id ⇒ Fixnum
Output only.
-
#cm_tracking_ad ⇒ Google::Apis::DisplayvideoV4::CmTrackingAd
A Campaign Manager 360 tracking ad.
-
#companion_creative_ids ⇒ Array<Fixnum>
Optional.
-
#counter_events ⇒ Array<Google::Apis::DisplayvideoV4::CounterEvent>
Optional.
-
#create_time ⇒ String
Output only.
-
#creative_attributes ⇒ Array<String>
Output only.
-
#creative_id ⇒ Fixnum
Output only.
-
#creative_type ⇒ String
Required.
-
#dimensions ⇒ Google::Apis::DisplayvideoV4::Dimensions
Dimensions.
-
#display_name ⇒ String
Required.
-
#dynamic ⇒ Boolean
(also: #dynamic?)
Output only.
-
#entity_status ⇒ String
Required.
-
#exit_events ⇒ Array<Google::Apis::DisplayvideoV4::ExitEvent>
Required.
-
#expand_on_hover ⇒ Boolean
(also: #expand_on_hover?)
Optional.
-
#expanding_direction ⇒ String
Optional.
-
#hosting_source ⇒ String
Required.
-
#html5_video ⇒ Boolean
(also: #html5_video?)
Output only.
-
#ias_campaign_monitoring ⇒ Boolean
(also: #ias_campaign_monitoring?)
Optional.
-
#integration_code ⇒ String
Optional.
-
#js_tracker_url ⇒ String
Optional.
-
#line_item_ids ⇒ Array<Fixnum>
Output only.
-
#media_duration ⇒ String
Output only.
-
#mp3_audio ⇒ Boolean
(also: #mp3_audio?)
Output only.
-
#name ⇒ String
Output only.
-
#notes ⇒ String
Optional.
-
#oba_icon ⇒ Google::Apis::DisplayvideoV4::ObaIcon
OBA Icon for a Creative Corresponds to the JSON property
obaIcon. -
#ogg_audio ⇒ Boolean
(also: #ogg_audio?)
Output only.
-
#progress_offset ⇒ Google::Apis::DisplayvideoV4::AudioVideoOffset
The length an audio or a video has been played.
-
#require_html5 ⇒ Boolean
(also: #require_html5?)
Optional.
-
#require_mraid ⇒ Boolean
(also: #require_mraid?)
Optional.
-
#require_ping_for_attribution ⇒ Boolean
(also: #require_ping_for_attribution?)
Optional.
-
#review_status ⇒ Google::Apis::DisplayvideoV4::ReviewStatusInfo
Review statuses for the creative.
-
#skip_offset ⇒ Google::Apis::DisplayvideoV4::AudioVideoOffset
The length an audio or a video has been played.
-
#skippable ⇒ Boolean
(also: #skippable?)
Optional.
-
#synthetic_content_attestation_status ⇒ String
Optional.
-
#third_party_tag ⇒ String
Optional.
-
#third_party_urls ⇒ Array<Google::Apis::DisplayvideoV4::ThirdPartyUrl>
Optional.
-
#timer_events ⇒ Array<Google::Apis::DisplayvideoV4::TimerEvent>
Optional.
-
#tracker_urls ⇒ Array<String>
Optional.
-
#transcodes ⇒ Array<Google::Apis::DisplayvideoV4::Transcode>
Output only.
-
#universal_ad_id ⇒ Google::Apis::DisplayvideoV4::UniversalAdId
A creative identifier provided by a registry that is unique across all platforms.
-
#update_time ⇒ String
Output only.
-
#vast_tag_url ⇒ String
Optional.
-
#vpaid ⇒ Boolean
(also: #vpaid?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Creative
constructor
A new instance of Creative.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Creative
Returns a new instance of Creative.
5858 5859 5860 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5858 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_dimensions ⇒ Array<Google::Apis::DisplayvideoV4::Dimensions>
Optional. Additional dimensions. Applicable when creative_type is one of: *
CREATIVE_TYPE_STANDARD * CREATIVE_TYPE_EXPANDABLE * CREATIVE_TYPE_NATIVE *
CREATIVE_TYPE_NATIVE_SITE_SQUARE * CREATIVE_TYPE_LIGHTBOX *
CREATIVE_TYPE_PUBLISHER_HOSTED If this field is specified, width_pixels and
height_pixels are both required and must be greater than or equal to 0.
Corresponds to the JSON property additionalDimensions
5504 5505 5506 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5504 def additional_dimensions @additional_dimensions end |
#advertiser_id ⇒ Fixnum
Output only. The unique ID of the advertiser the creative belongs to.
Corresponds to the JSON property advertiserId
5509 5510 5511 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5509 def advertiser_id @advertiser_id end |
#appended_tag ⇒ String
Optional. Third-party HTML tracking tag to be appended to the creative tag.
Corresponds to the JSON property appendedTag
5514 5515 5516 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5514 def appended_tag @appended_tag end |
#assets ⇒ Array<Google::Apis::DisplayvideoV4::AssetAssociation>
Required. Assets associated to this creative.
Corresponds to the JSON property assets
5519 5520 5521 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5519 def assets @assets end |
#cm_placement_id ⇒ Fixnum
Output only. The unique ID of the Campaign Manager 360 placement associated
with the creative. This field is only applicable for creatives that are synced
from Campaign Manager.
Corresponds to the JSON property cmPlacementId
5526 5527 5528 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5526 def cm_placement_id @cm_placement_id end |
#cm_tracking_ad ⇒ Google::Apis::DisplayvideoV4::CmTrackingAd
A Campaign Manager 360 tracking ad.
Corresponds to the JSON property cmTrackingAd
5531 5532 5533 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5531 def cm_tracking_ad @cm_tracking_ad end |
#companion_creative_ids ⇒ Array<Fixnum>
Optional. The IDs of companion creatives for a video creative. You can assign
existing display creatives (with image or HTML5 assets) to serve surrounding
the publisher's video player. Companions display around the video player while
the video is playing and remain after the video has completed. Creatives
contain additional dimensions can not be companion creatives. This field is
only supported for the following creative_type: * CREATIVE_TYPE_AUDIO *
CREATIVE_TYPE_VIDEO
Corresponds to the JSON property companionCreativeIds
5542 5543 5544 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5542 def companion_creative_ids @companion_creative_ids end |
#counter_events ⇒ Array<Google::Apis::DisplayvideoV4::CounterEvent>
Optional. Counter events for a rich media creative. Counters track the number
of times that a user interacts with any part of a rich media creative in a
specified way (mouse-overs, mouse-outs, clicks, taps, data loading, keyboard
entries, etc.). Any event that can be captured in the creative can be recorded
as a counter. Leave it empty or unset for creatives containing image assets
only.
Corresponds to the JSON property counterEvents
5552 5553 5554 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5552 def counter_events @counter_events end |
#create_time ⇒ String
Output only. The timestamp when the creative was created. Assigned by the
system.
Corresponds to the JSON property createTime
5558 5559 5560 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5558 def create_time @create_time end |
#creative_attributes ⇒ Array<String>
Output only. A list of attributes of the creative that is generated by the
system.
Corresponds to the JSON property creativeAttributes
5564 5565 5566 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5564 def creative_attributes @creative_attributes end |
#creative_id ⇒ Fixnum
Output only. The unique ID of the creative. Assigned by the system.
Corresponds to the JSON property creativeId
5569 5570 5571 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5569 def creative_id @creative_id end |
#creative_type ⇒ String
Required. Immutable. The type of the creative.
Corresponds to the JSON property creativeType
5574 5575 5576 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5574 def creative_type @creative_type end |
#dimensions ⇒ Google::Apis::DisplayvideoV4::Dimensions
Dimensions.
Corresponds to the JSON property dimensions
5579 5580 5581 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5579 def dimensions @dimensions end |
#display_name ⇒ String
Required. The display name of the creative. Must be UTF-8 encoded with a
maximum size of 240 bytes.
Corresponds to the JSON property displayName
5585 5586 5587 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5585 def display_name @display_name end |
#dynamic ⇒ Boolean Also known as: dynamic?
Output only. Indicates whether the creative is dynamic.
Corresponds to the JSON property dynamic
5590 5591 5592 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5590 def dynamic @dynamic end |
#entity_status ⇒ String
Required. Controls whether or not the creative can serve. Accepted values are:
ENTITY_STATUS_ACTIVE*ENTITY_STATUS_ARCHIVED*ENTITY_STATUS_PAUSEDCorresponds to the JSON propertyentityStatus
5597 5598 5599 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5597 def entity_status @entity_status end |
#exit_events ⇒ Array<Google::Apis::DisplayvideoV4::ExitEvent>
Required. Exit events for this creative. An exit (also known as a click tag)
is any area in your creative that someone can click or tap to open an
advertiser's landing page. Every creative must include at least one exit. You
can add an exit to your creative in any of the following ways: * Use Google
Web Designer's tap area. * Define a JavaScript variable called "clickTag". *
Use the Enabler (Enabler.exit()) to track exits in rich media formats.
Corresponds to the JSON property exitEvents
5607 5608 5609 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5607 def exit_events @exit_events end |
#expand_on_hover ⇒ Boolean Also known as: expand_on_hover?
Optional. Indicates the creative will automatically expand on hover. Optional
and only valid for third-party expandable creatives. Third-party expandable
creatives are creatives with following hosting source: *
HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: *
CREATIVE_TYPE_EXPANDABLE
Corresponds to the JSON property expandOnHover
5616 5617 5618 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5616 def @expand_on_hover end |
#expanding_direction ⇒ String
Optional. Specifies the expanding direction of the creative. Required and only
valid for third-party expandable creatives. Third-party expandable creatives
are creatives with following hosting source: * HOSTING_SOURCE_THIRD_PARTY
combined with following creative_type: * CREATIVE_TYPE_EXPANDABLE
Corresponds to the JSON property expandingDirection
5625 5626 5627 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5625 def @expanding_direction end |
#hosting_source ⇒ String
Required. Indicates where the creative is hosted.
Corresponds to the JSON property hostingSource
5630 5631 5632 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5630 def hosting_source @hosting_source end |
#html5_video ⇒ Boolean Also known as: html5_video?
Output only. Indicates the third-party VAST tag creative requires HTML5 Video
support. Output only and only valid for third-party VAST tag creatives. Third-
party VAST tag creatives are creatives with following hosting_source: *
HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: *
CREATIVE_TYPE_VIDEO
Corresponds to the JSON property html5Video
5639 5640 5641 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5639 def html5_video @html5_video end |
#ias_campaign_monitoring ⇒ Boolean Also known as: ias_campaign_monitoring?
Optional. Indicates whether Integral Ad Science (IAS) campaign monitoring is
enabled. To enable this for the creative, make sure the Advertiser.
creative_config.ias_client_id has been set to your IAS client ID.
Corresponds to the JSON property iasCampaignMonitoring
5647 5648 5649 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5647 def ias_campaign_monitoring @ias_campaign_monitoring end |
#integration_code ⇒ String
Optional. ID information used to link this creative to an external system.
Must be UTF-8 encoded with a length of no more than 10,000 characters.
Corresponds to the JSON property integrationCode
5654 5655 5656 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5654 def integration_code @integration_code end |
#js_tracker_url ⇒ String
Optional. JavaScript measurement URL from supported third-party verification
providers (ComScore, DoubleVerify, IAS, Moat). HTML script tags are not
supported. This field is only writeable in the following creative_type: *
CREATIVE_TYPE_NATIVE * CREATIVE_TYPE_NATIVE_SITE_SQUARE *
CREATIVE_TYPE_NATIVE_VIDEO
Corresponds to the JSON property jsTrackerUrl
5663 5664 5665 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5663 def js_tracker_url @js_tracker_url end |
#line_item_ids ⇒ Array<Fixnum>
Output only. The IDs of the line items this creative is associated with. To
associate a creative to a line item, use LineItem.creative_ids instead.
Corresponds to the JSON property lineItemIds
5669 5670 5671 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5669 def line_item_ids @line_item_ids end |
#media_duration ⇒ String
Output only. Media duration of the creative. Applicable when creative_type is
one of: * CREATIVE_TYPE_VIDEO * CREATIVE_TYPE_AUDIO *
CREATIVE_TYPE_NATIVE_VIDEO * CREATIVE_TYPE_PUBLISHER_HOSTED
Corresponds to the JSON property mediaDuration
5676 5677 5678 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5676 def media_duration @media_duration end |
#mp3_audio ⇒ Boolean Also known as: mp3_audio?
Output only. Indicates the third-party audio creative supports MP3. Output
only and only valid for third-party audio creatives. Third-party audio
creatives are creatives with following hosting_source: *
HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: *
CREATIVE_TYPE_AUDIO
Corresponds to the JSON property mp3Audio
5685 5686 5687 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5685 def mp3_audio @mp3_audio end |
#name ⇒ String
Output only. The resource name of the creative.
Corresponds to the JSON property name
5691 5692 5693 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5691 def name @name end |
#notes ⇒ String
Optional. User notes for this creative. Must be UTF-8 encoded with a length of
no more than 20,000 characters.
Corresponds to the JSON property notes
5697 5698 5699 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5697 def notes @notes end |
#oba_icon ⇒ Google::Apis::DisplayvideoV4::ObaIcon
OBA Icon for a Creative
Corresponds to the JSON property obaIcon
5702 5703 5704 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5702 def oba_icon @oba_icon end |
#ogg_audio ⇒ Boolean Also known as: ogg_audio?
Output only. Indicates the third-party audio creative supports OGG. Output
only and only valid for third-party audio creatives. Third-party audio
creatives are creatives with following hosting_source: *
HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: *
CREATIVE_TYPE_AUDIO
Corresponds to the JSON property oggAudio
5711 5712 5713 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5711 def ogg_audio @ogg_audio end |
#progress_offset ⇒ Google::Apis::DisplayvideoV4::AudioVideoOffset
The length an audio or a video has been played.
Corresponds to the JSON property progressOffset
5717 5718 5719 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5717 def progress_offset @progress_offset end |
#require_html5 ⇒ Boolean Also known as: require_html5?
Optional. Indicates that the creative relies on HTML5 to render properly.
Optional and only valid for third-party tag creatives. Third-party tag
creatives are creatives with following hosting_source: *
HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: *
CREATIVE_TYPE_STANDARD * CREATIVE_TYPE_EXPANDABLE
Corresponds to the JSON property requireHtml5
5726 5727 5728 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5726 def require_html5 @require_html5 end |
#require_mraid ⇒ Boolean Also known as: require_mraid?
Optional. Indicates that the creative requires MRAID (Mobile Rich Media Ad
Interface Definitions system). Set this if the creative relies on mobile
gestures for interactivity, such as swiping or tapping. Optional and only
valid for third-party tag creatives. Third-party tag creatives are creatives
with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with
following creative_type: * CREATIVE_TYPE_STANDARD *
CREATIVE_TYPE_EXPANDABLE
Corresponds to the JSON property requireMraid
5738 5739 5740 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5738 def require_mraid @require_mraid end |
#require_ping_for_attribution ⇒ Boolean Also known as: require_ping_for_attribution?
Optional. Indicates that the creative will wait for a return ping for
attribution. Only valid when using a Campaign Manager 360 tracking ad with a
third-party ad server parameter and the $DC_DBM_TOKEN macro. Optional and
only valid for third-party tag creatives or third-party VAST tag creatives.
Third-party tag creatives are creatives with following hosting_source: *
HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: *
CREATIVE_TYPE_STANDARD * CREATIVE_TYPE_EXPANDABLE Third-party VAST tag
creatives are creatives with following hosting_source: *
HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: *
CREATIVE_TYPE_AUDIO * CREATIVE_TYPE_VIDEO
Corresponds to the JSON property requirePingForAttribution
5753 5754 5755 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5753 def require_ping_for_attribution @require_ping_for_attribution end |
#review_status ⇒ Google::Apis::DisplayvideoV4::ReviewStatusInfo
Review statuses for the creative.
Corresponds to the JSON property reviewStatus
5759 5760 5761 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5759 def review_status @review_status end |
#skip_offset ⇒ Google::Apis::DisplayvideoV4::AudioVideoOffset
The length an audio or a video has been played.
Corresponds to the JSON property skipOffset
5764 5765 5766 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5764 def skip_offset @skip_offset end |
#skippable ⇒ Boolean Also known as: skippable?
Optional. Whether the user can choose to skip a video creative. This field is
only supported for the following creative_type: * CREATIVE_TYPE_VIDEO
Corresponds to the JSON property skippable
5770 5771 5772 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5770 def skippable @skippable end |
#synthetic_content_attestation_status ⇒ String
Optional. Whether to add a label to the creative as created or edited using AI
when served in regions with local AI labeling regulations.
Corresponds to the JSON property syntheticContentAttestationStatus
5777 5778 5779 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5777 def synthetic_content_attestation_status @synthetic_content_attestation_status end |
#third_party_tag ⇒ String
Optional. The original third-party tag used for the creative. Required and
only valid for third-party tag creatives. Third-party tag creatives are
creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY
combined with following creative_type: * CREATIVE_TYPE_STANDARD *
CREATIVE_TYPE_EXPANDABLE
Corresponds to the JSON property thirdPartyTag
5786 5787 5788 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5786 def third_party_tag @third_party_tag end |
#third_party_urls ⇒ Array<Google::Apis::DisplayvideoV4::ThirdPartyUrl>
Optional. Tracking URLs from third parties to track interactions with a video
creative. This field is only supported for the following creative_type: *
CREATIVE_TYPE_AUDIO * CREATIVE_TYPE_VIDEO * CREATIVE_TYPE_NATIVE_VIDEO
Corresponds to the JSON property thirdPartyUrls
5793 5794 5795 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5793 def third_party_urls @third_party_urls end |
#timer_events ⇒ Array<Google::Apis::DisplayvideoV4::TimerEvent>
Optional. Timer custom events for a rich media creative. Timers track the time
during which a user views and interacts with a specified part of a rich media
creative. A creative can have multiple timer events, each timed independently.
Leave it empty or unset for creatives containing image assets only.
Corresponds to the JSON property timerEvents
5801 5802 5803 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5801 def timer_events @timer_events end |
#tracker_urls ⇒ Array<String>
Optional. Tracking URLs for analytics providers or third-party ad technology
vendors. The URLs must start with https: (except on inventory that doesn't
require SSL compliance). If using macros in your URL, use only macros
supported by Display & Video 360. Standard URLs only, no IMG or SCRIPT tags.
This field is only writeable in the following creative_type: *
CREATIVE_TYPE_NATIVE * CREATIVE_TYPE_NATIVE_SITE_SQUARE *
CREATIVE_TYPE_NATIVE_VIDEO
Corresponds to the JSON property trackerUrls
5812 5813 5814 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5812 def tracker_urls @tracker_urls end |
#transcodes ⇒ Array<Google::Apis::DisplayvideoV4::Transcode>
Output only. Audio/Video transcodes. Display & Video 360 transcodes the main
asset into a number of alternative versions that use different file formats or
have different properties (resolution, audio bit rate, and video bit rate),
each designed for specific video players or bandwidths. These transcodes give
a publisher's system more options to choose from for each impression on your
video and ensures that the appropriate file serves based on the viewer’s
connection and screen size. This field is only supported in the following
creative_type: * CREATIVE_TYPE_VIDEO * CREATIVE_TYPE_NATIVE_VIDEO *
CREATIVE_TYPE_AUDIO
Corresponds to the JSON property transcodes
5825 5826 5827 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5825 def transcodes @transcodes end |
#universal_ad_id ⇒ Google::Apis::DisplayvideoV4::UniversalAdId
A creative identifier provided by a registry that is unique across all
platforms. This is part of the VAST 4.0 standard.
Corresponds to the JSON property universalAdId
5831 5832 5833 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5831 def universal_ad_id @universal_ad_id end |
#update_time ⇒ String
Output only. The timestamp when the creative was last updated, either by the
user or system (e.g. creative review). Assigned by the system.
Corresponds to the JSON property updateTime
5837 5838 5839 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5837 def update_time @update_time end |
#vast_tag_url ⇒ String
Optional. The URL of the VAST tag for a third-party VAST tag creative.
Required and only valid for third-party VAST tag creatives. Third-party VAST
tag creatives are creatives with following hosting_source: *
HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: *
CREATIVE_TYPE_AUDIO * CREATIVE_TYPE_VIDEO
Corresponds to the JSON property vastTagUrl
5846 5847 5848 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5846 def vast_tag_url @vast_tag_url end |
#vpaid ⇒ Boolean Also known as: vpaid?
Output only. Indicates the third-party VAST tag creative requires VPAID (
Digital Video Player-Ad Interface). Output only and only valid for third-party
VAST tag creatives. Third-party VAST tag creatives are creatives with
following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with
following creative_type: * CREATIVE_TYPE_VIDEO
Corresponds to the JSON property vpaid
5855 5856 5857 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5855 def vpaid @vpaid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 5883 5884 5885 5886 5887 5888 5889 5890 5891 5892 5893 5894 5895 5896 5897 5898 5899 5900 5901 5902 5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5863 def update!(**args) @additional_dimensions = args[:additional_dimensions] if args.key?(:additional_dimensions) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @appended_tag = args[:appended_tag] if args.key?(:appended_tag) @assets = args[:assets] if args.key?(:assets) @cm_placement_id = args[:cm_placement_id] if args.key?(:cm_placement_id) @cm_tracking_ad = args[:cm_tracking_ad] if args.key?(:cm_tracking_ad) @companion_creative_ids = args[:companion_creative_ids] if args.key?(:companion_creative_ids) @counter_events = args[:counter_events] if args.key?(:counter_events) @create_time = args[:create_time] if args.key?(:create_time) @creative_attributes = args[:creative_attributes] if args.key?(:creative_attributes) @creative_id = args[:creative_id] if args.key?(:creative_id) @creative_type = args[:creative_type] if args.key?(:creative_type) @dimensions = args[:dimensions] if args.key?(:dimensions) @display_name = args[:display_name] if args.key?(:display_name) @dynamic = args[:dynamic] if args.key?(:dynamic) @entity_status = args[:entity_status] if args.key?(:entity_status) @exit_events = args[:exit_events] if args.key?(:exit_events) @expand_on_hover = args[:expand_on_hover] if args.key?(:expand_on_hover) @expanding_direction = args[:expanding_direction] if args.key?(:expanding_direction) @hosting_source = args[:hosting_source] if args.key?(:hosting_source) @html5_video = args[:html5_video] if args.key?(:html5_video) @ias_campaign_monitoring = args[:ias_campaign_monitoring] if args.key?(:ias_campaign_monitoring) @integration_code = args[:integration_code] if args.key?(:integration_code) @js_tracker_url = args[:js_tracker_url] if args.key?(:js_tracker_url) @line_item_ids = args[:line_item_ids] if args.key?(:line_item_ids) @media_duration = args[:media_duration] if args.key?(:media_duration) @mp3_audio = args[:mp3_audio] if args.key?(:mp3_audio) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @oba_icon = args[:oba_icon] if args.key?(:oba_icon) @ogg_audio = args[:ogg_audio] if args.key?(:ogg_audio) @progress_offset = args[:progress_offset] if args.key?(:progress_offset) @require_html5 = args[:require_html5] if args.key?(:require_html5) @require_mraid = args[:require_mraid] if args.key?(:require_mraid) @require_ping_for_attribution = args[:require_ping_for_attribution] if args.key?(:require_ping_for_attribution) @review_status = args[:review_status] if args.key?(:review_status) @skip_offset = args[:skip_offset] if args.key?(:skip_offset) @skippable = args[:skippable] if args.key?(:skippable) @synthetic_content_attestation_status = args[:synthetic_content_attestation_status] if args.key?(:synthetic_content_attestation_status) @third_party_tag = args[:third_party_tag] if args.key?(:third_party_tag) @third_party_urls = args[:third_party_urls] if args.key?(:third_party_urls) @timer_events = args[:timer_events] if args.key?(:timer_events) @tracker_urls = args[:tracker_urls] if args.key?(:tracker_urls) @transcodes = args[:transcodes] if args.key?(:transcodes) @universal_ad_id = args[:universal_ad_id] if args.key?(:universal_ad_id) @update_time = args[:update_time] if args.key?(:update_time) @vast_tag_url = args[:vast_tag_url] if args.key?(:vast_tag_url) @vpaid = args[:vpaid] if args.key?(:vpaid) end |