Class: Google::Apis::DisplayvideoV4::Creative

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single Creative.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Creative

Returns a new instance of Creative.



5716
5717
5718
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_dimensionsArray<Google::Apis::DisplayvideoV4::Dimensions>

Optional. Additional dimensions. Applicable when creative_type is one of: * CREATIVE_TYPE_STANDARD * CREATIVE_TYPE_EXPANDABLE * CREATIVE_TYPE_NATIVE * CREATIVE_TYPE_NATIVE_SITE_SQUARE * CREATIVE_TYPE_LIGHTBOX * CREATIVE_TYPE_PUBLISHER_HOSTED If this field is specified, width_pixels and height_pixels are both required and must be greater than or equal to 0. Corresponds to the JSON property additionalDimensions



5368
5369
5370
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5368

def additional_dimensions
  @additional_dimensions
end

#advertiser_idFixnum

Output only. The unique ID of the advertiser the creative belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


5373
5374
5375
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5373

def advertiser_id
  @advertiser_id
end

#appended_tagString

Optional. Third-party HTML tracking tag to be appended to the creative tag. Corresponds to the JSON property appendedTag

Returns:

  • (String)


5378
5379
5380
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5378

def appended_tag
  @appended_tag
end

#assetsArray<Google::Apis::DisplayvideoV4::AssetAssociation>

Required. Assets associated to this creative. Corresponds to the JSON property assets



5383
5384
5385
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5383

def assets
  @assets
end

#cm_placement_idFixnum

Output only. The unique ID of the Campaign Manager 360 placement associated with the creative. This field is only applicable for creatives that are synced from Campaign Manager. Corresponds to the JSON property cmPlacementId

Returns:

  • (Fixnum)


5390
5391
5392
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5390

def cm_placement_id
  @cm_placement_id
end

#cm_tracking_adGoogle::Apis::DisplayvideoV4::CmTrackingAd

A Campaign Manager 360 tracking ad. Corresponds to the JSON property cmTrackingAd



5395
5396
5397
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5395

def cm_tracking_ad
  @cm_tracking_ad
end

#companion_creative_idsArray<Fixnum>

Optional. The IDs of companion creatives for a video creative. You can assign existing display creatives (with image or HTML5 assets) to serve surrounding the publisher's video player. Companions display around the video player while the video is playing and remain after the video has completed. Creatives contain additional dimensions can not be companion creatives. This field is only supported for the following creative_type: * CREATIVE_TYPE_AUDIO * CREATIVE_TYPE_VIDEO Corresponds to the JSON property companionCreativeIds

Returns:

  • (Array<Fixnum>)


5406
5407
5408
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5406

def companion_creative_ids
  @companion_creative_ids
end

#counter_eventsArray<Google::Apis::DisplayvideoV4::CounterEvent>

Optional. Counter events for a rich media creative. Counters track the number of times that a user interacts with any part of a rich media creative in a specified way (mouse-overs, mouse-outs, clicks, taps, data loading, keyboard entries, etc.). Any event that can be captured in the creative can be recorded as a counter. Leave it empty or unset for creatives containing image assets only. Corresponds to the JSON property counterEvents



5416
5417
5418
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5416

def counter_events
  @counter_events
end

#create_timeString

Output only. The timestamp when the creative was created. Assigned by the system. Corresponds to the JSON property createTime

Returns:

  • (String)


5422
5423
5424
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5422

def create_time
  @create_time
end

#creative_attributesArray<String>

Output only. A list of attributes of the creative that is generated by the system. Corresponds to the JSON property creativeAttributes

Returns:

  • (Array<String>)


5428
5429
5430
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5428

def creative_attributes
  @creative_attributes
end

#creative_idFixnum

Output only. The unique ID of the creative. Assigned by the system. Corresponds to the JSON property creativeId

Returns:

  • (Fixnum)


5433
5434
5435
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5433

def creative_id
  @creative_id
end

#creative_typeString

Required. Immutable. The type of the creative. Corresponds to the JSON property creativeType

Returns:

  • (String)


5438
5439
5440
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5438

def creative_type
  @creative_type
end

#dimensionsGoogle::Apis::DisplayvideoV4::Dimensions

Dimensions. Corresponds to the JSON property dimensions



5443
5444
5445
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5443

def dimensions
  @dimensions
end

#display_nameString

Required. The display name of the creative. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


5449
5450
5451
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5449

def display_name
  @display_name
end

#dynamicBoolean Also known as: dynamic?

Output only. Indicates whether the creative is dynamic. Corresponds to the JSON property dynamic

Returns:

  • (Boolean)


5454
5455
5456
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5454

def dynamic
  @dynamic
end

#entity_statusString

Required. Controls whether or not the creative can serve. Accepted values are:

  • ENTITY_STATUS_ACTIVE * ENTITY_STATUS_ARCHIVED * ENTITY_STATUS_PAUSED Corresponds to the JSON property entityStatus

Returns:

  • (String)


5461
5462
5463
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5461

def entity_status
  @entity_status
end

#exit_eventsArray<Google::Apis::DisplayvideoV4::ExitEvent>

Required. Exit events for this creative. An exit (also known as a click tag) is any area in your creative that someone can click or tap to open an advertiser's landing page. Every creative must include at least one exit. You can add an exit to your creative in any of the following ways: * Use Google Web Designer's tap area. * Define a JavaScript variable called "clickTag". * Use the Enabler (Enabler.exit()) to track exits in rich media formats. Corresponds to the JSON property exitEvents



5471
5472
5473
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5471

def exit_events
  @exit_events
end

#expand_on_hoverBoolean Also known as: expand_on_hover?

Optional. Indicates the creative will automatically expand on hover. Optional and only valid for third-party expandable creatives. Third-party expandable creatives are creatives with following hosting source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_EXPANDABLE Corresponds to the JSON property expandOnHover

Returns:

  • (Boolean)


5480
5481
5482
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5480

def expand_on_hover
  @expand_on_hover
end

#expanding_directionString

Optional. Specifies the expanding direction of the creative. Required and only valid for third-party expandable creatives. Third-party expandable creatives are creatives with following hosting source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_EXPANDABLE Corresponds to the JSON property expandingDirection

Returns:

  • (String)


5489
5490
5491
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5489

def expanding_direction
  @expanding_direction
end

#hosting_sourceString

Required. Indicates where the creative is hosted. Corresponds to the JSON property hostingSource

Returns:

  • (String)


5494
5495
5496
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5494

def hosting_source
  @hosting_source
end

#html5_videoBoolean Also known as: html5_video?

Output only. Indicates the third-party VAST tag creative requires HTML5 Video support. Output only and only valid for third-party VAST tag creatives. Third- party VAST tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_VIDEO Corresponds to the JSON property html5Video

Returns:

  • (Boolean)


5503
5504
5505
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5503

def html5_video
  @html5_video
end

#ias_campaign_monitoringBoolean Also known as: ias_campaign_monitoring?

Optional. Indicates whether Integral Ad Science (IAS) campaign monitoring is enabled. To enable this for the creative, make sure the Advertiser. creative_config.ias_client_id has been set to your IAS client ID. Corresponds to the JSON property iasCampaignMonitoring

Returns:

  • (Boolean)


5511
5512
5513
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5511

def ias_campaign_monitoring
  @ias_campaign_monitoring
end

#integration_codeString

Optional. ID information used to link this creative to an external system. Must be UTF-8 encoded with a length of no more than 10,000 characters. Corresponds to the JSON property integrationCode

Returns:

  • (String)


5518
5519
5520
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5518

def integration_code
  @integration_code
end

#js_tracker_urlString

Optional. JavaScript measurement URL from supported third-party verification providers (ComScore, DoubleVerify, IAS, Moat). HTML script tags are not supported. This field is only writeable in the following creative_type: * CREATIVE_TYPE_NATIVE * CREATIVE_TYPE_NATIVE_SITE_SQUARE * CREATIVE_TYPE_NATIVE_VIDEO Corresponds to the JSON property jsTrackerUrl

Returns:

  • (String)


5527
5528
5529
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5527

def js_tracker_url
  @js_tracker_url
end

#line_item_idsArray<Fixnum>

Output only. The IDs of the line items this creative is associated with. To associate a creative to a line item, use LineItem.creative_ids instead. Corresponds to the JSON property lineItemIds

Returns:

  • (Array<Fixnum>)


5533
5534
5535
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5533

def line_item_ids
  @line_item_ids
end

#media_durationString

Output only. Media duration of the creative. Applicable when creative_type is one of: * CREATIVE_TYPE_VIDEO * CREATIVE_TYPE_AUDIO * CREATIVE_TYPE_NATIVE_VIDEO * CREATIVE_TYPE_PUBLISHER_HOSTED Corresponds to the JSON property mediaDuration

Returns:

  • (String)


5540
5541
5542
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5540

def media_duration
  @media_duration
end

#mp3_audioBoolean Also known as: mp3_audio?

Output only. Indicates the third-party audio creative supports MP3. Output only and only valid for third-party audio creatives. Third-party audio creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_AUDIO Corresponds to the JSON property mp3Audio

Returns:

  • (Boolean)


5549
5550
5551
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5549

def mp3_audio
  @mp3_audio
end

#nameString

Output only. The resource name of the creative. Corresponds to the JSON property name

Returns:

  • (String)


5555
5556
5557
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5555

def name
  @name
end

#notesString

Optional. User notes for this creative. Must be UTF-8 encoded with a length of no more than 20,000 characters. Corresponds to the JSON property notes

Returns:

  • (String)


5561
5562
5563
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5561

def notes
  @notes
end

#oba_iconGoogle::Apis::DisplayvideoV4::ObaIcon

OBA Icon for a Creative Corresponds to the JSON property obaIcon



5566
5567
5568
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5566

def oba_icon
  @oba_icon
end

#ogg_audioBoolean Also known as: ogg_audio?

Output only. Indicates the third-party audio creative supports OGG. Output only and only valid for third-party audio creatives. Third-party audio creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_AUDIO Corresponds to the JSON property oggAudio

Returns:

  • (Boolean)


5575
5576
5577
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5575

def ogg_audio
  @ogg_audio
end

#progress_offsetGoogle::Apis::DisplayvideoV4::AudioVideoOffset

The length an audio or a video has been played. Corresponds to the JSON property progressOffset



5581
5582
5583
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5581

def progress_offset
  @progress_offset
end

#require_html5Boolean Also known as: require_html5?

Optional. Indicates that the creative relies on HTML5 to render properly. Optional and only valid for third-party tag creatives. Third-party tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_STANDARD * CREATIVE_TYPE_EXPANDABLE Corresponds to the JSON property requireHtml5

Returns:

  • (Boolean)


5590
5591
5592
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5590

def require_html5
  @require_html5
end

#require_mraidBoolean Also known as: require_mraid?

Optional. Indicates that the creative requires MRAID (Mobile Rich Media Ad Interface Definitions system). Set this if the creative relies on mobile gestures for interactivity, such as swiping or tapping. Optional and only valid for third-party tag creatives. Third-party tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_STANDARD * CREATIVE_TYPE_EXPANDABLE Corresponds to the JSON property requireMraid

Returns:

  • (Boolean)


5602
5603
5604
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5602

def require_mraid
  @require_mraid
end

#require_ping_for_attributionBoolean Also known as: require_ping_for_attribution?

Optional. Indicates that the creative will wait for a return ping for attribution. Only valid when using a Campaign Manager 360 tracking ad with a third-party ad server parameter and the $DC_DBM_TOKEN macro. Optional and only valid for third-party tag creatives or third-party VAST tag creatives. Third-party tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_STANDARD * CREATIVE_TYPE_EXPANDABLE Third-party VAST tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_AUDIO * CREATIVE_TYPE_VIDEO Corresponds to the JSON property requirePingForAttribution

Returns:

  • (Boolean)


5617
5618
5619
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5617

def require_ping_for_attribution
  @require_ping_for_attribution
end

#review_statusGoogle::Apis::DisplayvideoV4::ReviewStatusInfo

Review statuses for the creative. Corresponds to the JSON property reviewStatus



5623
5624
5625
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5623

def review_status
  @review_status
end

#skip_offsetGoogle::Apis::DisplayvideoV4::AudioVideoOffset

The length an audio or a video has been played. Corresponds to the JSON property skipOffset



5628
5629
5630
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5628

def skip_offset
  @skip_offset
end

#skippableBoolean Also known as: skippable?

Optional. Whether the user can choose to skip a video creative. This field is only supported for the following creative_type: * CREATIVE_TYPE_VIDEO Corresponds to the JSON property skippable

Returns:

  • (Boolean)


5634
5635
5636
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5634

def skippable
  @skippable
end

#third_party_tagString

Optional. The original third-party tag used for the creative. Required and only valid for third-party tag creatives. Third-party tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_STANDARD * CREATIVE_TYPE_EXPANDABLE Corresponds to the JSON property thirdPartyTag

Returns:

  • (String)


5644
5645
5646
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5644

def third_party_tag
  @third_party_tag
end

#third_party_urlsArray<Google::Apis::DisplayvideoV4::ThirdPartyUrl>

Optional. Tracking URLs from third parties to track interactions with a video creative. This field is only supported for the following creative_type: * CREATIVE_TYPE_AUDIO * CREATIVE_TYPE_VIDEO * CREATIVE_TYPE_NATIVE_VIDEO Corresponds to the JSON property thirdPartyUrls



5651
5652
5653
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5651

def third_party_urls
  @third_party_urls
end

#timer_eventsArray<Google::Apis::DisplayvideoV4::TimerEvent>

Optional. Timer custom events for a rich media creative. Timers track the time during which a user views and interacts with a specified part of a rich media creative. A creative can have multiple timer events, each timed independently. Leave it empty or unset for creatives containing image assets only. Corresponds to the JSON property timerEvents



5659
5660
5661
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5659

def timer_events
  @timer_events
end

#tracker_urlsArray<String>

Optional. Tracking URLs for analytics providers or third-party ad technology vendors. The URLs must start with https: (except on inventory that doesn't require SSL compliance). If using macros in your URL, use only macros supported by Display & Video 360. Standard URLs only, no IMG or SCRIPT tags. This field is only writeable in the following creative_type: * CREATIVE_TYPE_NATIVE * CREATIVE_TYPE_NATIVE_SITE_SQUARE * CREATIVE_TYPE_NATIVE_VIDEO Corresponds to the JSON property trackerUrls

Returns:

  • (Array<String>)


5670
5671
5672
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5670

def tracker_urls
  @tracker_urls
end

#transcodesArray<Google::Apis::DisplayvideoV4::Transcode>

Output only. Audio/Video transcodes. Display & Video 360 transcodes the main asset into a number of alternative versions that use different file formats or have different properties (resolution, audio bit rate, and video bit rate), each designed for specific video players or bandwidths. These transcodes give a publisher's system more options to choose from for each impression on your video and ensures that the appropriate file serves based on the viewer’s connection and screen size. This field is only supported in the following creative_type: * CREATIVE_TYPE_VIDEO * CREATIVE_TYPE_NATIVE_VIDEO * CREATIVE_TYPE_AUDIO Corresponds to the JSON property transcodes



5683
5684
5685
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5683

def transcodes
  @transcodes
end

#universal_ad_idGoogle::Apis::DisplayvideoV4::UniversalAdId

A creative identifier provided by a registry that is unique across all platforms. This is part of the VAST 4.0 standard. Corresponds to the JSON property universalAdId



5689
5690
5691
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5689

def universal_ad_id
  @universal_ad_id
end

#update_timeString

Output only. The timestamp when the creative was last updated, either by the user or system (e.g. creative review). Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


5695
5696
5697
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5695

def update_time
  @update_time
end

#vast_tag_urlString

Optional. The URL of the VAST tag for a third-party VAST tag creative. Required and only valid for third-party VAST tag creatives. Third-party VAST tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_AUDIO * CREATIVE_TYPE_VIDEO Corresponds to the JSON property vastTagUrl

Returns:

  • (String)


5704
5705
5706
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5704

def vast_tag_url
  @vast_tag_url
end

#vpaidBoolean Also known as: vpaid?

Output only. Indicates the third-party VAST tag creative requires VPAID ( Digital Video Player-Ad Interface). Output only and only valid for third-party VAST tag creatives. Third-party VAST tag creatives are creatives with following hosting_source: * HOSTING_SOURCE_THIRD_PARTY combined with following creative_type: * CREATIVE_TYPE_VIDEO Corresponds to the JSON property vpaid

Returns:

  • (Boolean)


5713
5714
5715
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5713

def vpaid
  @vpaid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
5739
5740
5741
5742
5743
5744
5745
5746
5747
5748
5749
5750
5751
5752
5753
5754
5755
5756
5757
5758
5759
5760
5761
5762
5763
5764
5765
5766
5767
5768
5769
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5721

def update!(**args)
  @additional_dimensions = args[:additional_dimensions] if args.key?(:additional_dimensions)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @appended_tag = args[:appended_tag] if args.key?(:appended_tag)
  @assets = args[:assets] if args.key?(:assets)
  @cm_placement_id = args[:cm_placement_id] if args.key?(:cm_placement_id)
  @cm_tracking_ad = args[:cm_tracking_ad] if args.key?(:cm_tracking_ad)
  @companion_creative_ids = args[:companion_creative_ids] if args.key?(:companion_creative_ids)
  @counter_events = args[:counter_events] if args.key?(:counter_events)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creative_attributes = args[:creative_attributes] if args.key?(:creative_attributes)
  @creative_id = args[:creative_id] if args.key?(:creative_id)
  @creative_type = args[:creative_type] if args.key?(:creative_type)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @dynamic = args[:dynamic] if args.key?(:dynamic)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @exit_events = args[:exit_events] if args.key?(:exit_events)
  @expand_on_hover = args[:expand_on_hover] if args.key?(:expand_on_hover)
  @expanding_direction = args[:expanding_direction] if args.key?(:expanding_direction)
  @hosting_source = args[:hosting_source] if args.key?(:hosting_source)
  @html5_video = args[:html5_video] if args.key?(:html5_video)
  @ias_campaign_monitoring = args[:ias_campaign_monitoring] if args.key?(:ias_campaign_monitoring)
  @integration_code = args[:integration_code] if args.key?(:integration_code)
  @js_tracker_url = args[:js_tracker_url] if args.key?(:js_tracker_url)
  @line_item_ids = args[:line_item_ids] if args.key?(:line_item_ids)
  @media_duration = args[:media_duration] if args.key?(:media_duration)
  @mp3_audio = args[:mp3_audio] if args.key?(:mp3_audio)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @oba_icon = args[:oba_icon] if args.key?(:oba_icon)
  @ogg_audio = args[:ogg_audio] if args.key?(:ogg_audio)
  @progress_offset = args[:progress_offset] if args.key?(:progress_offset)
  @require_html5 = args[:require_html5] if args.key?(:require_html5)
  @require_mraid = args[:require_mraid] if args.key?(:require_mraid)
  @require_ping_for_attribution = args[:require_ping_for_attribution] if args.key?(:require_ping_for_attribution)
  @review_status = args[:review_status] if args.key?(:review_status)
  @skip_offset = args[:skip_offset] if args.key?(:skip_offset)
  @skippable = args[:skippable] if args.key?(:skippable)
  @third_party_tag = args[:third_party_tag] if args.key?(:third_party_tag)
  @third_party_urls = args[:third_party_urls] if args.key?(:third_party_urls)
  @timer_events = args[:timer_events] if args.key?(:timer_events)
  @tracker_urls = args[:tracker_urls] if args.key?(:tracker_urls)
  @transcodes = args[:transcodes] if args.key?(:transcodes)
  @universal_ad_id = args[:universal_ad_id] if args.key?(:universal_ad_id)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vast_tag_url = args[:vast_tag_url] if args.key?(:vast_tag_url)
  @vpaid = args[:vpaid] if args.key?(:vpaid)
end