Class: Google::Apis::DisplayvideoV4::CustomBiddingAlgorithm
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::CustomBiddingAlgorithm
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single custom bidding algorithm.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Immutable.
-
#custom_bidding_algorithm_id ⇒ Fixnum
Output only.
-
#custom_bidding_algorithm_type ⇒ String
Required.
-
#display_name ⇒ String
Required.
-
#entity_status ⇒ String
Controls whether or not the custom bidding algorithm can be used as a bidding strategy.
-
#model_details ⇒ Array<Google::Apis::DisplayvideoV4::CustomBiddingModelDetails>
Output only.
-
#name ⇒ String
Output only.
-
#partner_id ⇒ Fixnum
Immutable.
-
#shared_advertiser_ids ⇒ Array<Fixnum>
The IDs of the advertisers who have access to this algorithm.
-
#third_party_optimization_partner ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomBiddingAlgorithm
constructor
A new instance of CustomBiddingAlgorithm.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomBiddingAlgorithm
Returns a new instance of CustomBiddingAlgorithm.
6006 6007 6008 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Immutable. The unique ID of the advertiser that owns the custom bidding
algorithm.
Corresponds to the JSON property advertiserId
5942 5943 5944 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5942 def advertiser_id @advertiser_id end |
#custom_bidding_algorithm_id ⇒ Fixnum
Output only. The unique ID of the custom bidding algorithm. Assigned by the
system.
Corresponds to the JSON property customBiddingAlgorithmId
5948 5949 5950 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5948 def custom_bidding_algorithm_id @custom_bidding_algorithm_id end |
#custom_bidding_algorithm_type ⇒ String
Required. Immutable. The type of custom bidding algorithm.
Corresponds to the JSON property customBiddingAlgorithmType
5953 5954 5955 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5953 def custom_bidding_algorithm_type @custom_bidding_algorithm_type end |
#display_name ⇒ String
Required. The display name of the custom bidding algorithm. Must be UTF-8
encoded with a maximum size of 240 bytes.
Corresponds to the JSON property displayName
5959 5960 5961 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5959 def display_name @display_name end |
#entity_status ⇒ String
Controls whether or not the custom bidding algorithm can be used as a bidding
strategy. Accepted values are: * ENTITY_STATUS_ACTIVE *
ENTITY_STATUS_ARCHIVED
Corresponds to the JSON property entityStatus
5966 5967 5968 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5966 def entity_status @entity_status end |
#model_details ⇒ Array<Google::Apis::DisplayvideoV4::CustomBiddingModelDetails>
5977 5978 5979 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5977 def model_details @model_details end |
#name ⇒ String
Output only. The resource name of the custom bidding algorithm.
Corresponds to the JSON property name
5982 5983 5984 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5982 def name @name end |
#partner_id ⇒ Fixnum
Immutable. The unique ID of the partner that owns the custom bidding algorithm.
Corresponds to the JSON property partnerId
5987 5988 5989 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5987 def partner_id @partner_id end |
#shared_advertiser_ids ⇒ Array<Fixnum>
5998 5999 6000 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5998 def shared_advertiser_ids @shared_advertiser_ids end |
#third_party_optimization_partner ⇒ String
Optional. Immutable. Designates the third party optimization partner that
manages this algorithm.
Corresponds to the JSON property thirdPartyOptimizationPartner
6004 6005 6006 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6004 def third_party_optimization_partner @third_party_optimization_partner end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6011 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id) @custom_bidding_algorithm_type = args[:custom_bidding_algorithm_type] if args.key?(:custom_bidding_algorithm_type) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @model_details = args[:model_details] if args.key?(:model_details) @name = args[:name] if args.key?(:name) @partner_id = args[:partner_id] if args.key?(:partner_id) @shared_advertiser_ids = args[:shared_advertiser_ids] if args.key?(:shared_advertiser_ids) @third_party_optimization_partner = args[:third_party_optimization_partner] if args.key?(:third_party_optimization_partner) end |