Class: Google::Apis::DisplayvideoV4::CustomBiddingAlgorithm
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::CustomBiddingAlgorithm
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single custom bidding algorithm.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Immutable.
-
#custom_bidding_algorithm_id ⇒ Fixnum
Output only.
-
#custom_bidding_algorithm_type ⇒ String
Required.
-
#display_name ⇒ String
Required.
-
#entity_status ⇒ String
Controls whether or not the custom bidding algorithm can be used as a bidding strategy.
-
#model_details ⇒ Array<Google::Apis::DisplayvideoV4::CustomBiddingModelDetails>
Output only.
-
#name ⇒ String
Output only.
-
#partner_id ⇒ Fixnum
Immutable.
-
#shared_advertiser_ids ⇒ Array<Fixnum>
The IDs of the advertisers who have access to this algorithm.
-
#third_party_optimization_partner ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomBiddingAlgorithm
constructor
A new instance of CustomBiddingAlgorithm.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomBiddingAlgorithm
Returns a new instance of CustomBiddingAlgorithm.
5868 5869 5870 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Immutable. The unique ID of the advertiser that owns the custom bidding
algorithm.
Corresponds to the JSON property advertiserId
5804 5805 5806 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5804 def advertiser_id @advertiser_id end |
#custom_bidding_algorithm_id ⇒ Fixnum
Output only. The unique ID of the custom bidding algorithm. Assigned by the
system.
Corresponds to the JSON property customBiddingAlgorithmId
5810 5811 5812 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5810 def custom_bidding_algorithm_id @custom_bidding_algorithm_id end |
#custom_bidding_algorithm_type ⇒ String
Required. Immutable. The type of custom bidding algorithm.
Corresponds to the JSON property customBiddingAlgorithmType
5815 5816 5817 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5815 def custom_bidding_algorithm_type @custom_bidding_algorithm_type end |
#display_name ⇒ String
Required. The display name of the custom bidding algorithm. Must be UTF-8
encoded with a maximum size of 240 bytes.
Corresponds to the JSON property displayName
5821 5822 5823 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5821 def display_name @display_name end |
#entity_status ⇒ String
Controls whether or not the custom bidding algorithm can be used as a bidding
strategy. Accepted values are: * ENTITY_STATUS_ACTIVE *
ENTITY_STATUS_ARCHIVED
Corresponds to the JSON property entityStatus
5828 5829 5830 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5828 def entity_status @entity_status end |
#model_details ⇒ Array<Google::Apis::DisplayvideoV4::CustomBiddingModelDetails>
5839 5840 5841 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5839 def model_details @model_details end |
#name ⇒ String
Output only. The resource name of the custom bidding algorithm.
Corresponds to the JSON property name
5844 5845 5846 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5844 def name @name end |
#partner_id ⇒ Fixnum
Immutable. The unique ID of the partner that owns the custom bidding algorithm.
Corresponds to the JSON property partnerId
5849 5850 5851 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5849 def partner_id @partner_id end |
#shared_advertiser_ids ⇒ Array<Fixnum>
5860 5861 5862 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5860 def shared_advertiser_ids @shared_advertiser_ids end |
#third_party_optimization_partner ⇒ String
Optional. Immutable. Designates the third party optimization partner that
manages this algorithm.
Corresponds to the JSON property thirdPartyOptimizationPartner
5866 5867 5868 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5866 def third_party_optimization_partner @third_party_optimization_partner end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 5883 5884 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5873 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id) @custom_bidding_algorithm_type = args[:custom_bidding_algorithm_type] if args.key?(:custom_bidding_algorithm_type) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @model_details = args[:model_details] if args.key?(:model_details) @name = args[:name] if args.key?(:name) @partner_id = args[:partner_id] if args.key?(:partner_id) @shared_advertiser_ids = args[:shared_advertiser_ids] if args.key?(:shared_advertiser_ids) @third_party_optimization_partner = args[:third_party_optimization_partner] if args.key?(:third_party_optimization_partner) end |