Class: Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRules
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRules
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single custom bidding algorithm rules.
Instance Attribute Summary collapse
-
#active ⇒ Boolean
(also: #active?)
Output only.
-
#create_time ⇒ String
Output only.
-
#custom_bidding_algorithm_id ⇒ Fixnum
Output only.
-
#custom_bidding_algorithm_rules_id ⇒ Fixnum
Output only.
-
#error ⇒ Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesError
An error message for a CustomBiddingAlgorithmRules resource.
-
#name ⇒ String
Output only.
-
#rules ⇒ Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesRef
The reference to the uploaded AlgorithmRules file.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomBiddingAlgorithmRules
constructor
A new instance of CustomBiddingAlgorithmRules.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomBiddingAlgorithmRules
Returns a new instance of CustomBiddingAlgorithmRules.
6087 6088 6089 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active ⇒ Boolean Also known as: active?
Output only. Whether the rules resource is currently being used for scoring by
the parent algorithm.
Corresponds to the JSON property active
6047 6048 6049 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6047 def active @active end |
#create_time ⇒ String
Output only. The time when the rules resource was created.
Corresponds to the JSON property createTime
6053 6054 6055 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6053 def create_time @create_time end |
#custom_bidding_algorithm_id ⇒ Fixnum
Output only. The unique ID of the custom bidding algorithm that the rules
resource belongs to.
Corresponds to the JSON property customBiddingAlgorithmId
6059 6060 6061 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6059 def custom_bidding_algorithm_id @custom_bidding_algorithm_id end |
#custom_bidding_algorithm_rules_id ⇒ Fixnum
Output only. The unique ID of the rules resource.
Corresponds to the JSON property customBiddingAlgorithmRulesId
6064 6065 6066 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6064 def custom_bidding_algorithm_rules_id @custom_bidding_algorithm_rules_id end |
#error ⇒ Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesError
An error message for a CustomBiddingAlgorithmRules resource.
Corresponds to the JSON property error
6069 6070 6071 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6069 def error @error end |
#name ⇒ String
Output only. The resource name of the rules resource.
Corresponds to the JSON property name
6074 6075 6076 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6074 def name @name end |
#rules ⇒ Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesRef
The reference to the uploaded AlgorithmRules file. Retrieve the location to
upload new AlgorithmRules file to using customBiddingAlgorithms.uploadRules.
Corresponds to the JSON property rules
6080 6081 6082 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6080 def rules @rules end |
#state ⇒ String
Output only. The state of the rules resource.
Corresponds to the JSON property state
6085 6086 6087 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6085 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6092 6093 6094 6095 6096 6097 6098 6099 6100 6101 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6092 def update!(**args) @active = args[:active] if args.key?(:active) @create_time = args[:create_time] if args.key?(:create_time) @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id) @custom_bidding_algorithm_rules_id = args[:custom_bidding_algorithm_rules_id] if args.key?(:custom_bidding_algorithm_rules_id) @error = args[:error] if args.key?(:error) @name = args[:name] if args.key?(:name) @rules = args[:rules] if args.key?(:rules) @state = args[:state] if args.key?(:state) end |