Class: Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRules
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRules
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single custom bidding algorithm rules.
Instance Attribute Summary collapse
-
#active ⇒ Boolean
(also: #active?)
Output only.
-
#create_time ⇒ String
Output only.
-
#custom_bidding_algorithm_id ⇒ Fixnum
Output only.
-
#custom_bidding_algorithm_rules_id ⇒ Fixnum
Output only.
-
#error ⇒ Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesError
An error message for a CustomBiddingAlgorithmRules resource.
-
#name ⇒ String
Output only.
-
#rules ⇒ Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesRef
The reference to the uploaded AlgorithmRules file.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomBiddingAlgorithmRules
constructor
A new instance of CustomBiddingAlgorithmRules.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomBiddingAlgorithmRules
Returns a new instance of CustomBiddingAlgorithmRules.
6056 6057 6058 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6056 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active ⇒ Boolean Also known as: active?
Output only. Whether the rules resource is currently being used for scoring by
the parent algorithm.
Corresponds to the JSON property active
6016 6017 6018 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6016 def active @active end |
#create_time ⇒ String
Output only. The time when the rules resource was created.
Corresponds to the JSON property createTime
6022 6023 6024 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6022 def create_time @create_time end |
#custom_bidding_algorithm_id ⇒ Fixnum
Output only. The unique ID of the custom bidding algorithm that the rules
resource belongs to.
Corresponds to the JSON property customBiddingAlgorithmId
6028 6029 6030 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6028 def custom_bidding_algorithm_id @custom_bidding_algorithm_id end |
#custom_bidding_algorithm_rules_id ⇒ Fixnum
Output only. The unique ID of the rules resource.
Corresponds to the JSON property customBiddingAlgorithmRulesId
6033 6034 6035 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6033 def custom_bidding_algorithm_rules_id @custom_bidding_algorithm_rules_id end |
#error ⇒ Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesError
An error message for a CustomBiddingAlgorithmRules resource.
Corresponds to the JSON property error
6038 6039 6040 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6038 def error @error end |
#name ⇒ String
Output only. The resource name of the rules resource.
Corresponds to the JSON property name
6043 6044 6045 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6043 def name @name end |
#rules ⇒ Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesRef
The reference to the uploaded AlgorithmRules file. Retrieve the location to
upload new AlgorithmRules file to using customBiddingAlgorithms.uploadRules.
Corresponds to the JSON property rules
6049 6050 6051 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6049 def rules @rules end |
#state ⇒ String
Output only. The state of the rules resource.
Corresponds to the JSON property state
6054 6055 6056 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6054 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6061 def update!(**args) @active = args[:active] if args.key?(:active) @create_time = args[:create_time] if args.key?(:create_time) @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id) @custom_bidding_algorithm_rules_id = args[:custom_bidding_algorithm_rules_id] if args.key?(:custom_bidding_algorithm_rules_id) @error = args[:error] if args.key?(:error) @name = args[:name] if args.key?(:name) @rules = args[:rules] if args.key?(:rules) @state = args[:state] if args.key?(:state) end |