Class: Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRules

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single custom bidding algorithm rules.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomBiddingAlgorithmRules

Returns a new instance of CustomBiddingAlgorithmRules.



5944
5945
5946
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Output only. Whether the rules resource is currently being used for scoring by the parent algorithm. Corresponds to the JSON property active

Returns:

  • (Boolean)


5904
5905
5906
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5904

def active
  @active
end

#create_timeString

Output only. The time when the rules resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5910
5911
5912
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5910

def create_time
  @create_time
end

#custom_bidding_algorithm_idFixnum

Output only. The unique ID of the custom bidding algorithm that the rules resource belongs to. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


5916
5917
5918
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5916

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#custom_bidding_algorithm_rules_idFixnum

Output only. The unique ID of the rules resource. Corresponds to the JSON property customBiddingAlgorithmRulesId

Returns:

  • (Fixnum)


5921
5922
5923
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5921

def custom_bidding_algorithm_rules_id
  @custom_bidding_algorithm_rules_id
end

#errorGoogle::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesError

An error message for a CustomBiddingAlgorithmRules resource. Corresponds to the JSON property error



5926
5927
5928
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5926

def error
  @error
end

#nameString

Output only. The resource name of the rules resource. Corresponds to the JSON property name

Returns:

  • (String)


5931
5932
5933
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5931

def name
  @name
end

#rulesGoogle::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesRef

The reference to the uploaded AlgorithmRules file. Retrieve the location to upload new AlgorithmRules file to using customBiddingAlgorithms.uploadRules. Corresponds to the JSON property rules



5937
5938
5939
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5937

def rules
  @rules
end

#stateString

Output only. The state of the rules resource. Corresponds to the JSON property state

Returns:

  • (String)


5942
5943
5944
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5942

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5949
5950
5951
5952
5953
5954
5955
5956
5957
5958
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5949

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @custom_bidding_algorithm_rules_id = args[:custom_bidding_algorithm_rules_id] if args.key?(:custom_bidding_algorithm_rules_id)
  @error = args[:error] if args.key?(:error)
  @name = args[:name] if args.key?(:name)
  @rules = args[:rules] if args.key?(:rules)
  @state = args[:state] if args.key?(:state)
end