Class: Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRules
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRules
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single custom bidding algorithm rules.
Instance Attribute Summary collapse
-
#active ⇒ Boolean
(also: #active?)
Output only.
-
#create_time ⇒ String
Output only.
-
#custom_bidding_algorithm_id ⇒ Fixnum
Output only.
-
#custom_bidding_algorithm_rules_id ⇒ Fixnum
Output only.
-
#error ⇒ Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesError
An error message for a CustomBiddingAlgorithmRules resource.
-
#name ⇒ String
Output only.
-
#rules ⇒ Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesRef
The reference to the uploaded AlgorithmRules file.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomBiddingAlgorithmRules
constructor
A new instance of CustomBiddingAlgorithmRules.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomBiddingAlgorithmRules
Returns a new instance of CustomBiddingAlgorithmRules.
5935 5936 5937 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5935 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active ⇒ Boolean Also known as: active?
Output only. Whether the rules resource is currently being used for scoring by
the parent algorithm.
Corresponds to the JSON property active
5895 5896 5897 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5895 def active @active end |
#create_time ⇒ String
Output only. The time when the rules resource was created.
Corresponds to the JSON property createTime
5901 5902 5903 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5901 def create_time @create_time end |
#custom_bidding_algorithm_id ⇒ Fixnum
Output only. The unique ID of the custom bidding algorithm that the rules
resource belongs to.
Corresponds to the JSON property customBiddingAlgorithmId
5907 5908 5909 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5907 def custom_bidding_algorithm_id @custom_bidding_algorithm_id end |
#custom_bidding_algorithm_rules_id ⇒ Fixnum
Output only. The unique ID of the rules resource.
Corresponds to the JSON property customBiddingAlgorithmRulesId
5912 5913 5914 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5912 def custom_bidding_algorithm_rules_id @custom_bidding_algorithm_rules_id end |
#error ⇒ Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesError
An error message for a CustomBiddingAlgorithmRules resource.
Corresponds to the JSON property error
5917 5918 5919 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5917 def error @error end |
#name ⇒ String
Output only. The resource name of the rules resource.
Corresponds to the JSON property name
5922 5923 5924 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5922 def name @name end |
#rules ⇒ Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRulesRef
The reference to the uploaded AlgorithmRules file. Retrieve the location to
upload new AlgorithmRules file to using customBiddingAlgorithms.uploadRules.
Corresponds to the JSON property rules
5928 5929 5930 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5928 def rules @rules end |
#state ⇒ String
Output only. The state of the rules resource.
Corresponds to the JSON property state
5933 5934 5935 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5933 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5940 5941 5942 5943 5944 5945 5946 5947 5948 5949 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 5940 def update!(**args) @active = args[:active] if args.key?(:active) @create_time = args[:create_time] if args.key?(:create_time) @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id) @custom_bidding_algorithm_rules_id = args[:custom_bidding_algorithm_rules_id] if args.key?(:custom_bidding_algorithm_rules_id) @error = args[:error] if args.key?(:error) @name = args[:name] if args.key?(:name) @rules = args[:rules] if args.key?(:rules) @state = args[:state] if args.key?(:state) end |