Class: Google::Apis::DisplayvideoV4::CustomBiddingScript

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single custom bidding script.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomBiddingScript

Returns a new instance of CustomBiddingScript.



6223
6224
6225
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Output only. Whether the script is currently being used for scoring by the parent algorithm. Corresponds to the JSON property active

Returns:

  • (Boolean)


6183
6184
6185
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6183

def active
  @active
end

#create_timeString

Output only. The time when the script was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6189
6190
6191
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6189

def create_time
  @create_time
end

#custom_bidding_algorithm_idFixnum

Output only. The unique ID of the custom bidding algorithm the script belongs to. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


6195
6196
6197
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6195

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#custom_bidding_script_idFixnum

Output only. The unique ID of the custom bidding script. Corresponds to the JSON property customBiddingScriptId

Returns:

  • (Fixnum)


6200
6201
6202
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6200

def custom_bidding_script_id
  @custom_bidding_script_id
end

#errorsArray<Google::Apis::DisplayvideoV4::ScriptError>

Output only. Error details of a rejected custom bidding script. This field will only be populated when state is REJECTED. Corresponds to the JSON property errors



6206
6207
6208
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6206

def errors
  @errors
end

#nameString

Output only. The resource name of the custom bidding script. Corresponds to the JSON property name

Returns:

  • (String)


6211
6212
6213
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6211

def name
  @name
end

#scriptGoogle::Apis::DisplayvideoV4::CustomBiddingScriptRef

The reference to the uploaded custom bidding script file. Corresponds to the JSON property script



6216
6217
6218
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6216

def script
  @script
end

#stateString

Output only. The state of the custom bidding script. Corresponds to the JSON property state

Returns:

  • (String)


6221
6222
6223
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6221

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6228
6229
6230
6231
6232
6233
6234
6235
6236
6237
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6228

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @custom_bidding_script_id = args[:custom_bidding_script_id] if args.key?(:custom_bidding_script_id)
  @errors = args[:errors] if args.key?(:errors)
  @name = args[:name] if args.key?(:name)
  @script = args[:script] if args.key?(:script)
  @state = args[:state] if args.key?(:state)
end