Class: Google::Apis::DisplayvideoV4::CustomBiddingScript
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::CustomBiddingScript
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single custom bidding script.
Instance Attribute Summary collapse
-
#active ⇒ Boolean
(also: #active?)
Output only.
-
#create_time ⇒ String
Output only.
-
#custom_bidding_algorithm_id ⇒ Fixnum
Output only.
-
#custom_bidding_script_id ⇒ Fixnum
Output only.
-
#errors ⇒ Array<Google::Apis::DisplayvideoV4::ScriptError>
Output only.
-
#name ⇒ String
Output only.
-
#script ⇒ Google::Apis::DisplayvideoV4::CustomBiddingScriptRef
The reference to the uploaded custom bidding script file.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomBiddingScript
constructor
A new instance of CustomBiddingScript.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomBiddingScript
Returns a new instance of CustomBiddingScript.
6210 6211 6212 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6210 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active ⇒ Boolean Also known as: active?
Output only. Whether the script is currently being used for scoring by the
parent algorithm.
Corresponds to the JSON property active
6170 6171 6172 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6170 def active @active end |
#create_time ⇒ String
Output only. The time when the script was created.
Corresponds to the JSON property createTime
6176 6177 6178 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6176 def create_time @create_time end |
#custom_bidding_algorithm_id ⇒ Fixnum
Output only. The unique ID of the custom bidding algorithm the script belongs
to.
Corresponds to the JSON property customBiddingAlgorithmId
6182 6183 6184 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6182 def custom_bidding_algorithm_id @custom_bidding_algorithm_id end |
#custom_bidding_script_id ⇒ Fixnum
Output only. The unique ID of the custom bidding script.
Corresponds to the JSON property customBiddingScriptId
6187 6188 6189 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6187 def custom_bidding_script_id @custom_bidding_script_id end |
#errors ⇒ Array<Google::Apis::DisplayvideoV4::ScriptError>
Output only. Error details of a rejected custom bidding script. This field
will only be populated when state is REJECTED.
Corresponds to the JSON property errors
6193 6194 6195 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6193 def errors @errors end |
#name ⇒ String
Output only. The resource name of the custom bidding script.
Corresponds to the JSON property name
6198 6199 6200 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6198 def name @name end |
#script ⇒ Google::Apis::DisplayvideoV4::CustomBiddingScriptRef
The reference to the uploaded custom bidding script file.
Corresponds to the JSON property script
6203 6204 6205 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6203 def script @script end |
#state ⇒ String
Output only. The state of the custom bidding script.
Corresponds to the JSON property state
6208 6209 6210 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6208 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6215 6216 6217 6218 6219 6220 6221 6222 6223 6224 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6215 def update!(**args) @active = args[:active] if args.key?(:active) @create_time = args[:create_time] if args.key?(:create_time) @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id) @custom_bidding_script_id = args[:custom_bidding_script_id] if args.key?(:custom_bidding_script_id) @errors = args[:errors] if args.key?(:errors) @name = args[:name] if args.key?(:name) @script = args[:script] if args.key?(:script) @state = args[:state] if args.key?(:state) end |