Class: Google::Apis::DisplayvideoV4::CustomBiddingScript

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single custom bidding script.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomBiddingScript

Returns a new instance of CustomBiddingScript.



6193
6194
6195
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Output only. Whether the script is currently being used for scoring by the parent algorithm. Corresponds to the JSON property active

Returns:

  • (Boolean)


6153
6154
6155
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6153

def active
  @active
end

#create_timeString

Output only. The time when the script was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6159
6160
6161
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6159

def create_time
  @create_time
end

#custom_bidding_algorithm_idFixnum

Output only. The unique ID of the custom bidding algorithm the script belongs to. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


6165
6166
6167
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6165

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#custom_bidding_script_idFixnum

Output only. The unique ID of the custom bidding script. Corresponds to the JSON property customBiddingScriptId

Returns:

  • (Fixnum)


6170
6171
6172
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6170

def custom_bidding_script_id
  @custom_bidding_script_id
end

#errorsArray<Google::Apis::DisplayvideoV4::ScriptError>

Output only. Error details of a rejected custom bidding script. This field will only be populated when state is REJECTED. Corresponds to the JSON property errors



6176
6177
6178
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6176

def errors
  @errors
end

#nameString

Output only. The resource name of the custom bidding script. Corresponds to the JSON property name

Returns:

  • (String)


6181
6182
6183
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6181

def name
  @name
end

#scriptGoogle::Apis::DisplayvideoV4::CustomBiddingScriptRef

The reference to the uploaded custom bidding script file. Corresponds to the JSON property script



6186
6187
6188
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6186

def script
  @script
end

#stateString

Output only. The state of the custom bidding script. Corresponds to the JSON property state

Returns:

  • (String)


6191
6192
6193
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6191

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6198

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @custom_bidding_script_id = args[:custom_bidding_script_id] if args.key?(:custom_bidding_script_id)
  @errors = args[:errors] if args.key?(:errors)
  @name = args[:name] if args.key?(:name)
  @script = args[:script] if args.key?(:script)
  @state = args[:state] if args.key?(:state)
end