Class: Google::Apis::DisplayvideoV4::CustomBiddingScript

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single custom bidding script.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomBiddingScript

Returns a new instance of CustomBiddingScript.



6081
6082
6083
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

Output only. Whether the script is currently being used for scoring by the parent algorithm. Corresponds to the JSON property active

Returns:

  • (Boolean)


6041
6042
6043
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6041

def active
  @active
end

#create_timeString

Output only. The time when the script was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6047
6048
6049
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6047

def create_time
  @create_time
end

#custom_bidding_algorithm_idFixnum

Output only. The unique ID of the custom bidding algorithm the script belongs to. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


6053
6054
6055
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6053

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#custom_bidding_script_idFixnum

Output only. The unique ID of the custom bidding script. Corresponds to the JSON property customBiddingScriptId

Returns:

  • (Fixnum)


6058
6059
6060
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6058

def custom_bidding_script_id
  @custom_bidding_script_id
end

#errorsArray<Google::Apis::DisplayvideoV4::ScriptError>

Output only. Error details of a rejected custom bidding script. This field will only be populated when state is REJECTED. Corresponds to the JSON property errors



6064
6065
6066
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6064

def errors
  @errors
end

#nameString

Output only. The resource name of the custom bidding script. Corresponds to the JSON property name

Returns:

  • (String)


6069
6070
6071
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6069

def name
  @name
end

#scriptGoogle::Apis::DisplayvideoV4::CustomBiddingScriptRef

The reference to the uploaded custom bidding script file. Corresponds to the JSON property script



6074
6075
6076
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6074

def script
  @script
end

#stateString

Output only. The state of the custom bidding script. Corresponds to the JSON property state

Returns:

  • (String)


6079
6080
6081
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6079

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6086
6087
6088
6089
6090
6091
6092
6093
6094
6095
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6086

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @custom_bidding_script_id = args[:custom_bidding_script_id] if args.key?(:custom_bidding_script_id)
  @errors = args[:errors] if args.key?(:errors)
  @name = args[:name] if args.key?(:name)
  @script = args[:script] if args.key?(:script)
  @state = args[:state] if args.key?(:state)
end