Class: Google::Apis::DisplayvideoV4::DemandGenCarouselAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::DemandGenCarouselAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details for a Demand Gen carousel ad.
Instance Attribute Summary collapse
-
#business_name ⇒ String
Optional.
-
#cards ⇒ Array<Google::Apis::DisplayvideoV4::CarouselCard>
Required.
-
#custom_parameters ⇒ Hash<String,String>
Optional.
-
#description ⇒ String
Required.
-
#final_url ⇒ String
Required.
-
#final_url_suffix ⇒ String
Optional.
-
#headline ⇒ String
Required.
-
#logo ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
-
#tracking_url ⇒ String
Output only.
-
#user_specified_tracking_url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DemandGenCarouselAd
constructor
A new instance of DemandGenCarouselAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DemandGenCarouselAd
Returns a new instance of DemandGenCarouselAd.
6677 6678 6679 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6677 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_name ⇒ String
Optional. The business name shown on the ad. This setting is required unless a
default value is set at the advertiser level. If left unset, the default value
will be applied.
Corresponds to the JSON property businessName
6628 6629 6630 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6628 def business_name @business_name end |
#cards ⇒ Array<Google::Apis::DisplayvideoV4::CarouselCard>
Required. The list of cards shown on the ad.
Corresponds to the JSON property cards
6633 6634 6635 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6633 def cards @cards end |
#custom_parameters ⇒ Hash<String,String>
Optional. The custom parameters and accompanying values to add to the tracking
URL.
Corresponds to the JSON property customParameters
6639 6640 6641 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6639 def custom_parameters @custom_parameters end |
#description ⇒ String
Required. The description of the ad.
Corresponds to the JSON property description
6644 6645 6646 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6644 def description @description end |
#final_url ⇒ String
Required. The URL address of the webpage that people reach after they click
the ad.
Corresponds to the JSON property finalUrl
6650 6651 6652 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6650 def final_url @final_url end |
#final_url_suffix ⇒ String
Optional. The suffix to append to landing page URLs.
Corresponds to the JSON property finalUrlSuffix
6655 6656 6657 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6655 def final_url_suffix @final_url_suffix end |
#headline ⇒ String
Required. The headline of the ad.
Corresponds to the JSON property headline
6660 6661 6662 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6660 def headline @headline end |
#logo ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
Corresponds to the JSON property logo
6665 6666 6667 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6665 def logo @logo end |
#tracking_url ⇒ String
Output only. The URL address loaded in the background for tracking purposes.
Corresponds to the JSON property trackingUrl
6670 6671 6672 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6670 def tracking_url @tracking_url end |
#user_specified_tracking_url ⇒ String
Optional. The tracking URL specified by the user manually.
Corresponds to the JSON property userSpecifiedTrackingUrl
6675 6676 6677 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6675 def user_specified_tracking_url @user_specified_tracking_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6682 6683 6684 6685 6686 6687 6688 6689 6690 6691 6692 6693 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6682 def update!(**args) @business_name = args[:business_name] if args.key?(:business_name) @cards = args[:cards] if args.key?(:cards) @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters) @description = args[:description] if args.key?(:description) @final_url = args[:final_url] if args.key?(:final_url) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @headline = args[:headline] if args.key?(:headline) @logo = args[:logo] if args.key?(:logo) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url) end |