Class: Google::Apis::DisplayvideoV4::DemandGenCarouselAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen carousel ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenCarouselAd

Returns a new instance of DemandGenCarouselAd.



6664
6665
6666
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6664

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Optional. The business name shown on the ad. This setting is required unless a default value is set at the advertiser level. If left unset, the default value will be applied. Corresponds to the JSON property businessName

Returns:

  • (String)


6615
6616
6617
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6615

def business_name
  @business_name
end

#cardsArray<Google::Apis::DisplayvideoV4::CarouselCard>

Required. The list of cards shown on the ad. Corresponds to the JSON property cards



6620
6621
6622
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6620

def cards
  @cards
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6626
6627
6628
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6626

def custom_parameters
  @custom_parameters
end

#descriptionString

Required. The description of the ad. Corresponds to the JSON property description

Returns:

  • (String)


6631
6632
6633
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6631

def description
  @description
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6637
6638
6639
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6637

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6642
6643
6644
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6642

def final_url_suffix
  @final_url_suffix
end

#headlineString

Required. The headline of the ad. Corresponds to the JSON property headline

Returns:

  • (String)


6647
6648
6649
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6647

def headline
  @headline
end

#logoGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property logo



6652
6653
6654
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6652

def 
  @logo
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


6657
6658
6659
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6657

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


6662
6663
6664
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6662

def user_specified_tracking_url
  @user_specified_tracking_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6669
6670
6671
6672
6673
6674
6675
6676
6677
6678
6679
6680
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6669

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @cards = args[:cards] if args.key?(:cards)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @description = args[:description] if args.key?(:description)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headline = args[:headline] if args.key?(:headline)
  @logo = args[:logo] if args.key?(:logo)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
end