Class: Google::Apis::DisplayvideoV4::DemandGenCarouselAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::DemandGenCarouselAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details for a Demand Gen carousel ad.
Instance Attribute Summary collapse
-
#business_name ⇒ String
Required.
-
#cards ⇒ Array<Google::Apis::DisplayvideoV4::CarouselCard>
Required.
-
#custom_parameters ⇒ Hash<String,String>
Optional.
-
#description ⇒ String
Required.
-
#final_url ⇒ String
Required.
-
#final_url_suffix ⇒ String
Optional.
-
#headline ⇒ String
Required.
-
#logo ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
-
#tracking_url ⇒ String
Output only.
-
#user_specified_tracking_url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DemandGenCarouselAd
constructor
A new instance of DemandGenCarouselAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DemandGenCarouselAd
Returns a new instance of DemandGenCarouselAd.
6647 6648 6649 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6647 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_name ⇒ String
Required. The business name shown on the ad. Warning: Starting July 13,
2026, this setting will no longer be required if a default value is set at
the advertiser level. If left unset, the default value will be applied.
Corresponds to the JSON property businessName
6598 6599 6600 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6598 def business_name @business_name end |
#cards ⇒ Array<Google::Apis::DisplayvideoV4::CarouselCard>
Required. The list of cards shown on the ad.
Corresponds to the JSON property cards
6603 6604 6605 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6603 def cards @cards end |
#custom_parameters ⇒ Hash<String,String>
Optional. The custom parameters and accompanying values to add to the tracking
URL.
Corresponds to the JSON property customParameters
6609 6610 6611 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6609 def custom_parameters @custom_parameters end |
#description ⇒ String
Required. The description of the ad.
Corresponds to the JSON property description
6614 6615 6616 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6614 def description @description end |
#final_url ⇒ String
Required. The URL address of the webpage that people reach after they click
the ad.
Corresponds to the JSON property finalUrl
6620 6621 6622 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6620 def final_url @final_url end |
#final_url_suffix ⇒ String
Optional. The suffix to append to landing page URLs.
Corresponds to the JSON property finalUrlSuffix
6625 6626 6627 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6625 def final_url_suffix @final_url_suffix end |
#headline ⇒ String
Required. The headline of the ad.
Corresponds to the JSON property headline
6630 6631 6632 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6630 def headline @headline end |
#logo ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
Corresponds to the JSON property logo
6635 6636 6637 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6635 def logo @logo end |
#tracking_url ⇒ String
Output only. The URL address loaded in the background for tracking purposes.
Corresponds to the JSON property trackingUrl
6640 6641 6642 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6640 def tracking_url @tracking_url end |
#user_specified_tracking_url ⇒ String
Optional. The tracking URL specified by the user manually.
Corresponds to the JSON property userSpecifiedTrackingUrl
6645 6646 6647 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6645 def user_specified_tracking_url @user_specified_tracking_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6652 6653 6654 6655 6656 6657 6658 6659 6660 6661 6662 6663 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6652 def update!(**args) @business_name = args[:business_name] if args.key?(:business_name) @cards = args[:cards] if args.key?(:cards) @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters) @description = args[:description] if args.key?(:description) @final_url = args[:final_url] if args.key?(:final_url) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @headline = args[:headline] if args.key?(:headline) @logo = args[:logo] if args.key?(:logo) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url) end |