Class: Google::Apis::DisplayvideoV4::DemandGenCarouselAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen carousel ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenCarouselAd

Returns a new instance of DemandGenCarouselAd.



6533
6534
6535
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Required. The business name shown on the ad. Corresponds to the JSON property businessName

Returns:

  • (String)


6484
6485
6486
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6484

def business_name
  @business_name
end

#cardsArray<Google::Apis::DisplayvideoV4::CarouselCard>

Required. The list of cards shown on the ad. Corresponds to the JSON property cards



6489
6490
6491
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6489

def cards
  @cards
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6495
6496
6497
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6495

def custom_parameters
  @custom_parameters
end

#descriptionString

Required. The description of the ad. Corresponds to the JSON property description

Returns:

  • (String)


6500
6501
6502
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6500

def description
  @description
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6506
6507
6508
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6506

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6511
6512
6513
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6511

def final_url_suffix
  @final_url_suffix
end

#headlineString

Required. The headline of the ad. Corresponds to the JSON property headline

Returns:

  • (String)


6516
6517
6518
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6516

def headline
  @headline
end

#logoGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property logo



6521
6522
6523
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6521

def 
  @logo
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


6526
6527
6528
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6526

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


6531
6532
6533
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6531

def user_specified_tracking_url
  @user_specified_tracking_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6538
6539
6540
6541
6542
6543
6544
6545
6546
6547
6548
6549
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6538

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @cards = args[:cards] if args.key?(:cards)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @description = args[:description] if args.key?(:description)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headline = args[:headline] if args.key?(:headline)
  @logo = args[:logo] if args.key?(:logo)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
end