Class: Google::Apis::DisplayvideoV4::DemandGenCarouselAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen carousel ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenCarouselAd

Returns a new instance of DemandGenCarouselAd.



6524
6525
6526
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Required. The business name shown on the ad. Corresponds to the JSON property businessName

Returns:

  • (String)


6475
6476
6477
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6475

def business_name
  @business_name
end

#cardsArray<Google::Apis::DisplayvideoV4::CarouselCard>

Required. The list of cards shown on the ad. Corresponds to the JSON property cards



6480
6481
6482
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6480

def cards
  @cards
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6486
6487
6488
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6486

def custom_parameters
  @custom_parameters
end

#descriptionString

Required. The description of the ad. Corresponds to the JSON property description

Returns:

  • (String)


6491
6492
6493
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6491

def description
  @description
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6497
6498
6499
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6497

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6502
6503
6504
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6502

def final_url_suffix
  @final_url_suffix
end

#headlineString

Required. The headline of the ad. Corresponds to the JSON property headline

Returns:

  • (String)


6507
6508
6509
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6507

def headline
  @headline
end

#logoGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property logo



6512
6513
6514
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6512

def 
  @logo
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


6517
6518
6519
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6517

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


6522
6523
6524
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6522

def user_specified_tracking_url
  @user_specified_tracking_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6529
6530
6531
6532
6533
6534
6535
6536
6537
6538
6539
6540
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6529

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @cards = args[:cards] if args.key?(:cards)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @description = args[:description] if args.key?(:description)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headline = args[:headline] if args.key?(:headline)
  @logo = args[:logo] if args.key?(:logo)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
end