Class: Google::Apis::DisplayvideoV4::DemandGenImageAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen image ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenImageAd

Returns a new instance of DemandGenImageAd.



6747
6748
6749
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Required. The business name shown on the ad. Warning: Starting July 13, 2026, this setting will no longer be required if a default value is set at the advertiser level. If left unset, the default value will be applied. Corresponds to the JSON property businessName

Returns:

  • (String)


6675
6676
6677
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6675

def business_name
  @business_name
end

#call_to_actionString

Required. The call-to-action button shown on the ad. Corresponds to the JSON property callToAction

Returns:

  • (String)


6680
6681
6682
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6680

def call_to_action
  @call_to_action
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6686
6687
6688
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6686

def custom_parameters
  @custom_parameters
end

#descriptionsArray<String>

Required. The list of descriptions shown on the ad. Corresponds to the JSON property descriptions

Returns:

  • (Array<String>)


6691
6692
6693
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6691

def descriptions
  @descriptions
end

#final_mobile_urlString

Optional. The URL address of the webpage that people reach after they click the ad on a mobile device. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


6697
6698
6699
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6697

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6703
6704
6705
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6703

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6708
6709
6710
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6708

def final_url_suffix
  @final_url_suffix
end

#headlinesArray<String>

Required. The list of headlines shown on the ad. Corresponds to the JSON property headlines

Returns:

  • (Array<String>)


6713
6714
6715
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6713

def headlines
  @headlines
end

#logo_imagesArray<Google::Apis::DisplayvideoV4::ImageAsset>

The list of logo images shown on the ad. Warning: Starting July 13, 2026, this setting will no longer be required if a default value is set at the advertiser level. If left unset, the default value will be applied. Corresponds to the JSON property logoImages



6720
6721
6722
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6720

def logo_images
  @logo_images
end

#marketing_imagesArray<Google::Apis::DisplayvideoV4::ImageAsset>

The list of marketing images shown on the ad. Corresponds to the JSON property marketingImages



6725
6726
6727
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6725

def marketing_images
  @marketing_images
end

#portrait_marketing_imagesArray<Google::Apis::DisplayvideoV4::ImageAsset>

The list of portrait marketing images shown on the ad. Corresponds to the JSON property portraitMarketingImages



6730
6731
6732
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6730

def portrait_marketing_images
  @portrait_marketing_images
end

#square_marketing_imagesArray<Google::Apis::DisplayvideoV4::ImageAsset>

The list of square marketing images shown on the ad. Corresponds to the JSON property squareMarketingImages



6735
6736
6737
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6735

def square_marketing_images
  @square_marketing_images
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


6740
6741
6742
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6740

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


6745
6746
6747
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6745

def user_specified_tracking_url
  @user_specified_tracking_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6752
6753
6754
6755
6756
6757
6758
6759
6760
6761
6762
6763
6764
6765
6766
6767
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6752

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headlines = args[:headlines] if args.key?(:headlines)
  @logo_images = args[:logo_images] if args.key?(:logo_images)
  @marketing_images = args[:marketing_images] if args.key?(:marketing_images)
  @portrait_marketing_images = args[:portrait_marketing_images] if args.key?(:portrait_marketing_images)
  @square_marketing_images = args[:square_marketing_images] if args.key?(:square_marketing_images)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
end