Class: Google::Apis::DisplayvideoV4::DemandGenImageAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen image ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenImageAd

Returns a new instance of DemandGenImageAd.



6629
6630
6631
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Required. The business name shown on the ad. Corresponds to the JSON property businessName

Returns:

  • (String)


6559
6560
6561
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6559

def business_name
  @business_name
end

#call_to_actionString

Required. The call-to-action button shown on the ad. Corresponds to the JSON property callToAction

Returns:

  • (String)


6564
6565
6566
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6564

def call_to_action
  @call_to_action
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6570
6571
6572
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6570

def custom_parameters
  @custom_parameters
end

#descriptionsArray<String>

Required. The list of descriptions shown on the ad. Corresponds to the JSON property descriptions

Returns:

  • (Array<String>)


6575
6576
6577
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6575

def descriptions
  @descriptions
end

#final_mobile_urlString

Optional. The URL address of the webpage that people reach after they click the ad on a mobile device. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


6581
6582
6583
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6581

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6587
6588
6589
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6587

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6592
6593
6594
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6592

def final_url_suffix
  @final_url_suffix
end

#headlinesArray<String>

Required. The list of headlines shown on the ad. Corresponds to the JSON property headlines

Returns:

  • (Array<String>)


6597
6598
6599
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6597

def headlines
  @headlines
end

#logo_imagesArray<Google::Apis::DisplayvideoV4::ImageAsset>

The list of logo images shown on the ad. Corresponds to the JSON property logoImages



6602
6603
6604
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6602

def logo_images
  @logo_images
end

#marketing_imagesArray<Google::Apis::DisplayvideoV4::ImageAsset>

The list of marketing images shown on the ad. Corresponds to the JSON property marketingImages



6607
6608
6609
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6607

def marketing_images
  @marketing_images
end

#portrait_marketing_imagesArray<Google::Apis::DisplayvideoV4::ImageAsset>

The list of portrait marketing images shown on the ad. Corresponds to the JSON property portraitMarketingImages



6612
6613
6614
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6612

def portrait_marketing_images
  @portrait_marketing_images
end

#square_marketing_imagesArray<Google::Apis::DisplayvideoV4::ImageAsset>

The list of square marketing images shown on the ad. Corresponds to the JSON property squareMarketingImages



6617
6618
6619
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6617

def square_marketing_images
  @square_marketing_images
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


6622
6623
6624
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6622

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


6627
6628
6629
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6627

def user_specified_tracking_url
  @user_specified_tracking_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6634
6635
6636
6637
6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6634

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headlines = args[:headlines] if args.key?(:headlines)
  @logo_images = args[:logo_images] if args.key?(:logo_images)
  @marketing_images = args[:marketing_images] if args.key?(:marketing_images)
  @portrait_marketing_images = args[:portrait_marketing_images] if args.key?(:portrait_marketing_images)
  @square_marketing_images = args[:square_marketing_images] if args.key?(:square_marketing_images)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
end