Class: Google::Apis::DisplayvideoV4::DemandGenProductAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::DemandGenProductAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details for a Demand Gen product ad.
Instance Attribute Summary collapse
-
#business_name ⇒ String
Required.
-
#call_to_action ⇒ String
Required.
-
#custom_parameters ⇒ Hash<String,String>
Optional.
-
#description ⇒ String
Required.
-
#display_url_breadcrumb1 ⇒ String
Optional.
-
#display_url_breadcrumb2 ⇒ String
Optional.
-
#final_url ⇒ String
Required.
-
#final_url_suffix ⇒ String
Optional.
-
#headline ⇒ String
Required.
-
#logo ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
-
#tracking_url ⇒ String
Output only.
-
#user_specified_tracking_url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DemandGenProductAd
constructor
A new instance of DemandGenProductAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DemandGenProductAd
Returns a new instance of DemandGenProductAd.
6720 6721 6722 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6720 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_name ⇒ String
Required. The business name shown on the ad.
Corresponds to the JSON property businessName
6659 6660 6661 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6659 def business_name @business_name end |
#call_to_action ⇒ String
Required. The call-to-action button shown on the ad. The supported values are:
AUTOMATED*APPLY_NOW*BOOK_NOW*CONTACT_US*DOWNLOAD*GET_QUOTE*LEARN_MORE*SHOP_NOW*SIGN_UP*SUBSCRIBECorresponds to the JSON propertycallToAction
6666 6667 6668 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6666 def call_to_action @call_to_action end |
#custom_parameters ⇒ Hash<String,String>
Optional. The custom parameters and accompanying values to add to the tracking
URL.
Corresponds to the JSON property customParameters
6672 6673 6674 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6672 def custom_parameters @custom_parameters end |
#description ⇒ String
Required. The description of the ad.
Corresponds to the JSON property description
6677 6678 6679 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6677 def description @description end |
#display_url_breadcrumb1 ⇒ String
Optional. The first piece after the domain in the display URL.
Corresponds to the JSON property displayUrlBreadcrumb1
6682 6683 6684 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6682 def @display_url_breadcrumb1 end |
#display_url_breadcrumb2 ⇒ String
Optional. The second piece after the domain in the display URL.
Corresponds to the JSON property displayUrlBreadcrumb2
6687 6688 6689 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6687 def @display_url_breadcrumb2 end |
#final_url ⇒ String
Required. The URL address of the webpage that people reach after they click
the ad.
Corresponds to the JSON property finalUrl
6693 6694 6695 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6693 def final_url @final_url end |
#final_url_suffix ⇒ String
Optional. The suffix to append to landing page URLs.
Corresponds to the JSON property finalUrlSuffix
6698 6699 6700 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6698 def final_url_suffix @final_url_suffix end |
#headline ⇒ String
Required. The headline of the ad.
Corresponds to the JSON property headline
6703 6704 6705 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6703 def headline @headline end |
#logo ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
Corresponds to the JSON property logo
6708 6709 6710 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6708 def logo @logo end |
#tracking_url ⇒ String
Output only. The URL address loaded in the background for tracking purposes.
Corresponds to the JSON property trackingUrl
6713 6714 6715 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6713 def tracking_url @tracking_url end |
#user_specified_tracking_url ⇒ String
Optional. The tracking URL specified by the user manually.
Corresponds to the JSON property userSpecifiedTrackingUrl
6718 6719 6720 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6718 def user_specified_tracking_url @user_specified_tracking_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6725 6726 6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6725 def update!(**args) @business_name = args[:business_name] if args.key?(:business_name) @call_to_action = args[:call_to_action] if args.key?(:call_to_action) @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters) @description = args[:description] if args.key?(:description) @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1) @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2) @final_url = args[:final_url] if args.key?(:final_url) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @headline = args[:headline] if args.key?(:headline) @logo = args[:logo] if args.key?(:logo) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url) end |