Class: Google::Apis::DisplayvideoV4::DemandGenProductAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen product ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenProductAd

Returns a new instance of DemandGenProductAd.



6711
6712
6713
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6711

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Required. The business name shown on the ad. Corresponds to the JSON property businessName

Returns:

  • (String)


6650
6651
6652
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6650

def business_name
  @business_name
end

#call_to_actionString

Required. The call-to-action button shown on the ad. The supported values are:

  • AUTOMATED * APPLY_NOW * BOOK_NOW * CONTACT_US * DOWNLOAD * GET_QUOTE * LEARN_MORE * SHOP_NOW * SIGN_UP * SUBSCRIBE Corresponds to the JSON property callToAction

Returns:

  • (String)


6657
6658
6659
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6657

def call_to_action
  @call_to_action
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6663
6664
6665
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6663

def custom_parameters
  @custom_parameters
end

#descriptionString

Required. The description of the ad. Corresponds to the JSON property description

Returns:

  • (String)


6668
6669
6670
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6668

def description
  @description
end

#display_url_breadcrumb1String

Optional. The first piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb1

Returns:

  • (String)


6673
6674
6675
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6673

def display_url_breadcrumb1
  @display_url_breadcrumb1
end

#display_url_breadcrumb2String

Optional. The second piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb2

Returns:

  • (String)


6678
6679
6680
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6678

def display_url_breadcrumb2
  @display_url_breadcrumb2
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6684
6685
6686
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6684

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6689
6690
6691
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6689

def final_url_suffix
  @final_url_suffix
end

#headlineString

Required. The headline of the ad. Corresponds to the JSON property headline

Returns:

  • (String)


6694
6695
6696
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6694

def headline
  @headline
end

#logoGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property logo



6699
6700
6701
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6699

def 
  @logo
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


6704
6705
6706
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6704

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


6709
6710
6711
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6709

def user_specified_tracking_url
  @user_specified_tracking_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6716
6717
6718
6719
6720
6721
6722
6723
6724
6725
6726
6727
6728
6729
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6716

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @description = args[:description] if args.key?(:description)
  @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1)
  @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headline = args[:headline] if args.key?(:headline)
  @logo = args[:logo] if args.key?(:logo)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
end