Class: Google::Apis::DisplayvideoV4::DemandGenSettings
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::DemandGenSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Settings for Demand Gen line items.
Instance Attribute Summary collapse
-
#geo_language_targeting_enabled ⇒ Boolean
(also: #geo_language_targeting_enabled?)
Optional.
-
#linked_merchant_id ⇒ Fixnum
Optional.
-
#third_party_measurement_configs ⇒ Google::Apis::DisplayvideoV4::ThirdPartyMeasurementConfigs
Settings that control what third-party vendors are measuring specific line item metrics.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DemandGenSettings
constructor
A new instance of DemandGenSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DemandGenSettings
Returns a new instance of DemandGenSettings.
6916 6917 6918 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#geo_language_targeting_enabled ⇒ Boolean Also known as: geo_language_targeting_enabled?
Optional. Immutable. Whether location and language targeting can be set at the
line item level. Otherwise, relevant targeting types must be assigned directly
to ad groups.
Corresponds to the JSON property geoLanguageTargetingEnabled
6901 6902 6903 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6901 def geo_language_targeting_enabled @geo_language_targeting_enabled end |
#linked_merchant_id ⇒ Fixnum
Optional. The ID of the Merchant Center account used to provide a product feed.
This Merchant Center account must already be linked to the advertiser.
Corresponds to the JSON property linkedMerchantId
6908 6909 6910 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6908 def linked_merchant_id @linked_merchant_id end |
#third_party_measurement_configs ⇒ Google::Apis::DisplayvideoV4::ThirdPartyMeasurementConfigs
Settings that control what third-party vendors are measuring specific line
item metrics.
Corresponds to the JSON property thirdPartyMeasurementConfigs
6914 6915 6916 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6914 def third_party_measurement_configs @third_party_measurement_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6921 6922 6923 6924 6925 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6921 def update!(**args) @geo_language_targeting_enabled = args[:geo_language_targeting_enabled] if args.key?(:geo_language_targeting_enabled) @linked_merchant_id = args[:linked_merchant_id] if args.key?(:linked_merchant_id) @third_party_measurement_configs = args[:third_party_measurement_configs] if args.key?(:third_party_measurement_configs) end |