Class: Google::Apis::DisplayvideoV4::DemandGenSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Settings for Demand Gen line items.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenSettings

Returns a new instance of DemandGenSettings.



6765
6766
6767
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6765

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#geo_language_targeting_enabledBoolean Also known as: geo_language_targeting_enabled?

Optional. Immutable. Whether location and language targeting can be set at the line item level. Otherwise, relevant targeting types must be assigned directly to ad groups. Corresponds to the JSON property geoLanguageTargetingEnabled

Returns:

  • (Boolean)


6750
6751
6752
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6750

def geo_language_targeting_enabled
  @geo_language_targeting_enabled
end

#linked_merchant_idFixnum

Optional. The ID of the Merchant Center account used to provide a product feed. This Merchant Center account must already be linked to the advertiser. Corresponds to the JSON property linkedMerchantId

Returns:

  • (Fixnum)


6757
6758
6759
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6757

def linked_merchant_id
  @linked_merchant_id
end

#third_party_measurement_configsGoogle::Apis::DisplayvideoV4::ThirdPartyMeasurementConfigs

Settings that control what third-party vendors are measuring specific line item metrics. Corresponds to the JSON property thirdPartyMeasurementConfigs



6763
6764
6765
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6763

def third_party_measurement_configs
  @third_party_measurement_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6770
6771
6772
6773
6774
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6770

def update!(**args)
  @geo_language_targeting_enabled = args[:geo_language_targeting_enabled] if args.key?(:geo_language_targeting_enabled)
  @linked_merchant_id = args[:linked_merchant_id] if args.key?(:linked_merchant_id)
  @third_party_measurement_configs = args[:third_party_measurement_configs] if args.key?(:third_party_measurement_configs)
end