Class: Google::Apis::DisplayvideoV4::DemandGenVideoAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen video ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenVideoAd

Returns a new instance of DemandGenVideoAd.



7020
7021
7022
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Optional. The business name shown on the ad. This setting is required unless a default value is set at the advertiser level. If left unset, the default value will be applied. Corresponds to the JSON property businessName

Returns:

  • (String)


6936
6937
6938
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6936

def business_name
  @business_name
end

#call_to_actionString

Required. The call-to-action button shown on the ad. The supported values are:

  • AUTOMATED * LEARN_MORE * GET_QUOTE * APPLY_NOW * SIGN_UP * CONTACT_US * SUBSCRIBE * DOWNLOAD * BOOK_NOW * SHOP_NOW * BUY_NOW * DONATE_NOW * ORDER_NOW * PLAY_NOW * SEE_MORE * START_NOW * VISIT_SITE * WATCH_NOW Corresponds to the JSON property callToAction

Returns:

  • (String)


6945
6946
6947
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6945

def call_to_action
  @call_to_action
end

#companion_bannerGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property companionBanner



6950
6951
6952
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6950

def companion_banner
  @companion_banner
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6956
6957
6958
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6956

def custom_parameters
  @custom_parameters
end

#descriptionsArray<String>

Required. The list of descriptions shown on the ad. Corresponds to the JSON property descriptions

Returns:

  • (Array<String>)


6961
6962
6963
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6961

def descriptions
  @descriptions
end

#display_url_breadcrumb1String

Optional. The first piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb1

Returns:

  • (String)


6966
6967
6968
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6966

def display_url_breadcrumb1
  @display_url_breadcrumb1
end

#display_url_breadcrumb2String

Optional. The second piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb2

Returns:

  • (String)


6971
6972
6973
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6971

def display_url_breadcrumb2
  @display_url_breadcrumb2
end

#final_mobile_urlString

Optional. The URL address of the webpage that people reach after they click the ad on a mobile device. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


6977
6978
6979
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6977

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6983
6984
6985
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6983

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6988
6989
6990
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6988

def final_url_suffix
  @final_url_suffix
end

#headlinesArray<String>

Required. The list of headlines shown on the ad. Corresponds to the JSON property headlines

Returns:

  • (Array<String>)


6993
6994
6995
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6993

def headlines
  @headlines
end

#logoGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property logo



6998
6999
7000
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6998

def 
  @logo
end

#long_headlinesArray<String>

Required. The list of long headlines shown on the ad. Corresponds to the JSON property longHeadlines

Returns:

  • (Array<String>)


7003
7004
7005
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7003

def long_headlines
  @long_headlines
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


7008
7009
7010
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7008

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


7013
7014
7015
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7013

def user_specified_tracking_url
  @user_specified_tracking_url
end

#videosArray<Google::Apis::DisplayvideoV4::YoutubeVideoDetails>

Required. The list of YouTube video assets used by this ad. Corresponds to the JSON property videos



7018
7019
7020
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7018

def videos
  @videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7025
7026
7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
7042
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7025

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @companion_banner = args[:companion_banner] if args.key?(:companion_banner)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1)
  @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headlines = args[:headlines] if args.key?(:headlines)
  @logo = args[:logo] if args.key?(:logo)
  @long_headlines = args[:long_headlines] if args.key?(:long_headlines)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
  @videos = args[:videos] if args.key?(:videos)
end