Class: Google::Apis::DisplayvideoV4::DemandGenVideoAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::DemandGenVideoAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details for a Demand Gen video ad.
Instance Attribute Summary collapse
-
#business_name ⇒ String
Required.
-
#call_to_action ⇒ String
Required.
-
#companion_banner ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
-
#custom_parameters ⇒ Hash<String,String>
Optional.
-
#descriptions ⇒ Array<String>
Required.
-
#display_url_breadcrumb1 ⇒ String
Optional.
-
#display_url_breadcrumb2 ⇒ String
Optional.
-
#final_mobile_url ⇒ String
Optional.
-
#final_url ⇒ String
Required.
-
#final_url_suffix ⇒ String
Optional.
-
#headlines ⇒ Array<String>
Required.
-
#logo ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
-
#long_headlines ⇒ Array<String>
Required.
-
#tracking_url ⇒ String
Output only.
-
#user_specified_tracking_url ⇒ String
Optional.
-
#videos ⇒ Array<Google::Apis::DisplayvideoV4::YoutubeVideoDetails>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DemandGenVideoAd
constructor
A new instance of DemandGenVideoAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DemandGenVideoAd
Returns a new instance of DemandGenVideoAd.
6990 6991 6992 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_name ⇒ String
Required. The business name shown on the ad. Warning: Starting July 13,
2026, this setting will no longer be required if a default value is set at
the advertiser level. If left unset, the default value will be applied.
Corresponds to the JSON property businessName
6906 6907 6908 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6906 def business_name @business_name end |
#call_to_action ⇒ String
Required. The call-to-action button shown on the ad. The supported values are:
AUTOMATED*LEARN_MORE*GET_QUOTE*APPLY_NOW*SIGN_UP*CONTACT_US*SUBSCRIBE*DOWNLOAD*BOOK_NOW*SHOP_NOW*BUY_NOW*DONATE_NOW*ORDER_NOW*PLAY_NOW*SEE_MORE*START_NOW*VISIT_SITE*WATCH_NOWCorresponds to the JSON propertycallToAction
6915 6916 6917 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6915 def call_to_action @call_to_action end |
#companion_banner ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
Corresponds to the JSON property companionBanner
6920 6921 6922 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6920 def @companion_banner end |
#custom_parameters ⇒ Hash<String,String>
Optional. The custom parameters and accompanying values to add to the tracking
URL.
Corresponds to the JSON property customParameters
6926 6927 6928 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6926 def custom_parameters @custom_parameters end |
#descriptions ⇒ Array<String>
Required. The list of descriptions shown on the ad.
Corresponds to the JSON property descriptions
6931 6932 6933 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6931 def descriptions @descriptions end |
#display_url_breadcrumb1 ⇒ String
Optional. The first piece after the domain in the display URL.
Corresponds to the JSON property displayUrlBreadcrumb1
6936 6937 6938 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6936 def @display_url_breadcrumb1 end |
#display_url_breadcrumb2 ⇒ String
Optional. The second piece after the domain in the display URL.
Corresponds to the JSON property displayUrlBreadcrumb2
6941 6942 6943 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6941 def @display_url_breadcrumb2 end |
#final_mobile_url ⇒ String
Optional. The URL address of the webpage that people reach after they click
the ad on a mobile device.
Corresponds to the JSON property finalMobileUrl
6947 6948 6949 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6947 def final_mobile_url @final_mobile_url end |
#final_url ⇒ String
Required. The URL address of the webpage that people reach after they click
the ad.
Corresponds to the JSON property finalUrl
6953 6954 6955 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6953 def final_url @final_url end |
#final_url_suffix ⇒ String
Optional. The suffix to append to landing page URLs.
Corresponds to the JSON property finalUrlSuffix
6958 6959 6960 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6958 def final_url_suffix @final_url_suffix end |
#headlines ⇒ Array<String>
Required. The list of headlines shown on the ad.
Corresponds to the JSON property headlines
6963 6964 6965 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6963 def headlines @headlines end |
#logo ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
Corresponds to the JSON property logo
6968 6969 6970 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6968 def logo @logo end |
#long_headlines ⇒ Array<String>
Required. The list of long headlines shown on the ad.
Corresponds to the JSON property longHeadlines
6973 6974 6975 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6973 def long_headlines @long_headlines end |
#tracking_url ⇒ String
Output only. The URL address loaded in the background for tracking purposes.
Corresponds to the JSON property trackingUrl
6978 6979 6980 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6978 def tracking_url @tracking_url end |
#user_specified_tracking_url ⇒ String
Optional. The tracking URL specified by the user manually.
Corresponds to the JSON property userSpecifiedTrackingUrl
6983 6984 6985 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6983 def user_specified_tracking_url @user_specified_tracking_url end |
#videos ⇒ Array<Google::Apis::DisplayvideoV4::YoutubeVideoDetails>
Required. The list of YouTube video assets used by this ad.
Corresponds to the JSON property videos
6988 6989 6990 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6988 def videos @videos end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6995 6996 6997 6998 6999 7000 7001 7002 7003 7004 7005 7006 7007 7008 7009 7010 7011 7012 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6995 def update!(**args) @business_name = args[:business_name] if args.key?(:business_name) @call_to_action = args[:call_to_action] if args.key?(:call_to_action) @companion_banner = args[:companion_banner] if args.key?(:companion_banner) @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters) @descriptions = args[:descriptions] if args.key?(:descriptions) @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1) @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2) @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url) @final_url = args[:final_url] if args.key?(:final_url) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @headlines = args[:headlines] if args.key?(:headlines) @logo = args[:logo] if args.key?(:logo) @long_headlines = args[:long_headlines] if args.key?(:long_headlines) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url) @videos = args[:videos] if args.key?(:videos) end |