Class: Google::Apis::DisplayvideoV4::DemandGenVideoAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::DemandGenVideoAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details for a Demand Gen video ad.
Instance Attribute Summary collapse
-
#business_name ⇒ String
Required.
-
#call_to_action ⇒ String
Required.
-
#companion_banner ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
-
#custom_parameters ⇒ Hash<String,String>
Optional.
-
#descriptions ⇒ Array<String>
Required.
-
#display_url_breadcrumb1 ⇒ String
Optional.
-
#display_url_breadcrumb2 ⇒ String
Optional.
-
#final_mobile_url ⇒ String
Optional.
-
#final_url ⇒ String
Required.
-
#final_url_suffix ⇒ String
Optional.
-
#headlines ⇒ Array<String>
Required.
-
#logo ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
-
#long_headlines ⇒ Array<String>
Required.
-
#tracking_url ⇒ String
Output only.
-
#user_specified_tracking_url ⇒ String
Optional.
-
#videos ⇒ Array<Google::Apis::DisplayvideoV4::YoutubeVideoDetails>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DemandGenVideoAd
constructor
A new instance of DemandGenVideoAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DemandGenVideoAd
Returns a new instance of DemandGenVideoAd.
6868 6869 6870 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_name ⇒ String
Required. The business name shown on the ad.
Corresponds to the JSON property businessName
6784 6785 6786 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6784 def business_name @business_name end |
#call_to_action ⇒ String
Required. The call-to-action button shown on the ad. The supported values are:
AUTOMATED*LEARN_MORE*GET_QUOTE*APPLY_NOW*SIGN_UP*CONTACT_US*SUBSCRIBE*DOWNLOAD*BOOK_NOW*SHOP_NOW*BUY_NOW*DONATE_NOW*ORDER_NOW*PLAY_NOW*SEE_MORE*START_NOW*VISIT_SITE*WATCH_NOWCorresponds to the JSON propertycallToAction
6793 6794 6795 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6793 def call_to_action @call_to_action end |
#companion_banner ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
Corresponds to the JSON property companionBanner
6798 6799 6800 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6798 def @companion_banner end |
#custom_parameters ⇒ Hash<String,String>
Optional. The custom parameters and accompanying values to add to the tracking
URL.
Corresponds to the JSON property customParameters
6804 6805 6806 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6804 def custom_parameters @custom_parameters end |
#descriptions ⇒ Array<String>
Required. The list of descriptions shown on the ad.
Corresponds to the JSON property descriptions
6809 6810 6811 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6809 def descriptions @descriptions end |
#display_url_breadcrumb1 ⇒ String
Optional. The first piece after the domain in the display URL.
Corresponds to the JSON property displayUrlBreadcrumb1
6814 6815 6816 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6814 def @display_url_breadcrumb1 end |
#display_url_breadcrumb2 ⇒ String
Optional. The second piece after the domain in the display URL.
Corresponds to the JSON property displayUrlBreadcrumb2
6819 6820 6821 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6819 def @display_url_breadcrumb2 end |
#final_mobile_url ⇒ String
Optional. The URL address of the webpage that people reach after they click
the ad on a mobile device.
Corresponds to the JSON property finalMobileUrl
6825 6826 6827 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6825 def final_mobile_url @final_mobile_url end |
#final_url ⇒ String
Required. The URL address of the webpage that people reach after they click
the ad.
Corresponds to the JSON property finalUrl
6831 6832 6833 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6831 def final_url @final_url end |
#final_url_suffix ⇒ String
Optional. The suffix to append to landing page URLs.
Corresponds to the JSON property finalUrlSuffix
6836 6837 6838 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6836 def final_url_suffix @final_url_suffix end |
#headlines ⇒ Array<String>
Required. The list of headlines shown on the ad.
Corresponds to the JSON property headlines
6841 6842 6843 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6841 def headlines @headlines end |
#logo ⇒ Google::Apis::DisplayvideoV4::ImageAsset
Meta data of an image asset.
Corresponds to the JSON property logo
6846 6847 6848 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6846 def logo @logo end |
#long_headlines ⇒ Array<String>
Required. The list of long headlines shown on the ad.
Corresponds to the JSON property longHeadlines
6851 6852 6853 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6851 def long_headlines @long_headlines end |
#tracking_url ⇒ String
Output only. The URL address loaded in the background for tracking purposes.
Corresponds to the JSON property trackingUrl
6856 6857 6858 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6856 def tracking_url @tracking_url end |
#user_specified_tracking_url ⇒ String
Optional. The tracking URL specified by the user manually.
Corresponds to the JSON property userSpecifiedTrackingUrl
6861 6862 6863 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6861 def user_specified_tracking_url @user_specified_tracking_url end |
#videos ⇒ Array<Google::Apis::DisplayvideoV4::YoutubeVideoDetails>
Required. The list of YouTube video assets used by this ad.
Corresponds to the JSON property videos
6866 6867 6868 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6866 def videos @videos end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 6883 6884 6885 6886 6887 6888 6889 6890 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6873 def update!(**args) @business_name = args[:business_name] if args.key?(:business_name) @call_to_action = args[:call_to_action] if args.key?(:call_to_action) @companion_banner = args[:companion_banner] if args.key?(:companion_banner) @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters) @descriptions = args[:descriptions] if args.key?(:descriptions) @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1) @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2) @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url) @final_url = args[:final_url] if args.key?(:final_url) @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix) @headlines = args[:headlines] if args.key?(:headlines) @logo = args[:logo] if args.key?(:logo) @long_headlines = args[:long_headlines] if args.key?(:long_headlines) @tracking_url = args[:tracking_url] if args.key?(:tracking_url) @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url) @videos = args[:videos] if args.key?(:videos) end |