Class: Google::Apis::DisplayvideoV4::DemandGenVideoAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Demand Gen video ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DemandGenVideoAd

Returns a new instance of DemandGenVideoAd.



6859
6860
6861
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6859

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_nameString

Required. The business name shown on the ad. Corresponds to the JSON property businessName

Returns:

  • (String)


6775
6776
6777
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6775

def business_name
  @business_name
end

#call_to_actionString

Required. The call-to-action button shown on the ad. The supported values are:

  • AUTOMATED * LEARN_MORE * GET_QUOTE * APPLY_NOW * SIGN_UP * CONTACT_US * SUBSCRIBE * DOWNLOAD * BOOK_NOW * SHOP_NOW * BUY_NOW * DONATE_NOW * ORDER_NOW * PLAY_NOW * SEE_MORE * START_NOW * VISIT_SITE * WATCH_NOW Corresponds to the JSON property callToAction

Returns:

  • (String)


6784
6785
6786
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6784

def call_to_action
  @call_to_action
end

#companion_bannerGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property companionBanner



6789
6790
6791
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6789

def companion_banner
  @companion_banner
end

#custom_parametersHash<String,String>

Optional. The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


6795
6796
6797
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6795

def custom_parameters
  @custom_parameters
end

#descriptionsArray<String>

Required. The list of descriptions shown on the ad. Corresponds to the JSON property descriptions

Returns:

  • (Array<String>)


6800
6801
6802
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6800

def descriptions
  @descriptions
end

#display_url_breadcrumb1String

Optional. The first piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb1

Returns:

  • (String)


6805
6806
6807
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6805

def display_url_breadcrumb1
  @display_url_breadcrumb1
end

#display_url_breadcrumb2String

Optional. The second piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb2

Returns:

  • (String)


6810
6811
6812
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6810

def display_url_breadcrumb2
  @display_url_breadcrumb2
end

#final_mobile_urlString

Optional. The URL address of the webpage that people reach after they click the ad on a mobile device. Corresponds to the JSON property finalMobileUrl

Returns:

  • (String)


6816
6817
6818
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6816

def final_mobile_url
  @final_mobile_url
end

#final_urlString

Required. The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


6822
6823
6824
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6822

def final_url
  @final_url
end

#final_url_suffixString

Optional. The suffix to append to landing page URLs. Corresponds to the JSON property finalUrlSuffix

Returns:

  • (String)


6827
6828
6829
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6827

def final_url_suffix
  @final_url_suffix
end

#headlinesArray<String>

Required. The list of headlines shown on the ad. Corresponds to the JSON property headlines

Returns:

  • (Array<String>)


6832
6833
6834
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6832

def headlines
  @headlines
end

#logoGoogle::Apis::DisplayvideoV4::ImageAsset

Meta data of an image asset. Corresponds to the JSON property logo



6837
6838
6839
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6837

def 
  @logo
end

#long_headlinesArray<String>

Required. The list of long headlines shown on the ad. Corresponds to the JSON property longHeadlines

Returns:

  • (Array<String>)


6842
6843
6844
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6842

def long_headlines
  @long_headlines
end

#tracking_urlString

Output only. The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


6847
6848
6849
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6847

def tracking_url
  @tracking_url
end

#user_specified_tracking_urlString

Optional. The tracking URL specified by the user manually. Corresponds to the JSON property userSpecifiedTrackingUrl

Returns:

  • (String)


6852
6853
6854
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6852

def user_specified_tracking_url
  @user_specified_tracking_url
end

#videosArray<Google::Apis::DisplayvideoV4::YoutubeVideoDetails>

Required. The list of YouTube video assets used by this ad. Corresponds to the JSON property videos



6857
6858
6859
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6857

def videos
  @videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6864
6865
6866
6867
6868
6869
6870
6871
6872
6873
6874
6875
6876
6877
6878
6879
6880
6881
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 6864

def update!(**args)
  @business_name = args[:business_name] if args.key?(:business_name)
  @call_to_action = args[:call_to_action] if args.key?(:call_to_action)
  @companion_banner = args[:companion_banner] if args.key?(:companion_banner)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1)
  @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2)
  @final_mobile_url = args[:final_mobile_url] if args.key?(:final_mobile_url)
  @final_url = args[:final_url] if args.key?(:final_url)
  @final_url_suffix = args[:final_url_suffix] if args.key?(:final_url_suffix)
  @headlines = args[:headlines] if args.key?(:headlines)
  @logo = args[:logo] if args.key?(:logo)
  @long_headlines = args[:long_headlines] if args.key?(:long_headlines)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @user_specified_tracking_url = args[:user_specified_tracking_url] if args.key?(:user_specified_tracking_url)
  @videos = args[:videos] if args.key?(:videos)
end