Class: Google::Apis::DisplayvideoV4::EditCustomerMatchMembersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Request message for FirstAndThirdPartyAudienceService.EditCustomerMatchMembers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EditCustomerMatchMembersRequest

Returns a new instance of EditCustomerMatchMembersRequest.



7364
7365
7366
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7364

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#added_contact_info_listGoogle::Apis::DisplayvideoV4::ContactInfoList

Wrapper message for a list of contact information defining Customer Match audience members. Corresponds to the JSON property addedContactInfoList



7338
7339
7340
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7338

def added_contact_info_list
  @added_contact_info_list
end

#added_mobile_device_id_listGoogle::Apis::DisplayvideoV4::MobileDeviceIdList

Wrapper message for a list of mobile device IDs defining Customer Match audience members. Corresponds to the JSON property addedMobileDeviceIdList



7344
7345
7346
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7344

def added_mobile_device_id_list
  @added_mobile_device_id_list
end

#advertiser_idFixnum

Required. The ID of the owner advertiser of the updated Customer Match FirstAndThirdPartyAudience. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


7350
7351
7352
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7350

def advertiser_id
  @advertiser_id
end

#removed_contact_info_listGoogle::Apis::DisplayvideoV4::ContactInfoList

Wrapper message for a list of contact information defining Customer Match audience members. Corresponds to the JSON property removedContactInfoList



7356
7357
7358
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7356

def removed_contact_info_list
  @removed_contact_info_list
end

#removed_mobile_device_id_listGoogle::Apis::DisplayvideoV4::MobileDeviceIdList

Wrapper message for a list of mobile device IDs defining Customer Match audience members. Corresponds to the JSON property removedMobileDeviceIdList



7362
7363
7364
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7362

def removed_mobile_device_id_list
  @removed_mobile_device_id_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7369
7370
7371
7372
7373
7374
7375
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7369

def update!(**args)
  @added_contact_info_list = args[:added_contact_info_list] if args.key?(:added_contact_info_list)
  @added_mobile_device_id_list = args[:added_mobile_device_id_list] if args.key?(:added_mobile_device_id_list)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @removed_contact_info_list = args[:removed_contact_info_list] if args.key?(:removed_contact_info_list)
  @removed_mobile_device_id_list = args[:removed_mobile_device_id_list] if args.key?(:removed_mobile_device_id_list)
end