Class: Google::Apis::DisplayvideoV4::ExchangeConfigEnabledExchange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

An enabled exchange in the partner.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangeConfigEnabledExchange

Returns a new instance of ExchangeConfigEnabledExchange.



7782
7783
7784
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exchangeString

The enabled exchange. Corresponds to the JSON property exchange

Returns:

  • (String)


7763
7764
7765
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7763

def exchange
  @exchange
end

Output only. Agency ID of Google Ad Manager. The field is only relevant when Google Ad Manager is the enabled exchange. Corresponds to the JSON property googleAdManagerAgencyId

Returns:

  • (String)


7769
7770
7771
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7769

def google_ad_manager_agency_id
  @google_ad_manager_agency_id
end

Output only. Network ID of Google Ad Manager. The field is only relevant when Google Ad Manager is the enabled exchange. Corresponds to the JSON property googleAdManagerBuyerNetworkId

Returns:

  • (String)


7775
7776
7777
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7775

def google_ad_manager_buyer_network_id
  @google_ad_manager_buyer_network_id
end

#seat_idString

Output only. Seat ID of the enabled exchange. Corresponds to the JSON property seatId

Returns:

  • (String)


7780
7781
7782
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7780

def seat_id
  @seat_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7787
7788
7789
7790
7791
7792
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7787

def update!(**args)
  @exchange = args[:exchange] if args.key?(:exchange)
  @google_ad_manager_agency_id = args[:google_ad_manager_agency_id] if args.key?(:google_ad_manager_agency_id)
  @google_ad_manager_buyer_network_id = args[:google_ad_manager_buyer_network_id] if args.key?(:google_ad_manager_buyer_network_id)
  @seat_id = args[:seat_id] if args.key?(:seat_id)
end