Class: Google::Apis::DisplayvideoV4::ExitEvent
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ExitEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Exit event of the creative.
Instance Attribute Summary collapse
-
#name ⇒ String
Optional.
-
#reporting_name ⇒ String
Optional.
-
#type ⇒ String
Required.
-
#url ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExitEvent
constructor
A new instance of ExitEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExitEvent
Returns a new instance of ExitEvent.
7899 7900 7901 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7899 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Optional. The name of the click tag of the exit event. The name must be unique
within one creative. Leave it empty or unset for creatives containing image
assets only.
Corresponds to the JSON property name
7880 7881 7882 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7880 def name @name end |
#reporting_name ⇒ String
Optional. The name used to identify this event in reports. Leave it empty or
unset for creatives containing image assets only.
Corresponds to the JSON property reportingName
7886 7887 7888 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7886 def reporting_name @reporting_name end |
#type ⇒ String
Required. The type of the exit event.
Corresponds to the JSON property type
7891 7892 7893 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7891 def type @type end |
#url ⇒ String
Required. The click through URL of the exit event. This is required when type
is: * EXIT_EVENT_TYPE_DEFAULT * EXIT_EVENT_TYPE_BACKUP
Corresponds to the JSON property url
7897 7898 7899 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7897 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7904 7905 7906 7907 7908 7909 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7904 def update!(**args) @name = args[:name] if args.key?(:name) @reporting_name = args[:reporting_name] if args.key?(:reporting_name) @type = args[:type] if args.key?(:type) @url = args[:url] if args.key?(:url) end |