Class: Google::Apis::DisplayvideoV4::ExitEvent
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ExitEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Exit event of the creative.
Instance Attribute Summary collapse
-
#name ⇒ String
Optional.
-
#reporting_name ⇒ String
Optional.
-
#type ⇒ String
Required.
-
#url ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExitEvent
constructor
A new instance of ExitEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExitEvent
Returns a new instance of ExitEvent.
7869 7870 7871 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7869 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Optional. The name of the click tag of the exit event. The name must be unique
within one creative. Leave it empty or unset for creatives containing image
assets only.
Corresponds to the JSON property name
7850 7851 7852 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7850 def name @name end |
#reporting_name ⇒ String
Optional. The name used to identify this event in reports. Leave it empty or
unset for creatives containing image assets only.
Corresponds to the JSON property reportingName
7856 7857 7858 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7856 def reporting_name @reporting_name end |
#type ⇒ String
Required. The type of the exit event.
Corresponds to the JSON property type
7861 7862 7863 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7861 def type @type end |
#url ⇒ String
Required. The click through URL of the exit event. This is required when type
is: * EXIT_EVENT_TYPE_DEFAULT * EXIT_EVENT_TYPE_BACKUP
Corresponds to the JSON property url
7867 7868 7869 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7867 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7874 7875 7876 7877 7878 7879 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7874 def update!(**args) @name = args[:name] if args.key?(:name) @reporting_name = args[:reporting_name] if args.key?(:reporting_name) @type = args[:type] if args.key?(:type) @url = args[:url] if args.key?(:url) end |