Class: Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudience
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudience
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Describes a first or partner audience list used for targeting. First party audiences are created via usage of client data. Partner audiences are provided by Third Party data providers and can only be licensed to customers.
Instance Attribute Summary collapse
-
#active_display_audience_size ⇒ Fixnum
Output only.
-
#app_id ⇒ String
Optional.
-
#audience_source ⇒ String
Output only.
-
#audience_type ⇒ String
Immutable.
-
#contact_info_list ⇒ Google::Apis::DisplayvideoV4::ContactInfoList
Wrapper message for a list of contact information defining Customer Match audience members.
-
#description ⇒ String
Optional.
-
#display_audience_size ⇒ Fixnum
Output only.
-
#display_desktop_audience_size ⇒ Fixnum
Output only.
-
#display_mobile_app_audience_size ⇒ Fixnum
Output only.
-
#display_mobile_web_audience_size ⇒ Fixnum
Output only.
-
#display_name ⇒ String
Optional.
-
#first_party_and_partner_audience_id ⇒ Fixnum
Identifier.
-
#first_party_and_partner_audience_type ⇒ String
Output only.
-
#gmail_audience_size ⇒ Fixnum
Output only.
-
#membership_duration_days ⇒ Fixnum
Optional.
-
#mobile_device_id_list ⇒ Google::Apis::DisplayvideoV4::MobileDeviceIdList
Wrapper message for a list of mobile device IDs defining Customer Match audience members.
-
#name ⇒ String
Output only.
-
#youtube_audience_size ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirstPartyAndPartnerAudience
constructor
A new instance of FirstPartyAndPartnerAudience.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirstPartyAndPartnerAudience
Returns a new instance of FirstPartyAndPartnerAudience.
8041 8042 8043 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8041 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_display_audience_size ⇒ Fixnum
Output only. The estimated audience size for the Display network in the past
month. If the size is less than 1000, the number will be hidden and 0 will be
returned due to privacy reasons. Otherwise, the number will be rounded off to
two significant digits. Only returned in GET request.
Corresponds to the JSON property activeDisplayAudienceSize
7924 7925 7926 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7924 def active_display_audience_size @active_display_audience_size end |
#app_id ⇒ String
Optional. The app_id matches with the type of the mobile_device_ids being
uploaded. Only applicable to audience_type CUSTOMER_MATCH_DEVICE_ID
Corresponds to the JSON property appId
7930 7931 7932 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7930 def app_id @app_id end |
#audience_source ⇒ String
Output only. The source of the audience.
Corresponds to the JSON property audienceSource
7935 7936 7937 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7935 def audience_source @audience_source end |
#audience_type ⇒ String
Immutable. The type of the audience.
Corresponds to the JSON property audienceType
7940 7941 7942 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7940 def audience_type @audience_type end |
#contact_info_list ⇒ Google::Apis::DisplayvideoV4::ContactInfoList
Wrapper message for a list of contact information defining Customer Match
audience members.
Corresponds to the JSON property contactInfoList
7946 7947 7948 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7946 def contact_info_list @contact_info_list end |
#description ⇒ String
Optional. The user-provided description of the audience. Only applicable to
first party audiences.
Corresponds to the JSON property description
7952 7953 7954 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7952 def description @description end |
#display_audience_size ⇒ Fixnum
Output only. The estimated audience size for the Display network. If the size
is less than 1000, the number will be hidden and 0 will be returned due to
privacy reasons. Otherwise, the number will be rounded off to two significant
digits. Only returned in GET request.
Corresponds to the JSON property displayAudienceSize
7960 7961 7962 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7960 def display_audience_size @display_audience_size end |
#display_desktop_audience_size ⇒ Fixnum
Output only. The estimated desktop audience size in Display network. If the
size is less than 1000, the number will be hidden and 0 will be returned due
to privacy reasons. Otherwise, the number will be rounded off to two
significant digits. Only applicable to first party audiences. Only returned in
GET request.
Corresponds to the JSON property displayDesktopAudienceSize
7969 7970 7971 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7969 def display_desktop_audience_size @display_desktop_audience_size end |
#display_mobile_app_audience_size ⇒ Fixnum
Output only. The estimated mobile app audience size in Display network. If the
size is less than 1000, the number will be hidden and 0 will be returned due
to privacy reasons. Otherwise, the number will be rounded off to two
significant digits. Only applicable to first party audiences. Only returned in
GET request.
Corresponds to the JSON property displayMobileAppAudienceSize
7978 7979 7980 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7978 def display_mobile_app_audience_size @display_mobile_app_audience_size end |
#display_mobile_web_audience_size ⇒ Fixnum
Output only. The estimated mobile web audience size in Display network. If the
size is less than 1000, the number will be hidden and 0 will be returned due
to privacy reasons. Otherwise, the number will be rounded off to two
significant digits. Only applicable to first party audiences. Only returned in
GET request.
Corresponds to the JSON property displayMobileWebAudienceSize
7987 7988 7989 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7987 def display_mobile_web_audience_size @display_mobile_web_audience_size end |
#display_name ⇒ String
Optional. The display name of the first party and partner audience.
Corresponds to the JSON property displayName
7992 7993 7994 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7992 def display_name @display_name end |
#first_party_and_partner_audience_id ⇒ Fixnum
Identifier. The unique ID of the first party and partner audience. Assigned by
the system.
Corresponds to the JSON property firstPartyAndPartnerAudienceId
7998 7999 8000 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7998 def first_party_and_partner_audience_id @first_party_and_partner_audience_id end |
#first_party_and_partner_audience_type ⇒ String
Output only. Whether the audience is a first party and partner audience.
Corresponds to the JSON property firstPartyAndPartnerAudienceType
8003 8004 8005 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8003 def first_party_and_partner_audience_type @first_party_and_partner_audience_type end |
#gmail_audience_size ⇒ Fixnum
Output only. The estimated audience size for Gmail network. If the size is
less than 1000, the number will be hidden and 0 will be returned due to
privacy reasons. Otherwise, the number will be rounded off to two significant
digits. Only applicable to first party audiences. Only returned in GET request.
Corresponds to the JSON property gmailAudienceSize
8011 8012 8013 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8011 def gmail_audience_size @gmail_audience_size end |
#membership_duration_days ⇒ Fixnum
Optional. The duration in days that an entry remains in the audience after the
qualifying event. The set value must be greater than 0 and less than or equal
to 540. Only applicable to first party audiences. This field is required if
one of the following audience_type is used: * CUSTOMER_MATCH_CONTACT_INFO *
CUSTOMER_MATCH_DEVICE_ID
Corresponds to the JSON property membershipDurationDays
8020 8021 8022 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8020 def membership_duration_days @membership_duration_days end |
#mobile_device_id_list ⇒ Google::Apis::DisplayvideoV4::MobileDeviceIdList
Wrapper message for a list of mobile device IDs defining Customer Match
audience members.
Corresponds to the JSON property mobileDeviceIdList
8026 8027 8028 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8026 def mobile_device_id_list @mobile_device_id_list end |
#name ⇒ String
Output only. The resource name of the first party and partner audience.
Corresponds to the JSON property name
8031 8032 8033 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8031 def name @name end |
#youtube_audience_size ⇒ Fixnum
Output only. The estimated audience size for YouTube network. If the size is
less than 1000, the number will be hidden and 0 will be returned due to
privacy reasons. Otherwise, the number will be rounded off to two significant
digits. Only applicable to first party audiences. Only returned in GET request.
Corresponds to the JSON property youtubeAudienceSize
8039 8040 8041 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8039 def youtube_audience_size @youtube_audience_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8046 8047 8048 8049 8050 8051 8052 8053 8054 8055 8056 8057 8058 8059 8060 8061 8062 8063 8064 8065 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8046 def update!(**args) @active_display_audience_size = args[:active_display_audience_size] if args.key?(:active_display_audience_size) @app_id = args[:app_id] if args.key?(:app_id) @audience_source = args[:audience_source] if args.key?(:audience_source) @audience_type = args[:audience_type] if args.key?(:audience_type) @contact_info_list = args[:contact_info_list] if args.key?(:contact_info_list) @description = args[:description] if args.key?(:description) @display_audience_size = args[:display_audience_size] if args.key?(:display_audience_size) @display_desktop_audience_size = args[:display_desktop_audience_size] if args.key?(:display_desktop_audience_size) @display_mobile_app_audience_size = args[:display_mobile_app_audience_size] if args.key?(:display_mobile_app_audience_size) @display_mobile_web_audience_size = args[:display_mobile_web_audience_size] if args.key?(:display_mobile_web_audience_size) @display_name = args[:display_name] if args.key?(:display_name) @first_party_and_partner_audience_id = args[:first_party_and_partner_audience_id] if args.key?(:first_party_and_partner_audience_id) @first_party_and_partner_audience_type = args[:first_party_and_partner_audience_type] if args.key?(:first_party_and_partner_audience_type) @gmail_audience_size = args[:gmail_audience_size] if args.key?(:gmail_audience_size) @membership_duration_days = args[:membership_duration_days] if args.key?(:membership_duration_days) @mobile_device_id_list = args[:mobile_device_id_list] if args.key?(:mobile_device_id_list) @name = args[:name] if args.key?(:name) @youtube_audience_size = args[:youtube_audience_size] if args.key?(:youtube_audience_size) end |