Class: Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudience

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Describes a first or partner audience list used for targeting. First party audiences are created via usage of client data. Partner audiences are provided by Third Party data providers and can only be licensed to customers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirstPartyAndPartnerAudience

Returns a new instance of FirstPartyAndPartnerAudience.



8011
8012
8013
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8011

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_display_audience_sizeFixnum

Output only. The estimated audience size for the Display network in the past month. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only returned in GET request. Corresponds to the JSON property activeDisplayAudienceSize

Returns:

  • (Fixnum)


7894
7895
7896
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7894

def active_display_audience_size
  @active_display_audience_size
end

#app_idString

Optional. The app_id matches with the type of the mobile_device_ids being uploaded. Only applicable to audience_type CUSTOMER_MATCH_DEVICE_ID Corresponds to the JSON property appId

Returns:

  • (String)


7900
7901
7902
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7900

def app_id
  @app_id
end

#audience_sourceString

Output only. The source of the audience. Corresponds to the JSON property audienceSource

Returns:

  • (String)


7905
7906
7907
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7905

def audience_source
  @audience_source
end

#audience_typeString

Immutable. The type of the audience. Corresponds to the JSON property audienceType

Returns:

  • (String)


7910
7911
7912
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7910

def audience_type
  @audience_type
end

#contact_info_listGoogle::Apis::DisplayvideoV4::ContactInfoList

Wrapper message for a list of contact information defining Customer Match audience members. Corresponds to the JSON property contactInfoList



7916
7917
7918
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7916

def contact_info_list
  @contact_info_list
end

#descriptionString

Optional. The user-provided description of the audience. Only applicable to first party audiences. Corresponds to the JSON property description

Returns:

  • (String)


7922
7923
7924
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7922

def description
  @description
end

#display_audience_sizeFixnum

Output only. The estimated audience size for the Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only returned in GET request. Corresponds to the JSON property displayAudienceSize

Returns:

  • (Fixnum)


7930
7931
7932
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7930

def display_audience_size
  @display_audience_size
end

#display_desktop_audience_sizeFixnum

Output only. The estimated desktop audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayDesktopAudienceSize

Returns:

  • (Fixnum)


7939
7940
7941
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7939

def display_desktop_audience_size
  @display_desktop_audience_size
end

#display_mobile_app_audience_sizeFixnum

Output only. The estimated mobile app audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayMobileAppAudienceSize

Returns:

  • (Fixnum)


7948
7949
7950
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7948

def display_mobile_app_audience_size
  @display_mobile_app_audience_size
end

#display_mobile_web_audience_sizeFixnum

Output only. The estimated mobile web audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayMobileWebAudienceSize

Returns:

  • (Fixnum)


7957
7958
7959
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7957

def display_mobile_web_audience_size
  @display_mobile_web_audience_size
end

#display_nameString

Optional. The display name of the first party and partner audience. Corresponds to the JSON property displayName

Returns:

  • (String)


7962
7963
7964
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7962

def display_name
  @display_name
end

#first_party_and_partner_audience_idFixnum

Identifier. The unique ID of the first party and partner audience. Assigned by the system. Corresponds to the JSON property firstPartyAndPartnerAudienceId

Returns:

  • (Fixnum)


7968
7969
7970
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7968

def first_party_and_partner_audience_id
  @first_party_and_partner_audience_id
end

#first_party_and_partner_audience_typeString

Output only. Whether the audience is a first party and partner audience. Corresponds to the JSON property firstPartyAndPartnerAudienceType

Returns:

  • (String)


7973
7974
7975
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7973

def first_party_and_partner_audience_type
  @first_party_and_partner_audience_type
end

#gmail_audience_sizeFixnum

Output only. The estimated audience size for Gmail network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property gmailAudienceSize

Returns:

  • (Fixnum)


7981
7982
7983
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7981

def gmail_audience_size
  @gmail_audience_size
end

#membership_duration_daysFixnum

Optional. The duration in days that an entry remains in the audience after the qualifying event. The set value must be greater than 0 and less than or equal to 540. Only applicable to first party audiences. This field is required if one of the following audience_type is used: * CUSTOMER_MATCH_CONTACT_INFO * CUSTOMER_MATCH_DEVICE_ID Corresponds to the JSON property membershipDurationDays

Returns:

  • (Fixnum)


7990
7991
7992
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7990

def membership_duration_days
  @membership_duration_days
end

#mobile_device_id_listGoogle::Apis::DisplayvideoV4::MobileDeviceIdList

Wrapper message for a list of mobile device IDs defining Customer Match audience members. Corresponds to the JSON property mobileDeviceIdList



7996
7997
7998
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7996

def mobile_device_id_list
  @mobile_device_id_list
end

#nameString

Output only. The resource name of the first party and partner audience. Corresponds to the JSON property name

Returns:

  • (String)


8001
8002
8003
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8001

def name
  @name
end

#youtube_audience_sizeFixnum

Output only. The estimated audience size for YouTube network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property youtubeAudienceSize

Returns:

  • (Fixnum)


8009
8010
8011
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8009

def youtube_audience_size
  @youtube_audience_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8016
8017
8018
8019
8020
8021
8022
8023
8024
8025
8026
8027
8028
8029
8030
8031
8032
8033
8034
8035
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8016

def update!(**args)
  @active_display_audience_size = args[:active_display_audience_size] if args.key?(:active_display_audience_size)
  @app_id = args[:app_id] if args.key?(:app_id)
  @audience_source = args[:audience_source] if args.key?(:audience_source)
  @audience_type = args[:audience_type] if args.key?(:audience_type)
  @contact_info_list = args[:contact_info_list] if args.key?(:contact_info_list)
  @description = args[:description] if args.key?(:description)
  @display_audience_size = args[:display_audience_size] if args.key?(:display_audience_size)
  @display_desktop_audience_size = args[:display_desktop_audience_size] if args.key?(:display_desktop_audience_size)
  @display_mobile_app_audience_size = args[:display_mobile_app_audience_size] if args.key?(:display_mobile_app_audience_size)
  @display_mobile_web_audience_size = args[:display_mobile_web_audience_size] if args.key?(:display_mobile_web_audience_size)
  @display_name = args[:display_name] if args.key?(:display_name)
  @first_party_and_partner_audience_id = args[:first_party_and_partner_audience_id] if args.key?(:first_party_and_partner_audience_id)
  @first_party_and_partner_audience_type = args[:first_party_and_partner_audience_type] if args.key?(:first_party_and_partner_audience_type)
  @gmail_audience_size = args[:gmail_audience_size] if args.key?(:gmail_audience_size)
  @membership_duration_days = args[:membership_duration_days] if args.key?(:membership_duration_days)
  @mobile_device_id_list = args[:mobile_device_id_list] if args.key?(:mobile_device_id_list)
  @name = args[:name] if args.key?(:name)
  @youtube_audience_size = args[:youtube_audience_size] if args.key?(:youtube_audience_size)
end