Class: Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudience

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Describes a first or partner audience list used for targeting. First party audiences are created via usage of client data. Partner audiences are provided by Third Party data providers and can only be licensed to customers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirstPartyAndPartnerAudience

Returns a new instance of FirstPartyAndPartnerAudience.



7888
7889
7890
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_display_audience_sizeFixnum

Output only. The estimated audience size for the Display network in the past month. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only returned in GET request. Corresponds to the JSON property activeDisplayAudienceSize

Returns:

  • (Fixnum)


7771
7772
7773
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7771

def active_display_audience_size
  @active_display_audience_size
end

#app_idString

Optional. The app_id matches with the type of the mobile_device_ids being uploaded. Only applicable to audience_type CUSTOMER_MATCH_DEVICE_ID Corresponds to the JSON property appId

Returns:

  • (String)


7777
7778
7779
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7777

def app_id
  @app_id
end

#audience_sourceString

Output only. The source of the audience. Corresponds to the JSON property audienceSource

Returns:

  • (String)


7782
7783
7784
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7782

def audience_source
  @audience_source
end

#audience_typeString

Immutable. The type of the audience. Corresponds to the JSON property audienceType

Returns:

  • (String)


7787
7788
7789
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7787

def audience_type
  @audience_type
end

#contact_info_listGoogle::Apis::DisplayvideoV4::ContactInfoList

Wrapper message for a list of contact information defining Customer Match audience members. Corresponds to the JSON property contactInfoList



7793
7794
7795
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7793

def contact_info_list
  @contact_info_list
end

#descriptionString

Optional. The user-provided description of the audience. Only applicable to first party audiences. Corresponds to the JSON property description

Returns:

  • (String)


7799
7800
7801
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7799

def description
  @description
end

#display_audience_sizeFixnum

Output only. The estimated audience size for the Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only returned in GET request. Corresponds to the JSON property displayAudienceSize

Returns:

  • (Fixnum)


7807
7808
7809
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7807

def display_audience_size
  @display_audience_size
end

#display_desktop_audience_sizeFixnum

Output only. The estimated desktop audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayDesktopAudienceSize

Returns:

  • (Fixnum)


7816
7817
7818
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7816

def display_desktop_audience_size
  @display_desktop_audience_size
end

#display_mobile_app_audience_sizeFixnum

Output only. The estimated mobile app audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayMobileAppAudienceSize

Returns:

  • (Fixnum)


7825
7826
7827
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7825

def display_mobile_app_audience_size
  @display_mobile_app_audience_size
end

#display_mobile_web_audience_sizeFixnum

Output only. The estimated mobile web audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayMobileWebAudienceSize

Returns:

  • (Fixnum)


7834
7835
7836
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7834

def display_mobile_web_audience_size
  @display_mobile_web_audience_size
end

#display_nameString

Optional. The display name of the first party and partner audience. Corresponds to the JSON property displayName

Returns:

  • (String)


7839
7840
7841
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7839

def display_name
  @display_name
end

#first_party_and_partner_audience_idFixnum

Identifier. The unique ID of the first party and partner audience. Assigned by the system. Corresponds to the JSON property firstPartyAndPartnerAudienceId

Returns:

  • (Fixnum)


7845
7846
7847
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7845

def first_party_and_partner_audience_id
  @first_party_and_partner_audience_id
end

#first_party_and_partner_audience_typeString

Output only. Whether the audience is a first party and partner audience. Corresponds to the JSON property firstPartyAndPartnerAudienceType

Returns:

  • (String)


7850
7851
7852
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7850

def first_party_and_partner_audience_type
  @first_party_and_partner_audience_type
end

#gmail_audience_sizeFixnum

Output only. The estimated audience size for Gmail network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property gmailAudienceSize

Returns:

  • (Fixnum)


7858
7859
7860
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7858

def gmail_audience_size
  @gmail_audience_size
end

#membership_duration_daysFixnum

Optional. The duration in days that an entry remains in the audience after the qualifying event. The set value must be greater than 0 and less than or equal to 540. Only applicable to first party audiences. This field is required if one of the following audience_type is used: * CUSTOMER_MATCH_CONTACT_INFO * CUSTOMER_MATCH_DEVICE_ID Corresponds to the JSON property membershipDurationDays

Returns:

  • (Fixnum)


7867
7868
7869
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7867

def membership_duration_days
  @membership_duration_days
end

#mobile_device_id_listGoogle::Apis::DisplayvideoV4::MobileDeviceIdList

Wrapper message for a list of mobile device IDs defining Customer Match audience members. Corresponds to the JSON property mobileDeviceIdList



7873
7874
7875
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7873

def mobile_device_id_list
  @mobile_device_id_list
end

#nameString

Output only. The resource name of the first party and partner audience. Corresponds to the JSON property name

Returns:

  • (String)


7878
7879
7880
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7878

def name
  @name
end

#youtube_audience_sizeFixnum

Output only. The estimated audience size for YouTube network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property youtubeAudienceSize

Returns:

  • (Fixnum)


7886
7887
7888
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7886

def youtube_audience_size
  @youtube_audience_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7893

def update!(**args)
  @active_display_audience_size = args[:active_display_audience_size] if args.key?(:active_display_audience_size)
  @app_id = args[:app_id] if args.key?(:app_id)
  @audience_source = args[:audience_source] if args.key?(:audience_source)
  @audience_type = args[:audience_type] if args.key?(:audience_type)
  @contact_info_list = args[:contact_info_list] if args.key?(:contact_info_list)
  @description = args[:description] if args.key?(:description)
  @display_audience_size = args[:display_audience_size] if args.key?(:display_audience_size)
  @display_desktop_audience_size = args[:display_desktop_audience_size] if args.key?(:display_desktop_audience_size)
  @display_mobile_app_audience_size = args[:display_mobile_app_audience_size] if args.key?(:display_mobile_app_audience_size)
  @display_mobile_web_audience_size = args[:display_mobile_web_audience_size] if args.key?(:display_mobile_web_audience_size)
  @display_name = args[:display_name] if args.key?(:display_name)
  @first_party_and_partner_audience_id = args[:first_party_and_partner_audience_id] if args.key?(:first_party_and_partner_audience_id)
  @first_party_and_partner_audience_type = args[:first_party_and_partner_audience_type] if args.key?(:first_party_and_partner_audience_type)
  @gmail_audience_size = args[:gmail_audience_size] if args.key?(:gmail_audience_size)
  @membership_duration_days = args[:membership_duration_days] if args.key?(:membership_duration_days)
  @mobile_device_id_list = args[:mobile_device_id_list] if args.key?(:mobile_device_id_list)
  @name = args[:name] if args.key?(:name)
  @youtube_audience_size = args[:youtube_audience_size] if args.key?(:youtube_audience_size)
end