Class: Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceGroup
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details of first party and partner audience group. All first party and partner audience targeting settings are logically ‘OR’ of each other.
Instance Attribute Summary collapse
-
#settings ⇒ Array<Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceTargetingSetting>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirstPartyAndPartnerAudienceGroup
constructor
A new instance of FirstPartyAndPartnerAudienceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirstPartyAndPartnerAudienceGroup
Returns a new instance of FirstPartyAndPartnerAudienceGroup.
8081 8082 8083 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8081 def initialize(**args) update!(**args) end |
Instance Attribute Details
#settings ⇒ Array<Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceTargetingSetting>
Required. All first party and partner audience targeting settings in first
party and partner audience group. Repeated settings with the same id are not
allowed.
Corresponds to the JSON property settings
8079 8080 8081 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8079 def settings @settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8086 8087 8088 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8086 def update!(**args) @settings = args[:settings] if args.key?(:settings) end |