Class: Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceGroup
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details of first party and partner audience group. All first party and partner audience targeting settings are logically ‘OR’ of each other.
Instance Attribute Summary collapse
-
#settings ⇒ Array<Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceTargetingSetting>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirstPartyAndPartnerAudienceGroup
constructor
A new instance of FirstPartyAndPartnerAudienceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirstPartyAndPartnerAudienceGroup
Returns a new instance of FirstPartyAndPartnerAudienceGroup.
8050 8051 8052 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8050 def initialize(**args) update!(**args) end |
Instance Attribute Details
#settings ⇒ Array<Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceTargetingSetting>
Required. All first party and partner audience targeting settings in first
party and partner audience group. Repeated settings with the same id are not
allowed.
Corresponds to the JSON property settings
8048 8049 8050 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8048 def settings @settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8055 8056 8057 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8055 def update!(**args) @settings = args[:settings] if args.key?(:settings) end |