Class: Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details of first party and partner audience group. All first party and partner audience targeting settings are logically ‘OR’ of each other.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirstPartyAndPartnerAudienceGroup

Returns a new instance of FirstPartyAndPartnerAudienceGroup.



7918
7919
7920
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#settingsArray<Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceTargetingSetting>

Required. All first party and partner audience targeting settings in first party and partner audience group. Repeated settings with the same id are not allowed. Corresponds to the JSON property settings



7916
7917
7918
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7916

def settings
  @settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7923
7924
7925
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7923

def update!(**args)
  @settings = args[:settings] if args.key?(:settings)
end