Class: Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceTargetingSetting
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudienceTargetingSetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details of first party and partner audience targeting setting.
Instance Attribute Summary collapse
-
#first_party_and_partner_audience_id ⇒ Fixnum
Required.
-
#recency ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirstPartyAndPartnerAudienceTargetingSetting
constructor
A new instance of FirstPartyAndPartnerAudienceTargetingSetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirstPartyAndPartnerAudienceTargetingSetting
Returns a new instance of FirstPartyAndPartnerAudienceTargetingSetting.
7946 7947 7948 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7946 def initialize(**args) update!(**args) end |
Instance Attribute Details
#first_party_and_partner_audience_id ⇒ Fixnum
Required. First party and partner audience id of the first party and partner
audience targeting setting. This id is first_party_and_partner_audience_id.
Corresponds to the JSON property firstPartyAndPartnerAudienceId
7936 7937 7938 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7936 def first_party_and_partner_audience_id @first_party_and_partner_audience_id end |
#recency ⇒ String
Required. The recency of the first party and partner audience targeting
setting. Only applicable to first party audiences, otherwise will be ignored.
For more info, refer to https://support.google.com/displayvideo/answer/2949947#
recency When unspecified, no recency limit will be used.
Corresponds to the JSON property recency
7944 7945 7946 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7944 def recency @recency end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7951 7952 7953 7954 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 7951 def update!(**args) @first_party_and_partner_audience_id = args[:first_party_and_partner_audience_id] if args.key?(:first_party_and_partner_audience_id) @recency = args[:recency] if args.key?(:recency) end |