Class: Google::Apis::DisplayvideoV4::FloodlightActivity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single Floodlight activity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FloodlightActivity

Returns a new instance of FloodlightActivity.



8192
8193
8194
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8192

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idsArray<Fixnum>

Output only. IDs of the advertisers that have access to the parent Floodlight group. Only advertisers under the provided partner ID will be listed in this field. Corresponds to the JSON property advertiserIds

Returns:

  • (Array<Fixnum>)


8151
8152
8153
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8151

def advertiser_ids
  @advertiser_ids
end

#display_nameString

Required. The display name of the Floodlight activity. Corresponds to the JSON property displayName

Returns:

  • (String)


8156
8157
8158
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8156

def display_name
  @display_name
end

#floodlight_activity_idFixnum

Output only. The unique ID of the Floodlight activity. Assigned by the system. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


8161
8162
8163
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8161

def floodlight_activity_id
  @floodlight_activity_id
end

#floodlight_group_idFixnum

Required. Immutable. The ID of the parent Floodlight group. Corresponds to the JSON property floodlightGroupId

Returns:

  • (Fixnum)


8166
8167
8168
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8166

def floodlight_group_id
  @floodlight_group_id
end

#nameString

Output only. The resource name of the Floodlight activity. Corresponds to the JSON property name

Returns:

  • (String)


8171
8172
8173
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8171

def name
  @name
end

#remarketing_configsArray<Google::Apis::DisplayvideoV4::RemarketingConfig>

Output only. A list of configuration objects designating whether remarketing for this Floodlight Activity is enabled and available for a specifc advertiser. If enabled, this Floodlight Activity generates a remarketing user list that is able to be used in targeting under the advertiser. Corresponds to the JSON property remarketingConfigs



8179
8180
8181
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8179

def remarketing_configs
  @remarketing_configs
end

#serving_statusString

Optional. Whether the Floodlight activity is served. Corresponds to the JSON property servingStatus

Returns:

  • (String)


8184
8185
8186
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8184

def serving_status
  @serving_status
end

#ssl_requiredBoolean Also known as: ssl_required?

Output only. Whether tags are required to be compliant. Corresponds to the JSON property sslRequired

Returns:

  • (Boolean)


8189
8190
8191
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8189

def ssl_required
  @ssl_required
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8197

def update!(**args)
  @advertiser_ids = args[:advertiser_ids] if args.key?(:advertiser_ids)
  @display_name = args[:display_name] if args.key?(:display_name)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
  @floodlight_group_id = args[:floodlight_group_id] if args.key?(:floodlight_group_id)
  @name = args[:name] if args.key?(:name)
  @remarketing_configs = args[:remarketing_configs] if args.key?(:remarketing_configs)
  @serving_status = args[:serving_status] if args.key?(:serving_status)
  @ssl_required = args[:ssl_required] if args.key?(:ssl_required)
end