Class: Google::Apis::DisplayvideoV4::FloodlightActivity
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::FloodlightActivity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single Floodlight activity.
Instance Attribute Summary collapse
-
#advertiser_ids ⇒ Array<Fixnum>
Output only.
-
#display_name ⇒ String
Required.
-
#floodlight_activity_id ⇒ Fixnum
Output only.
-
#floodlight_group_id ⇒ Fixnum
Required.
-
#name ⇒ String
Output only.
-
#remarketing_configs ⇒ Array<Google::Apis::DisplayvideoV4::RemarketingConfig>
Output only.
-
#serving_status ⇒ String
Optional.
-
#ssl_required ⇒ Boolean
(also: #ssl_required?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FloodlightActivity
constructor
A new instance of FloodlightActivity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FloodlightActivity
Returns a new instance of FloodlightActivity.
8162 8163 8164 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_ids ⇒ Array<Fixnum>
Output only. IDs of the advertisers that have access to the parent Floodlight
group. Only advertisers under the provided partner ID will be listed in this
field.
Corresponds to the JSON property advertiserIds
8121 8122 8123 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8121 def advertiser_ids @advertiser_ids end |
#display_name ⇒ String
Required. The display name of the Floodlight activity.
Corresponds to the JSON property displayName
8126 8127 8128 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8126 def display_name @display_name end |
#floodlight_activity_id ⇒ Fixnum
Output only. The unique ID of the Floodlight activity. Assigned by the system.
Corresponds to the JSON property floodlightActivityId
8131 8132 8133 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8131 def floodlight_activity_id @floodlight_activity_id end |
#floodlight_group_id ⇒ Fixnum
Required. Immutable. The ID of the parent Floodlight group.
Corresponds to the JSON property floodlightGroupId
8136 8137 8138 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8136 def floodlight_group_id @floodlight_group_id end |
#name ⇒ String
Output only. The resource name of the Floodlight activity.
Corresponds to the JSON property name
8141 8142 8143 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8141 def name @name end |
#remarketing_configs ⇒ Array<Google::Apis::DisplayvideoV4::RemarketingConfig>
Output only. A list of configuration objects designating whether remarketing
for this Floodlight Activity is enabled and available for a specifc advertiser.
If enabled, this Floodlight Activity generates a remarketing user list that
is able to be used in targeting under the advertiser.
Corresponds to the JSON property remarketingConfigs
8149 8150 8151 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8149 def remarketing_configs @remarketing_configs end |
#serving_status ⇒ String
Optional. Whether the Floodlight activity is served.
Corresponds to the JSON property servingStatus
8154 8155 8156 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8154 def serving_status @serving_status end |
#ssl_required ⇒ Boolean Also known as: ssl_required?
Output only. Whether tags are required to be compliant.
Corresponds to the JSON property sslRequired
8159 8160 8161 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8159 def ssl_required @ssl_required end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8167 8168 8169 8170 8171 8172 8173 8174 8175 8176 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8167 def update!(**args) @advertiser_ids = args[:advertiser_ids] if args.key?(:advertiser_ids) @display_name = args[:display_name] if args.key?(:display_name) @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id) @floodlight_group_id = args[:floodlight_group_id] if args.key?(:floodlight_group_id) @name = args[:name] if args.key?(:name) @remarketing_configs = args[:remarketing_configs] if args.key?(:remarketing_configs) @serving_status = args[:serving_status] if args.key?(:serving_status) @ssl_required = args[:ssl_required] if args.key?(:ssl_required) end |