Class: Google::Apis::DisplayvideoV4::FloodlightGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single Floodlight group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FloodlightGroup

Returns a new instance of FloodlightGroup.



8231
8232
8233
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_view_configGoogle::Apis::DisplayvideoV4::ActiveViewVideoViewabilityMetricConfig

Configuration for custom Active View video viewability metrics. Corresponds to the JSON property activeViewConfig



8186
8187
8188
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8186

def active_view_config
  @active_view_config
end

#custom_variablesHash<String,Object>

User-defined custom variables owned by the Floodlight group. Use custom Floodlight variables to create reporting data that is tailored to your unique business needs. Custom Floodlight variables use the keys U1=, U2=, and so on, and can take any values that you choose to pass to them. You can use them to track virtually any type of data that you collect about your customers, such as the genre of movie that a customer purchases, the country to which the item is shipped, and so on. Custom Floodlight variables may not be used to pass any data that could be used or recognized as personally identifiable information (PII). Example: custom_variables fields "U1": value number_value: 123.4 , "U2": value string_value: "MyVariable2" , "U3": value string_value: "MyVariable3" `Acceptable values for keys are "U1" through "U100", inclusive. String values must be less than 64 characters long, and cannot contain the following characters:"<>. Corresponds to the JSON propertycustomVariables`

Returns:

  • (Hash<String,Object>)


8203
8204
8205
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8203

def custom_variables
  @custom_variables
end

#display_nameString

Required. The display name of the Floodlight group. Corresponds to the JSON property displayName

Returns:

  • (String)


8208
8209
8210
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8208

def display_name
  @display_name
end

#floodlight_group_idFixnum

Output only. The unique ID of the Floodlight group. Assigned by the system. Corresponds to the JSON property floodlightGroupId

Returns:

  • (Fixnum)


8213
8214
8215
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8213

def floodlight_group_id
  @floodlight_group_id
end

#lookback_windowGoogle::Apis::DisplayvideoV4::LookbackWindow

Specifies how many days into the past to look when determining whether to record a conversion. Corresponds to the JSON property lookbackWindow



8219
8220
8221
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8219

def lookback_window
  @lookback_window
end

#nameString

Output only. The resource name of the Floodlight group. Corresponds to the JSON property name

Returns:

  • (String)


8224
8225
8226
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8224

def name
  @name
end

#web_tag_typeString

Required. The web tag type enabled for the Floodlight group. Corresponds to the JSON property webTagType

Returns:

  • (String)


8229
8230
8231
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8229

def web_tag_type
  @web_tag_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8236
8237
8238
8239
8240
8241
8242
8243
8244
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8236

def update!(**args)
  @active_view_config = args[:active_view_config] if args.key?(:active_view_config)
  @custom_variables = args[:custom_variables] if args.key?(:custom_variables)
  @display_name = args[:display_name] if args.key?(:display_name)
  @floodlight_group_id = args[:floodlight_group_id] if args.key?(:floodlight_group_id)
  @lookback_window = args[:lookback_window] if args.key?(:lookback_window)
  @name = args[:name] if args.key?(:name)
  @web_tag_type = args[:web_tag_type] if args.key?(:web_tag_type)
end