Class: Google::Apis::DisplayvideoV4::FrequencyCap

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Settings that control the number of times a user may be shown with the same ad during a given time period.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FrequencyCap

Returns a new instance of FrequencyCap.



8166
8167
8168
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_impressionsFixnum

The maximum number of times a user may be shown the same ad during this period. Must be greater than 0. Required when unlimited is false and max_views is not set. Corresponds to the JSON property maxImpressions

Returns:

  • (Fixnum)


8134
8135
8136
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8134

def max_impressions
  @max_impressions
end

#max_viewsFixnum

Optional. The maximum number of times a user may click-through or fully view an ad during this period until it is no longer served to them. Must be greater than 0. Only applicable to YouTube and Partners resources. Required when unlimited is false and max_impressions is not set. Corresponds to the JSON property maxViews

Returns:

  • (Fixnum)


8142
8143
8144
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8142

def max_views
  @max_views
end

#time_unitString

The time unit in which the frequency cap will be applied. Required when unlimited is false. Corresponds to the JSON property timeUnit

Returns:

  • (String)


8148
8149
8150
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8148

def time_unit
  @time_unit
end

#time_unit_countFixnum

The number of time_unit the frequency cap will last. Required when unlimited is false. The following restrictions apply based on the value of time_unit: * TIME_UNIT_MONTHS - must be 1 * TIME_UNIT_WEEKS - must be between 1 and 4 * TIME_UNIT_DAYS - must be between 1 and 6 * TIME_UNIT_HOURS - must be between 1 and 23 * TIME_UNIT_MINUTES - must be between 1 and 59 Corresponds to the JSON property timeUnitCount

Returns:

  • (Fixnum)


8157
8158
8159
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8157

def time_unit_count
  @time_unit_count
end

#unlimitedBoolean Also known as: unlimited?

Whether unlimited frequency capping is applied. When this field is set to true, the remaining frequency cap fields are not applicable. Corresponds to the JSON property unlimited

Returns:

  • (Boolean)


8163
8164
8165
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8163

def unlimited
  @unlimited
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8171
8172
8173
8174
8175
8176
8177
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8171

def update!(**args)
  @max_impressions = args[:max_impressions] if args.key?(:max_impressions)
  @max_views = args[:max_views] if args.key?(:max_views)
  @time_unit = args[:time_unit] if args.key?(:time_unit)
  @time_unit_count = args[:time_unit_count] if args.key?(:time_unit_count)
  @unlimited = args[:unlimited] if args.key?(:unlimited)
end