Class: Google::Apis::DisplayvideoV4::GenerateReachForecastRequest
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::GenerateReachForecastRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Request message for ReachForecastService.GenerateReachForecast.
Instance Attribute Summary collapse
-
#campaign_duration ⇒ Google::Apis::DisplayvideoV4::CampaignDuration
The duration of the reach plan.
-
#currency_code ⇒ String
Required.
-
#min_effective_frequency ⇒ Fixnum
Optional.
-
#planned_products ⇒ Array<Google::Apis::DisplayvideoV4::PlannedProduct>
Required.
-
#targeting ⇒ Google::Apis::DisplayvideoV4::Targeting
Targeting settings for a planned campaign.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateReachForecastRequest
constructor
A new instance of GenerateReachForecastRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateReachForecastRequest
Returns a new instance of GenerateReachForecastRequest.
8376 8377 8378 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8376 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaign_duration ⇒ Google::Apis::DisplayvideoV4::CampaignDuration
The duration of the reach plan.
Corresponds to the JSON property campaignDuration
8351 8352 8353 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8351 def campaign_duration @campaign_duration end |
#currency_code ⇒ String
Required. The currency code for the plan in ISO 4217 format.
Corresponds to the JSON property currencyCode
8356 8357 8358 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8356 def currency_code @currency_code end |
#min_effective_frequency ⇒ Fixnum
Optional. The minimum effective frequency for the reported reach metrics. This
is the smallest number of times a customer must be exposed to the ad for it to
be considered effective. This setting only impacts reporting. Must be between
1 and 10, inclusive. If not specified, a default of 1 is applied.
Corresponds to the JSON property minEffectiveFrequency
8364 8365 8366 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8364 def min_effective_frequency @min_effective_frequency end |
#planned_products ⇒ Array<Google::Apis::DisplayvideoV4::PlannedProduct>
Required. The list of line items to include in the forecast.
Corresponds to the JSON property plannedProducts
8369 8370 8371 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8369 def planned_products @planned_products end |
#targeting ⇒ Google::Apis::DisplayvideoV4::Targeting
Targeting settings for a planned campaign.
Corresponds to the JSON property targeting
8374 8375 8376 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8374 def targeting @targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8381 8382 8383 8384 8385 8386 8387 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8381 def update!(**args) @campaign_duration = args[:campaign_duration] if args.key?(:campaign_duration) @currency_code = args[:currency_code] if args.key?(:currency_code) @min_effective_frequency = args[:min_effective_frequency] if args.key?(:min_effective_frequency) @planned_products = args[:planned_products] if args.key?(:planned_products) @targeting = args[:targeting] if args.key?(:targeting) end |