Class: Google::Apis::DisplayvideoV4::GuaranteedOrder
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::GuaranteedOrder
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A guaranteed order. Guaranteed orders are parent entity of guaranteed inventory sources. When creating a guaranteed inventory source, a guaranteed order ID must be assigned to the inventory source.
Instance Attribute Summary collapse
-
#default_advertiser_id ⇒ Fixnum
Output only.
-
#default_campaign_id ⇒ Fixnum
The ID of the default campaign that is assigned to the guaranteed order.
-
#display_name ⇒ String
Required.
-
#exchange ⇒ String
Required.
-
#guaranteed_order_id ⇒ String
Output only.
-
#legacy_guaranteed_order_id ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#publisher_name ⇒ String
Required.
-
#read_access_inherited ⇒ Boolean
(also: #read_access_inherited?)
Whether all advertisers of read_write_partner_id have read access to the guaranteed order.
-
#read_advertiser_ids ⇒ Array<Fixnum>
The IDs of advertisers with read access to the guaranteed order.
-
#read_write_advertiser_id ⇒ Fixnum
The advertiser with read/write access to the guaranteed order.
-
#read_write_partner_id ⇒ Fixnum
The partner with read/write access to the guaranteed order.
-
#status ⇒ Google::Apis::DisplayvideoV4::GuaranteedOrderStatus
The status settings of the guaranteed order.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GuaranteedOrder
constructor
A new instance of GuaranteedOrder.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GuaranteedOrder
Returns a new instance of GuaranteedOrder.
8711 8712 8713 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_advertiser_id ⇒ Fixnum
Output only. The ID of default advertiser of the guaranteed order. The default
advertiser is either the read_write_advertiser_id or, if that is not set, the
first advertiser listed in read_advertiser_ids. Otherwise, there is no default
advertiser.
Corresponds to the JSON property defaultAdvertiserId
8630 8631 8632 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8630 def default_advertiser_id @default_advertiser_id end |
#default_campaign_id ⇒ Fixnum
The ID of the default campaign that is assigned to the guaranteed order. The
default campaign must belong to the default advertiser.
Corresponds to the JSON property defaultCampaignId
8636 8637 8638 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8636 def default_campaign_id @default_campaign_id end |
#display_name ⇒ String
Required. The display name of the guaranteed order. Must be UTF-8 encoded with
a maximum size of 240 bytes.
Corresponds to the JSON property displayName
8642 8643 8644 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8642 def display_name @display_name end |
#exchange ⇒ String
Required. Immutable. The exchange where the guaranteed order originated.
Corresponds to the JSON property exchange
8647 8648 8649 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8647 def exchange @exchange end |
#guaranteed_order_id ⇒ String
Output only. The unique identifier of the guaranteed order. The guaranteed
order IDs have the format exchange`-`legacy_guaranteed_order_id.
Corresponds to the JSON property guaranteedOrderId
8653 8654 8655 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8653 def guaranteed_order_id @guaranteed_order_id end |
#legacy_guaranteed_order_id ⇒ String
Output only. The legacy ID of the guaranteed order. Assigned by the original
exchange. The legacy ID is unique within one exchange, but is not guaranteed
to be unique across all guaranteed orders. This ID is used in SDF and UI.
Corresponds to the JSON property legacyGuaranteedOrderId
8660 8661 8662 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8660 def legacy_guaranteed_order_id @legacy_guaranteed_order_id end |
#name ⇒ String
Output only. The resource name of the guaranteed order.
Corresponds to the JSON property name
8665 8666 8667 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8665 def name @name end |
#publisher_name ⇒ String
Required. The publisher name of the guaranteed order. Must be UTF-8 encoded
with a maximum size of 240 bytes.
Corresponds to the JSON property publisherName
8671 8672 8673 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8671 def publisher_name @publisher_name end |
#read_access_inherited ⇒ Boolean Also known as: read_access_inherited?
Whether all advertisers of read_write_partner_id have read access to the
guaranteed order. Only applicable if read_write_partner_id is set. If True,
overrides read_advertiser_ids.
Corresponds to the JSON property readAccessInherited
8678 8679 8680 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8678 def read_access_inherited @read_access_inherited end |
#read_advertiser_ids ⇒ Array<Fixnum>
The IDs of advertisers with read access to the guaranteed order. This field
must not include the advertiser assigned to read_write_advertiser_id if it is
set. All advertisers in this field must belong to read_write_partner_id or the
same partner as read_write_advertiser_id.
Corresponds to the JSON property readAdvertiserIds
8687 8688 8689 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8687 def read_advertiser_ids @read_advertiser_ids end |
#read_write_advertiser_id ⇒ Fixnum
The advertiser with read/write access to the guaranteed order. This is also
the default advertiser of the guaranteed order.
Corresponds to the JSON property readWriteAdvertiserId
8693 8694 8695 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8693 def read_write_advertiser_id @read_write_advertiser_id end |
#read_write_partner_id ⇒ Fixnum
The partner with read/write access to the guaranteed order.
Corresponds to the JSON property readWritePartnerId
8698 8699 8700 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8698 def read_write_partner_id @read_write_partner_id end |
#status ⇒ Google::Apis::DisplayvideoV4::GuaranteedOrderStatus
The status settings of the guaranteed order.
Corresponds to the JSON property status
8703 8704 8705 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8703 def status @status end |
#update_time ⇒ String
Output only. The timestamp when the guaranteed order was last updated.
Assigned by the system.
Corresponds to the JSON property updateTime
8709 8710 8711 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8709 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8716 8717 8718 8719 8720 8721 8722 8723 8724 8725 8726 8727 8728 8729 8730 8731 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8716 def update!(**args) @default_advertiser_id = args[:default_advertiser_id] if args.key?(:default_advertiser_id) @default_campaign_id = args[:default_campaign_id] if args.key?(:default_campaign_id) @display_name = args[:display_name] if args.key?(:display_name) @exchange = args[:exchange] if args.key?(:exchange) @guaranteed_order_id = args[:guaranteed_order_id] if args.key?(:guaranteed_order_id) @legacy_guaranteed_order_id = args[:legacy_guaranteed_order_id] if args.key?(:legacy_guaranteed_order_id) @name = args[:name] if args.key?(:name) @publisher_name = args[:publisher_name] if args.key?(:publisher_name) @read_access_inherited = args[:read_access_inherited] if args.key?(:read_access_inherited) @read_advertiser_ids = args[:read_advertiser_ids] if args.key?(:read_advertiser_ids) @read_write_advertiser_id = args[:read_write_advertiser_id] if args.key?(:read_write_advertiser_id) @read_write_partner_id = args[:read_write_partner_id] if args.key?(:read_write_partner_id) @status = args[:status] if args.key?(:status) @update_time = args[:update_time] if args.key?(:update_time) end |