Class: Google::Apis::DisplayvideoV4::GuaranteedOrder
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::GuaranteedOrder
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A guaranteed order. Guaranteed orders are parent entity of guaranteed inventory sources. When creating a guaranteed inventory source, a guaranteed order ID must be assigned to the inventory source.
Instance Attribute Summary collapse
-
#default_advertiser_id ⇒ Fixnum
Output only.
-
#default_campaign_id ⇒ Fixnum
The ID of the default campaign that is assigned to the guaranteed order.
-
#display_name ⇒ String
Required.
-
#exchange ⇒ String
Required.
-
#guaranteed_order_id ⇒ String
Output only.
-
#legacy_guaranteed_order_id ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#publisher_name ⇒ String
Required.
-
#read_access_inherited ⇒ Boolean
(also: #read_access_inherited?)
Whether all advertisers of read_write_partner_id have read access to the guaranteed order.
-
#read_advertiser_ids ⇒ Array<Fixnum>
The IDs of advertisers with read access to the guaranteed order.
-
#read_write_advertiser_id ⇒ Fixnum
The advertiser with read/write access to the guaranteed order.
-
#read_write_partner_id ⇒ Fixnum
The partner with read/write access to the guaranteed order.
-
#status ⇒ Google::Apis::DisplayvideoV4::GuaranteedOrderStatus
The status settings of the guaranteed order.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GuaranteedOrder
constructor
A new instance of GuaranteedOrder.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GuaranteedOrder
Returns a new instance of GuaranteedOrder.
8500 8501 8502 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8500 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_advertiser_id ⇒ Fixnum
Output only. The ID of default advertiser of the guaranteed order. The default
advertiser is either the read_write_advertiser_id or, if that is not set, the
first advertiser listed in read_advertiser_ids. Otherwise, there is no default
advertiser.
Corresponds to the JSON property defaultAdvertiserId
8419 8420 8421 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8419 def default_advertiser_id @default_advertiser_id end |
#default_campaign_id ⇒ Fixnum
The ID of the default campaign that is assigned to the guaranteed order. The
default campaign must belong to the default advertiser.
Corresponds to the JSON property defaultCampaignId
8425 8426 8427 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8425 def default_campaign_id @default_campaign_id end |
#display_name ⇒ String
Required. The display name of the guaranteed order. Must be UTF-8 encoded with
a maximum size of 240 bytes.
Corresponds to the JSON property displayName
8431 8432 8433 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8431 def display_name @display_name end |
#exchange ⇒ String
Required. Immutable. The exchange where the guaranteed order originated.
Corresponds to the JSON property exchange
8436 8437 8438 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8436 def exchange @exchange end |
#guaranteed_order_id ⇒ String
Output only. The unique identifier of the guaranteed order. The guaranteed
order IDs have the format exchange`-`legacy_guaranteed_order_id.
Corresponds to the JSON property guaranteedOrderId
8442 8443 8444 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8442 def guaranteed_order_id @guaranteed_order_id end |
#legacy_guaranteed_order_id ⇒ String
Output only. The legacy ID of the guaranteed order. Assigned by the original
exchange. The legacy ID is unique within one exchange, but is not guaranteed
to be unique across all guaranteed orders. This ID is used in SDF and UI.
Corresponds to the JSON property legacyGuaranteedOrderId
8449 8450 8451 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8449 def legacy_guaranteed_order_id @legacy_guaranteed_order_id end |
#name ⇒ String
Output only. The resource name of the guaranteed order.
Corresponds to the JSON property name
8454 8455 8456 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8454 def name @name end |
#publisher_name ⇒ String
Required. The publisher name of the guaranteed order. Must be UTF-8 encoded
with a maximum size of 240 bytes.
Corresponds to the JSON property publisherName
8460 8461 8462 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8460 def publisher_name @publisher_name end |
#read_access_inherited ⇒ Boolean Also known as: read_access_inherited?
Whether all advertisers of read_write_partner_id have read access to the
guaranteed order. Only applicable if read_write_partner_id is set. If True,
overrides read_advertiser_ids.
Corresponds to the JSON property readAccessInherited
8467 8468 8469 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8467 def read_access_inherited @read_access_inherited end |
#read_advertiser_ids ⇒ Array<Fixnum>
The IDs of advertisers with read access to the guaranteed order. This field
must not include the advertiser assigned to read_write_advertiser_id if it is
set. All advertisers in this field must belong to read_write_partner_id or the
same partner as read_write_advertiser_id.
Corresponds to the JSON property readAdvertiserIds
8476 8477 8478 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8476 def read_advertiser_ids @read_advertiser_ids end |
#read_write_advertiser_id ⇒ Fixnum
The advertiser with read/write access to the guaranteed order. This is also
the default advertiser of the guaranteed order.
Corresponds to the JSON property readWriteAdvertiserId
8482 8483 8484 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8482 def read_write_advertiser_id @read_write_advertiser_id end |
#read_write_partner_id ⇒ Fixnum
The partner with read/write access to the guaranteed order.
Corresponds to the JSON property readWritePartnerId
8487 8488 8489 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8487 def read_write_partner_id @read_write_partner_id end |
#status ⇒ Google::Apis::DisplayvideoV4::GuaranteedOrderStatus
The status settings of the guaranteed order.
Corresponds to the JSON property status
8492 8493 8494 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8492 def status @status end |
#update_time ⇒ String
Output only. The timestamp when the guaranteed order was last updated.
Assigned by the system.
Corresponds to the JSON property updateTime
8498 8499 8500 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8498 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 8519 8520 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8505 def update!(**args) @default_advertiser_id = args[:default_advertiser_id] if args.key?(:default_advertiser_id) @default_campaign_id = args[:default_campaign_id] if args.key?(:default_campaign_id) @display_name = args[:display_name] if args.key?(:display_name) @exchange = args[:exchange] if args.key?(:exchange) @guaranteed_order_id = args[:guaranteed_order_id] if args.key?(:guaranteed_order_id) @legacy_guaranteed_order_id = args[:legacy_guaranteed_order_id] if args.key?(:legacy_guaranteed_order_id) @name = args[:name] if args.key?(:name) @publisher_name = args[:publisher_name] if args.key?(:publisher_name) @read_access_inherited = args[:read_access_inherited] if args.key?(:read_access_inherited) @read_advertiser_ids = args[:read_advertiser_ids] if args.key?(:read_advertiser_ids) @read_write_advertiser_id = args[:read_write_advertiser_id] if args.key?(:read_write_advertiser_id) @read_write_partner_id = args[:read_write_partner_id] if args.key?(:read_write_partner_id) @status = args[:status] if args.key?(:status) @update_time = args[:update_time] if args.key?(:update_time) end |