Class: Google::Apis::DisplayvideoV4::InsertionOrder
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::InsertionOrder
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single insertion order.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Output only.
-
#bid_strategy ⇒ Google::Apis::DisplayvideoV4::BiddingStrategy
Settings that control the bid strategy.
-
#budget ⇒ Google::Apis::DisplayvideoV4::InsertionOrderBudget
Settings that control how insertion order budget is allocated.
-
#campaign_id ⇒ Fixnum
Required.
-
#display_name ⇒ String
Required.
-
#entity_status ⇒ String
Required.
-
#frequency_cap ⇒ Google::Apis::DisplayvideoV4::FrequencyCap
Settings that control the number of times a user may be shown with the same ad during a given time period.
-
#insertion_order_id ⇒ Fixnum
Output only.
-
#insertion_order_type ⇒ String
Optional.
-
#integration_details ⇒ Google::Apis::DisplayvideoV4::IntegrationDetails
Integration details of an entry.
-
#kpi ⇒ Google::Apis::DisplayvideoV4::Kpi
Settings that control the key performance indicator, or KPI, of an insertion order.
-
#name ⇒ String
Output only.
-
#optimization_objective ⇒ String
Optional.
-
#pacing ⇒ Google::Apis::DisplayvideoV4::Pacing
Settings that control the rate at which a budget is spent.
-
#partner_costs ⇒ Array<Google::Apis::DisplayvideoV4::PartnerCost>
Optional.
-
#reservation_type ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InsertionOrder
constructor
A new instance of InsertionOrder.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InsertionOrder
Returns a new instance of InsertionOrder.
9064 9065 9066 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Output only. The unique ID of the advertiser the insertion order belongs to.
Corresponds to the JSON property advertiserId
8968 8969 8970 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8968 def advertiser_id @advertiser_id end |
#bid_strategy ⇒ Google::Apis::DisplayvideoV4::BiddingStrategy
Settings that control the bid strategy. Bid strategy determines the bid price.
Corresponds to the JSON property bidStrategy
8973 8974 8975 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8973 def bid_strategy @bid_strategy end |
#budget ⇒ Google::Apis::DisplayvideoV4::InsertionOrderBudget
Settings that control how insertion order budget is allocated.
Corresponds to the JSON property budget
8978 8979 8980 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8978 def budget @budget end |
#campaign_id ⇒ Fixnum
Required. Immutable. The unique ID of the campaign that the insertion order
belongs to.
Corresponds to the JSON property campaignId
8984 8985 8986 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8984 def campaign_id @campaign_id end |
#display_name ⇒ String
Required. The display name of the insertion order. Must be UTF-8 encoded with
a maximum size of 240 bytes.
Corresponds to the JSON property displayName
8990 8991 8992 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8990 def display_name @display_name end |
#entity_status ⇒ String
Required. Controls whether or not the insertion order can spend its budget and
bid on inventory. * For CreateInsertionOrder method, only ENTITY_STATUS_DRAFT
is allowed. To activate an insertion order, use UpdateInsertionOrder method
and update the status to ENTITY_STATUS_ACTIVE after creation. * An insertion
order cannot be changed back to ENTITY_STATUS_DRAFT status from any other
status. * An insertion order cannot be set to ENTITY_STATUS_ACTIVE if its
parent campaign is not active.
Corresponds to the JSON property entityStatus
9001 9002 9003 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9001 def entity_status @entity_status end |
#frequency_cap ⇒ Google::Apis::DisplayvideoV4::FrequencyCap
Settings that control the number of times a user may be shown with the same ad
during a given time period.
Corresponds to the JSON property frequencyCap
9007 9008 9009 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9007 def frequency_cap @frequency_cap end |
#insertion_order_id ⇒ Fixnum
Output only. The unique ID of the insertion order. Assigned by the system.
Corresponds to the JSON property insertionOrderId
9012 9013 9014 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9012 def insertion_order_id @insertion_order_id end |
#insertion_order_type ⇒ String
Optional. The type of insertion order. If this field is unspecified in
creation, the value defaults to RTB.
Corresponds to the JSON property insertionOrderType
9018 9019 9020 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9018 def insertion_order_type @insertion_order_type end |
#integration_details ⇒ Google::Apis::DisplayvideoV4::IntegrationDetails
Integration details of an entry.
Corresponds to the JSON property integrationDetails
9023 9024 9025 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9023 def integration_details @integration_details end |
#kpi ⇒ Google::Apis::DisplayvideoV4::Kpi
Settings that control the key performance indicator, or KPI, of an insertion
order.
Corresponds to the JSON property kpi
9029 9030 9031 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9029 def kpi @kpi end |
#name ⇒ String
Output only. The resource name of the insertion order.
Corresponds to the JSON property name
9034 9035 9036 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9034 def name @name end |
#optimization_objective ⇒ String
Optional. Required. The optimization objective of the insertion order.
Corresponds to the JSON property optimizationObjective
9039 9040 9041 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9039 def optimization_objective @optimization_objective end |
#pacing ⇒ Google::Apis::DisplayvideoV4::Pacing
Settings that control the rate at which a budget is spent.
Corresponds to the JSON property pacing
9044 9045 9046 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9044 def pacing @pacing end |
#partner_costs ⇒ Array<Google::Apis::DisplayvideoV4::PartnerCost>
Optional. The partner costs associated with the insertion order. If absent or
empty in CreateInsertionOrder method, the newly created insertion order will
inherit partner costs from the partner settings.
Corresponds to the JSON property partnerCosts
9051 9052 9053 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9051 def partner_costs @partner_costs end |
#reservation_type ⇒ String
Output only. The reservation type of the insertion order.
Corresponds to the JSON property reservationType
9056 9057 9058 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9056 def reservation_type @reservation_type end |
#update_time ⇒ String
Output only. The timestamp when the insertion order was last updated. Assigned
by the system.
Corresponds to the JSON property updateTime
9062 9063 9064 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9062 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9069 9070 9071 9072 9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9069 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy) @budget = args[:budget] if args.key?(:budget) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap) @insertion_order_id = args[:insertion_order_id] if args.key?(:insertion_order_id) @insertion_order_type = args[:insertion_order_type] if args.key?(:insertion_order_type) @integration_details = args[:integration_details] if args.key?(:integration_details) @kpi = args[:kpi] if args.key?(:kpi) @name = args[:name] if args.key?(:name) @optimization_objective = args[:optimization_objective] if args.key?(:optimization_objective) @pacing = args[:pacing] if args.key?(:pacing) @partner_costs = args[:partner_costs] if args.key?(:partner_costs) @reservation_type = args[:reservation_type] if args.key?(:reservation_type) @update_time = args[:update_time] if args.key?(:update_time) end |