Class: Google::Apis::DisplayvideoV4::InsertionOrder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single insertion order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertionOrder

Returns a new instance of InsertionOrder.



9063
9064
9065
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The unique ID of the advertiser the insertion order belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


8967
8968
8969
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8967

def advertiser_id
  @advertiser_id
end

#bid_strategyGoogle::Apis::DisplayvideoV4::BiddingStrategy

Settings that control the bid strategy. Bid strategy determines the bid price. Corresponds to the JSON property bidStrategy



8972
8973
8974
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8972

def bid_strategy
  @bid_strategy
end

#budgetGoogle::Apis::DisplayvideoV4::InsertionOrderBudget

Settings that control how insertion order budget is allocated. Corresponds to the JSON property budget



8977
8978
8979
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8977

def budget
  @budget
end

#campaign_idFixnum

Required. Immutable. The unique ID of the campaign that the insertion order belongs to. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


8983
8984
8985
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8983

def campaign_id
  @campaign_id
end

#display_nameString

Required. The display name of the insertion order. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


8989
8990
8991
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8989

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not the insertion order can spend its budget and bid on inventory. * For CreateInsertionOrder method, only ENTITY_STATUS_DRAFT is allowed. To activate an insertion order, use UpdateInsertionOrder method and update the status to ENTITY_STATUS_ACTIVE after creation. * An insertion order cannot be changed back to ENTITY_STATUS_DRAFT status from any other status. * An insertion order cannot be set to ENTITY_STATUS_ACTIVE if its parent campaign is not active. Corresponds to the JSON property entityStatus

Returns:

  • (String)


9000
9001
9002
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9000

def entity_status
  @entity_status
end

#frequency_capGoogle::Apis::DisplayvideoV4::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property frequencyCap



9006
9007
9008
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9006

def frequency_cap
  @frequency_cap
end

#insertion_order_idFixnum

Output only. The unique ID of the insertion order. Assigned by the system. Corresponds to the JSON property insertionOrderId

Returns:

  • (Fixnum)


9011
9012
9013
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9011

def insertion_order_id
  @insertion_order_id
end

#insertion_order_typeString

Optional. The type of insertion order. If this field is unspecified in creation, the value defaults to RTB. Corresponds to the JSON property insertionOrderType

Returns:

  • (String)


9017
9018
9019
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9017

def insertion_order_type
  @insertion_order_type
end

#integration_detailsGoogle::Apis::DisplayvideoV4::IntegrationDetails

Integration details of an entry. Corresponds to the JSON property integrationDetails



9022
9023
9024
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9022

def integration_details
  @integration_details
end

#kpiGoogle::Apis::DisplayvideoV4::Kpi

Settings that control the key performance indicator, or KPI, of an insertion order. Corresponds to the JSON property kpi



9028
9029
9030
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9028

def kpi
  @kpi
end

#nameString

Output only. The resource name of the insertion order. Corresponds to the JSON property name

Returns:

  • (String)


9033
9034
9035
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9033

def name
  @name
end

#optimization_objectiveString

Optional. Required. The optimization objective of the insertion order. Corresponds to the JSON property optimizationObjective

Returns:

  • (String)


9038
9039
9040
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9038

def optimization_objective
  @optimization_objective
end

#pacingGoogle::Apis::DisplayvideoV4::Pacing

Settings that control the rate at which a budget is spent. Corresponds to the JSON property pacing



9043
9044
9045
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9043

def pacing
  @pacing
end

#partner_costsArray<Google::Apis::DisplayvideoV4::PartnerCost>

Optional. The partner costs associated with the insertion order. If absent or empty in CreateInsertionOrder method, the newly created insertion order will inherit partner costs from the partner settings. Corresponds to the JSON property partnerCosts



9050
9051
9052
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9050

def partner_costs
  @partner_costs
end

#reservation_typeString

Output only. The reservation type of the insertion order. Corresponds to the JSON property reservationType

Returns:

  • (String)


9055
9056
9057
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9055

def reservation_type
  @reservation_type
end

#update_timeString

Output only. The timestamp when the insertion order was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


9061
9062
9063
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9061

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
9080
9081
9082
9083
9084
9085
9086
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9068

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy)
  @budget = args[:budget] if args.key?(:budget)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap)
  @insertion_order_id = args[:insertion_order_id] if args.key?(:insertion_order_id)
  @insertion_order_type = args[:insertion_order_type] if args.key?(:insertion_order_type)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @kpi = args[:kpi] if args.key?(:kpi)
  @name = args[:name] if args.key?(:name)
  @optimization_objective = args[:optimization_objective] if args.key?(:optimization_objective)
  @pacing = args[:pacing] if args.key?(:pacing)
  @partner_costs = args[:partner_costs] if args.key?(:partner_costs)
  @reservation_type = args[:reservation_type] if args.key?(:reservation_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end