Class: Google::Apis::DisplayvideoV4::InsertionOrder
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::InsertionOrder
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single insertion order.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Output only.
-
#bid_strategy ⇒ Google::Apis::DisplayvideoV4::BiddingStrategy
Settings that control the bid strategy.
-
#budget ⇒ Google::Apis::DisplayvideoV4::InsertionOrderBudget
Settings that control how insertion order budget is allocated.
-
#campaign_id ⇒ Fixnum
Required.
-
#display_name ⇒ String
Required.
-
#entity_status ⇒ String
Required.
-
#frequency_cap ⇒ Google::Apis::DisplayvideoV4::FrequencyCap
Settings that control the number of times a user may be shown with the same ad during a given time period.
-
#insertion_order_id ⇒ Fixnum
Output only.
-
#insertion_order_type ⇒ String
Optional.
-
#integration_details ⇒ Google::Apis::DisplayvideoV4::IntegrationDetails
Integration details of an entry.
-
#kpi ⇒ Google::Apis::DisplayvideoV4::Kpi
Settings that control the key performance indicator, or KPI, of an insertion order.
-
#name ⇒ String
Output only.
-
#optimization_objective ⇒ String
Optional.
-
#pacing ⇒ Google::Apis::DisplayvideoV4::Pacing
Settings that control the rate at which a budget is spent.
-
#partner_costs ⇒ Array<Google::Apis::DisplayvideoV4::PartnerCost>
Optional.
-
#reservation_type ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InsertionOrder
constructor
A new instance of InsertionOrder.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InsertionOrder
Returns a new instance of InsertionOrder.
8839 8840 8841 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Output only. The unique ID of the advertiser the insertion order belongs to.
Corresponds to the JSON property advertiserId
8743 8744 8745 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8743 def advertiser_id @advertiser_id end |
#bid_strategy ⇒ Google::Apis::DisplayvideoV4::BiddingStrategy
Settings that control the bid strategy. Bid strategy determines the bid price.
Corresponds to the JSON property bidStrategy
8748 8749 8750 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8748 def bid_strategy @bid_strategy end |
#budget ⇒ Google::Apis::DisplayvideoV4::InsertionOrderBudget
Settings that control how insertion order budget is allocated.
Corresponds to the JSON property budget
8753 8754 8755 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8753 def budget @budget end |
#campaign_id ⇒ Fixnum
Required. Immutable. The unique ID of the campaign that the insertion order
belongs to.
Corresponds to the JSON property campaignId
8759 8760 8761 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8759 def campaign_id @campaign_id end |
#display_name ⇒ String
Required. The display name of the insertion order. Must be UTF-8 encoded with
a maximum size of 240 bytes.
Corresponds to the JSON property displayName
8765 8766 8767 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8765 def display_name @display_name end |
#entity_status ⇒ String
Required. Controls whether or not the insertion order can spend its budget and
bid on inventory. * For CreateInsertionOrder method, only ENTITY_STATUS_DRAFT
is allowed. To activate an insertion order, use UpdateInsertionOrder method
and update the status to ENTITY_STATUS_ACTIVE after creation. * An insertion
order cannot be changed back to ENTITY_STATUS_DRAFT status from any other
status. * An insertion order cannot be set to ENTITY_STATUS_ACTIVE if its
parent campaign is not active.
Corresponds to the JSON property entityStatus
8776 8777 8778 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8776 def entity_status @entity_status end |
#frequency_cap ⇒ Google::Apis::DisplayvideoV4::FrequencyCap
Settings that control the number of times a user may be shown with the same ad
during a given time period.
Corresponds to the JSON property frequencyCap
8782 8783 8784 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8782 def frequency_cap @frequency_cap end |
#insertion_order_id ⇒ Fixnum
Output only. The unique ID of the insertion order. Assigned by the system.
Corresponds to the JSON property insertionOrderId
8787 8788 8789 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8787 def insertion_order_id @insertion_order_id end |
#insertion_order_type ⇒ String
Optional. The type of insertion order. If this field is unspecified in
creation, the value defaults to RTB.
Corresponds to the JSON property insertionOrderType
8793 8794 8795 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8793 def insertion_order_type @insertion_order_type end |
#integration_details ⇒ Google::Apis::DisplayvideoV4::IntegrationDetails
Integration details of an entry.
Corresponds to the JSON property integrationDetails
8798 8799 8800 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8798 def integration_details @integration_details end |
#kpi ⇒ Google::Apis::DisplayvideoV4::Kpi
Settings that control the key performance indicator, or KPI, of an insertion
order.
Corresponds to the JSON property kpi
8804 8805 8806 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8804 def kpi @kpi end |
#name ⇒ String
Output only. The resource name of the insertion order.
Corresponds to the JSON property name
8809 8810 8811 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8809 def name @name end |
#optimization_objective ⇒ String
Optional. Required. The optimization objective of the insertion order.
Corresponds to the JSON property optimizationObjective
8814 8815 8816 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8814 def optimization_objective @optimization_objective end |
#pacing ⇒ Google::Apis::DisplayvideoV4::Pacing
Settings that control the rate at which a budget is spent.
Corresponds to the JSON property pacing
8819 8820 8821 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8819 def pacing @pacing end |
#partner_costs ⇒ Array<Google::Apis::DisplayvideoV4::PartnerCost>
Optional. The partner costs associated with the insertion order. If absent or
empty in CreateInsertionOrder method, the newly created insertion order will
inherit partner costs from the partner settings.
Corresponds to the JSON property partnerCosts
8826 8827 8828 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8826 def partner_costs @partner_costs end |
#reservation_type ⇒ String
Output only. The reservation type of the insertion order.
Corresponds to the JSON property reservationType
8831 8832 8833 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8831 def reservation_type @reservation_type end |
#update_time ⇒ String
Output only. The timestamp when the insertion order was last updated. Assigned
by the system.
Corresponds to the JSON property updateTime
8837 8838 8839 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8837 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8844 8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8844 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy) @budget = args[:budget] if args.key?(:budget) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap) @insertion_order_id = args[:insertion_order_id] if args.key?(:insertion_order_id) @insertion_order_type = args[:insertion_order_type] if args.key?(:insertion_order_type) @integration_details = args[:integration_details] if args.key?(:integration_details) @kpi = args[:kpi] if args.key?(:kpi) @name = args[:name] if args.key?(:name) @optimization_objective = args[:optimization_objective] if args.key?(:optimization_objective) @pacing = args[:pacing] if args.key?(:pacing) @partner_costs = args[:partner_costs] if args.key?(:partner_costs) @reservation_type = args[:reservation_type] if args.key?(:reservation_type) @update_time = args[:update_time] if args.key?(:update_time) end |