Class: Google::Apis::DisplayvideoV4::InsertionOrderBudget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Settings that control how insertion order budget is allocated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertionOrderBudget

Returns a new instance of InsertionOrderBudget.



8888
8889
8890
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automation_typeString

Optional. The type of automation used to manage bid and budget for the insertion order. If this field is unspecified in creation, the value defaults to INSERTION_ORDER_AUTOMATION_TYPE_NONE. Corresponds to the JSON property automationType

Returns:

  • (String)


8874
8875
8876
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8874

def automation_type
  @automation_type
end

#budget_segmentsArray<Google::Apis::DisplayvideoV4::InsertionOrderBudgetSegment>

Required. The list of budget segments. Use a budget segment to specify a specific budget for a given period of time an insertion order is running. Corresponds to the JSON property budgetSegments



8880
8881
8882
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8880

def budget_segments
  @budget_segments
end

#budget_unitString

Required. Immutable. The budget unit specifies whether the budget is currency based or impression based. Corresponds to the JSON property budgetUnit

Returns:

  • (String)


8886
8887
8888
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8886

def budget_unit
  @budget_unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8893
8894
8895
8896
8897
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8893

def update!(**args)
  @automation_type = args[:automation_type] if args.key?(:automation_type)
  @budget_segments = args[:budget_segments] if args.key?(:budget_segments)
  @budget_unit = args[:budget_unit] if args.key?(:budget_unit)
end