Class: Google::Apis::DisplayvideoV4::InsertionOrderBudget
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::InsertionOrderBudget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Settings that control how insertion order budget is allocated.
Instance Attribute Summary collapse
-
#automation_type ⇒ String
Optional.
-
#budget_segments ⇒ Array<Google::Apis::DisplayvideoV4::InsertionOrderBudgetSegment>
Required.
-
#budget_unit ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InsertionOrderBudget
constructor
A new instance of InsertionOrderBudget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InsertionOrderBudget
Returns a new instance of InsertionOrderBudget.
8879 8880 8881 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8879 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automation_type ⇒ String
Optional. The type of automation used to manage bid and budget for the
insertion order. If this field is unspecified in creation, the value defaults
to INSERTION_ORDER_AUTOMATION_TYPE_NONE.
Corresponds to the JSON property automationType
8865 8866 8867 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8865 def automation_type @automation_type end |
#budget_segments ⇒ Array<Google::Apis::DisplayvideoV4::InsertionOrderBudgetSegment>
Required. The list of budget segments. Use a budget segment to specify a
specific budget for a given period of time an insertion order is running.
Corresponds to the JSON property budgetSegments
8871 8872 8873 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8871 def budget_segments @budget_segments end |
#budget_unit ⇒ String
Required. Immutable. The budget unit specifies whether the budget is currency
based or impression based.
Corresponds to the JSON property budgetUnit
8877 8878 8879 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8877 def budget_unit @budget_unit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8884 8885 8886 8887 8888 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 8884 def update!(**args) @automation_type = args[:automation_type] if args.key?(:automation_type) @budget_segments = args[:budget_segments] if args.key?(:budget_segments) @budget_unit = args[:budget_unit] if args.key?(:budget_unit) end |