Class: Google::Apis::DisplayvideoV4::IntegrationDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::IntegrationDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Integration details of an entry.
Instance Attribute Summary collapse
-
#details ⇒ String
Additional details of the entry in string format.
-
#integration_code ⇒ String
An external identifier to be associated with the entry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IntegrationDetails
constructor
A new instance of IntegrationDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IntegrationDetails
Returns a new instance of IntegrationDetails.
9289 9290 9291 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ String
Additional details of the entry in string format. Must be UTF-8 encoded with a
length of no more than 1000 characters.
Corresponds to the JSON property details
9280 9281 9282 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9280 def details @details end |
#integration_code ⇒ String
An external identifier to be associated with the entry. The integration code
will show up together with the entry in many places in the system, for example,
reporting. Must be UTF-8 encoded with a length of no more than 500 characters.
Corresponds to the JSON property integrationCode
9287 9288 9289 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9287 def integration_code @integration_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9294 9295 9296 9297 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9294 def update!(**args) @details = args[:details] if args.key?(:details) @integration_code = args[:integration_code] if args.key?(:integration_code) end |