Class: Google::Apis::DisplayvideoV4::IntegrationDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Integration details of an entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IntegrationDetails

Returns a new instance of IntegrationDetails.



9065
9066
9067
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9065

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsString

Additional details of the entry in string format. Must be UTF-8 encoded with a length of no more than 1000 characters. Corresponds to the JSON property details

Returns:

  • (String)


9056
9057
9058
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9056

def details
  @details
end

#integration_codeString

An external identifier to be associated with the entry. The integration code will show up together with the entry in many places in the system, for example, reporting. Must be UTF-8 encoded with a length of no more than 500 characters. Corresponds to the JSON property integrationCode

Returns:

  • (String)


9063
9064
9065
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9063

def integration_code
  @integration_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9070
9071
9072
9073
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9070

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @integration_code = args[:integration_code] if args.key?(:integration_code)
end