Class: Google::Apis::DisplayvideoV4::InventorySource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

An inventory source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventorySource

Returns a new instance of InventorySource.



9401
9402
9403
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commitmentString

Whether the inventory source has a guaranteed or non-guaranteed delivery. Corresponds to the JSON property commitment

Returns:

  • (String)


9294
9295
9296
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9294

def commitment
  @commitment
end

#creative_configsArray<Google::Apis::DisplayvideoV4::CreativeConfig>

The creative requirements of the inventory source. Not applicable for auction packages. Corresponds to the JSON property creativeConfigs



9300
9301
9302
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9300

def creative_configs
  @creative_configs
end

#deal_idString

The ID in the exchange space that uniquely identifies the inventory source. Must be unique across buyers within each exchange but not necessarily unique across exchanges. Corresponds to the JSON property dealId

Returns:

  • (String)


9307
9308
9309
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9307

def deal_id
  @deal_id
end

#delivery_methodString

The delivery method of the inventory source. * For non-guaranteed inventory sources, the only acceptable value is INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC. * For guaranteed inventory sources, acceptable values are INVENTORY_SOURCE_DELIVERY_METHOD_TAG and INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC. Corresponds to the JSON property deliveryMethod

Returns:

  • (String)


9316
9317
9318
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9316

def delivery_method
  @delivery_method
end

#display_nameString

The display name of the inventory source. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


9322
9323
9324
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9322

def display_name
  @display_name
end

#exchangeString

The exchange to which the inventory source belongs. Corresponds to the JSON property exchange

Returns:

  • (String)


9327
9328
9329
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9327

def exchange
  @exchange
end

#guaranteed_order_idString

Immutable. The ID of the guaranteed order that this inventory source belongs to. Only applicable when commitment is INVENTORY_SOURCE_COMMITMENT_GUARANTEED . Corresponds to the JSON property guaranteedOrderId

Returns:

  • (String)


9334
9335
9336
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9334

def guaranteed_order_id
  @guaranteed_order_id
end

#inventory_source_idFixnum

Output only. The unique ID of the inventory source. Assigned by the system. Corresponds to the JSON property inventorySourceId

Returns:

  • (Fixnum)


9339
9340
9341
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9339

def inventory_source_id
  @inventory_source_id
end

#inventory_source_product_typeString

Output only. The product type of the inventory source, denoting the way through which it sells inventory. Corresponds to the JSON property inventorySourceProductType

Returns:

  • (String)


9345
9346
9347
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9345

def inventory_source_product_type
  @inventory_source_product_type
end

#inventory_source_typeString

Denotes the type of the inventory source. Corresponds to the JSON property inventorySourceType

Returns:

  • (String)


9350
9351
9352
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9350

def inventory_source_type
  @inventory_source_type
end

#nameString

Output only. The resource name of the inventory source. Corresponds to the JSON property name

Returns:

  • (String)


9355
9356
9357
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9355

def name
  @name
end

#publisher_nameString

The publisher/seller name of the inventory source. Corresponds to the JSON property publisherName

Returns:

  • (String)


9360
9361
9362
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9360

def publisher_name
  @publisher_name
end

#rate_detailsGoogle::Apis::DisplayvideoV4::RateDetails

The rate related settings of the inventory source. Corresponds to the JSON property rateDetails



9365
9366
9367
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9365

def rate_details
  @rate_details
end

#read_advertiser_idsArray<Fixnum>

Output only. The IDs of advertisers with read-only access to the inventory source. Corresponds to the JSON property readAdvertiserIds

Returns:

  • (Array<Fixnum>)


9371
9372
9373
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9371

def read_advertiser_ids
  @read_advertiser_ids
end

#read_partner_idsArray<Fixnum>

Output only. The IDs of partners with read-only access to the inventory source. All advertisers of partners in this field inherit read-only access to the inventory source. Corresponds to the JSON property readPartnerIds

Returns:

  • (Array<Fixnum>)


9378
9379
9380
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9378

def read_partner_ids
  @read_partner_ids
end

#read_write_accessorsGoogle::Apis::DisplayvideoV4::InventorySourceAccessors

The partner or advertisers with access to the inventory source. Corresponds to the JSON property readWriteAccessors



9383
9384
9385
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9383

def read_write_accessors
  @read_write_accessors
end

#statusGoogle::Apis::DisplayvideoV4::InventorySourceStatus

The status related settings of the inventory source. Corresponds to the JSON property status



9388
9389
9390
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9388

def status
  @status
end

#time_rangeGoogle::Apis::DisplayvideoV4::TimeRange

A time range. Corresponds to the JSON property timeRange



9393
9394
9395
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9393

def time_range
  @time_range
end

#update_timeString

Output only. The timestamp when the inventory source was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


9399
9400
9401
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9399

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9406
9407
9408
9409
9410
9411
9412
9413
9414
9415
9416
9417
9418
9419
9420
9421
9422
9423
9424
9425
9426
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9406

def update!(**args)
  @commitment = args[:commitment] if args.key?(:commitment)
  @creative_configs = args[:creative_configs] if args.key?(:creative_configs)
  @deal_id = args[:deal_id] if args.key?(:deal_id)
  @delivery_method = args[:delivery_method] if args.key?(:delivery_method)
  @display_name = args[:display_name] if args.key?(:display_name)
  @exchange = args[:exchange] if args.key?(:exchange)
  @guaranteed_order_id = args[:guaranteed_order_id] if args.key?(:guaranteed_order_id)
  @inventory_source_id = args[:inventory_source_id] if args.key?(:inventory_source_id)
  @inventory_source_product_type = args[:inventory_source_product_type] if args.key?(:inventory_source_product_type)
  @inventory_source_type = args[:inventory_source_type] if args.key?(:inventory_source_type)
  @name = args[:name] if args.key?(:name)
  @publisher_name = args[:publisher_name] if args.key?(:publisher_name)
  @rate_details = args[:rate_details] if args.key?(:rate_details)
  @read_advertiser_ids = args[:read_advertiser_ids] if args.key?(:read_advertiser_ids)
  @read_partner_ids = args[:read_partner_ids] if args.key?(:read_partner_ids)
  @read_write_accessors = args[:read_write_accessors] if args.key?(:read_write_accessors)
  @status = args[:status] if args.key?(:status)
  @time_range = args[:time_range] if args.key?(:time_range)
  @update_time = args[:update_time] if args.key?(:update_time)
end