Class: Google::Apis::DisplayvideoV4::InventorySource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

An inventory source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventorySource

Returns a new instance of InventorySource.



9190
9191
9192
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commitmentString

Whether the inventory source has a guaranteed or non-guaranteed delivery. Corresponds to the JSON property commitment

Returns:

  • (String)


9083
9084
9085
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9083

def commitment
  @commitment
end

#creative_configsArray<Google::Apis::DisplayvideoV4::CreativeConfig>

The creative requirements of the inventory source. Not applicable for auction packages. Corresponds to the JSON property creativeConfigs



9089
9090
9091
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9089

def creative_configs
  @creative_configs
end

#deal_idString

The ID in the exchange space that uniquely identifies the inventory source. Must be unique across buyers within each exchange but not necessarily unique across exchanges. Corresponds to the JSON property dealId

Returns:

  • (String)


9096
9097
9098
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9096

def deal_id
  @deal_id
end

#delivery_methodString

The delivery method of the inventory source. * For non-guaranteed inventory sources, the only acceptable value is INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC. * For guaranteed inventory sources, acceptable values are INVENTORY_SOURCE_DELIVERY_METHOD_TAG and INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC. Corresponds to the JSON property deliveryMethod

Returns:

  • (String)


9105
9106
9107
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9105

def delivery_method
  @delivery_method
end

#display_nameString

The display name of the inventory source. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


9111
9112
9113
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9111

def display_name
  @display_name
end

#exchangeString

The exchange to which the inventory source belongs. Corresponds to the JSON property exchange

Returns:

  • (String)


9116
9117
9118
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9116

def exchange
  @exchange
end

#guaranteed_order_idString

Immutable. The ID of the guaranteed order that this inventory source belongs to. Only applicable when commitment is INVENTORY_SOURCE_COMMITMENT_GUARANTEED . Corresponds to the JSON property guaranteedOrderId

Returns:

  • (String)


9123
9124
9125
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9123

def guaranteed_order_id
  @guaranteed_order_id
end

#inventory_source_idFixnum

Output only. The unique ID of the inventory source. Assigned by the system. Corresponds to the JSON property inventorySourceId

Returns:

  • (Fixnum)


9128
9129
9130
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9128

def inventory_source_id
  @inventory_source_id
end

#inventory_source_product_typeString

Output only. The product type of the inventory source, denoting the way through which it sells inventory. Corresponds to the JSON property inventorySourceProductType

Returns:

  • (String)


9134
9135
9136
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9134

def inventory_source_product_type
  @inventory_source_product_type
end

#inventory_source_typeString

Denotes the type of the inventory source. Corresponds to the JSON property inventorySourceType

Returns:

  • (String)


9139
9140
9141
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9139

def inventory_source_type
  @inventory_source_type
end

#nameString

Output only. The resource name of the inventory source. Corresponds to the JSON property name

Returns:

  • (String)


9144
9145
9146
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9144

def name
  @name
end

#publisher_nameString

The publisher/seller name of the inventory source. Corresponds to the JSON property publisherName

Returns:

  • (String)


9149
9150
9151
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9149

def publisher_name
  @publisher_name
end

#rate_detailsGoogle::Apis::DisplayvideoV4::RateDetails

The rate related settings of the inventory source. Corresponds to the JSON property rateDetails



9154
9155
9156
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9154

def rate_details
  @rate_details
end

#read_advertiser_idsArray<Fixnum>

Output only. The IDs of advertisers with read-only access to the inventory source. Corresponds to the JSON property readAdvertiserIds

Returns:

  • (Array<Fixnum>)


9160
9161
9162
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9160

def read_advertiser_ids
  @read_advertiser_ids
end

#read_partner_idsArray<Fixnum>

Output only. The IDs of partners with read-only access to the inventory source. All advertisers of partners in this field inherit read-only access to the inventory source. Corresponds to the JSON property readPartnerIds

Returns:

  • (Array<Fixnum>)


9167
9168
9169
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9167

def read_partner_ids
  @read_partner_ids
end

#read_write_accessorsGoogle::Apis::DisplayvideoV4::InventorySourceAccessors

The partner or advertisers with access to the inventory source. Corresponds to the JSON property readWriteAccessors



9172
9173
9174
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9172

def read_write_accessors
  @read_write_accessors
end

#statusGoogle::Apis::DisplayvideoV4::InventorySourceStatus

The status related settings of the inventory source. Corresponds to the JSON property status



9177
9178
9179
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9177

def status
  @status
end

#time_rangeGoogle::Apis::DisplayvideoV4::TimeRange

A time range. Corresponds to the JSON property timeRange



9182
9183
9184
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9182

def time_range
  @time_range
end

#update_timeString

Output only. The timestamp when the inventory source was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


9188
9189
9190
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9188

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9195
9196
9197
9198
9199
9200
9201
9202
9203
9204
9205
9206
9207
9208
9209
9210
9211
9212
9213
9214
9215
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9195

def update!(**args)
  @commitment = args[:commitment] if args.key?(:commitment)
  @creative_configs = args[:creative_configs] if args.key?(:creative_configs)
  @deal_id = args[:deal_id] if args.key?(:deal_id)
  @delivery_method = args[:delivery_method] if args.key?(:delivery_method)
  @display_name = args[:display_name] if args.key?(:display_name)
  @exchange = args[:exchange] if args.key?(:exchange)
  @guaranteed_order_id = args[:guaranteed_order_id] if args.key?(:guaranteed_order_id)
  @inventory_source_id = args[:inventory_source_id] if args.key?(:inventory_source_id)
  @inventory_source_product_type = args[:inventory_source_product_type] if args.key?(:inventory_source_product_type)
  @inventory_source_type = args[:inventory_source_type] if args.key?(:inventory_source_type)
  @name = args[:name] if args.key?(:name)
  @publisher_name = args[:publisher_name] if args.key?(:publisher_name)
  @rate_details = args[:rate_details] if args.key?(:rate_details)
  @read_advertiser_ids = args[:read_advertiser_ids] if args.key?(:read_advertiser_ids)
  @read_partner_ids = args[:read_partner_ids] if args.key?(:read_partner_ids)
  @read_write_accessors = args[:read_write_accessors] if args.key?(:read_write_accessors)
  @status = args[:status] if args.key?(:status)
  @time_range = args[:time_range] if args.key?(:time_range)
  @update_time = args[:update_time] if args.key?(:update_time)
end