Class: Google::Apis::DisplayvideoV4::InventorySource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

An inventory source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventorySource

Returns a new instance of InventorySource.



9181
9182
9183
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9181

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commitmentString

Whether the inventory source has a guaranteed or non-guaranteed delivery. Corresponds to the JSON property commitment

Returns:

  • (String)


9074
9075
9076
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9074

def commitment
  @commitment
end

#creative_configsArray<Google::Apis::DisplayvideoV4::CreativeConfig>

The creative requirements of the inventory source. Not applicable for auction packages. Corresponds to the JSON property creativeConfigs



9080
9081
9082
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9080

def creative_configs
  @creative_configs
end

#deal_idString

The ID in the exchange space that uniquely identifies the inventory source. Must be unique across buyers within each exchange but not necessarily unique across exchanges. Corresponds to the JSON property dealId

Returns:

  • (String)


9087
9088
9089
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9087

def deal_id
  @deal_id
end

#delivery_methodString

The delivery method of the inventory source. * For non-guaranteed inventory sources, the only acceptable value is INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC. * For guaranteed inventory sources, acceptable values are INVENTORY_SOURCE_DELIVERY_METHOD_TAG and INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC. Corresponds to the JSON property deliveryMethod

Returns:

  • (String)


9096
9097
9098
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9096

def delivery_method
  @delivery_method
end

#display_nameString

The display name of the inventory source. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


9102
9103
9104
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9102

def display_name
  @display_name
end

#exchangeString

The exchange to which the inventory source belongs. Corresponds to the JSON property exchange

Returns:

  • (String)


9107
9108
9109
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9107

def exchange
  @exchange
end

#guaranteed_order_idString

Immutable. The ID of the guaranteed order that this inventory source belongs to. Only applicable when commitment is INVENTORY_SOURCE_COMMITMENT_GUARANTEED . Corresponds to the JSON property guaranteedOrderId

Returns:

  • (String)


9114
9115
9116
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9114

def guaranteed_order_id
  @guaranteed_order_id
end

#inventory_source_idFixnum

Output only. The unique ID of the inventory source. Assigned by the system. Corresponds to the JSON property inventorySourceId

Returns:

  • (Fixnum)


9119
9120
9121
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9119

def inventory_source_id
  @inventory_source_id
end

#inventory_source_product_typeString

Output only. The product type of the inventory source, denoting the way through which it sells inventory. Corresponds to the JSON property inventorySourceProductType

Returns:

  • (String)


9125
9126
9127
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9125

def inventory_source_product_type
  @inventory_source_product_type
end

#inventory_source_typeString

Denotes the type of the inventory source. Corresponds to the JSON property inventorySourceType

Returns:

  • (String)


9130
9131
9132
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9130

def inventory_source_type
  @inventory_source_type
end

#nameString

Output only. The resource name of the inventory source. Corresponds to the JSON property name

Returns:

  • (String)


9135
9136
9137
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9135

def name
  @name
end

#publisher_nameString

The publisher/seller name of the inventory source. Corresponds to the JSON property publisherName

Returns:

  • (String)


9140
9141
9142
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9140

def publisher_name
  @publisher_name
end

#rate_detailsGoogle::Apis::DisplayvideoV4::RateDetails

The rate related settings of the inventory source. Corresponds to the JSON property rateDetails



9145
9146
9147
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9145

def rate_details
  @rate_details
end

#read_advertiser_idsArray<Fixnum>

Output only. The IDs of advertisers with read-only access to the inventory source. Corresponds to the JSON property readAdvertiserIds

Returns:

  • (Array<Fixnum>)


9151
9152
9153
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9151

def read_advertiser_ids
  @read_advertiser_ids
end

#read_partner_idsArray<Fixnum>

Output only. The IDs of partners with read-only access to the inventory source. All advertisers of partners in this field inherit read-only access to the inventory source. Corresponds to the JSON property readPartnerIds

Returns:

  • (Array<Fixnum>)


9158
9159
9160
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9158

def read_partner_ids
  @read_partner_ids
end

#read_write_accessorsGoogle::Apis::DisplayvideoV4::InventorySourceAccessors

The partner or advertisers with access to the inventory source. Corresponds to the JSON property readWriteAccessors



9163
9164
9165
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9163

def read_write_accessors
  @read_write_accessors
end

#statusGoogle::Apis::DisplayvideoV4::InventorySourceStatus

The status related settings of the inventory source. Corresponds to the JSON property status



9168
9169
9170
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9168

def status
  @status
end

#time_rangeGoogle::Apis::DisplayvideoV4::TimeRange

A time range. Corresponds to the JSON property timeRange



9173
9174
9175
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9173

def time_range
  @time_range
end

#update_timeString

Output only. The timestamp when the inventory source was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


9179
9180
9181
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9179

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9186
9187
9188
9189
9190
9191
9192
9193
9194
9195
9196
9197
9198
9199
9200
9201
9202
9203
9204
9205
9206
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9186

def update!(**args)
  @commitment = args[:commitment] if args.key?(:commitment)
  @creative_configs = args[:creative_configs] if args.key?(:creative_configs)
  @deal_id = args[:deal_id] if args.key?(:deal_id)
  @delivery_method = args[:delivery_method] if args.key?(:delivery_method)
  @display_name = args[:display_name] if args.key?(:display_name)
  @exchange = args[:exchange] if args.key?(:exchange)
  @guaranteed_order_id = args[:guaranteed_order_id] if args.key?(:guaranteed_order_id)
  @inventory_source_id = args[:inventory_source_id] if args.key?(:inventory_source_id)
  @inventory_source_product_type = args[:inventory_source_product_type] if args.key?(:inventory_source_product_type)
  @inventory_source_type = args[:inventory_source_type] if args.key?(:inventory_source_type)
  @name = args[:name] if args.key?(:name)
  @publisher_name = args[:publisher_name] if args.key?(:publisher_name)
  @rate_details = args[:rate_details] if args.key?(:rate_details)
  @read_advertiser_ids = args[:read_advertiser_ids] if args.key?(:read_advertiser_ids)
  @read_partner_ids = args[:read_partner_ids] if args.key?(:read_partner_ids)
  @read_write_accessors = args[:read_write_accessors] if args.key?(:read_write_accessors)
  @status = args[:status] if args.key?(:status)
  @time_range = args[:time_range] if args.key?(:time_range)
  @update_time = args[:update_time] if args.key?(:update_time)
end