Class: Google::Apis::DisplayvideoV4::Invoice
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::Invoice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single invoice.
Instance Attribute Summary collapse
-
#budget_invoice_grouping_id ⇒ String
The budget grouping ID for this invoice.
-
#budget_summaries ⇒ Array<Google::Apis::DisplayvideoV4::BudgetSummary>
The list of summarized information for each budget associated with this invoice.
-
#corrected_invoice_id ⇒ String
The ID of the original invoice being adjusted by this invoice, if applicable.
-
#currency_code ⇒ String
The currency used in the invoice in ISO 4217 format.
-
#display_name ⇒ String
The display name of the invoice.
-
#due_date ⇒ Google::Apis::DisplayvideoV4::Date
Represents a whole or partial calendar date, such as a birthday.
-
#invoice_id ⇒ String
The unique ID of the invoice.
-
#invoice_type ⇒ String
The type of invoice document.
-
#issue_date ⇒ Google::Apis::DisplayvideoV4::Date
Represents a whole or partial calendar date, such as a birthday.
-
#name ⇒ String
The resource name of the invoice.
-
#non_budget_micros ⇒ Fixnum
The total amount of costs or adjustments not tied to a particular budget, in micros of the invoice's currency.
-
#payments_account_id ⇒ String
The ID of the payments account the invoice belongs to.
-
#payments_profile_id ⇒ String
The ID of the payments profile the invoice belongs to.
-
#pdf_url ⇒ String
The URL to download a PDF copy of the invoice.
-
#purchase_order_number ⇒ String
Purchase order number associated with the invoice.
-
#replaced_invoice_ids ⇒ Array<String>
The ID(s) of any originally issued invoice that is being cancelled by this invoice, if applicable.
-
#service_date_range ⇒ Google::Apis::DisplayvideoV4::DateRange
A date range.
-
#subtotal_amount_micros ⇒ Fixnum
The pre-tax subtotal amount, in micros of the invoice's currency.
-
#total_amount_micros ⇒ Fixnum
The invoice total amount, in micros of the invoice's currency.
-
#total_tax_amount_micros ⇒ Fixnum
The sum of all taxes in invoice, in micros of the invoice's currency.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Invoice
constructor
A new instance of Invoice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Invoice
Returns a new instance of Invoice.
9840 9841 9842 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#budget_invoice_grouping_id ⇒ String
The budget grouping ID for this invoice. This field will only be set if the
invoice level of the corresponding billing profile was set to "Budget invoice
grouping ID".
Corresponds to the JSON property budgetInvoiceGroupingId
9708 9709 9710 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9708 def budget_invoice_grouping_id @budget_invoice_grouping_id end |
#budget_summaries ⇒ Array<Google::Apis::DisplayvideoV4::BudgetSummary>
The list of summarized information for each budget associated with this
invoice. This field will only be set if the invoice detail level of the
corresponding billing profile was set to "Budget level PO".
Corresponds to the JSON property budgetSummaries
9715 9716 9717 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9715 def budget_summaries @budget_summaries end |
#corrected_invoice_id ⇒ String
The ID of the original invoice being adjusted by this invoice, if applicable.
May appear on the invoice PDF as Reference invoice number. If
replaced_invoice_ids is set, this field will be empty.
Corresponds to the JSON property correctedInvoiceId
9722 9723 9724 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9722 def corrected_invoice_id @corrected_invoice_id end |
#currency_code ⇒ String
The currency used in the invoice in ISO 4217 format.
Corresponds to the JSON property currencyCode
9727 9728 9729 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9727 def currency_code @currency_code end |
#display_name ⇒ String
The display name of the invoice.
Corresponds to the JSON property displayName
9732 9733 9734 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9732 def display_name @display_name end |
#due_date ⇒ Google::Apis::DisplayvideoV4::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property dueDate
9744 9745 9746 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9744 def due_date @due_date end |
#invoice_id ⇒ String
The unique ID of the invoice.
Corresponds to the JSON property invoiceId
9749 9750 9751 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9749 def invoice_id @invoice_id end |
#invoice_type ⇒ String
The type of invoice document.
Corresponds to the JSON property invoiceType
9754 9755 9756 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9754 def invoice_type @invoice_type end |
#issue_date ⇒ Google::Apis::DisplayvideoV4::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property issueDate
9766 9767 9768 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9766 def issue_date @issue_date end |
#name ⇒ String
The resource name of the invoice.
Corresponds to the JSON property name
9771 9772 9773 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9771 def name @name end |
#non_budget_micros ⇒ Fixnum
The total amount of costs or adjustments not tied to a particular budget, in
micros of the invoice's currency. For example, if currency_code is USD, then
1000000 represents one US dollar.
Corresponds to the JSON property nonBudgetMicros
9778 9779 9780 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9778 def non_budget_micros @non_budget_micros end |
#payments_account_id ⇒ String
The ID of the payments account the invoice belongs to. Appears on the invoice
PDF as Billing Account Number.
Corresponds to the JSON property paymentsAccountId
9784 9785 9786 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9784 def payments_account_id @payments_account_id end |
#payments_profile_id ⇒ String
The ID of the payments profile the invoice belongs to. Appears on the invoice
PDF as Billing ID.
Corresponds to the JSON property paymentsProfileId
9790 9791 9792 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9790 def payments_profile_id @payments_profile_id end |
#pdf_url ⇒ String
The URL to download a PDF copy of the invoice. This URL is user specific and
requires a valid OAuth 2.0 access token to access. The access token must be
provided in an Authorization: Bearer HTTP header and be authorized for one
of the following scopes: * https://www.googleapis.com/auth/display-video-
mediaplanning * https://www.googleapis.com/auth/display-video The URL will
be valid for 7 days after retrieval of this invoice object or until this
invoice is retrieved again.
Corresponds to the JSON property pdfUrl
9801 9802 9803 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9801 def pdf_url @pdf_url end |
#purchase_order_number ⇒ String
Purchase order number associated with the invoice.
Corresponds to the JSON property purchaseOrderNumber
9806 9807 9808 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9806 def purchase_order_number @purchase_order_number end |
#replaced_invoice_ids ⇒ Array<String>
The ID(s) of any originally issued invoice that is being cancelled by this
invoice, if applicable. Multiple invoices may be listed if those invoices are
being consolidated into a single invoice. May appear on invoice PDF as
Replaced invoice numbers. If corrected_invoice_id is set, this field will be
empty.
Corresponds to the JSON property replacedInvoiceIds
9815 9816 9817 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9815 def replaced_invoice_ids @replaced_invoice_ids end |
#service_date_range ⇒ Google::Apis::DisplayvideoV4::DateRange
A date range.
Corresponds to the JSON property serviceDateRange
9820 9821 9822 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9820 def service_date_range @service_date_range end |
#subtotal_amount_micros ⇒ Fixnum
The pre-tax subtotal amount, in micros of the invoice's currency. For example,
if currency_code is USD, then 1000000 represents one US dollar.
Corresponds to the JSON property subtotalAmountMicros
9826 9827 9828 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9826 def subtotal_amount_micros @subtotal_amount_micros end |
#total_amount_micros ⇒ Fixnum
The invoice total amount, in micros of the invoice's currency. For example, if
currency_code is USD, then 1000000 represents one US dollar.
Corresponds to the JSON property totalAmountMicros
9832 9833 9834 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9832 def total_amount_micros @total_amount_micros end |
#total_tax_amount_micros ⇒ Fixnum
The sum of all taxes in invoice, in micros of the invoice's currency. For
example, if currency_code is USD, then 1000000 represents one US dollar.
Corresponds to the JSON property totalTaxAmountMicros
9838 9839 9840 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9838 def total_tax_amount_micros @total_tax_amount_micros end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9845 9846 9847 9848 9849 9850 9851 9852 9853 9854 9855 9856 9857 9858 9859 9860 9861 9862 9863 9864 9865 9866 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9845 def update!(**args) @budget_invoice_grouping_id = args[:budget_invoice_grouping_id] if args.key?(:budget_invoice_grouping_id) @budget_summaries = args[:budget_summaries] if args.key?(:budget_summaries) @corrected_invoice_id = args[:corrected_invoice_id] if args.key?(:corrected_invoice_id) @currency_code = args[:currency_code] if args.key?(:currency_code) @display_name = args[:display_name] if args.key?(:display_name) @due_date = args[:due_date] if args.key?(:due_date) @invoice_id = args[:invoice_id] if args.key?(:invoice_id) @invoice_type = args[:invoice_type] if args.key?(:invoice_type) @issue_date = args[:issue_date] if args.key?(:issue_date) @name = args[:name] if args.key?(:name) @non_budget_micros = args[:non_budget_micros] if args.key?(:non_budget_micros) @payments_account_id = args[:payments_account_id] if args.key?(:payments_account_id) @payments_profile_id = args[:payments_profile_id] if args.key?(:payments_profile_id) @pdf_url = args[:pdf_url] if args.key?(:pdf_url) @purchase_order_number = args[:purchase_order_number] if args.key?(:purchase_order_number) @replaced_invoice_ids = args[:replaced_invoice_ids] if args.key?(:replaced_invoice_ids) @service_date_range = args[:service_date_range] if args.key?(:service_date_range) @subtotal_amount_micros = args[:subtotal_amount_micros] if args.key?(:subtotal_amount_micros) @total_amount_micros = args[:total_amount_micros] if args.key?(:total_amount_micros) @total_tax_amount_micros = args[:total_tax_amount_micros] if args.key?(:total_tax_amount_micros) end |