Class: Google::Apis::DisplayvideoV4::KeywordAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::KeywordAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details for assigned keyword targeting option. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_KEYWORD.
Instance Attribute Summary collapse
-
#exempted_policy_names ⇒ Array<String>
Optional.
-
#keyword ⇒ String
Required.
-
#negative ⇒ Boolean
(also: #negative?)
Indicates if this option is being negatively targeted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeywordAssignedTargetingOptionDetails
constructor
A new instance of KeywordAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeywordAssignedTargetingOptionDetails
Returns a new instance of KeywordAssignedTargetingOptionDetails.
9885 9886 9887 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exempted_policy_names ⇒ Array<String>
Optional. The policy names to exempt the keyword from. When attempting to
target a keyword that violates a policy, the error returned will include the
name of the relevant policy. Use that name in this field to exempt the
targeted keyword from the policy. This field is only applicable for positively-
targeted keywords assigned to Demand Gen resources. Retrieval and management
of Demand Gen resources is currently in beta. This field is only available to
allowlisted users.
Corresponds to the JSON property exemptedPolicyNames
9870 9871 9872 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9870 def exempted_policy_names @exempted_policy_names end |
#keyword ⇒ String
Required. The keyword, for example car insurance. Positive keyword cannot be
offensive word. Must be UTF-8 encoded with a maximum size of 255 bytes.
Maximum number of characters is 80. Maximum number of words is 10.
Corresponds to the JSON property keyword
9877 9878 9879 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9877 def keyword @keyword end |
#negative ⇒ Boolean Also known as: negative?
Indicates if this option is being negatively targeted.
Corresponds to the JSON property negative
9882 9883 9884 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9882 def negative @negative end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9890 9891 9892 9893 9894 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9890 def update!(**args) @exempted_policy_names = args[:exempted_policy_names] if args.key?(:exempted_policy_names) @keyword = args[:keyword] if args.key?(:keyword) @negative = args[:negative] if args.key?(:negative) end |