Class: Google::Apis::DisplayvideoV4::KeywordAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for assigned keyword targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_KEYWORD.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeywordAssignedTargetingOptionDetails

Returns a new instance of KeywordAssignedTargetingOptionDetails.



9665
9666
9667
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exempted_policy_namesArray<String>

Optional. The policy names to exempt the keyword from. When attempting to target a keyword that violates a policy, the error returned will include the name of the relevant policy. Use that name in this field to exempt the targeted keyword from the policy. This field is only applicable for positively- targeted keywords assigned to Demand Gen resources. Retrieval and management of Demand Gen resources is currently in beta. This field is only available to allowlisted users. Corresponds to the JSON property exemptedPolicyNames

Returns:

  • (Array<String>)


9650
9651
9652
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9650

def exempted_policy_names
  @exempted_policy_names
end

#keywordString

Required. The keyword, for example car insurance. Positive keyword cannot be offensive word. Must be UTF-8 encoded with a maximum size of 255 bytes. Maximum number of characters is 80. Maximum number of words is 10. Corresponds to the JSON property keyword

Returns:

  • (String)


9657
9658
9659
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9657

def keyword
  @keyword
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. Corresponds to the JSON property negative

Returns:

  • (Boolean)


9662
9663
9664
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9662

def negative
  @negative
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9670
9671
9672
9673
9674
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9670

def update!(**args)
  @exempted_policy_names = args[:exempted_policy_names] if args.key?(:exempted_policy_names)
  @keyword = args[:keyword] if args.key?(:keyword)
  @negative = args[:negative] if args.key?(:negative)
end