Class: Google::Apis::DisplayvideoV4::LanguageAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for assigned language targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_LANGUAGE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LanguageAssignedTargetingOptionDetails

Returns a new instance of LanguageAssignedTargetingOptionDetails.



9988
9989
9990
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the language (e.g., "French"). Corresponds to the JSON property displayName

Returns:

  • (String)


9973
9974
9975
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9973

def display_name
  @display_name
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. All assigned language targeting options on the same resource must have the same value for this field. Corresponds to the JSON property negative

Returns:

  • (Boolean)


9979
9980
9981
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9979

def negative
  @negative
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_LANGUAGE. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


9986
9987
9988
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9986

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9993
9994
9995
9996
9997
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9993

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @negative = args[:negative] if args.key?(:negative)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end