Class: Google::Apis::DisplayvideoV4::LanguageAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for assigned language targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_LANGUAGE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LanguageAssignedTargetingOptionDetails

Returns a new instance of LanguageAssignedTargetingOptionDetails.



9755
9756
9757
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the language (e.g., "French"). Corresponds to the JSON property displayName

Returns:

  • (String)


9740
9741
9742
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9740

def display_name
  @display_name
end

#negativeBoolean Also known as: negative?

Indicates if this option is being negatively targeted. All assigned language targeting options on the same resource must have the same value for this field. Corresponds to the JSON property negative

Returns:

  • (Boolean)


9746
9747
9748
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9746

def negative
  @negative
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_LANGUAGE. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


9753
9754
9755
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9753

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9760
9761
9762
9763
9764
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9760

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @negative = args[:negative] if args.key?(:negative)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end