Class: Google::Apis::DisplayvideoV4::LineItem
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::LineItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single line item.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Output only.
-
#bid_strategy ⇒ Google::Apis::DisplayvideoV4::BiddingStrategy
Settings that control the bid strategy.
-
#budget ⇒ Google::Apis::DisplayvideoV4::LineItemBudget
Settings that control how budget is allocated.
-
#campaign_id ⇒ Fixnum
Output only.
-
#contains_eu_political_ads ⇒ String
Whether this line item will serve European Union political ads.
-
#conversion_counting ⇒ Google::Apis::DisplayvideoV4::ConversionCountingConfig
Settings that control how conversions are counted.
-
#creative_ids ⇒ Array<Fixnum>
The IDs of the creatives associated with the line item.
-
#demand_gen_settings ⇒ Google::Apis::DisplayvideoV4::DemandGenSettings
Settings for Demand Gen line items.
-
#display_name ⇒ String
Required.
-
#entity_status ⇒ String
Required.
-
#exclude_new_exchanges ⇒ Boolean
(also: #exclude_new_exchanges?)
Whether to exclude new exchanges from automatically being targeted by the line item.
-
#flight ⇒ Google::Apis::DisplayvideoV4::LineItemFlight
Settings that control the active duration of a line item.
-
#frequency_cap ⇒ Google::Apis::DisplayvideoV4::FrequencyCap
Settings that control the number of times a user may be shown with the same ad during a given time period.
-
#insertion_order_id ⇒ Fixnum
Required.
-
#integration_details ⇒ Google::Apis::DisplayvideoV4::IntegrationDetails
Integration details of an entry.
-
#line_item_id ⇒ Fixnum
Output only.
-
#line_item_type ⇒ String
Required.
-
#mobile_app ⇒ Google::Apis::DisplayvideoV4::MobileApp
A mobile app promoted by a mobile app install line item.
-
#name ⇒ String
Output only.
-
#optimize_fixed_bidding ⇒ Boolean
(also: #optimize_fixed_bidding?)
Optional.
-
#pacing ⇒ Google::Apis::DisplayvideoV4::Pacing
Settings that control the rate at which a budget is spent.
-
#partner_costs ⇒ Array<Google::Apis::DisplayvideoV4::PartnerCost>
The partner costs associated with the line item.
-
#partner_revenue_model ⇒ Google::Apis::DisplayvideoV4::PartnerRevenueModel
Settings that control how partner revenue is calculated.
-
#reservation_type ⇒ String
Output only.
-
#targeting_expansion ⇒ Google::Apis::DisplayvideoV4::TargetingExpansionConfig
Settings that control the optimized targeting settings of the line item.
-
#update_time ⇒ String
Output only.
-
#warning_messages ⇒ Array<String>
Output only.
-
#youtube_and_partners_settings ⇒ Google::Apis::DisplayvideoV4::YoutubeAndPartnersSettings
Settings for YouTube and Partners line items.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LineItem
constructor
A new instance of LineItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LineItem
Returns a new instance of LineItem.
10196 10197 10198 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10196 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Output only. The unique ID of the advertiser the line item belongs to.
Corresponds to the JSON property advertiserId
10027 10028 10029 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10027 def advertiser_id @advertiser_id end |
#bid_strategy ⇒ Google::Apis::DisplayvideoV4::BiddingStrategy
Settings that control the bid strategy. Bid strategy determines the bid price.
Corresponds to the JSON property bidStrategy
10032 10033 10034 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10032 def bid_strategy @bid_strategy end |
#budget ⇒ Google::Apis::DisplayvideoV4::LineItemBudget
Settings that control how budget is allocated.
Corresponds to the JSON property budget
10037 10038 10039 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10037 def budget @budget end |
#campaign_id ⇒ Fixnum
Output only. The unique ID of the campaign that the line item belongs to.
Corresponds to the JSON property campaignId
10042 10043 10044 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10042 def campaign_id @campaign_id end |
#contains_eu_political_ads ⇒ String
Whether this line item will serve European Union political ads. If
contains_eu_political_ads has been set to
DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING in the parent advertiser, then this
field will be assigned DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING if not
otherwise specified. This field can then be updated using the UI, API, or
Structured Data Files. This field must be assigned when creating a new line
item. Otherwise, the advertisers.lineItems.create request will fail.
Corresponds to the JSON property containsEuPoliticalAds
10053 10054 10055 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10053 def contains_eu_political_ads @contains_eu_political_ads end |
#conversion_counting ⇒ Google::Apis::DisplayvideoV4::ConversionCountingConfig
Settings that control how conversions are counted. All post-click conversions
will be counted. A percentage value can be set for post-view conversions
counting.
Corresponds to the JSON property conversionCounting
10060 10061 10062 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10060 def conversion_counting @conversion_counting end |
#creative_ids ⇒ Array<Fixnum>
The IDs of the creatives associated with the line item.
Corresponds to the JSON property creativeIds
10065 10066 10067 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10065 def creative_ids @creative_ids end |
#demand_gen_settings ⇒ Google::Apis::DisplayvideoV4::DemandGenSettings
Settings for Demand Gen line items.
Corresponds to the JSON property demandGenSettings
10070 10071 10072 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10070 def demand_gen_settings @demand_gen_settings end |
#display_name ⇒ String
Required. The display name of the line item. Must be UTF-8 encoded with a
maximum size of 240 bytes.
Corresponds to the JSON property displayName
10076 10077 10078 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10076 def display_name @display_name end |
#entity_status ⇒ String
Required. Controls whether or not the line item can spend its budget and bid
on inventory. * For CreateLineItem method, only ENTITY_STATUS_DRAFT is
allowed. To activate a line item, use UpdateLineItem method and update the
status to ENTITY_STATUS_ACTIVE after creation. * A line item cannot be
changed back to ENTITY_STATUS_DRAFT status from any other status. * If the
line item's parent insertion order is not active, the line item can't spend
its budget even if its own status is ENTITY_STATUS_ACTIVE.
Corresponds to the JSON property entityStatus
10087 10088 10089 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10087 def entity_status @entity_status end |
#exclude_new_exchanges ⇒ Boolean Also known as: exclude_new_exchanges?
Whether to exclude new exchanges from automatically being targeted by the line
item. This field is false by default.
Corresponds to the JSON property excludeNewExchanges
10093 10094 10095 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10093 def exclude_new_exchanges @exclude_new_exchanges end |
#flight ⇒ Google::Apis::DisplayvideoV4::LineItemFlight
Settings that control the active duration of a line item.
Corresponds to the JSON property flight
10099 10100 10101 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10099 def flight @flight end |
#frequency_cap ⇒ Google::Apis::DisplayvideoV4::FrequencyCap
Settings that control the number of times a user may be shown with the same ad
during a given time period.
Corresponds to the JSON property frequencyCap
10105 10106 10107 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10105 def frequency_cap @frequency_cap end |
#insertion_order_id ⇒ Fixnum
Required. Immutable. The unique ID of the insertion order that the line item
belongs to.
Corresponds to the JSON property insertionOrderId
10111 10112 10113 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10111 def insertion_order_id @insertion_order_id end |
#integration_details ⇒ Google::Apis::DisplayvideoV4::IntegrationDetails
Integration details of an entry.
Corresponds to the JSON property integrationDetails
10116 10117 10118 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10116 def integration_details @integration_details end |
#line_item_id ⇒ Fixnum
Output only. The unique ID of the line item. Assigned by the system.
Corresponds to the JSON property lineItemId
10121 10122 10123 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10121 def line_item_id @line_item_id end |
#line_item_type ⇒ String
Required. Immutable. The type of the line item.
Corresponds to the JSON property lineItemType
10126 10127 10128 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10126 def line_item_type @line_item_type end |
#mobile_app ⇒ Google::Apis::DisplayvideoV4::MobileApp
A mobile app promoted by a mobile app install line item.
Corresponds to the JSON property mobileApp
10131 10132 10133 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10131 def mobile_app @mobile_app end |
#name ⇒ String
Output only. The resource name of the line item.
Corresponds to the JSON property name
10136 10137 10138 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10136 def name @name end |
#optimize_fixed_bidding ⇒ Boolean Also known as: optimize_fixed_bidding?
Optional. Whether to enable DV360's bid optimization for fixed bid line items.
By default, DV360 optimizes your fixed bid by automatically lowering bids for
impressions that are less likely to perform well. This optimization is enabled
by default (value is true). When this field is set to false, this
optimization is disabled, and the bid will not be lowered for any reason. This
setting only applies to line items with a bidding_strategy of type
FIXED_BID.
Corresponds to the JSON property optimizeFixedBidding
10147 10148 10149 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10147 def optimize_fixed_bidding @optimize_fixed_bidding end |
#pacing ⇒ Google::Apis::DisplayvideoV4::Pacing
Settings that control the rate at which a budget is spent.
Corresponds to the JSON property pacing
10153 10154 10155 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10153 def pacing @pacing end |
#partner_costs ⇒ Array<Google::Apis::DisplayvideoV4::PartnerCost>
The partner costs associated with the line item. If absent or empty in
CreateLineItem method, the newly created line item will inherit partner costs
from its parent insertion order.
Corresponds to the JSON property partnerCosts
10160 10161 10162 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10160 def partner_costs @partner_costs end |
#partner_revenue_model ⇒ Google::Apis::DisplayvideoV4::PartnerRevenueModel
Settings that control how partner revenue is calculated.
Corresponds to the JSON property partnerRevenueModel
10165 10166 10167 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10165 def partner_revenue_model @partner_revenue_model end |
#reservation_type ⇒ String
Output only. The reservation type of the line item.
Corresponds to the JSON property reservationType
10170 10171 10172 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10170 def reservation_type @reservation_type end |
#targeting_expansion ⇒ Google::Apis::DisplayvideoV4::TargetingExpansionConfig
Settings that control the optimized targeting settings of the line item.
Corresponds to the JSON property targetingExpansion
10176 10177 10178 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10176 def targeting_expansion @targeting_expansion end |
#update_time ⇒ String
Output only. The timestamp when the line item was last updated. Assigned by
the system.
Corresponds to the JSON property updateTime
10182 10183 10184 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10182 def update_time @update_time end |
#warning_messages ⇒ Array<String>
Output only. The warning messages generated by the line item. These warnings
do not block saving the line item, but some may block the line item from
running.
Corresponds to the JSON property warningMessages
10189 10190 10191 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10189 def @warning_messages end |
#youtube_and_partners_settings ⇒ Google::Apis::DisplayvideoV4::YoutubeAndPartnersSettings
Settings for YouTube and Partners line items.
Corresponds to the JSON property youtubeAndPartnersSettings
10194 10195 10196 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10194 def youtube_and_partners_settings @youtube_and_partners_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10201 10202 10203 10204 10205 10206 10207 10208 10209 10210 10211 10212 10213 10214 10215 10216 10217 10218 10219 10220 10221 10222 10223 10224 10225 10226 10227 10228 10229 10230 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10201 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy) @budget = args[:budget] if args.key?(:budget) @campaign_id = args[:campaign_id] if args.key?(:campaign_id) @contains_eu_political_ads = args[:contains_eu_political_ads] if args.key?(:contains_eu_political_ads) @conversion_counting = args[:conversion_counting] if args.key?(:conversion_counting) @creative_ids = args[:creative_ids] if args.key?(:creative_ids) @demand_gen_settings = args[:demand_gen_settings] if args.key?(:demand_gen_settings) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @exclude_new_exchanges = args[:exclude_new_exchanges] if args.key?(:exclude_new_exchanges) @flight = args[:flight] if args.key?(:flight) @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap) @insertion_order_id = args[:insertion_order_id] if args.key?(:insertion_order_id) @integration_details = args[:integration_details] if args.key?(:integration_details) @line_item_id = args[:line_item_id] if args.key?(:line_item_id) @line_item_type = args[:line_item_type] if args.key?(:line_item_type) @mobile_app = args[:mobile_app] if args.key?(:mobile_app) @name = args[:name] if args.key?(:name) @optimize_fixed_bidding = args[:optimize_fixed_bidding] if args.key?(:optimize_fixed_bidding) @pacing = args[:pacing] if args.key?(:pacing) @partner_costs = args[:partner_costs] if args.key?(:partner_costs) @partner_revenue_model = args[:partner_revenue_model] if args.key?(:partner_revenue_model) @reservation_type = args[:reservation_type] if args.key?(:reservation_type) @targeting_expansion = args[:targeting_expansion] if args.key?(:targeting_expansion) @update_time = args[:update_time] if args.key?(:update_time) @warning_messages = args[:warning_messages] if args.key?(:warning_messages) @youtube_and_partners_settings = args[:youtube_and_partners_settings] if args.key?(:youtube_and_partners_settings) end |