Class: Google::Apis::DisplayvideoV4::LineItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A single line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LineItem

Returns a new instance of LineItem.



9972
9973
9974
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9972

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The unique ID of the advertiser the line item belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


9803
9804
9805
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9803

def advertiser_id
  @advertiser_id
end

#bid_strategyGoogle::Apis::DisplayvideoV4::BiddingStrategy

Settings that control the bid strategy. Bid strategy determines the bid price. Corresponds to the JSON property bidStrategy



9808
9809
9810
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9808

def bid_strategy
  @bid_strategy
end

#budgetGoogle::Apis::DisplayvideoV4::LineItemBudget

Settings that control how budget is allocated. Corresponds to the JSON property budget



9813
9814
9815
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9813

def budget
  @budget
end

#campaign_idFixnum

Output only. The unique ID of the campaign that the line item belongs to. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


9818
9819
9820
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9818

def campaign_id
  @campaign_id
end

#contains_eu_political_adsString

Whether this line item will serve European Union political ads. If contains_eu_political_ads has been set to DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING in the parent advertiser, then this field will be assigned DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING if not otherwise specified. This field can then be updated using the UI, API, or Structured Data Files. This field must be assigned when creating a new line item. Otherwise, the advertisers.lineItems.create request will fail. Corresponds to the JSON property containsEuPoliticalAds

Returns:

  • (String)


9829
9830
9831
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9829

def contains_eu_political_ads
  @contains_eu_political_ads
end

#conversion_countingGoogle::Apis::DisplayvideoV4::ConversionCountingConfig

Settings that control how conversions are counted. All post-click conversions will be counted. A percentage value can be set for post-view conversions counting. Corresponds to the JSON property conversionCounting



9836
9837
9838
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9836

def conversion_counting
  @conversion_counting
end

#creative_idsArray<Fixnum>

The IDs of the creatives associated with the line item. Corresponds to the JSON property creativeIds

Returns:

  • (Array<Fixnum>)


9841
9842
9843
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9841

def creative_ids
  @creative_ids
end

#demand_gen_settingsGoogle::Apis::DisplayvideoV4::DemandGenSettings

Settings for Demand Gen line items. Corresponds to the JSON property demandGenSettings



9846
9847
9848
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9846

def demand_gen_settings
  @demand_gen_settings
end

#display_nameString

Required. The display name of the line item. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


9852
9853
9854
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9852

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not the line item can spend its budget and bid on inventory. * For CreateLineItem method, only ENTITY_STATUS_DRAFT is allowed. To activate a line item, use UpdateLineItem method and update the status to ENTITY_STATUS_ACTIVE after creation. * A line item cannot be changed back to ENTITY_STATUS_DRAFT status from any other status. * If the line item's parent insertion order is not active, the line item can't spend its budget even if its own status is ENTITY_STATUS_ACTIVE. Corresponds to the JSON property entityStatus

Returns:

  • (String)


9863
9864
9865
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9863

def entity_status
  @entity_status
end

#exclude_new_exchangesBoolean Also known as: exclude_new_exchanges?

Whether to exclude new exchanges from automatically being targeted by the line item. This field is false by default. Corresponds to the JSON property excludeNewExchanges

Returns:

  • (Boolean)


9869
9870
9871
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9869

def exclude_new_exchanges
  @exclude_new_exchanges
end

#flightGoogle::Apis::DisplayvideoV4::LineItemFlight

Settings that control the active duration of a line item. Corresponds to the JSON property flight



9875
9876
9877
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9875

def flight
  @flight
end

#frequency_capGoogle::Apis::DisplayvideoV4::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property frequencyCap



9881
9882
9883
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9881

def frequency_cap
  @frequency_cap
end

#insertion_order_idFixnum

Required. Immutable. The unique ID of the insertion order that the line item belongs to. Corresponds to the JSON property insertionOrderId

Returns:

  • (Fixnum)


9887
9888
9889
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9887

def insertion_order_id
  @insertion_order_id
end

#integration_detailsGoogle::Apis::DisplayvideoV4::IntegrationDetails

Integration details of an entry. Corresponds to the JSON property integrationDetails



9892
9893
9894
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9892

def integration_details
  @integration_details
end

#line_item_idFixnum

Output only. The unique ID of the line item. Assigned by the system. Corresponds to the JSON property lineItemId

Returns:

  • (Fixnum)


9897
9898
9899
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9897

def line_item_id
  @line_item_id
end

#line_item_typeString

Required. Immutable. The type of the line item. Corresponds to the JSON property lineItemType

Returns:

  • (String)


9902
9903
9904
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9902

def line_item_type
  @line_item_type
end

#mobile_appGoogle::Apis::DisplayvideoV4::MobileApp

A mobile app promoted by a mobile app install line item. Corresponds to the JSON property mobileApp



9907
9908
9909
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9907

def mobile_app
  @mobile_app
end

#nameString

Output only. The resource name of the line item. Corresponds to the JSON property name

Returns:

  • (String)


9912
9913
9914
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9912

def name
  @name
end

#optimize_fixed_biddingBoolean Also known as: optimize_fixed_bidding?

Optional. Whether to enable DV360's bid optimization for fixed bid line items. By default, DV360 optimizes your fixed bid by automatically lowering bids for impressions that are less likely to perform well. This optimization is enabled by default (value is true). When this field is set to false, this optimization is disabled, and the bid will not be lowered for any reason. This setting only applies to line items with a bidding_strategy of type FIXED_BID. Corresponds to the JSON property optimizeFixedBidding

Returns:

  • (Boolean)


9923
9924
9925
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9923

def optimize_fixed_bidding
  @optimize_fixed_bidding
end

#pacingGoogle::Apis::DisplayvideoV4::Pacing

Settings that control the rate at which a budget is spent. Corresponds to the JSON property pacing



9929
9930
9931
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9929

def pacing
  @pacing
end

#partner_costsArray<Google::Apis::DisplayvideoV4::PartnerCost>

The partner costs associated with the line item. If absent or empty in CreateLineItem method, the newly created line item will inherit partner costs from its parent insertion order. Corresponds to the JSON property partnerCosts



9936
9937
9938
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9936

def partner_costs
  @partner_costs
end

#partner_revenue_modelGoogle::Apis::DisplayvideoV4::PartnerRevenueModel

Settings that control how partner revenue is calculated. Corresponds to the JSON property partnerRevenueModel



9941
9942
9943
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9941

def partner_revenue_model
  @partner_revenue_model
end

#reservation_typeString

Output only. The reservation type of the line item. Corresponds to the JSON property reservationType

Returns:

  • (String)


9946
9947
9948
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9946

def reservation_type
  @reservation_type
end

#targeting_expansionGoogle::Apis::DisplayvideoV4::TargetingExpansionConfig

Settings that control the optimized targeting settings of the line item. Corresponds to the JSON property targetingExpansion



9952
9953
9954
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9952

def targeting_expansion
  @targeting_expansion
end

#update_timeString

Output only. The timestamp when the line item was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


9958
9959
9960
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9958

def update_time
  @update_time
end

#warning_messagesArray<String>

Output only. The warning messages generated by the line item. These warnings do not block saving the line item, but some may block the line item from running. Corresponds to the JSON property warningMessages

Returns:

  • (Array<String>)


9965
9966
9967
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9965

def warning_messages
  @warning_messages
end

#youtube_and_partners_settingsGoogle::Apis::DisplayvideoV4::YoutubeAndPartnersSettings

Settings for YouTube and Partners line items. Corresponds to the JSON property youtubeAndPartnersSettings



9970
9971
9972
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9970

def youtube_and_partners_settings
  @youtube_and_partners_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9977
9978
9979
9980
9981
9982
9983
9984
9985
9986
9987
9988
9989
9990
9991
9992
9993
9994
9995
9996
9997
9998
9999
10000
10001
10002
10003
10004
10005
10006
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 9977

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy)
  @budget = args[:budget] if args.key?(:budget)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @contains_eu_political_ads = args[:contains_eu_political_ads] if args.key?(:contains_eu_political_ads)
  @conversion_counting = args[:conversion_counting] if args.key?(:conversion_counting)
  @creative_ids = args[:creative_ids] if args.key?(:creative_ids)
  @demand_gen_settings = args[:demand_gen_settings] if args.key?(:demand_gen_settings)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @exclude_new_exchanges = args[:exclude_new_exchanges] if args.key?(:exclude_new_exchanges)
  @flight = args[:flight] if args.key?(:flight)
  @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap)
  @insertion_order_id = args[:insertion_order_id] if args.key?(:insertion_order_id)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @line_item_id = args[:line_item_id] if args.key?(:line_item_id)
  @line_item_type = args[:line_item_type] if args.key?(:line_item_type)
  @mobile_app = args[:mobile_app] if args.key?(:mobile_app)
  @name = args[:name] if args.key?(:name)
  @optimize_fixed_bidding = args[:optimize_fixed_bidding] if args.key?(:optimize_fixed_bidding)
  @pacing = args[:pacing] if args.key?(:pacing)
  @partner_costs = args[:partner_costs] if args.key?(:partner_costs)
  @partner_revenue_model = args[:partner_revenue_model] if args.key?(:partner_revenue_model)
  @reservation_type = args[:reservation_type] if args.key?(:reservation_type)
  @targeting_expansion = args[:targeting_expansion] if args.key?(:targeting_expansion)
  @update_time = args[:update_time] if args.key?(:update_time)
  @warning_messages = args[:warning_messages] if args.key?(:warning_messages)
  @youtube_and_partners_settings = args[:youtube_and_partners_settings] if args.key?(:youtube_and_partners_settings)
end