Class: Google::Apis::DisplayvideoV4::LineItemBudget
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::LineItemBudget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Settings that control how budget is allocated.
Instance Attribute Summary collapse
-
#budget_allocation_type ⇒ String
Required.
-
#budget_unit ⇒ String
Output only.
-
#max_amount ⇒ Fixnum
The maximum budget amount the line item will spend.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LineItemBudget
constructor
A new instance of LineItemBudget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LineItemBudget
Returns a new instance of LineItemBudget.
10262 10263 10264 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10262 def initialize(**args) update!(**args) end |
Instance Attribute Details
#budget_allocation_type ⇒ String
Required. The type of the budget allocation.
LINE_ITEM_BUDGET_ALLOCATION_TYPE_AUTOMATIC is only applicable when automatic
budget allocation is enabled for the parent insertion order. This field must
be set to LINE_ITEM_BUDGET_ALLOCATION_TYPE_FIXED for Demand Gen line items.
Corresponds to the JSON property budgetAllocationType
10240 10241 10242 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10240 def budget_allocation_type @budget_allocation_type end |
#budget_unit ⇒ String
Output only. The budget unit specifies whether the budget is currency based or
impression based. This value is inherited from the parent insertion order.
Corresponds to the JSON property budgetUnit
10246 10247 10248 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10246 def budget_unit @budget_unit end |
#max_amount ⇒ Fixnum
The maximum budget amount the line item will spend. Must be greater than 0.
When budget_allocation_type is: * LINE_ITEM_BUDGET_ALLOCATION_TYPE_AUTOMATIC,
this field is immutable and is set by the system. *
LINE_ITEM_BUDGET_ALLOCATION_TYPE_FIXED, if budget_unit is: -
BUDGET_UNIT_CURRENCY, this field represents maximum budget amount to spend,
in micros of the advertiser's currency. For example, 1500000 represents 1.5
standard units of the currency. - BUDGET_UNIT_IMPRESSIONS, this field
represents the maximum number of impressions to serve. *
LINE_ITEM_BUDGET_ALLOCATION_TYPE_UNLIMITED, this field is not applicable and
will be ignored by the system.
Corresponds to the JSON property maxAmount
10260 10261 10262 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10260 def max_amount @max_amount end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10267 10268 10269 10270 10271 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10267 def update!(**args) @budget_allocation_type = args[:budget_allocation_type] if args.key?(:budget_allocation_type) @budget_unit = args[:budget_unit] if args.key?(:budget_unit) @max_amount = args[:max_amount] if args.key?(:max_amount) end |