Class: Google::Apis::DisplayvideoV4::ListAdGroupAdsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAdGroupAdsResponse

Returns a new instance of ListAdGroupAdsResponse.



10140
10141
10142
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10140

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_adsArray<Google::Apis::DisplayvideoV4::AdGroupAd>

The list of ads. This list will be absent if empty. Corresponds to the JSON property adGroupAds



10131
10132
10133
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10131

def ad_group_ads
  @ad_group_ads
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListAdGroupAds method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10138
10139
10140
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10138

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10145
10146
10147
10148
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10145

def update!(**args)
  @ad_group_ads = args[:ad_group_ads] if args.key?(:ad_group_ads)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end