Class: Google::Apis::DisplayvideoV4::ListAdGroupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListAdGroupsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#ad_groups ⇒ Array<Google::Apis::DisplayvideoV4::AdGroup>
The list of ad groups.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListAdGroupsResponse
constructor
A new instance of ListAdGroupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListAdGroupsResponse
Returns a new instance of ListAdGroupsResponse.
10195 10196 10197 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_groups ⇒ Array<Google::Apis::DisplayvideoV4::AdGroup>
The list of ad groups. This list will be absent if empty.
Corresponds to the JSON property adGroups
10186 10187 10188 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10186 def ad_groups @ad_groups end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListAdGroups method to retrieve
the next page of results.
Corresponds to the JSON property nextPageToken
10193 10194 10195 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10193 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10200 10201 10202 10203 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10200 def update!(**args) @ad_groups = args[:ad_groups] if args.key?(:ad_groups) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |