Class: Google::Apis::DisplayvideoV4::ListCampaignsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListCampaignsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#campaigns ⇒ Array<Google::Apis::DisplayvideoV4::Campaign>
The list of campaigns.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCampaignsResponse
constructor
A new instance of ListCampaignsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCampaignsResponse
Returns a new instance of ListCampaignsResponse.
10332 10333 10334 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10332 def initialize(**args) update!(**args) end |
Instance Attribute Details
#campaigns ⇒ Array<Google::Apis::DisplayvideoV4::Campaign>
The list of campaigns. This list will be absent if empty.
Corresponds to the JSON property campaigns
10323 10324 10325 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10323 def campaigns @campaigns end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListCampaigns method to retrieve
the next page of results.
Corresponds to the JSON property nextPageToken
10330 10331 10332 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10330 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10337 10338 10339 10340 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10337 def update!(**args) @campaigns = args[:campaigns] if args.key?(:campaigns) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |