Class: Google::Apis::DisplayvideoV4::ListCreativesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListCreativesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#creatives ⇒ Array<Google::Apis::DisplayvideoV4::Creative>
The list of creatives.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCreativesResponse
constructor
A new instance of ListCreativesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCreativesResponse
Returns a new instance of ListCreativesResponse.
10634 10635 10636 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10634 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creatives ⇒ Array<Google::Apis::DisplayvideoV4::Creative>
The list of creatives. This list will be absent if empty.
Corresponds to the JSON property creatives
10624 10625 10626 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10624 def creatives @creatives end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListCreativesRequest method to
retrieve the next page of results. If this field is null, it means this is the
last page.
Corresponds to the JSON property nextPageToken
10632 10633 10634 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10632 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10639 10640 10641 10642 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10639 def update!(**args) @creatives = args[:creatives] if args.key?(:creatives) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |