Class: Google::Apis::DisplayvideoV4::ListCreativesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListCreativesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#creatives ⇒ Array<Google::Apis::DisplayvideoV4::Creative>
The list of creatives.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCreativesResponse
constructor
A new instance of ListCreativesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCreativesResponse
Returns a new instance of ListCreativesResponse.
10414 10415 10416 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10414 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creatives ⇒ Array<Google::Apis::DisplayvideoV4::Creative>
The list of creatives. This list will be absent if empty.
Corresponds to the JSON property creatives
10404 10405 10406 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10404 def creatives @creatives end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListCreativesRequest method to
retrieve the next page of results. If this field is null, it means this is the
last page.
Corresponds to the JSON property nextPageToken
10412 10413 10414 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10412 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10419 10420 10421 10422 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10419 def update!(**args) @creatives = args[:creatives] if args.key?(:creatives) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |