Class: Google::Apis::DisplayvideoV4::ListCustomBiddingAlgorithmRulesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCustomBiddingAlgorithmRulesResponse

Returns a new instance of ListCustomBiddingAlgorithmRulesResponse.



10443
10444
10445
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_bidding_rulesArray<Google::Apis::DisplayvideoV4::CustomBiddingAlgorithmRules>

The list of CustomBiddingAlgorithmRules resources. This list will be absent if empty. Corresponds to the JSON property customBiddingRules



10433
10434
10435
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10433

def custom_bidding_rules
  @custom_bidding_rules
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListCustomBiddingAlgorithmRulesRequest method to retrieve the next page of results. If this field is null, it means this is the last page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10441
10442
10443
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10441

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10448
10449
10450
10451
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10448

def update!(**args)
  @custom_bidding_rules = args[:custom_bidding_rules] if args.key?(:custom_bidding_rules)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end