Class: Google::Apis::DisplayvideoV4::ListCustomBiddingAlgorithmsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCustomBiddingAlgorithmsResponse

Returns a new instance of ListCustomBiddingAlgorithmsResponse.



10471
10472
10473
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10471

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_bidding_algorithmsArray<Google::Apis::DisplayvideoV4::CustomBiddingAlgorithm>

The list of custom bidding algorithms. This list will be absent if empty. Corresponds to the JSON property customBiddingAlgorithms



10461
10462
10463
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10461

def custom_bidding_algorithms
  @custom_bidding_algorithms
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListCustomBiddingAlgorithmsRequest method to retrieve the next page of results. If this field is null, it means this is the last page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10469
10470
10471
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10469

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10476
10477
10478
10479
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10476

def update!(**args)
  @custom_bidding_algorithms = args[:custom_bidding_algorithms] if args.key?(:custom_bidding_algorithms)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end