Class: Google::Apis::DisplayvideoV4::ListCustomBiddingScriptsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListCustomBiddingScriptsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#custom_bidding_scripts ⇒ Array<Google::Apis::DisplayvideoV4::CustomBiddingScript>
The list of custom bidding scripts.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCustomBiddingScriptsResponse
constructor
A new instance of ListCustomBiddingScriptsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCustomBiddingScriptsResponse
Returns a new instance of ListCustomBiddingScriptsResponse.
10733 10734 10735 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10733 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_bidding_scripts ⇒ Array<Google::Apis::DisplayvideoV4::CustomBiddingScript>
The list of custom bidding scripts. This list will be absent if empty.
Corresponds to the JSON property customBiddingScripts
10723 10724 10725 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10723 def custom_bidding_scripts @custom_bidding_scripts end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListCustomBiddingScriptsRequest
method to retrieve the next page of results. If this field is null, it means
this is the last page.
Corresponds to the JSON property nextPageToken
10731 10732 10733 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10731 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10738 10739 10740 10741 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10738 def update!(**args) @custom_bidding_scripts = args[:custom_bidding_scripts] if args.key?(:custom_bidding_scripts) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |