Class: Google::Apis::DisplayvideoV4::ListFirstPartyAndPartnerAudiencesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListFirstPartyAndPartnerAudiencesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#first_party_and_partner_audiences ⇒ Array<Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudience>
The list of first party and partner audiences.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFirstPartyAndPartnerAudiencesResponse
constructor
A new instance of ListFirstPartyAndPartnerAudiencesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFirstPartyAndPartnerAudiencesResponse
Returns a new instance of ListFirstPartyAndPartnerAudiencesResponse.
10774 10775 10776 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10774 def initialize(**args) update!(**args) end |
Instance Attribute Details
#first_party_and_partner_audiences ⇒ Array<Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudience>
The list of first party and partner audiences. Audience size properties will
not be included. This list will be absent if empty.
Corresponds to the JSON property firstPartyAndPartnerAudiences
10765 10766 10767 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10765 def first_party_and_partner_audiences @first_party_and_partner_audiences end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListFirstPartyAndPartnerAudiences
method to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
10772 10773 10774 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10772 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10779 10780 10781 10782 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10779 def update!(**args) @first_party_and_partner_audiences = args[:first_party_and_partner_audiences] if args.key?(:first_party_and_partner_audiences) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |