Class: Google::Apis::DisplayvideoV4::ListFirstPartyAndPartnerAudiencesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListFirstPartyAndPartnerAudiencesResponse

Returns a new instance of ListFirstPartyAndPartnerAudiencesResponse.



10554
10555
10556
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10554

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#first_party_and_partner_audiencesArray<Google::Apis::DisplayvideoV4::FirstPartyAndPartnerAudience>

The list of first party and partner audiences. Audience size properties will not be included. This list will be absent if empty. Corresponds to the JSON property firstPartyAndPartnerAudiences



10545
10546
10547
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10545

def first_party_and_partner_audiences
  @first_party_and_partner_audiences
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListFirstPartyAndPartnerAudiences method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10552
10553
10554
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10552

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10559
10560
10561
10562
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10559

def update!(**args)
  @first_party_and_partner_audiences = args[:first_party_and_partner_audiences] if args.key?(:first_party_and_partner_audiences)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end