Class: Google::Apis::DisplayvideoV4::ListInvoicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListInvoicesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#invoices ⇒ Array<Google::Apis::DisplayvideoV4::Invoice>
The list of invoices.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInvoicesResponse
constructor
A new instance of ListInvoicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInvoicesResponse
Returns a new instance of ListInvoicesResponse.
10964 10965 10966 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10964 def initialize(**args) update!(**args) end |
Instance Attribute Details
#invoices ⇒ Array<Google::Apis::DisplayvideoV4::Invoice>
The list of invoices. This list will be absent if empty.
Corresponds to the JSON property invoices
10954 10955 10956 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10954 def invoices @invoices end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListInvoices method to retrieve
the next page of results. This token will be absent if there are no more
invoices to return.
Corresponds to the JSON property nextPageToken
10962 10963 10964 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10962 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10969 10970 10971 10972 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10969 def update!(**args) @invoices = args[:invoices] if args.key?(:invoices) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |