Class: Google::Apis::DisplayvideoV4::ListInvoicesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInvoicesResponse

Returns a new instance of ListInvoicesResponse.



10947
10948
10949
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10947

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#invoicesArray<Google::Apis::DisplayvideoV4::Invoice>

The list of invoices. This list will be absent if empty. Corresponds to the JSON property invoices



10937
10938
10939
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10937

def invoices
  @invoices
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListInvoices method to retrieve the next page of results. This token will be absent if there are no more invoices to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10945
10946
10947
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10945

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10952
10953
10954
10955
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10952

def update!(**args)
  @invoices = args[:invoices] if args.key?(:invoices)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end