Class: Google::Apis::DisplayvideoV4::ListLocationListsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListLocationListsResponse

Returns a new instance of ListLocationListsResponse.



10826
10827
10828
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10826

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#location_listsArray<Google::Apis::DisplayvideoV4::LocationList>

The list of location lists. This list will be absent if empty. Corresponds to the JSON property locationLists



10817
10818
10819
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10817

def location_lists
  @location_lists
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListLocationLists method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10824
10825
10826
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10824

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10831
10832
10833
10834
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 10831

def update!(**args)
  @location_lists = args[:location_lists] if args.key?(:location_lists)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end