Class: Google::Apis::DisplayvideoV4::ListUsersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListUsersResponse

Returns a new instance of ListUsersResponse.



11250
11251
11252
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListUsers method to retrieve the next page of results. This token will be absent if there are no more results to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11243
11244
11245
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11243

def next_page_token
  @next_page_token
end

#usersArray<Google::Apis::DisplayvideoV4::User>

The list of users. This list will be absent if empty. Corresponds to the JSON property users



11248
11249
11250
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11248

def users
  @users
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11255
11256
11257
11258
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11255

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @users = args[:users] if args.key?(:users)
end