Class: Google::Apis::DisplayvideoV4::ListUsersResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListUsersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#users ⇒ Array<Google::Apis::DisplayvideoV4::User>
The list of users.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUsersResponse
constructor
A new instance of ListUsersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUsersResponse
Returns a new instance of ListUsersResponse.
11017 11018 11019 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListUsers method to retrieve the
next page of results. This token will be absent if there are no more results
to return.
Corresponds to the JSON property nextPageToken
11010 11011 11012 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11010 def next_page_token @next_page_token end |
#users ⇒ Array<Google::Apis::DisplayvideoV4::User>
The list of users. This list will be absent if empty.
Corresponds to the JSON property users
11015 11016 11017 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11015 def users @users end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11022 11023 11024 11025 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11022 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @users = args[:users] if args.key?(:users) end |