Class: Google::Apis::DisplayvideoV4::ListYoutubeAssetAssociationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ListYoutubeAssetAssociationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Response message for YoutubeAssetAssociationService. ListYoutubeAssetAssociations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#youtube_asset_associations ⇒ Array<Google::Apis::DisplayvideoV4::YoutubeAssetAssociation>
The list of asset associations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListYoutubeAssetAssociationsResponse
constructor
A new instance of ListYoutubeAssetAssociationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListYoutubeAssetAssociationsResponse
Returns a new instance of ListYoutubeAssetAssociationsResponse.
11045 11046 11047 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListYoutubeAssetAssociations
method to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
11038 11039 11040 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11038 def next_page_token @next_page_token end |
#youtube_asset_associations ⇒ Array<Google::Apis::DisplayvideoV4::YoutubeAssetAssociation>
The list of asset associations. This list will be absent if empty.
Corresponds to the JSON property youtubeAssetAssociations
11043 11044 11045 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11043 def youtube_asset_associations @youtube_asset_associations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11050 11051 11052 11053 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11050 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @youtube_asset_associations = args[:youtube_asset_associations] if args.key?(:youtube_asset_associations) end |