Class: Google::Apis::DisplayvideoV4::MastheadAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::MastheadAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details for a Masthead Ad.
Instance Attribute Summary collapse
-
#autoplay_video_duration ⇒ String
The duration of time the video will autoplay.
-
#autoplay_video_start_millisecond ⇒ Fixnum
The amount of time in milliseconds after which the video will start to play.
-
#call_to_action_button_label ⇒ String
The text on the call-to-action button.
-
#call_to_action_final_url ⇒ String
The destination URL for the call-to-action button.
-
#call_to_action_tracking_url ⇒ String
The tracking URL for the call-to-action button.
-
#companion_youtube_videos ⇒ Array<Google::Apis::DisplayvideoV4::YoutubeVideoDetails>
The videos that appear next to the Masthead Ad on desktop.
-
#description ⇒ String
The description of the ad.
-
#headline ⇒ String
The headline of the ad.
-
#show_channel_art ⇒ Boolean
(also: #show_channel_art?)
Whether to show a background or banner that appears at the top of a YouTube page.
-
#video ⇒ Google::Apis::DisplayvideoV4::YoutubeVideoDetails
Details of a YouTube video.
-
#video_aspect_ratio ⇒ String
The aspect ratio of the autoplaying YouTube video on the Masthead.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MastheadAd
constructor
A new instance of MastheadAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MastheadAd
Returns a new instance of MastheadAd.
11431 11432 11433 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11431 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoplay_video_duration ⇒ String
The duration of time the video will autoplay.
Corresponds to the JSON property autoplayVideoDuration
11376 11377 11378 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11376 def autoplay_video_duration @autoplay_video_duration end |
#autoplay_video_start_millisecond ⇒ Fixnum
The amount of time in milliseconds after which the video will start to play.
Corresponds to the JSON property autoplayVideoStartMillisecond
11381 11382 11383 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11381 def autoplay_video_start_millisecond @autoplay_video_start_millisecond end |
#call_to_action_button_label ⇒ String
The text on the call-to-action button.
Corresponds to the JSON property callToActionButtonLabel
11386 11387 11388 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11386 def @call_to_action_button_label end |
#call_to_action_final_url ⇒ String
The destination URL for the call-to-action button.
Corresponds to the JSON property callToActionFinalUrl
11391 11392 11393 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11391 def call_to_action_final_url @call_to_action_final_url end |
#call_to_action_tracking_url ⇒ String
The tracking URL for the call-to-action button.
Corresponds to the JSON property callToActionTrackingUrl
11396 11397 11398 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11396 def call_to_action_tracking_url @call_to_action_tracking_url end |
#companion_youtube_videos ⇒ Array<Google::Apis::DisplayvideoV4::YoutubeVideoDetails>
The videos that appear next to the Masthead Ad on desktop. Can be no more than
two.
Corresponds to the JSON property companionYoutubeVideos
11402 11403 11404 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11402 def companion_youtube_videos @companion_youtube_videos end |
#description ⇒ String
The description of the ad.
Corresponds to the JSON property description
11407 11408 11409 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11407 def description @description end |
#headline ⇒ String
The headline of the ad.
Corresponds to the JSON property headline
11412 11413 11414 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11412 def headline @headline end |
#show_channel_art ⇒ Boolean Also known as: show_channel_art?
Whether to show a background or banner that appears at the top of a YouTube
page.
Corresponds to the JSON property showChannelArt
11418 11419 11420 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11418 def show_channel_art @show_channel_art end |
#video ⇒ Google::Apis::DisplayvideoV4::YoutubeVideoDetails
Details of a YouTube video.
Corresponds to the JSON property video
11424 11425 11426 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11424 def video @video end |
#video_aspect_ratio ⇒ String
The aspect ratio of the autoplaying YouTube video on the Masthead.
Corresponds to the JSON property videoAspectRatio
11429 11430 11431 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11429 def video_aspect_ratio @video_aspect_ratio end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11436 11437 11438 11439 11440 11441 11442 11443 11444 11445 11446 11447 11448 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11436 def update!(**args) @autoplay_video_duration = args[:autoplay_video_duration] if args.key?(:autoplay_video_duration) @autoplay_video_start_millisecond = args[:autoplay_video_start_millisecond] if args.key?(:autoplay_video_start_millisecond) @call_to_action_button_label = args[:call_to_action_button_label] if args.key?(:call_to_action_button_label) @call_to_action_final_url = args[:call_to_action_final_url] if args.key?(:call_to_action_final_url) @call_to_action_tracking_url = args[:call_to_action_tracking_url] if args.key?(:call_to_action_tracking_url) @companion_youtube_videos = args[:companion_youtube_videos] if args.key?(:companion_youtube_videos) @description = args[:description] if args.key?(:description) @headline = args[:headline] if args.key?(:headline) @show_channel_art = args[:show_channel_art] if args.key?(:show_channel_art) @video = args[:video] if args.key?(:video) @video_aspect_ratio = args[:video_aspect_ratio] if args.key?(:video_aspect_ratio) end |