Class: Google::Apis::DisplayvideoV4::MastheadAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Masthead Ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MastheadAd

Returns a new instance of MastheadAd.



11220
11221
11222
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11220

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoplay_video_durationString

The duration of time the video will autoplay. Corresponds to the JSON property autoplayVideoDuration

Returns:

  • (String)


11165
11166
11167
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11165

def autoplay_video_duration
  @autoplay_video_duration
end

#autoplay_video_start_millisecondFixnum

The amount of time in milliseconds after which the video will start to play. Corresponds to the JSON property autoplayVideoStartMillisecond

Returns:

  • (Fixnum)


11170
11171
11172
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11170

def autoplay_video_start_millisecond
  @autoplay_video_start_millisecond
end

#call_to_action_button_labelString

The text on the call-to-action button. Corresponds to the JSON property callToActionButtonLabel

Returns:

  • (String)


11175
11176
11177
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11175

def call_to_action_button_label
  @call_to_action_button_label
end

#call_to_action_final_urlString

The destination URL for the call-to-action button. Corresponds to the JSON property callToActionFinalUrl

Returns:

  • (String)


11180
11181
11182
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11180

def call_to_action_final_url
  @call_to_action_final_url
end

#call_to_action_tracking_urlString

The tracking URL for the call-to-action button. Corresponds to the JSON property callToActionTrackingUrl

Returns:

  • (String)


11185
11186
11187
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11185

def call_to_action_tracking_url
  @call_to_action_tracking_url
end

#companion_youtube_videosArray<Google::Apis::DisplayvideoV4::YoutubeVideoDetails>

The videos that appear next to the Masthead Ad on desktop. Can be no more than two. Corresponds to the JSON property companionYoutubeVideos



11191
11192
11193
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11191

def companion_youtube_videos
  @companion_youtube_videos
end

#descriptionString

The description of the ad. Corresponds to the JSON property description

Returns:

  • (String)


11196
11197
11198
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11196

def description
  @description
end

#headlineString

The headline of the ad. Corresponds to the JSON property headline

Returns:

  • (String)


11201
11202
11203
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11201

def headline
  @headline
end

#show_channel_artBoolean Also known as: show_channel_art?

Whether to show a background or banner that appears at the top of a YouTube page. Corresponds to the JSON property showChannelArt

Returns:

  • (Boolean)


11207
11208
11209
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11207

def show_channel_art
  @show_channel_art
end

#videoGoogle::Apis::DisplayvideoV4::YoutubeVideoDetails

Details of a YouTube video. Corresponds to the JSON property video



11213
11214
11215
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11213

def video
  @video
end

#video_aspect_ratioString

The aspect ratio of the autoplaying YouTube video on the Masthead. Corresponds to the JSON property videoAspectRatio

Returns:

  • (String)


11218
11219
11220
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11218

def video_aspect_ratio
  @video_aspect_ratio
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11225
11226
11227
11228
11229
11230
11231
11232
11233
11234
11235
11236
11237
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11225

def update!(**args)
  @autoplay_video_duration = args[:autoplay_video_duration] if args.key?(:autoplay_video_duration)
  @autoplay_video_start_millisecond = args[:autoplay_video_start_millisecond] if args.key?(:autoplay_video_start_millisecond)
  @call_to_action_button_label = args[:call_to_action_button_label] if args.key?(:call_to_action_button_label)
  @call_to_action_final_url = args[:call_to_action_final_url] if args.key?(:call_to_action_final_url)
  @call_to_action_tracking_url = args[:call_to_action_tracking_url] if args.key?(:call_to_action_tracking_url)
  @companion_youtube_videos = args[:companion_youtube_videos] if args.key?(:companion_youtube_videos)
  @description = args[:description] if args.key?(:description)
  @headline = args[:headline] if args.key?(:headline)
  @show_channel_art = args[:show_channel_art] if args.key?(:show_channel_art)
  @video = args[:video] if args.key?(:video)
  @video_aspect_ratio = args[:video_aspect_ratio] if args.key?(:video_aspect_ratio)
end