Class: Google::Apis::DisplayvideoV4::MastheadAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a Masthead Ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MastheadAd

Returns a new instance of MastheadAd.



11211
11212
11213
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoplay_video_durationString

The duration of time the video will autoplay. Corresponds to the JSON property autoplayVideoDuration

Returns:

  • (String)


11156
11157
11158
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11156

def autoplay_video_duration
  @autoplay_video_duration
end

#autoplay_video_start_millisecondFixnum

The amount of time in milliseconds after which the video will start to play. Corresponds to the JSON property autoplayVideoStartMillisecond

Returns:

  • (Fixnum)


11161
11162
11163
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11161

def autoplay_video_start_millisecond
  @autoplay_video_start_millisecond
end

#call_to_action_button_labelString

The text on the call-to-action button. Corresponds to the JSON property callToActionButtonLabel

Returns:

  • (String)


11166
11167
11168
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11166

def call_to_action_button_label
  @call_to_action_button_label
end

#call_to_action_final_urlString

The destination URL for the call-to-action button. Corresponds to the JSON property callToActionFinalUrl

Returns:

  • (String)


11171
11172
11173
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11171

def call_to_action_final_url
  @call_to_action_final_url
end

#call_to_action_tracking_urlString

The tracking URL for the call-to-action button. Corresponds to the JSON property callToActionTrackingUrl

Returns:

  • (String)


11176
11177
11178
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11176

def call_to_action_tracking_url
  @call_to_action_tracking_url
end

#companion_youtube_videosArray<Google::Apis::DisplayvideoV4::YoutubeVideoDetails>

The videos that appear next to the Masthead Ad on desktop. Can be no more than two. Corresponds to the JSON property companionYoutubeVideos



11182
11183
11184
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11182

def companion_youtube_videos
  @companion_youtube_videos
end

#descriptionString

The description of the ad. Corresponds to the JSON property description

Returns:

  • (String)


11187
11188
11189
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11187

def description
  @description
end

#headlineString

The headline of the ad. Corresponds to the JSON property headline

Returns:

  • (String)


11192
11193
11194
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11192

def headline
  @headline
end

#show_channel_artBoolean Also known as: show_channel_art?

Whether to show a background or banner that appears at the top of a YouTube page. Corresponds to the JSON property showChannelArt

Returns:

  • (Boolean)


11198
11199
11200
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11198

def show_channel_art
  @show_channel_art
end

#videoGoogle::Apis::DisplayvideoV4::YoutubeVideoDetails

Details of a YouTube video. Corresponds to the JSON property video



11204
11205
11206
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11204

def video
  @video
end

#video_aspect_ratioString

The aspect ratio of the autoplaying YouTube video on the Masthead. Corresponds to the JSON property videoAspectRatio

Returns:

  • (String)


11209
11210
11211
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11209

def video_aspect_ratio
  @video_aspect_ratio
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11216
11217
11218
11219
11220
11221
11222
11223
11224
11225
11226
11227
11228
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11216

def update!(**args)
  @autoplay_video_duration = args[:autoplay_video_duration] if args.key?(:autoplay_video_duration)
  @autoplay_video_start_millisecond = args[:autoplay_video_start_millisecond] if args.key?(:autoplay_video_start_millisecond)
  @call_to_action_button_label = args[:call_to_action_button_label] if args.key?(:call_to_action_button_label)
  @call_to_action_final_url = args[:call_to_action_final_url] if args.key?(:call_to_action_final_url)
  @call_to_action_tracking_url = args[:call_to_action_tracking_url] if args.key?(:call_to_action_tracking_url)
  @companion_youtube_videos = args[:companion_youtube_videos] if args.key?(:companion_youtube_videos)
  @description = args[:description] if args.key?(:description)
  @headline = args[:headline] if args.key?(:headline)
  @show_channel_art = args[:show_channel_art] if args.key?(:show_channel_art)
  @video = args[:video] if args.key?(:video)
  @video_aspect_ratio = args[:video_aspect_ratio] if args.key?(:video_aspect_ratio)
end