Class: Google::Apis::DisplayvideoV4::MobileApp
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::MobileApp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A mobile app promoted by a mobile app install line item.
Instance Attribute Summary collapse
-
#app_id ⇒ String
Required.
-
#display_name ⇒ String
Output only.
-
#platform ⇒ String
Output only.
-
#publisher ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MobileApp
constructor
A new instance of MobileApp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MobileApp
Returns a new instance of MobileApp.
11536 11537 11538 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11536 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_id ⇒ String
Required. The ID of the app provided by the platform store. Android apps are
identified by the bundle ID used by Android's Play store, such as com.google.
android.gm. iOS apps are identified by a nine-digit app ID used by Apple's
App store, such as 422689480.
Corresponds to the JSON property appId
11519 11520 11521 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11519 def app_id @app_id end |
#display_name ⇒ String
Output only. The app name.
Corresponds to the JSON property displayName
11524 11525 11526 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11524 def display_name @display_name end |
#platform ⇒ String
Output only. The app platform.
Corresponds to the JSON property platform
11529 11530 11531 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11529 def platform @platform end |
#publisher ⇒ String
Output only. The app publisher.
Corresponds to the JSON property publisher
11534 11535 11536 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11534 def publisher @publisher end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11541 11542 11543 11544 11545 11546 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11541 def update!(**args) @app_id = args[:app_id] if args.key?(:app_id) @display_name = args[:display_name] if args.key?(:display_name) @platform = args[:platform] if args.key?(:platform) @publisher = args[:publisher] if args.key?(:publisher) end |