Class: Google::Apis::DisplayvideoV4::MobileApp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A mobile app promoted by a mobile app install line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MobileApp

Returns a new instance of MobileApp.



11333
11334
11335
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

Required. The ID of the app provided by the platform store. Android apps are identified by the bundle ID used by Android's Play store, such as com.google. android.gm. iOS apps are identified by a nine-digit app ID used by Apple's App store, such as 422689480. Corresponds to the JSON property appId

Returns:

  • (String)


11316
11317
11318
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11316

def app_id
  @app_id
end

#display_nameString

Output only. The app name. Corresponds to the JSON property displayName

Returns:

  • (String)


11321
11322
11323
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11321

def display_name
  @display_name
end

#platformString

Output only. The app platform. Corresponds to the JSON property platform

Returns:

  • (String)


11326
11327
11328
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11326

def platform
  @platform
end

#publisherString

Output only. The app publisher. Corresponds to the JSON property publisher

Returns:

  • (String)


11331
11332
11333
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11331

def publisher
  @publisher
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11338
11339
11340
11341
11342
11343
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11338

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @platform = args[:platform] if args.key?(:platform)
  @publisher = args[:publisher] if args.key?(:publisher)
end