Class: Google::Apis::DisplayvideoV4::NegativeKeywordList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A list of negative keywords used for targeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NegativeKeywordList

Returns a new instance of NegativeKeywordList.



11719
11720
11721
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The unique ID of the advertiser the negative keyword list belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


11694
11695
11696
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11694

def advertiser_id
  @advertiser_id
end

#display_nameString

Required. The display name of the negative keyword list. Must be UTF-8 encoded with a maximum size of 255 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


11700
11701
11702
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11700

def display_name
  @display_name
end

#nameString

Output only. The resource name of the negative keyword list. Corresponds to the JSON property name

Returns:

  • (String)


11705
11706
11707
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11705

def name
  @name
end

#negative_keyword_list_idFixnum

Output only. The unique ID of the negative keyword list. Assigned by the system. Corresponds to the JSON property negativeKeywordListId

Returns:

  • (Fixnum)


11711
11712
11713
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11711

def negative_keyword_list_id
  @negative_keyword_list_id
end

#targeted_line_item_countFixnum

Output only. Number of line items that are directly targeting this negative keyword list. Corresponds to the JSON property targetedLineItemCount

Returns:

  • (Fixnum)


11717
11718
11719
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11717

def targeted_line_item_count
  @targeted_line_item_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11724
11725
11726
11727
11728
11729
11730
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11724

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @negative_keyword_list_id = args[:negative_keyword_list_id] if args.key?(:negative_keyword_list_id)
  @targeted_line_item_count = args[:targeted_line_item_count] if args.key?(:targeted_line_item_count)
end