Class: Google::Apis::DisplayvideoV4::NonSkippableAd
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::NonSkippableAd
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Details for a non-skippable ad.
Instance Attribute Summary collapse
-
#common_in_stream_attribute ⇒ Google::Apis::DisplayvideoV4::CommonInStreamAttribute
Common attributes for in-stream, non-skippable and bumper ads.
-
#custom_parameters ⇒ Hash<String,String>
The custom parameters and accompanying values to add to the tracking URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NonSkippableAd
constructor
A new instance of NonSkippableAd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NonSkippableAd
Returns a new instance of NonSkippableAd.
11566 11567 11568 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11566 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common_in_stream_attribute ⇒ Google::Apis::DisplayvideoV4::CommonInStreamAttribute
Common attributes for in-stream, non-skippable and bumper ads.
Corresponds to the JSON property commonInStreamAttribute
11559 11560 11561 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11559 def common_in_stream_attribute @common_in_stream_attribute end |
#custom_parameters ⇒ Hash<String,String>
The custom parameters and accompanying values to add to the tracking URL.
Corresponds to the JSON property customParameters
11564 11565 11566 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11564 def custom_parameters @custom_parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11571 11572 11573 11574 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11571 def update!(**args) @common_in_stream_attribute = args[:common_in_stream_attribute] if args.key?(:common_in_stream_attribute) @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters) end |