Class: Google::Apis::DisplayvideoV4::Pacing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Settings that control the rate at which a budget is spent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Pacing

Returns a new instance of Pacing.



11910
11911
11912
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#daily_max_impressionsFixnum

Maximum number of impressions to serve every day. Applicable when the budget is impression based. Must be greater than 0. Corresponds to the JSON property dailyMaxImpressions

Returns:

  • (Fixnum)


11879
11880
11881
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11879

def daily_max_impressions
  @daily_max_impressions
end

#daily_max_microsFixnum

Maximum currency amount to spend every day in micros of advertiser's currency. Applicable when the budget is currency based. Must be greater than 0. For example, for 1.5 standard unit of the currency, set this field to 1500000. The value assigned will be rounded to whole billable units for the relevant currency by the following rules: any positive value less than a single billable unit will be rounded up to one billable unit and any value larger than a single billable unit will be rounded down to the nearest billable value. For example, if the currency's billable unit is 0.01, and this field is set to 10257770, it will round down to 10250000, a value of 10.25. If set to 505, it will round up to 10000, a value of 0.01. Corresponds to the JSON property dailyMaxMicros

Returns:

  • (Fixnum)


11893
11894
11895
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11893

def daily_max_micros
  @daily_max_micros
end

#pacing_periodString

Required. The time period in which the pacing budget will be spent. When automatic budget allocation is enabled at the insertion order via automationType, this field is output only and defaults to PACING_PERIOD_FLIGHT. Corresponds to the JSON property pacingPeriod

Returns:

  • (String)


11901
11902
11903
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11901

def pacing_period
  @pacing_period
end

#pacing_typeString

Required. The type of pacing that defines how the budget amount will be spent across the pacing_period. PACING_TYPE_ASAP is not compatible with pacing_period PACING_PERIOD_FLIGHT for insertion orders. Corresponds to the JSON property pacingType

Returns:

  • (String)


11908
11909
11910
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11908

def pacing_type
  @pacing_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11915
11916
11917
11918
11919
11920
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11915

def update!(**args)
  @daily_max_impressions = args[:daily_max_impressions] if args.key?(:daily_max_impressions)
  @daily_max_micros = args[:daily_max_micros] if args.key?(:daily_max_micros)
  @pacing_period = args[:pacing_period] if args.key?(:pacing_period)
  @pacing_type = args[:pacing_type] if args.key?(:pacing_type)
end