Class: Google::Apis::DisplayvideoV4::Partner
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::Partner
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single partner in Display & Video 360 (DV360).
Instance Attribute Summary collapse
-
#ad_server_config ⇒ Google::Apis::DisplayvideoV4::PartnerAdServerConfig
Ad server related settings of a partner.
-
#billing_config ⇒ Google::Apis::DisplayvideoV4::PartnerBillingConfig
Billing related settings of a partner.
-
#data_access_config ⇒ Google::Apis::DisplayvideoV4::PartnerDataAccessConfig
Settings that control how partner related data may be accessed.
-
#display_name ⇒ String
The display name of the partner.
-
#entity_status ⇒ String
Output only.
-
#exchange_config ⇒ Google::Apis::DisplayvideoV4::ExchangeConfig
Settings that control which exchanges are enabled for a partner.
-
#general_config ⇒ Google::Apis::DisplayvideoV4::PartnerGeneralConfig
General settings of a partner.
-
#name ⇒ String
Output only.
-
#partner_id ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Partner
constructor
A new instance of Partner.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Partner
Returns a new instance of Partner.
12054 12055 12056 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_server_config ⇒ Google::Apis::DisplayvideoV4::PartnerAdServerConfig
Ad server related settings of a partner.
Corresponds to the JSON property adServerConfig
12005 12006 12007 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12005 def ad_server_config @ad_server_config end |
#billing_config ⇒ Google::Apis::DisplayvideoV4::PartnerBillingConfig
Billing related settings of a partner.
Corresponds to the JSON property billingConfig
12010 12011 12012 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12010 def billing_config @billing_config end |
#data_access_config ⇒ Google::Apis::DisplayvideoV4::PartnerDataAccessConfig
Settings that control how partner related data may be accessed.
Corresponds to the JSON property dataAccessConfig
12015 12016 12017 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12015 def data_access_config @data_access_config end |
#display_name ⇒ String
The display name of the partner. Must be UTF-8 encoded with a maximum size of
240 bytes.
Corresponds to the JSON property displayName
12021 12022 12023 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12021 def display_name @display_name end |
#entity_status ⇒ String
Output only. The status of the partner.
Corresponds to the JSON property entityStatus
12026 12027 12028 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12026 def entity_status @entity_status end |
#exchange_config ⇒ Google::Apis::DisplayvideoV4::ExchangeConfig
Settings that control which exchanges are enabled for a partner.
Corresponds to the JSON property exchangeConfig
12031 12032 12033 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12031 def exchange_config @exchange_config end |
#general_config ⇒ Google::Apis::DisplayvideoV4::PartnerGeneralConfig
General settings of a partner.
Corresponds to the JSON property generalConfig
12036 12037 12038 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12036 def general_config @general_config end |
#name ⇒ String
Output only. The resource name of the partner.
Corresponds to the JSON property name
12041 12042 12043 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12041 def name @name end |
#partner_id ⇒ Fixnum
Output only. The unique ID of the partner. Assigned by the system.
Corresponds to the JSON property partnerId
12046 12047 12048 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12046 def partner_id @partner_id end |
#update_time ⇒ String
Output only. The timestamp when the partner was last updated. Assigned by the
system.
Corresponds to the JSON property updateTime
12052 12053 12054 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12052 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12059 12060 12061 12062 12063 12064 12065 12066 12067 12068 12069 12070 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12059 def update!(**args) @ad_server_config = args[:ad_server_config] if args.key?(:ad_server_config) @billing_config = args[:billing_config] if args.key?(:billing_config) @data_access_config = args[:data_access_config] if args.key?(:data_access_config) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @exchange_config = args[:exchange_config] if args.key?(:exchange_config) @general_config = args[:general_config] if args.key?(:general_config) @name = args[:name] if args.key?(:name) @partner_id = args[:partner_id] if args.key?(:partner_id) @update_time = args[:update_time] if args.key?(:update_time) end |