Class: Google::Apis::DisplayvideoV4::Partner
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::Partner
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A single partner in Display & Video 360 (DV360).
Instance Attribute Summary collapse
-
#ad_server_config ⇒ Google::Apis::DisplayvideoV4::PartnerAdServerConfig
Ad server related settings of a partner.
-
#billing_config ⇒ Google::Apis::DisplayvideoV4::PartnerBillingConfig
Billing related settings of a partner.
-
#data_access_config ⇒ Google::Apis::DisplayvideoV4::PartnerDataAccessConfig
Settings that control how partner related data may be accessed.
-
#display_name ⇒ String
The display name of the partner.
-
#entity_status ⇒ String
Output only.
-
#exchange_config ⇒ Google::Apis::DisplayvideoV4::ExchangeConfig
Settings that control which exchanges are enabled for a partner.
-
#general_config ⇒ Google::Apis::DisplayvideoV4::PartnerGeneralConfig
General settings of a partner.
-
#name ⇒ String
Output only.
-
#partner_id ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Partner
constructor
A new instance of Partner.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Partner
Returns a new instance of Partner.
12045 12046 12047 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_server_config ⇒ Google::Apis::DisplayvideoV4::PartnerAdServerConfig
Ad server related settings of a partner.
Corresponds to the JSON property adServerConfig
11996 11997 11998 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 11996 def ad_server_config @ad_server_config end |
#billing_config ⇒ Google::Apis::DisplayvideoV4::PartnerBillingConfig
Billing related settings of a partner.
Corresponds to the JSON property billingConfig
12001 12002 12003 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12001 def billing_config @billing_config end |
#data_access_config ⇒ Google::Apis::DisplayvideoV4::PartnerDataAccessConfig
Settings that control how partner related data may be accessed.
Corresponds to the JSON property dataAccessConfig
12006 12007 12008 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12006 def data_access_config @data_access_config end |
#display_name ⇒ String
The display name of the partner. Must be UTF-8 encoded with a maximum size of
240 bytes.
Corresponds to the JSON property displayName
12012 12013 12014 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12012 def display_name @display_name end |
#entity_status ⇒ String
Output only. The status of the partner.
Corresponds to the JSON property entityStatus
12017 12018 12019 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12017 def entity_status @entity_status end |
#exchange_config ⇒ Google::Apis::DisplayvideoV4::ExchangeConfig
Settings that control which exchanges are enabled for a partner.
Corresponds to the JSON property exchangeConfig
12022 12023 12024 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12022 def exchange_config @exchange_config end |
#general_config ⇒ Google::Apis::DisplayvideoV4::PartnerGeneralConfig
General settings of a partner.
Corresponds to the JSON property generalConfig
12027 12028 12029 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12027 def general_config @general_config end |
#name ⇒ String
Output only. The resource name of the partner.
Corresponds to the JSON property name
12032 12033 12034 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12032 def name @name end |
#partner_id ⇒ Fixnum
Output only. The unique ID of the partner. Assigned by the system.
Corresponds to the JSON property partnerId
12037 12038 12039 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12037 def partner_id @partner_id end |
#update_time ⇒ String
Output only. The timestamp when the partner was last updated. Assigned by the
system.
Corresponds to the JSON property updateTime
12043 12044 12045 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12043 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12050 12051 12052 12053 12054 12055 12056 12057 12058 12059 12060 12061 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12050 def update!(**args) @ad_server_config = args[:ad_server_config] if args.key?(:ad_server_config) @billing_config = args[:billing_config] if args.key?(:billing_config) @data_access_config = args[:data_access_config] if args.key?(:data_access_config) @display_name = args[:display_name] if args.key?(:display_name) @entity_status = args[:entity_status] if args.key?(:entity_status) @exchange_config = args[:exchange_config] if args.key?(:exchange_config) @general_config = args[:general_config] if args.key?(:general_config) @name = args[:name] if args.key?(:name) @partner_id = args[:partner_id] if args.key?(:partner_id) @update_time = args[:update_time] if args.key?(:update_time) end |