Class: Google::Apis::DisplayvideoV4::PlannableLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A plannable location used for forecasting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlannableLocation

Returns a new instance of PlannableLocation.



12649
12650
12651
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12649

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the location, for example "Algeria". Corresponds to the JSON property displayName

Returns:

  • (String)


12621
12622
12623
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12621

def display_name
  @display_name
end

#geo_region_typeString

Output only. The type of location. Corresponds to the JSON property geoRegionType

Returns:

  • (String)


12626
12627
12628
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12626

def geo_region_type
  @geo_region_type
end

#nameString

Output only. The resource name of the plannable location. Corresponds to the JSON property name

Returns:

  • (String)


12631
12632
12633
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12631

def name
  @name
end

#parent_plannable_location_idFixnum

Output only. The parent plannable location ID, for example the country ID for subgeos. Corresponds to the JSON property parentPlannableLocationId

Returns:

  • (Fixnum)


12637
12638
12639
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12637

def parent_plannable_location_id
  @parent_plannable_location_id
end

#plannable_location_idFixnum

Output only. The plannable location ID. Corresponds to the JSON property plannableLocationId

Returns:

  • (Fixnum)


12642
12643
12644
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12642

def plannable_location_id
  @plannable_location_id
end

#region_codeString

Output only. The region code of the location, for example "DZ" for Algeria. Corresponds to the JSON property regionCode

Returns:

  • (String)


12647
12648
12649
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12647

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12654
12655
12656
12657
12658
12659
12660
12661
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12654

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @geo_region_type = args[:geo_region_type] if args.key?(:geo_region_type)
  @name = args[:name] if args.key?(:name)
  @parent_plannable_location_id = args[:parent_plannable_location_id] if args.key?(:parent_plannable_location_id)
  @plannable_location_id = args[:plannable_location_id] if args.key?(:plannable_location_id)
  @region_code = args[:region_code] if args.key?(:region_code)
end