Class: Google::Apis::DisplayvideoV4::PlannableLocation
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::PlannableLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A plannable location used for forecasting.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#geo_region_type ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#parent_plannable_location_id ⇒ Fixnum
Output only.
-
#plannable_location_id ⇒ Fixnum
Output only.
-
#region_code ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlannableLocation
constructor
A new instance of PlannableLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlannableLocation
Returns a new instance of PlannableLocation.
12636 12637 12638 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. The display name of the location, for example "Algeria".
Corresponds to the JSON property displayName
12608 12609 12610 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12608 def display_name @display_name end |
#geo_region_type ⇒ String
Output only. The type of location.
Corresponds to the JSON property geoRegionType
12613 12614 12615 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12613 def geo_region_type @geo_region_type end |
#name ⇒ String
Output only. The resource name of the plannable location.
Corresponds to the JSON property name
12618 12619 12620 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12618 def name @name end |
#parent_plannable_location_id ⇒ Fixnum
Output only. The parent plannable location ID, for example the country ID for
subgeos.
Corresponds to the JSON property parentPlannableLocationId
12624 12625 12626 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12624 def parent_plannable_location_id @parent_plannable_location_id end |
#plannable_location_id ⇒ Fixnum
Output only. The plannable location ID.
Corresponds to the JSON property plannableLocationId
12629 12630 12631 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12629 def plannable_location_id @plannable_location_id end |
#region_code ⇒ String
Output only. The region code of the location, for example "DZ" for Algeria.
Corresponds to the JSON property regionCode
12634 12635 12636 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12634 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12641 12642 12643 12644 12645 12646 12647 12648 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12641 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @geo_region_type = args[:geo_region_type] if args.key?(:geo_region_type) @name = args[:name] if args.key?(:name) @parent_plannable_location_id = args[:parent_plannable_location_id] if args.key?(:parent_plannable_location_id) @plannable_location_id = args[:plannable_location_id] if args.key?(:plannable_location_id) @region_code = args[:region_code] if args.key?(:region_code) end |