Class: Google::Apis::DisplayvideoV4::PlannableLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A plannable location used for forecasting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlannableLocation

Returns a new instance of PlannableLocation.



12619
12620
12621
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of the location, for example "Algeria". Corresponds to the JSON property displayName

Returns:

  • (String)


12591
12592
12593
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12591

def display_name
  @display_name
end

#geo_region_typeString

Output only. The type of location. Corresponds to the JSON property geoRegionType

Returns:

  • (String)


12596
12597
12598
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12596

def geo_region_type
  @geo_region_type
end

#nameString

Output only. The resource name of the plannable location. Corresponds to the JSON property name

Returns:

  • (String)


12601
12602
12603
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12601

def name
  @name
end

#parent_plannable_location_idFixnum

Output only. The parent plannable location ID, for example the country ID for subgeos. Corresponds to the JSON property parentPlannableLocationId

Returns:

  • (Fixnum)


12607
12608
12609
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12607

def parent_plannable_location_id
  @parent_plannable_location_id
end

#plannable_location_idFixnum

Output only. The plannable location ID. Corresponds to the JSON property plannableLocationId

Returns:

  • (Fixnum)


12612
12613
12614
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12612

def plannable_location_id
  @plannable_location_id
end

#region_codeString

Output only. The region code of the location, for example "DZ" for Algeria. Corresponds to the JSON property regionCode

Returns:

  • (String)


12617
12618
12619
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12617

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12624
12625
12626
12627
12628
12629
12630
12631
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12624

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @geo_region_type = args[:geo_region_type] if args.key?(:geo_region_type)
  @name = args[:name] if args.key?(:name)
  @parent_plannable_location_id = args[:parent_plannable_location_id] if args.key?(:parent_plannable_location_id)
  @plannable_location_id = args[:plannable_location_id] if args.key?(:plannable_location_id)
  @region_code = args[:region_code] if args.key?(:region_code)
end