Class: Google::Apis::DisplayvideoV4::PlannedProductForecast
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::PlannedProductForecast
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Performance metrics for a forecast point.
Instance Attribute Summary collapse
-
#on_target_coview_impressions ⇒ Fixnum
Number of on-target impressions including co-viewers.
-
#on_target_coview_reach ⇒ Fixnum
Number of unique people reached that match the on-target definition including co-viewers.
-
#on_target_impressions ⇒ Fixnum
Number of on-target impressions.
-
#on_target_reach ⇒ Fixnum
Number of unique people reached that match the on-target definition.
-
#total_coview_impressions ⇒ Fixnum
Total number of impressions including co-viewers.
-
#total_coview_reach ⇒ Fixnum
Total number of unique people reached including co-viewers.
-
#total_impressions ⇒ Fixnum
Total number of impressions.
-
#total_reach ⇒ Fixnum
Total number of unique people reached.
-
#trueview_views ⇒ Fixnum
Number of TrueView views.
-
#viewable_impressions ⇒ Fixnum
Number of viewable impressions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlannedProductForecast
constructor
A new instance of PlannedProductForecast.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlannedProductForecast
Returns a new instance of PlannedProductForecast.
12914 12915 12916 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12914 def initialize(**args) update!(**args) end |
Instance Attribute Details
#on_target_coview_impressions ⇒ Fixnum
Number of on-target impressions including co-viewers.
Corresponds to the JSON property onTargetCoviewImpressions
12866 12867 12868 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12866 def on_target_coview_impressions @on_target_coview_impressions end |
#on_target_coview_reach ⇒ Fixnum
Number of unique people reached that match the on-target definition including
co-viewers.
Corresponds to the JSON property onTargetCoviewReach
12872 12873 12874 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12872 def on_target_coview_reach @on_target_coview_reach end |
#on_target_impressions ⇒ Fixnum
Number of on-target impressions.
Corresponds to the JSON property onTargetImpressions
12877 12878 12879 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12877 def on_target_impressions @on_target_impressions end |
#on_target_reach ⇒ Fixnum
Number of unique people reached that match the on-target definition.
Corresponds to the JSON property onTargetReach
12882 12883 12884 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12882 def on_target_reach @on_target_reach end |
#total_coview_impressions ⇒ Fixnum
Total number of impressions including co-viewers.
Corresponds to the JSON property totalCoviewImpressions
12887 12888 12889 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12887 def total_coview_impressions @total_coview_impressions end |
#total_coview_reach ⇒ Fixnum
Total number of unique people reached including co-viewers.
Corresponds to the JSON property totalCoviewReach
12892 12893 12894 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12892 def total_coview_reach @total_coview_reach end |
#total_impressions ⇒ Fixnum
Total number of impressions.
Corresponds to the JSON property totalImpressions
12897 12898 12899 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12897 def total_impressions @total_impressions end |
#total_reach ⇒ Fixnum
Total number of unique people reached.
Corresponds to the JSON property totalReach
12902 12903 12904 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12902 def total_reach @total_reach end |
#trueview_views ⇒ Fixnum
Number of TrueView views.
Corresponds to the JSON property trueviewViews
12907 12908 12909 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12907 def trueview_views @trueview_views end |
#viewable_impressions ⇒ Fixnum
Number of viewable impressions.
Corresponds to the JSON property viewableImpressions
12912 12913 12914 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12912 def viewable_impressions @viewable_impressions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 12930 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12919 def update!(**args) @on_target_coview_impressions = args[:on_target_coview_impressions] if args.key?(:on_target_coview_impressions) @on_target_coview_reach = args[:on_target_coview_reach] if args.key?(:on_target_coview_reach) @on_target_impressions = args[:on_target_impressions] if args.key?(:on_target_impressions) @on_target_reach = args[:on_target_reach] if args.key?(:on_target_reach) @total_coview_impressions = args[:total_coview_impressions] if args.key?(:total_coview_impressions) @total_coview_reach = args[:total_coview_reach] if args.key?(:total_coview_reach) @total_impressions = args[:total_impressions] if args.key?(:total_impressions) @total_reach = args[:total_reach] if args.key?(:total_reach) @trueview_views = args[:trueview_views] if args.key?(:trueview_views) @viewable_impressions = args[:viewable_impressions] if args.key?(:viewable_impressions) end |