Class: Google::Apis::DisplayvideoV4::PlannedProductForecast
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::PlannedProductForecast
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Performance metrics for a forecast point.
Instance Attribute Summary collapse
-
#on_target_coview_impressions ⇒ Fixnum
Number of on-target impressions including co-viewers.
-
#on_target_coview_reach ⇒ Fixnum
Number of unique people reached that match the on-target definition including co-viewers.
-
#on_target_impressions ⇒ Fixnum
Number of on-target impressions.
-
#on_target_reach ⇒ Fixnum
Number of unique people reached that match the on-target definition.
-
#total_coview_impressions ⇒ Fixnum
Total number of impressions including co-viewers.
-
#total_coview_reach ⇒ Fixnum
Total number of unique people reached including co-viewers.
-
#total_impressions ⇒ Fixnum
Total number of impressions.
-
#total_reach ⇒ Fixnum
Total number of unique people reached.
-
#trueview_views ⇒ Fixnum
Number of TrueView views.
-
#viewable_impressions ⇒ Fixnum
Number of viewable impressions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlannedProductForecast
constructor
A new instance of PlannedProductForecast.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlannedProductForecast
Returns a new instance of PlannedProductForecast.
12913 12914 12915 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12913 def initialize(**args) update!(**args) end |
Instance Attribute Details
#on_target_coview_impressions ⇒ Fixnum
Number of on-target impressions including co-viewers.
Corresponds to the JSON property onTargetCoviewImpressions
12865 12866 12867 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12865 def on_target_coview_impressions @on_target_coview_impressions end |
#on_target_coview_reach ⇒ Fixnum
Number of unique people reached that match the on-target definition including
co-viewers.
Corresponds to the JSON property onTargetCoviewReach
12871 12872 12873 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12871 def on_target_coview_reach @on_target_coview_reach end |
#on_target_impressions ⇒ Fixnum
Number of on-target impressions.
Corresponds to the JSON property onTargetImpressions
12876 12877 12878 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12876 def on_target_impressions @on_target_impressions end |
#on_target_reach ⇒ Fixnum
Number of unique people reached that match the on-target definition.
Corresponds to the JSON property onTargetReach
12881 12882 12883 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12881 def on_target_reach @on_target_reach end |
#total_coview_impressions ⇒ Fixnum
Total number of impressions including co-viewers.
Corresponds to the JSON property totalCoviewImpressions
12886 12887 12888 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12886 def total_coview_impressions @total_coview_impressions end |
#total_coview_reach ⇒ Fixnum
Total number of unique people reached including co-viewers.
Corresponds to the JSON property totalCoviewReach
12891 12892 12893 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12891 def total_coview_reach @total_coview_reach end |
#total_impressions ⇒ Fixnum
Total number of impressions.
Corresponds to the JSON property totalImpressions
12896 12897 12898 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12896 def total_impressions @total_impressions end |
#total_reach ⇒ Fixnum
Total number of unique people reached.
Corresponds to the JSON property totalReach
12901 12902 12903 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12901 def total_reach @total_reach end |
#trueview_views ⇒ Fixnum
Number of TrueView views.
Corresponds to the JSON property trueviewViews
12906 12907 12908 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12906 def trueview_views @trueview_views end |
#viewable_impressions ⇒ Fixnum
Number of viewable impressions.
Corresponds to the JSON property viewableImpressions
12911 12912 12913 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12911 def viewable_impressions @viewable_impressions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12918 12919 12920 12921 12922 12923 12924 12925 12926 12927 12928 12929 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12918 def update!(**args) @on_target_coview_impressions = args[:on_target_coview_impressions] if args.key?(:on_target_coview_impressions) @on_target_coview_reach = args[:on_target_coview_reach] if args.key?(:on_target_coview_reach) @on_target_impressions = args[:on_target_impressions] if args.key?(:on_target_impressions) @on_target_reach = args[:on_target_reach] if args.key?(:on_target_reach) @total_coview_impressions = args[:total_coview_impressions] if args.key?(:total_coview_impressions) @total_coview_reach = args[:total_coview_reach] if args.key?(:total_coview_reach) @total_impressions = args[:total_impressions] if args.key?(:total_impressions) @total_reach = args[:total_reach] if args.key?(:total_reach) @trueview_views = args[:trueview_views] if args.key?(:trueview_views) @viewable_impressions = args[:viewable_impressions] if args.key?(:viewable_impressions) end |