Class: Google::Apis::DisplayvideoV4::PlannedProductForecast
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::PlannedProductForecast
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Performance metrics for a forecast point.
Instance Attribute Summary collapse
-
#on_target_impressions ⇒ Fixnum
Number of on-target impressions.
-
#on_target_reach ⇒ Fixnum
Number of unique people reached that match the on-target definition.
-
#total_impressions ⇒ Fixnum
Total number of impressions.
-
#total_reach ⇒ Fixnum
Total number of unique people reached.
-
#trueview_views ⇒ Fixnum
Number of TrueView views.
-
#viewable_impressions ⇒ Fixnum
Number of viewable impressions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlannedProductForecast
constructor
A new instance of PlannedProductForecast.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlannedProductForecast
Returns a new instance of PlannedProductForecast.
12862 12863 12864 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12862 def initialize(**args) update!(**args) end |
Instance Attribute Details
#on_target_impressions ⇒ Fixnum
Number of on-target impressions.
Corresponds to the JSON property onTargetImpressions
12835 12836 12837 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12835 def on_target_impressions @on_target_impressions end |
#on_target_reach ⇒ Fixnum
Number of unique people reached that match the on-target definition.
Corresponds to the JSON property onTargetReach
12840 12841 12842 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12840 def on_target_reach @on_target_reach end |
#total_impressions ⇒ Fixnum
Total number of impressions.
Corresponds to the JSON property totalImpressions
12845 12846 12847 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12845 def total_impressions @total_impressions end |
#total_reach ⇒ Fixnum
Total number of unique people reached.
Corresponds to the JSON property totalReach
12850 12851 12852 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12850 def total_reach @total_reach end |
#trueview_views ⇒ Fixnum
Number of TrueView views.
Corresponds to the JSON property trueviewViews
12855 12856 12857 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12855 def trueview_views @trueview_views end |
#viewable_impressions ⇒ Fixnum
Number of viewable impressions.
Corresponds to the JSON property viewableImpressions
12860 12861 12862 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12860 def viewable_impressions @viewable_impressions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12867 12868 12869 12870 12871 12872 12873 12874 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12867 def update!(**args) @on_target_impressions = args[:on_target_impressions] if args.key?(:on_target_impressions) @on_target_reach = args[:on_target_reach] if args.key?(:on_target_reach) @total_impressions = args[:total_impressions] if args.key?(:total_impressions) @total_reach = args[:total_reach] if args.key?(:total_reach) @trueview_views = args[:trueview_views] if args.key?(:trueview_views) @viewable_impressions = args[:viewable_impressions] if args.key?(:viewable_impressions) end |