Class: Google::Apis::DisplayvideoV4::PoiAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for assigned POI targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_POI.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PoiAssignedTargetingOptionDetails

Returns a new instance of PoiAssignedTargetingOptionDetails.



12415
12416
12417
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12415

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of a POI, e.g. "Times Square", "Space Needle", followed by its full address if available. Corresponds to the JSON property displayName

Returns:

  • (String)


12375
12376
12377
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12375

def display_name
  @display_name
end

#latitudeFloat

Output only. Latitude of the POI rounding to 6th decimal place. Corresponds to the JSON property latitude

Returns:

  • (Float)


12380
12381
12382
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12380

def latitude
  @latitude
end

#longitudeFloat

Output only. Longitude of the POI rounding to 6th decimal place. Corresponds to the JSON property longitude

Returns:

  • (Float)


12385
12386
12387
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12385

def longitude
  @longitude
end

#proximity_radius_amountFloat

Required. The radius of the area around the POI that will be targeted. The units of the radius are specified by proximity_radius_unit. Must be 1 to 800 if unit is DISTANCE_UNIT_KILOMETERS and 1 to 500 if unit is DISTANCE_UNIT_MILES. Corresponds to the JSON property proximityRadiusAmount

Returns:

  • (Float)


12393
12394
12395
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12393

def proximity_radius_amount
  @proximity_radius_amount
end

#proximity_radius_unitString

Required. The unit of distance by which the targeting radius is measured. Corresponds to the JSON property proximityRadiusUnit

Returns:

  • (String)


12398
12399
12400
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12398

def proximity_radius_unit
  @proximity_radius_unit
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_POI. Accepted POI targeting option IDs can be retrieved using targetingTypes.targetingOptions.search. If targeting a specific latitude/ longitude coordinate removed from an address or POI name, you can generate the necessary targeting option ID by rounding the desired coordinate values to the 6th decimal place, removing the decimals, and concatenating the string values separated by a semicolon. For example, you can target the latitude/longitude pair of 40.7414691, -74.003387 using the targeting option ID "40741469;- 74003387". Upon creation, this field value will be updated to append a semicolon and alphanumerical hash value if only latitude/longitude coordinates are provided. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


12413
12414
12415
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12413

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12420
12421
12422
12423
12424
12425
12426
12427
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12420

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
  @proximity_radius_amount = args[:proximity_radius_amount] if args.key?(:proximity_radius_amount)
  @proximity_radius_unit = args[:proximity_radius_unit] if args.key?(:proximity_radius_unit)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end