Class: Google::Apis::DisplayvideoV4::PoiAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for assigned POI targeting option. This will be populated in the details field of an AssignedTargetingOption when targeting_type is TARGETING_TYPE_POI.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PoiAssignedTargetingOptionDetails

Returns a new instance of PoiAssignedTargetingOptionDetails.



12406
12407
12408
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. The display name of a POI, e.g. "Times Square", "Space Needle", followed by its full address if available. Corresponds to the JSON property displayName

Returns:

  • (String)


12366
12367
12368
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12366

def display_name
  @display_name
end

#latitudeFloat

Output only. Latitude of the POI rounding to 6th decimal place. Corresponds to the JSON property latitude

Returns:

  • (Float)


12371
12372
12373
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12371

def latitude
  @latitude
end

#longitudeFloat

Output only. Longitude of the POI rounding to 6th decimal place. Corresponds to the JSON property longitude

Returns:

  • (Float)


12376
12377
12378
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12376

def longitude
  @longitude
end

#proximity_radius_amountFloat

Required. The radius of the area around the POI that will be targeted. The units of the radius are specified by proximity_radius_unit. Must be 1 to 800 if unit is DISTANCE_UNIT_KILOMETERS and 1 to 500 if unit is DISTANCE_UNIT_MILES. Corresponds to the JSON property proximityRadiusAmount

Returns:

  • (Float)


12384
12385
12386
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12384

def proximity_radius_amount
  @proximity_radius_amount
end

#proximity_radius_unitString

Required. The unit of distance by which the targeting radius is measured. Corresponds to the JSON property proximityRadiusUnit

Returns:

  • (String)


12389
12390
12391
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12389

def proximity_radius_unit
  @proximity_radius_unit
end

#targeting_option_idString

Required. The targeting_option_id of a TargetingOption of type TARGETING_TYPE_POI. Accepted POI targeting option IDs can be retrieved using targetingTypes.targetingOptions.search. If targeting a specific latitude/ longitude coordinate removed from an address or POI name, you can generate the necessary targeting option ID by rounding the desired coordinate values to the 6th decimal place, removing the decimals, and concatenating the string values separated by a semicolon. For example, you can target the latitude/longitude pair of 40.7414691, -74.003387 using the targeting option ID "40741469;- 74003387". Upon creation, this field value will be updated to append a semicolon and alphanumerical hash value if only latitude/longitude coordinates are provided. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


12404
12405
12406
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12404

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12411
12412
12413
12414
12415
12416
12417
12418
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12411

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
  @proximity_radius_amount = args[:proximity_radius_amount] if args.key?(:proximity_radius_amount)
  @proximity_radius_unit = args[:proximity_radius_unit] if args.key?(:proximity_radius_unit)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end