Class: Google::Apis::DisplayvideoV4::RateDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

The rate related settings of the inventory source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RateDetails

Returns a new instance of RateDetails.



13255
13256
13257
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inventory_source_rate_typeString

The rate type. Acceptable values are INVENTORY_SOURCE_RATE_TYPE_CPM_FIXED, INVENTORY_SOURCE_RATE_TYPE_CPM_FLOOR, and INVENTORY_SOURCE_RATE_TYPE_CPD. Corresponds to the JSON property inventorySourceRateType

Returns:

  • (String)


13237
13238
13239
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13237

def inventory_source_rate_type
  @inventory_source_rate_type
end

#minimum_spendGoogle::Apis::DisplayvideoV4::Money

Represents an amount of money with its currency type. Corresponds to the JSON property minimumSpend



13242
13243
13244
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13242

def minimum_spend
  @minimum_spend
end

#rateGoogle::Apis::DisplayvideoV4::Money

Represents an amount of money with its currency type. Corresponds to the JSON property rate



13247
13248
13249
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13247

def rate
  @rate
end

#units_purchasedFixnum

Required for guaranteed inventory sources. The number of impressions guaranteed by the seller. Corresponds to the JSON property unitsPurchased

Returns:

  • (Fixnum)


13253
13254
13255
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13253

def units_purchased
  @units_purchased
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13260
13261
13262
13263
13264
13265
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13260

def update!(**args)
  @inventory_source_rate_type = args[:inventory_source_rate_type] if args.key?(:inventory_source_rate_type)
  @minimum_spend = args[:minimum_spend] if args.key?(:minimum_spend)
  @rate = args[:rate] if args.key?(:rate)
  @units_purchased = args[:units_purchased] if args.key?(:units_purchased)
end