Class: Google::Apis::DisplayvideoV4::ReplaceNegativeKeywordsRequest
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ReplaceNegativeKeywordsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Request message for NegativeKeywordService.ReplaceNegativeKeywords.
Instance Attribute Summary collapse
-
#new_negative_keywords ⇒ Array<Google::Apis::DisplayvideoV4::NegativeKeyword>
The negative keywords that will replace the existing keywords in the negative keyword list, specified as a list of NegativeKeywords.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplaceNegativeKeywordsRequest
constructor
A new instance of ReplaceNegativeKeywordsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplaceNegativeKeywordsRequest
Returns a new instance of ReplaceNegativeKeywordsRequest.
12740 12741 12742 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12740 def initialize(**args) update!(**args) end |
Instance Attribute Details
#new_negative_keywords ⇒ Array<Google::Apis::DisplayvideoV4::NegativeKeyword>
The negative keywords that will replace the existing keywords in the negative
keyword list, specified as a list of NegativeKeywords.
Corresponds to the JSON property newNegativeKeywords
12738 12739 12740 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12738 def new_negative_keywords @new_negative_keywords end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12745 12746 12747 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12745 def update!(**args) @new_negative_keywords = args[:new_negative_keywords] if args.key?(:new_negative_keywords) end |