Class: Google::Apis::DisplayvideoV4::ReplaceSitesRequest
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ReplaceSitesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Request message for SiteService.ReplaceSites.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
The ID of the advertiser that owns the parent channel.
-
#new_sites ⇒ Array<Google::Apis::DisplayvideoV4::Site>
The sites that will replace the existing sites assigned to the channel, specified as a list of Sites.
-
#partner_id ⇒ Fixnum
The ID of the partner that owns the parent channel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplaceSitesRequest
constructor
A new instance of ReplaceSitesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplaceSitesRequest
Returns a new instance of ReplaceSitesRequest.
12789 12790 12791 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12789 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
The ID of the advertiser that owns the parent channel.
Corresponds to the JSON property advertiserId
12776 12777 12778 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12776 def advertiser_id @advertiser_id end |
#new_sites ⇒ Array<Google::Apis::DisplayvideoV4::Site>
The sites that will replace the existing sites assigned to the channel,
specified as a list of Sites.
Corresponds to the JSON property newSites
12782 12783 12784 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12782 def new_sites @new_sites end |
#partner_id ⇒ Fixnum
The ID of the partner that owns the parent channel.
Corresponds to the JSON property partnerId
12787 12788 12789 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12787 def partner_id @partner_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12794 12795 12796 12797 12798 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12794 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @new_sites = args[:new_sites] if args.key?(:new_sites) @partner_id = args[:partner_id] if args.key?(:partner_id) end |