Class: Google::Apis::DisplayvideoV4::ScriptError
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::ScriptError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
An error message for a custom bidding script.
Instance Attribute Summary collapse
-
#column ⇒ Fixnum
The column number in the script where the error was thrown.
-
#error_code ⇒ String
The type of error.
-
#error_message ⇒ String
The detailed error message.
-
#line ⇒ Fixnum
The line number in the script where the error was thrown.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScriptError
constructor
A new instance of ScriptError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScriptError
Returns a new instance of ScriptError.
12883 12884 12885 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column ⇒ Fixnum
The column number in the script where the error was thrown.
Corresponds to the JSON property column
12866 12867 12868 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12866 def column @column end |
#error_code ⇒ String
The type of error.
Corresponds to the JSON property errorCode
12871 12872 12873 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12871 def error_code @error_code end |
#error_message ⇒ String
The detailed error message.
Corresponds to the JSON property errorMessage
12876 12877 12878 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12876 def @error_message end |
#line ⇒ Fixnum
The line number in the script where the error was thrown.
Corresponds to the JSON property line
12881 12882 12883 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12881 def line @line end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12888 12889 12890 12891 12892 12893 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 12888 def update!(**args) @column = args[:column] if args.key?(:column) @error_code = args[:error_code] if args.key?(:error_code) @error_message = args[:error_message] if args.key?(:error_message) @line = args[:line] if args.key?(:line) end |