Class: Google::Apis::DisplayvideoV4::SearchTargetingOptionsRequest
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::SearchTargetingOptionsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Request message for SearchTargetingOptions.
Instance Attribute Summary collapse
-
#advertiser_id ⇒ Fixnum
Required.
-
#business_chain_search_terms ⇒ Google::Apis::DisplayvideoV4::BusinessChainSearchTerms
Search terms for Business Chain targeting options.
-
#geo_region_search_terms ⇒ Google::Apis::DisplayvideoV4::GeoRegionSearchTerms
Search terms for geo region targeting options.
-
#page_size ⇒ Fixnum
Requested page size.
-
#page_token ⇒ String
A token identifying a page of results the server should return.
-
#poi_search_terms ⇒ Google::Apis::DisplayvideoV4::PoiSearchTerms
Search terms for POI targeting options.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchTargetingOptionsRequest
constructor
A new instance of SearchTargetingOptionsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchTargetingOptionsRequest
Returns a new instance of SearchTargetingOptionsRequest.
13760 13761 13762 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertiser_id ⇒ Fixnum
Required. The Advertiser this request is being made in the context of.
Corresponds to the JSON property advertiserId
13727 13728 13729 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13727 def advertiser_id @advertiser_id end |
#business_chain_search_terms ⇒ Google::Apis::DisplayvideoV4::BusinessChainSearchTerms
Search terms for Business Chain targeting options. At least one of the field
should be populated.
Corresponds to the JSON property businessChainSearchTerms
13733 13734 13735 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13733 def business_chain_search_terms @business_chain_search_terms end |
#geo_region_search_terms ⇒ Google::Apis::DisplayvideoV4::GeoRegionSearchTerms
Search terms for geo region targeting options.
Corresponds to the JSON property geoRegionSearchTerms
13738 13739 13740 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13738 def geo_region_search_terms @geo_region_search_terms end |
#page_size ⇒ Fixnum
Requested page size. Must be between 1 and 200. If unspecified will
default to 100. Returns error code INVALID_ARGUMENT if an invalid value is
specified.
Corresponds to the JSON property pageSize
13745 13746 13747 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13745 def page_size @page_size end |
#page_token ⇒ String
A token identifying a page of results the server should return. Typically,
this is the value of next_page_token returned from the previous call to
SearchTargetingOptions method. If not specified, the first page of results
will be returned.
Corresponds to the JSON property pageToken
13753 13754 13755 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13753 def page_token @page_token end |
#poi_search_terms ⇒ Google::Apis::DisplayvideoV4::PoiSearchTerms
Search terms for POI targeting options.
Corresponds to the JSON property poiSearchTerms
13758 13759 13760 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13758 def poi_search_terms @poi_search_terms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13765 13766 13767 13768 13769 13770 13771 13772 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13765 def update!(**args) @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id) @business_chain_search_terms = args[:business_chain_search_terms] if args.key?(:business_chain_search_terms) @geo_region_search_terms = args[:geo_region_search_terms] if args.key?(:geo_region_search_terms) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @poi_search_terms = args[:poi_search_terms] if args.key?(:poi_search_terms) end |