Class: Google::Apis::DisplayvideoV4::SearchTargetingOptionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::SearchTargetingOptionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Response message for SearchTargetingOptions.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#targeting_options ⇒ Array<Google::Apis::DisplayvideoV4::TargetingOption>
The list of targeting options that match the search criteria.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchTargetingOptionsResponse
constructor
A new instance of SearchTargetingOptionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchTargetingOptionsResponse
Returns a new instance of SearchTargetingOptionsResponse.
13047 13048 13049 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13047 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to SearchTargetingOptions method to
retrieve the next page of results.
Corresponds to the JSON property nextPageToken
13039 13040 13041 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13039 def next_page_token @next_page_token end |
#targeting_options ⇒ Array<Google::Apis::DisplayvideoV4::TargetingOption>
The list of targeting options that match the search criteria. This list will
be absent if empty.
Corresponds to the JSON property targetingOptions
13045 13046 13047 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13045 def @targeting_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13052 13053 13054 13055 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13052 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @targeting_options = args[:targeting_options] if args.key?(:targeting_options) end |