Class: Google::Apis::DisplayvideoV4::TargetingExpansionConfig
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::TargetingExpansionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
Settings that control the optimized targeting settings of the line item.
Instance Attribute Summary collapse
-
#audience_expansion_level ⇒ String
Output only.
-
#audience_expansion_seed_list_excluded ⇒ Boolean
(also: #audience_expansion_seed_list_excluded?)
Output only.
-
#enable_optimized_targeting ⇒ Boolean
(also: #enable_optimized_targeting?)
Required.
-
#exclude_demographic_expansion ⇒ Boolean
(also: #exclude_demographic_expansion?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetingExpansionConfig
constructor
A new instance of TargetingExpansionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetingExpansionConfig
Returns a new instance of TargetingExpansionConfig.
14201 14202 14203 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience_expansion_level ⇒ String
Output only. Magnitude of expansion for eligible first-party user lists under
this ad group. This field only applies to YouTube and Partners line item and
ad group resources.
Corresponds to the JSON property audienceExpansionLevel
14166 14167 14168 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14166 def audience_expansion_level @audience_expansion_level end |
#audience_expansion_seed_list_excluded ⇒ Boolean Also known as: audience_expansion_seed_list_excluded?
Output only. Whether to exclude seed list for audience expansion. This field
only applies to YouTube and Partners line item and ad group resources.
Corresponds to the JSON property audienceExpansionSeedListExcluded
14172 14173 14174 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14172 def audience_expansion_seed_list_excluded @audience_expansion_seed_list_excluded end |
#enable_optimized_targeting ⇒ Boolean Also known as: enable_optimized_targeting?
Required. Whether to enable Optimized Targeting for the line item. Optimized
targeting is not compatible with all bid strategies. Attempting to set this
field to true for a line item using the BiddingStrategy field fixed_bid or
one of the following combinations of BiddingStrategy fields and
BiddingStrategyPerformanceGoalType will result in an error:
maximize_auto_spend_bid: * BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CIVA *
BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_IVO_TEN *
BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_AV_VIEWED performance_goal_auto_bid: *
BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM This also applies if the
line item inherits one of the above bid strategies from the parent insertion
order. Bid strategies set at the insertion order-level will be inherited by
their line items if the InsertionOrder budget field automationType is set to
INSERTION_ORDER_AUTOMATION_TYPE_BUDGET or
INSERTION_ORDER_AUTOMATION_TYPE_BID_BUDGET.
Corresponds to the JSON property enableOptimizedTargeting
14191 14192 14193 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14191 def enable_optimized_targeting @enable_optimized_targeting end |
#exclude_demographic_expansion ⇒ Boolean Also known as: exclude_demographic_expansion?
Optional. Whether to exclude demographic expansion for Optimized Targeting.
This field can only be set for Demand Gen ad groups.
Corresponds to the JSON property excludeDemographicExpansion
14198 14199 14200 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14198 def exclude_demographic_expansion @exclude_demographic_expansion end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14206 14207 14208 14209 14210 14211 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14206 def update!(**args) @audience_expansion_level = args[:audience_expansion_level] if args.key?(:audience_expansion_level) @audience_expansion_seed_list_excluded = args[:audience_expansion_seed_list_excluded] if args.key?(:audience_expansion_seed_list_excluded) @enable_optimized_targeting = args[:enable_optimized_targeting] if args.key?(:enable_optimized_targeting) @exclude_demographic_expansion = args[:exclude_demographic_expansion] if args.key?(:exclude_demographic_expansion) end |