Class: Google::Apis::DisplayvideoV4::TargetingOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Represents a single targeting option, which is a targetable concept in DV360.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetingOption

Returns a new instance of TargetingOption.



14525
14526
14527
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14525

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_range_detailsGoogle::Apis::DisplayvideoV4::AgeRangeTargetingOptionDetails

Represents a targetable age range. This will be populated in the age_range_details field when targeting_type is TARGETING_TYPE_AGE_RANGE. Corresponds to the JSON property ageRangeDetails



14277
14278
14279
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14277

def age_range_details
  @age_range_details
end

#app_category_detailsGoogle::Apis::DisplayvideoV4::AppCategoryTargetingOptionDetails

Represents a targetable collection of apps. A collection lets you target dynamic groups of related apps that are maintained by the platform, for example All Apps/Google Play/Games. This will be populated in the app_category_details field when targeting_type is TARGETING_TYPE_APP_CATEGORY . Corresponds to the JSON property appCategoryDetails



14286
14287
14288
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14286

def app_category_details
  @app_category_details
end

#audio_content_type_detailsGoogle::Apis::DisplayvideoV4::AudioContentTypeTargetingOptionDetails

Represents a targetable audio content type. This will be populated in the audio_content_type_details field when targeting_type is TARGETING_TYPE_AUDIO_CONTENT_TYPE. Corresponds to the JSON property audioContentTypeDetails



14293
14294
14295
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14293

def audio_content_type_details
  @audio_content_type_details
end

#authorized_seller_status_detailsGoogle::Apis::DisplayvideoV4::AuthorizedSellerStatusTargetingOptionDetails

Represents a targetable authorized seller status. This will be populated in the authorized_seller_status_details field when targeting_type is TARGETING_TYPE_AUTHORIZED_SELLER_STATUS. Corresponds to the JSON property authorizedSellerStatusDetails



14300
14301
14302
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14300

def authorized_seller_status_details
  @authorized_seller_status_details
end

#browser_detailsGoogle::Apis::DisplayvideoV4::BrowserTargetingOptionDetails

Represents a targetable browser. This will be populated in the browser_details field when targeting_type is TARGETING_TYPE_BROWSER. Corresponds to the JSON property browserDetails



14306
14307
14308
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14306

def browser_details
  @browser_details
end

#business_chain_detailsGoogle::Apis::DisplayvideoV4::BusinessChainTargetingOptionDetails

Represents a targetable business chain within a geo region. This will be populated in the business_chain_details field when targeting_type is TARGETING_TYPE_BUSINESS_CHAIN. Corresponds to the JSON property businessChainDetails



14313
14314
14315
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14313

def business_chain_details
  @business_chain_details
end

#carrier_and_isp_detailsGoogle::Apis::DisplayvideoV4::CarrierAndIspTargetingOptionDetails

Represents a targetable carrier or ISP. This will be populated in the carrier_and_isp_details field of a TargetingOption when targeting_type is TARGETING_TYPE_CARRIER_AND_ISP. Corresponds to the JSON property carrierAndIspDetails



14320
14321
14322
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14320

def carrier_and_isp_details
  @carrier_and_isp_details
end

#category_detailsGoogle::Apis::DisplayvideoV4::CategoryTargetingOptionDetails

Represents a targetable category. This will be populated in the category_details field of a TargetingOption when targeting_type is TARGETING_TYPE_CATEGORY. Corresponds to the JSON property categoryDetails



14327
14328
14329
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14327

def category_details
  @category_details
end

#content_duration_detailsGoogle::Apis::DisplayvideoV4::ContentDurationTargetingOptionDetails

Represents a targetable content duration. This will be populated in the content_duration_details field when targeting_type is TARGETING_TYPE_CONTENT_DURATION. Corresponds to the JSON property contentDurationDetails



14334
14335
14336
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14334

def content_duration_details
  @content_duration_details
end

#content_genre_detailsGoogle::Apis::DisplayvideoV4::ContentGenreTargetingOptionDetails

Represents a targetable content genre. This will be populated in the content_genre_details field when targeting_type is TARGETING_TYPE_CONTENT_GENRE. Corresponds to the JSON property contentGenreDetails



14341
14342
14343
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14341

def content_genre_details
  @content_genre_details
end

#content_instream_position_detailsGoogle::Apis::DisplayvideoV4::ContentInstreamPositionTargetingOptionDetails

Represents a targetable content instream position, which could be used by video and audio ads. This will be populated in the content_instream_position_details field when targeting_type is TARGETING_TYPE_CONTENT_INSTREAM_POSITION. Corresponds to the JSON property contentInstreamPositionDetails



14349
14350
14351
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14349

def content_instream_position_details
  @content_instream_position_details
end

#content_outstream_position_detailsGoogle::Apis::DisplayvideoV4::ContentOutstreamPositionTargetingOptionDetails

Represents a targetable content outstream position, which could be used by display and video ads. This will be populated in the content_outstream_position_details field when targeting_type is TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION. Corresponds to the JSON property contentOutstreamPositionDetails



14357
14358
14359
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14357

def content_outstream_position_details
  @content_outstream_position_details
end

#content_stream_type_detailsGoogle::Apis::DisplayvideoV4::ContentStreamTypeTargetingOptionDetails

Represents a targetable content stream type. This will be populated in the content_stream_type_details field when targeting_type is TARGETING_TYPE_CONTENT_STREAM_TYPE. Corresponds to the JSON property contentStreamTypeDetails



14364
14365
14366
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14364

def content_stream_type_details
  @content_stream_type_details
end

#content_theme_detailsGoogle::Apis::DisplayvideoV4::ContentThemeTargetingOptionDetails

Represents a targetable content theme. This will be populated in the content_theme_details field of the TargetingOption when targeting_type is TARGETING_TYPE_CONTENT_THEME_EXCLUSION. Corresponds to the JSON property contentThemeDetails



14371
14372
14373
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14371

def content_theme_details
  @content_theme_details
end

#device_make_model_detailsGoogle::Apis::DisplayvideoV4::DeviceMakeModelTargetingOptionDetails

Represents a targetable device make and model. This will be populated in the device_make_model_details field of a TargetingOption when targeting_type is TARGETING_TYPE_DEVICE_MAKE_MODEL. Corresponds to the JSON property deviceMakeModelDetails



14378
14379
14380
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14378

def device_make_model_details
  @device_make_model_details
end

#device_type_detailsGoogle::Apis::DisplayvideoV4::DeviceTypeTargetingOptionDetails

Represents a targetable device type. This will be populated in the device_type_details field of a TargetingOption when targeting_type is TARGETING_TYPE_DEVICE_TYPE. Corresponds to the JSON property deviceTypeDetails



14385
14386
14387
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14385

def device_type_details
  @device_type_details
end

#digital_content_label_detailsGoogle::Apis::DisplayvideoV4::DigitalContentLabelTargetingOptionDetails

Represents a targetable digital content label rating tier. This will be populated in the digital_content_label_details field of the TargetingOption when targeting_type is TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION. Corresponds to the JSON property digitalContentLabelDetails



14392
14393
14394
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14392

def 
  @digital_content_label_details
end

#environment_detailsGoogle::Apis::DisplayvideoV4::EnvironmentTargetingOptionDetails

Represents a targetable environment. This will be populated in the environment_details field of a TargetingOption when targeting_type is TARGETING_TYPE_ENVIRONMENT. Corresponds to the JSON property environmentDetails



14399
14400
14401
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14399

def environment_details
  @environment_details
end

#exchange_detailsGoogle::Apis::DisplayvideoV4::ExchangeTargetingOptionDetails

Represents a targetable exchange. This will be populated in the exchange_details field of a TargetingOption when targeting_type is TARGETING_TYPE_EXCHANGE. Corresponds to the JSON property exchangeDetails



14406
14407
14408
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14406

def exchange_details
  @exchange_details
end

#gender_detailsGoogle::Apis::DisplayvideoV4::GenderTargetingOptionDetails

Represents a targetable gender. This will be populated in the gender_details field of a TargetingOption when targeting_type is TARGETING_TYPE_GENDER. Corresponds to the JSON property genderDetails



14412
14413
14414
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14412

def gender_details
  @gender_details
end

#geo_region_detailsGoogle::Apis::DisplayvideoV4::GeoRegionTargetingOptionDetails

Represents a targetable geographic region. This will be populated in the geo_region_details field when targeting_type is TARGETING_TYPE_GEO_REGION. Corresponds to the JSON property geoRegionDetails



14418
14419
14420
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14418

def geo_region_details
  @geo_region_details
end

#household_income_detailsGoogle::Apis::DisplayvideoV4::HouseholdIncomeTargetingOptionDetails

Represents a targetable household income. This will be populated in the household_income_details field of a TargetingOption when targeting_type is TARGETING_TYPE_HOUSEHOLD_INCOME. Corresponds to the JSON property householdIncomeDetails



14425
14426
14427
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14425

def household_income_details
  @household_income_details
end

#language_detailsGoogle::Apis::DisplayvideoV4::LanguageTargetingOptionDetails

Represents a targetable language. This will be populated in the language_details field when targeting_type is TARGETING_TYPE_LANGUAGE. Corresponds to the JSON property languageDetails



14431
14432
14433
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14431

def language_details
  @language_details
end

#nameString

Output only. The resource name for this targeting option. Corresponds to the JSON property name

Returns:

  • (String)


14436
14437
14438
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14436

def name
  @name
end

#native_content_position_detailsGoogle::Apis::DisplayvideoV4::NativeContentPositionTargetingOptionDetails

Represents a targetable native content position. This will be populated in the native_content_position_details field when targeting_type is TARGETING_TYPE_NATIVE_CONTENT_POSITION. Corresponds to the JSON property nativeContentPositionDetails



14443
14444
14445
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14443

def native_content_position_details
  @native_content_position_details
end

#omid_detailsGoogle::Apis::DisplayvideoV4::OmidTargetingOptionDetails

Represents a targetable Open Measurement enabled inventory type. This will be populated in the omid_details field when targeting_type is TARGETING_TYPE_OMID. Corresponds to the JSON property omidDetails



14450
14451
14452
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14450

def omid_details
  @omid_details
end

#on_screen_position_detailsGoogle::Apis::DisplayvideoV4::OnScreenPositionTargetingOptionDetails

Represents a targetable on screen position, which could be used by display and video ads. This will be populated in the on_screen_position_details field when targeting_type is TARGETING_TYPE_ON_SCREEN_POSITION. Corresponds to the JSON property onScreenPositionDetails



14457
14458
14459
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14457

def on_screen_position_details
  @on_screen_position_details
end

#operating_system_detailsGoogle::Apis::DisplayvideoV4::OperatingSystemTargetingOptionDetails

Represents a targetable operating system. This will be populated in the operating_system_details field of a TargetingOption when targeting_type is TARGETING_TYPE_OPERATING_SYSTEM. Corresponds to the JSON property operatingSystemDetails



14464
14465
14466
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14464

def operating_system_details
  @operating_system_details
end

#parental_status_detailsGoogle::Apis::DisplayvideoV4::ParentalStatusTargetingOptionDetails

Represents a targetable parental status. This will be populated in the parental_status_details field of a TargetingOption when targeting_type is TARGETING_TYPE_PARENTAL_STATUS. Corresponds to the JSON property parentalStatusDetails



14471
14472
14473
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14471

def parental_status_details
  @parental_status_details
end

#poi_detailsGoogle::Apis::DisplayvideoV4::PoiTargetingOptionDetails

Represents a targetable point of interest(POI). This will be populated in the poi_details field when targeting_type is TARGETING_TYPE_POI. Corresponds to the JSON property poiDetails



14477
14478
14479
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14477

def poi_details
  @poi_details
end

#sensitive_category_detailsGoogle::Apis::DisplayvideoV4::SensitiveCategoryTargetingOptionDetails

Represents a targetable sensitive category. This will be populated in the sensitive_category_details field of the TargetingOption when targeting_type is TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION. Corresponds to the JSON property sensitiveCategoryDetails



14484
14485
14486
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14484

def sensitive_category_details
  @sensitive_category_details
end

#sub_exchange_detailsGoogle::Apis::DisplayvideoV4::SubExchangeTargetingOptionDetails

Represents a targetable sub-exchange. This will be populated in the sub_exchange_details field of a TargetingOption when targeting_type is TARGETING_TYPE_SUB_EXCHANGE. Corresponds to the JSON property subExchangeDetails



14491
14492
14493
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14491

def sub_exchange_details
  @sub_exchange_details
end

#targeting_option_idString

Output only. A unique identifier for this targeting option. The tuple targeting_type`, `targeting_option_id will be unique. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


14497
14498
14499
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14497

def targeting_option_id
  @targeting_option_id
end

#targeting_typeString

Output only. The type of this targeting option. Corresponds to the JSON property targetingType

Returns:

  • (String)


14502
14503
14504
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14502

def targeting_type
  @targeting_type
end

#user_rewarded_content_detailsGoogle::Apis::DisplayvideoV4::UserRewardedContentTargetingOptionDetails

Represents a targetable user rewarded content status for video ads only. This will be populated in the user_rewarded_content_details field when targeting_type is TARGETING_TYPE_USER_REWARDED_CONTENT. Corresponds to the JSON property userRewardedContentDetails



14509
14510
14511
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14509

def user_rewarded_content_details
  @user_rewarded_content_details
end

#video_player_size_detailsGoogle::Apis::DisplayvideoV4::VideoPlayerSizeTargetingOptionDetails

Represents a targetable video player size. This will be populated in the video_player_size_details field when targeting_type is TARGETING_TYPE_VIDEO_PLAYER_SIZE. Corresponds to the JSON property videoPlayerSizeDetails



14516
14517
14518
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14516

def video_player_size_details
  @video_player_size_details
end

#viewability_detailsGoogle::Apis::DisplayvideoV4::ViewabilityTargetingOptionDetails

Represents a targetable viewability. This will be populated in the viewability_details field of a TargetingOption when targeting_type is TARGETING_TYPE_VIEWABILITY. Corresponds to the JSON property viewabilityDetails



14523
14524
14525
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14523

def viewability_details
  @viewability_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14530
14531
14532
14533
14534
14535
14536
14537
14538
14539
14540
14541
14542
14543
14544
14545
14546
14547
14548
14549
14550
14551
14552
14553
14554
14555
14556
14557
14558
14559
14560
14561
14562
14563
14564
14565
14566
14567
14568
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14530

def update!(**args)
  @age_range_details = args[:age_range_details] if args.key?(:age_range_details)
  @app_category_details = args[:app_category_details] if args.key?(:app_category_details)
  @audio_content_type_details = args[:audio_content_type_details] if args.key?(:audio_content_type_details)
  @authorized_seller_status_details = args[:authorized_seller_status_details] if args.key?(:authorized_seller_status_details)
  @browser_details = args[:browser_details] if args.key?(:browser_details)
  @business_chain_details = args[:business_chain_details] if args.key?(:business_chain_details)
  @carrier_and_isp_details = args[:carrier_and_isp_details] if args.key?(:carrier_and_isp_details)
  @category_details = args[:category_details] if args.key?(:category_details)
  @content_duration_details = args[:content_duration_details] if args.key?(:content_duration_details)
  @content_genre_details = args[:content_genre_details] if args.key?(:content_genre_details)
  @content_instream_position_details = args[:content_instream_position_details] if args.key?(:content_instream_position_details)
  @content_outstream_position_details = args[:content_outstream_position_details] if args.key?(:content_outstream_position_details)
  @content_stream_type_details = args[:content_stream_type_details] if args.key?(:content_stream_type_details)
  @content_theme_details = args[:content_theme_details] if args.key?(:content_theme_details)
  @device_make_model_details = args[:device_make_model_details] if args.key?(:device_make_model_details)
  @device_type_details = args[:device_type_details] if args.key?(:device_type_details)
  @digital_content_label_details = args[:digital_content_label_details] if args.key?(:digital_content_label_details)
  @environment_details = args[:environment_details] if args.key?(:environment_details)
  @exchange_details = args[:exchange_details] if args.key?(:exchange_details)
  @gender_details = args[:gender_details] if args.key?(:gender_details)
  @geo_region_details = args[:geo_region_details] if args.key?(:geo_region_details)
  @household_income_details = args[:household_income_details] if args.key?(:household_income_details)
  @language_details = args[:language_details] if args.key?(:language_details)
  @name = args[:name] if args.key?(:name)
  @native_content_position_details = args[:native_content_position_details] if args.key?(:native_content_position_details)
  @omid_details = args[:omid_details] if args.key?(:omid_details)
  @on_screen_position_details = args[:on_screen_position_details] if args.key?(:on_screen_position_details)
  @operating_system_details = args[:operating_system_details] if args.key?(:operating_system_details)
  @parental_status_details = args[:parental_status_details] if args.key?(:parental_status_details)
  @poi_details = args[:poi_details] if args.key?(:poi_details)
  @sensitive_category_details = args[:sensitive_category_details] if args.key?(:sensitive_category_details)
  @sub_exchange_details = args[:sub_exchange_details] if args.key?(:sub_exchange_details)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
  @targeting_type = args[:targeting_type] if args.key?(:targeting_type)
  @user_rewarded_content_details = args[:user_rewarded_content_details] if args.key?(:user_rewarded_content_details)
  @video_player_size_details = args[:video_player_size_details] if args.key?(:video_player_size_details)
  @viewability_details = args[:viewability_details] if args.key?(:viewability_details)
end