Class: Google::Apis::DisplayvideoV4::TargetingOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Represents a single targeting option, which is a targetable concept in DV360.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetingOption

Returns a new instance of TargetingOption.



13646
13647
13648
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_range_detailsGoogle::Apis::DisplayvideoV4::AgeRangeTargetingOptionDetails

Represents a targetable age range. This will be populated in the age_range_details field when targeting_type is TARGETING_TYPE_AGE_RANGE. Corresponds to the JSON property ageRangeDetails



13398
13399
13400
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13398

def age_range_details
  @age_range_details
end

#app_category_detailsGoogle::Apis::DisplayvideoV4::AppCategoryTargetingOptionDetails

Represents a targetable collection of apps. A collection lets you target dynamic groups of related apps that are maintained by the platform, for example All Apps/Google Play/Games. This will be populated in the app_category_details field when targeting_type is TARGETING_TYPE_APP_CATEGORY . Corresponds to the JSON property appCategoryDetails



13407
13408
13409
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13407

def app_category_details
  @app_category_details
end

#audio_content_type_detailsGoogle::Apis::DisplayvideoV4::AudioContentTypeTargetingOptionDetails

Represents a targetable audio content type. This will be populated in the audio_content_type_details field when targeting_type is TARGETING_TYPE_AUDIO_CONTENT_TYPE. Corresponds to the JSON property audioContentTypeDetails



13414
13415
13416
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13414

def audio_content_type_details
  @audio_content_type_details
end

#authorized_seller_status_detailsGoogle::Apis::DisplayvideoV4::AuthorizedSellerStatusTargetingOptionDetails

Represents a targetable authorized seller status. This will be populated in the authorized_seller_status_details field when targeting_type is TARGETING_TYPE_AUTHORIZED_SELLER_STATUS. Corresponds to the JSON property authorizedSellerStatusDetails



13421
13422
13423
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13421

def authorized_seller_status_details
  @authorized_seller_status_details
end

#browser_detailsGoogle::Apis::DisplayvideoV4::BrowserTargetingOptionDetails

Represents a targetable browser. This will be populated in the browser_details field when targeting_type is TARGETING_TYPE_BROWSER. Corresponds to the JSON property browserDetails



13427
13428
13429
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13427

def browser_details
  @browser_details
end

#business_chain_detailsGoogle::Apis::DisplayvideoV4::BusinessChainTargetingOptionDetails

Represents a targetable business chain within a geo region. This will be populated in the business_chain_details field when targeting_type is TARGETING_TYPE_BUSINESS_CHAIN. Corresponds to the JSON property businessChainDetails



13434
13435
13436
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13434

def business_chain_details
  @business_chain_details
end

#carrier_and_isp_detailsGoogle::Apis::DisplayvideoV4::CarrierAndIspTargetingOptionDetails

Represents a targetable carrier or ISP. This will be populated in the carrier_and_isp_details field of a TargetingOption when targeting_type is TARGETING_TYPE_CARRIER_AND_ISP. Corresponds to the JSON property carrierAndIspDetails



13441
13442
13443
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13441

def carrier_and_isp_details
  @carrier_and_isp_details
end

#category_detailsGoogle::Apis::DisplayvideoV4::CategoryTargetingOptionDetails

Represents a targetable category. This will be populated in the category_details field of a TargetingOption when targeting_type is TARGETING_TYPE_CATEGORY. Corresponds to the JSON property categoryDetails



13448
13449
13450
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13448

def category_details
  @category_details
end

#content_duration_detailsGoogle::Apis::DisplayvideoV4::ContentDurationTargetingOptionDetails

Represents a targetable content duration. This will be populated in the content_duration_details field when targeting_type is TARGETING_TYPE_CONTENT_DURATION. Corresponds to the JSON property contentDurationDetails



13455
13456
13457
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13455

def content_duration_details
  @content_duration_details
end

#content_genre_detailsGoogle::Apis::DisplayvideoV4::ContentGenreTargetingOptionDetails

Represents a targetable content genre. This will be populated in the content_genre_details field when targeting_type is TARGETING_TYPE_CONTENT_GENRE. Corresponds to the JSON property contentGenreDetails



13462
13463
13464
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13462

def content_genre_details
  @content_genre_details
end

#content_instream_position_detailsGoogle::Apis::DisplayvideoV4::ContentInstreamPositionTargetingOptionDetails

Represents a targetable content instream position, which could be used by video and audio ads. This will be populated in the content_instream_position_details field when targeting_type is TARGETING_TYPE_CONTENT_INSTREAM_POSITION. Corresponds to the JSON property contentInstreamPositionDetails



13470
13471
13472
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13470

def content_instream_position_details
  @content_instream_position_details
end

#content_outstream_position_detailsGoogle::Apis::DisplayvideoV4::ContentOutstreamPositionTargetingOptionDetails

Represents a targetable content outstream position, which could be used by display and video ads. This will be populated in the content_outstream_position_details field when targeting_type is TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION. Corresponds to the JSON property contentOutstreamPositionDetails



13478
13479
13480
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13478

def content_outstream_position_details
  @content_outstream_position_details
end

#content_stream_type_detailsGoogle::Apis::DisplayvideoV4::ContentStreamTypeTargetingOptionDetails

Represents a targetable content stream type. This will be populated in the content_stream_type_details field when targeting_type is TARGETING_TYPE_CONTENT_STREAM_TYPE. Corresponds to the JSON property contentStreamTypeDetails



13485
13486
13487
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13485

def content_stream_type_details
  @content_stream_type_details
end

#content_theme_detailsGoogle::Apis::DisplayvideoV4::ContentThemeTargetingOptionDetails

Represents a targetable content theme. This will be populated in the content_theme_details field of the TargetingOption when targeting_type is TARGETING_TYPE_CONTENT_THEME_EXCLUSION. Corresponds to the JSON property contentThemeDetails



13492
13493
13494
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13492

def content_theme_details
  @content_theme_details
end

#device_make_model_detailsGoogle::Apis::DisplayvideoV4::DeviceMakeModelTargetingOptionDetails

Represents a targetable device make and model. This will be populated in the device_make_model_details field of a TargetingOption when targeting_type is TARGETING_TYPE_DEVICE_MAKE_MODEL. Corresponds to the JSON property deviceMakeModelDetails



13499
13500
13501
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13499

def device_make_model_details
  @device_make_model_details
end

#device_type_detailsGoogle::Apis::DisplayvideoV4::DeviceTypeTargetingOptionDetails

Represents a targetable device type. This will be populated in the device_type_details field of a TargetingOption when targeting_type is TARGETING_TYPE_DEVICE_TYPE. Corresponds to the JSON property deviceTypeDetails



13506
13507
13508
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13506

def device_type_details
  @device_type_details
end

#digital_content_label_detailsGoogle::Apis::DisplayvideoV4::DigitalContentLabelTargetingOptionDetails

Represents a targetable digital content label rating tier. This will be populated in the digital_content_label_details field of the TargetingOption when targeting_type is TARGETING_TYPE_DIGITAL_CONTENT_LABEL_EXCLUSION. Corresponds to the JSON property digitalContentLabelDetails



13513
13514
13515
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13513

def 
  @digital_content_label_details
end

#environment_detailsGoogle::Apis::DisplayvideoV4::EnvironmentTargetingOptionDetails

Represents a targetable environment. This will be populated in the environment_details field of a TargetingOption when targeting_type is TARGETING_TYPE_ENVIRONMENT. Corresponds to the JSON property environmentDetails



13520
13521
13522
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13520

def environment_details
  @environment_details
end

#exchange_detailsGoogle::Apis::DisplayvideoV4::ExchangeTargetingOptionDetails

Represents a targetable exchange. This will be populated in the exchange_details field of a TargetingOption when targeting_type is TARGETING_TYPE_EXCHANGE. Corresponds to the JSON property exchangeDetails



13527
13528
13529
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13527

def exchange_details
  @exchange_details
end

#gender_detailsGoogle::Apis::DisplayvideoV4::GenderTargetingOptionDetails

Represents a targetable gender. This will be populated in the gender_details field of a TargetingOption when targeting_type is TARGETING_TYPE_GENDER. Corresponds to the JSON property genderDetails



13533
13534
13535
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13533

def gender_details
  @gender_details
end

#geo_region_detailsGoogle::Apis::DisplayvideoV4::GeoRegionTargetingOptionDetails

Represents a targetable geographic region. This will be populated in the geo_region_details field when targeting_type is TARGETING_TYPE_GEO_REGION. Corresponds to the JSON property geoRegionDetails



13539
13540
13541
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13539

def geo_region_details
  @geo_region_details
end

#household_income_detailsGoogle::Apis::DisplayvideoV4::HouseholdIncomeTargetingOptionDetails

Represents a targetable household income. This will be populated in the household_income_details field of a TargetingOption when targeting_type is TARGETING_TYPE_HOUSEHOLD_INCOME. Corresponds to the JSON property householdIncomeDetails



13546
13547
13548
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13546

def household_income_details
  @household_income_details
end

#language_detailsGoogle::Apis::DisplayvideoV4::LanguageTargetingOptionDetails

Represents a targetable language. This will be populated in the language_details field when targeting_type is TARGETING_TYPE_LANGUAGE. Corresponds to the JSON property languageDetails



13552
13553
13554
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13552

def language_details
  @language_details
end

#nameString

Output only. The resource name for this targeting option. Corresponds to the JSON property name

Returns:

  • (String)


13557
13558
13559
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13557

def name
  @name
end

#native_content_position_detailsGoogle::Apis::DisplayvideoV4::NativeContentPositionTargetingOptionDetails

Represents a targetable native content position. This will be populated in the native_content_position_details field when targeting_type is TARGETING_TYPE_NATIVE_CONTENT_POSITION. Corresponds to the JSON property nativeContentPositionDetails



13564
13565
13566
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13564

def native_content_position_details
  @native_content_position_details
end

#omid_detailsGoogle::Apis::DisplayvideoV4::OmidTargetingOptionDetails

Represents a targetable Open Measurement enabled inventory type. This will be populated in the omid_details field when targeting_type is TARGETING_TYPE_OMID. Corresponds to the JSON property omidDetails



13571
13572
13573
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13571

def omid_details
  @omid_details
end

#on_screen_position_detailsGoogle::Apis::DisplayvideoV4::OnScreenPositionTargetingOptionDetails

Represents a targetable on screen position, which could be used by display and video ads. This will be populated in the on_screen_position_details field when targeting_type is TARGETING_TYPE_ON_SCREEN_POSITION. Corresponds to the JSON property onScreenPositionDetails



13578
13579
13580
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13578

def on_screen_position_details
  @on_screen_position_details
end

#operating_system_detailsGoogle::Apis::DisplayvideoV4::OperatingSystemTargetingOptionDetails

Represents a targetable operating system. This will be populated in the operating_system_details field of a TargetingOption when targeting_type is TARGETING_TYPE_OPERATING_SYSTEM. Corresponds to the JSON property operatingSystemDetails



13585
13586
13587
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13585

def operating_system_details
  @operating_system_details
end

#parental_status_detailsGoogle::Apis::DisplayvideoV4::ParentalStatusTargetingOptionDetails

Represents a targetable parental status. This will be populated in the parental_status_details field of a TargetingOption when targeting_type is TARGETING_TYPE_PARENTAL_STATUS. Corresponds to the JSON property parentalStatusDetails



13592
13593
13594
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13592

def parental_status_details
  @parental_status_details
end

#poi_detailsGoogle::Apis::DisplayvideoV4::PoiTargetingOptionDetails

Represents a targetable point of interest(POI). This will be populated in the poi_details field when targeting_type is TARGETING_TYPE_POI. Corresponds to the JSON property poiDetails



13598
13599
13600
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13598

def poi_details
  @poi_details
end

#sensitive_category_detailsGoogle::Apis::DisplayvideoV4::SensitiveCategoryTargetingOptionDetails

Represents a targetable sensitive category. This will be populated in the sensitive_category_details field of the TargetingOption when targeting_type is TARGETING_TYPE_SENSITIVE_CATEGORY_EXCLUSION. Corresponds to the JSON property sensitiveCategoryDetails



13605
13606
13607
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13605

def sensitive_category_details
  @sensitive_category_details
end

#sub_exchange_detailsGoogle::Apis::DisplayvideoV4::SubExchangeTargetingOptionDetails

Represents a targetable sub-exchange. This will be populated in the sub_exchange_details field of a TargetingOption when targeting_type is TARGETING_TYPE_SUB_EXCHANGE. Corresponds to the JSON property subExchangeDetails



13612
13613
13614
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13612

def sub_exchange_details
  @sub_exchange_details
end

#targeting_option_idString

Output only. A unique identifier for this targeting option. The tuple targeting_type`, `targeting_option_id will be unique. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


13618
13619
13620
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13618

def targeting_option_id
  @targeting_option_id
end

#targeting_typeString

Output only. The type of this targeting option. Corresponds to the JSON property targetingType

Returns:

  • (String)


13623
13624
13625
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13623

def targeting_type
  @targeting_type
end

#user_rewarded_content_detailsGoogle::Apis::DisplayvideoV4::UserRewardedContentTargetingOptionDetails

Represents a targetable user rewarded content status for video ads only. This will be populated in the user_rewarded_content_details field when targeting_type is TARGETING_TYPE_USER_REWARDED_CONTENT. Corresponds to the JSON property userRewardedContentDetails



13630
13631
13632
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13630

def user_rewarded_content_details
  @user_rewarded_content_details
end

#video_player_size_detailsGoogle::Apis::DisplayvideoV4::VideoPlayerSizeTargetingOptionDetails

Represents a targetable video player size. This will be populated in the video_player_size_details field when targeting_type is TARGETING_TYPE_VIDEO_PLAYER_SIZE. Corresponds to the JSON property videoPlayerSizeDetails



13637
13638
13639
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13637

def video_player_size_details
  @video_player_size_details
end

#viewability_detailsGoogle::Apis::DisplayvideoV4::ViewabilityTargetingOptionDetails

Represents a targetable viewability. This will be populated in the viewability_details field of a TargetingOption when targeting_type is TARGETING_TYPE_VIEWABILITY. Corresponds to the JSON property viewabilityDetails



13644
13645
13646
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13644

def viewability_details
  @viewability_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13651
13652
13653
13654
13655
13656
13657
13658
13659
13660
13661
13662
13663
13664
13665
13666
13667
13668
13669
13670
13671
13672
13673
13674
13675
13676
13677
13678
13679
13680
13681
13682
13683
13684
13685
13686
13687
13688
13689
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13651

def update!(**args)
  @age_range_details = args[:age_range_details] if args.key?(:age_range_details)
  @app_category_details = args[:app_category_details] if args.key?(:app_category_details)
  @audio_content_type_details = args[:audio_content_type_details] if args.key?(:audio_content_type_details)
  @authorized_seller_status_details = args[:authorized_seller_status_details] if args.key?(:authorized_seller_status_details)
  @browser_details = args[:browser_details] if args.key?(:browser_details)
  @business_chain_details = args[:business_chain_details] if args.key?(:business_chain_details)
  @carrier_and_isp_details = args[:carrier_and_isp_details] if args.key?(:carrier_and_isp_details)
  @category_details = args[:category_details] if args.key?(:category_details)
  @content_duration_details = args[:content_duration_details] if args.key?(:content_duration_details)
  @content_genre_details = args[:content_genre_details] if args.key?(:content_genre_details)
  @content_instream_position_details = args[:content_instream_position_details] if args.key?(:content_instream_position_details)
  @content_outstream_position_details = args[:content_outstream_position_details] if args.key?(:content_outstream_position_details)
  @content_stream_type_details = args[:content_stream_type_details] if args.key?(:content_stream_type_details)
  @content_theme_details = args[:content_theme_details] if args.key?(:content_theme_details)
  @device_make_model_details = args[:device_make_model_details] if args.key?(:device_make_model_details)
  @device_type_details = args[:device_type_details] if args.key?(:device_type_details)
  @digital_content_label_details = args[:digital_content_label_details] if args.key?(:digital_content_label_details)
  @environment_details = args[:environment_details] if args.key?(:environment_details)
  @exchange_details = args[:exchange_details] if args.key?(:exchange_details)
  @gender_details = args[:gender_details] if args.key?(:gender_details)
  @geo_region_details = args[:geo_region_details] if args.key?(:geo_region_details)
  @household_income_details = args[:household_income_details] if args.key?(:household_income_details)
  @language_details = args[:language_details] if args.key?(:language_details)
  @name = args[:name] if args.key?(:name)
  @native_content_position_details = args[:native_content_position_details] if args.key?(:native_content_position_details)
  @omid_details = args[:omid_details] if args.key?(:omid_details)
  @on_screen_position_details = args[:on_screen_position_details] if args.key?(:on_screen_position_details)
  @operating_system_details = args[:operating_system_details] if args.key?(:operating_system_details)
  @parental_status_details = args[:parental_status_details] if args.key?(:parental_status_details)
  @poi_details = args[:poi_details] if args.key?(:poi_details)
  @sensitive_category_details = args[:sensitive_category_details] if args.key?(:sensitive_category_details)
  @sub_exchange_details = args[:sub_exchange_details] if args.key?(:sub_exchange_details)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
  @targeting_type = args[:targeting_type] if args.key?(:targeting_type)
  @user_rewarded_content_details = args[:user_rewarded_content_details] if args.key?(:user_rewarded_content_details)
  @video_player_size_details = args[:video_player_size_details] if args.key?(:video_player_size_details)
  @viewability_details = args[:viewability_details] if args.key?(:viewability_details)
end