Class: Google::Apis::DisplayvideoV4::ThirdPartyUrl

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Tracking URLs from third parties to track interactions with an audio or a video creative.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThirdPartyUrl

Returns a new instance of ThirdPartyUrl.



13773
13774
13775
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13773

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#typeString

Optional. The type of interaction needs to be tracked by the tracking URL Corresponds to the JSON property type

Returns:

  • (String)


13764
13765
13766
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13764

def type
  @type
end

#urlString

Optional. Tracking URL used to track the interaction. Provide a URL with optional path or query string, beginning with https:. For example, https:// www.example.com/path Corresponds to the JSON property url

Returns:

  • (String)


13771
13772
13773
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13771

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13778
13779
13780
13781
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13778

def update!(**args)
  @type = args[:type] if args.key?(:type)
  @url = args[:url] if args.key?(:url)
end