Class: Google::Apis::DisplayvideoV4::TrackingFloodlightActivityConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Settings that control the behavior of a single Floodlight activity config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrackingFloodlightActivityConfig

Returns a new instance of TrackingFloodlightActivityConfig.



13914
13915
13916
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13914

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#floodlight_activity_idFixnum

Required. The ID of the Floodlight activity. Corresponds to the JSON property floodlightActivityId

Returns:

  • (Fixnum)


13900
13901
13902
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13900

def floodlight_activity_id
  @floodlight_activity_id
end

#post_click_lookback_window_daysFixnum

Required. The number of days after an ad has been clicked in which a conversion may be counted. Must be between 0 and 90 inclusive. Corresponds to the JSON property postClickLookbackWindowDays

Returns:

  • (Fixnum)


13906
13907
13908
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13906

def post_click_lookback_window_days
  @post_click_lookback_window_days
end

#post_view_lookback_window_daysFixnum

Required. The number of days after an ad has been viewed in which a conversion may be counted. Must be between 0 and 90 inclusive. Corresponds to the JSON property postViewLookbackWindowDays

Returns:

  • (Fixnum)


13912
13913
13914
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13912

def post_view_lookback_window_days
  @post_view_lookback_window_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13919
13920
13921
13922
13923
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13919

def update!(**args)
  @floodlight_activity_id = args[:floodlight_activity_id] if args.key?(:floodlight_activity_id)
  @post_click_lookback_window_days = args[:post_click_lookback_window_days] if args.key?(:post_click_lookback_window_days)
  @post_view_lookback_window_days = args[:post_view_lookback_window_days] if args.key?(:post_view_lookback_window_days)
end