Class: Google::Apis::DisplayvideoV4::Transcode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Represents information about the transcoded audio or video file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Transcode

Returns a new instance of Transcode.



13989
13990
13991
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_bit_rate_kbpsFixnum

Optional. The bit rate for the audio stream of the transcoded video, or the bit rate for the transcoded audio, in kilobits per second. Corresponds to the JSON property audioBitRateKbps

Returns:

  • (Fixnum)


13944
13945
13946
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13944

def audio_bit_rate_kbps
  @audio_bit_rate_kbps
end

#audio_sample_rate_hzFixnum

Optional. The sample rate for the audio stream of the transcoded video, or the sample rate for the transcoded audio, in hertz. Corresponds to the JSON property audioSampleRateHz

Returns:

  • (Fixnum)


13950
13951
13952
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13950

def audio_sample_rate_hz
  @audio_sample_rate_hz
end

#bit_rate_kbpsFixnum

Optional. The transcoding bit rate of the transcoded video, in kilobits per second. Corresponds to the JSON property bitRateKbps

Returns:

  • (Fixnum)


13956
13957
13958
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13956

def bit_rate_kbps
  @bit_rate_kbps
end

#dimensionsGoogle::Apis::DisplayvideoV4::Dimensions

Dimensions. Corresponds to the JSON property dimensions



13961
13962
13963
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13961

def dimensions
  @dimensions
end

#file_size_bytesFixnum

Optional. The size of the transcoded file, in bytes. Corresponds to the JSON property fileSizeBytes

Returns:

  • (Fixnum)


13966
13967
13968
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13966

def file_size_bytes
  @file_size_bytes
end

#frame_rateFloat

Optional. The frame rate of the transcoded video, in frames per second. Corresponds to the JSON property frameRate

Returns:

  • (Float)


13971
13972
13973
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13971

def frame_rate
  @frame_rate
end

#mime_typeString

Optional. The MIME type of the transcoded file. Corresponds to the JSON property mimeType

Returns:

  • (String)


13976
13977
13978
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13976

def mime_type
  @mime_type
end

#nameString

Optional. The name of the transcoded file. Corresponds to the JSON property name

Returns:

  • (String)


13981
13982
13983
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13981

def name
  @name
end

#transcodedBoolean Also known as: transcoded?

Optional. Indicates if the transcoding was successful. Corresponds to the JSON property transcoded

Returns:

  • (Boolean)


13986
13987
13988
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13986

def transcoded
  @transcoded
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13994
13995
13996
13997
13998
13999
14000
14001
14002
14003
14004
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13994

def update!(**args)
  @audio_bit_rate_kbps = args[:audio_bit_rate_kbps] if args.key?(:audio_bit_rate_kbps)
  @audio_sample_rate_hz = args[:audio_sample_rate_hz] if args.key?(:audio_sample_rate_hz)
  @bit_rate_kbps = args[:bit_rate_kbps] if args.key?(:bit_rate_kbps)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @file_size_bytes = args[:file_size_bytes] if args.key?(:file_size_bytes)
  @frame_rate = args[:frame_rate] if args.key?(:frame_rate)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @name = args[:name] if args.key?(:name)
  @transcoded = args[:transcoded] if args.key?(:transcoded)
end