Class: Google::Apis::DisplayvideoV4::Transcode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Represents information about the transcoded audio or video file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Transcode

Returns a new instance of Transcode.



13979
13980
13981
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13979

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_bit_rate_kbpsFixnum

Optional. The bit rate for the audio stream of the transcoded video, or the bit rate for the transcoded audio, in kilobits per second. Corresponds to the JSON property audioBitRateKbps

Returns:

  • (Fixnum)


13934
13935
13936
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13934

def audio_bit_rate_kbps
  @audio_bit_rate_kbps
end

#audio_sample_rate_hzFixnum

Optional. The sample rate for the audio stream of the transcoded video, or the sample rate for the transcoded audio, in hertz. Corresponds to the JSON property audioSampleRateHz

Returns:

  • (Fixnum)


13940
13941
13942
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13940

def audio_sample_rate_hz
  @audio_sample_rate_hz
end

#bit_rate_kbpsFixnum

Optional. The transcoding bit rate of the transcoded video, in kilobits per second. Corresponds to the JSON property bitRateKbps

Returns:

  • (Fixnum)


13946
13947
13948
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13946

def bit_rate_kbps
  @bit_rate_kbps
end

#dimensionsGoogle::Apis::DisplayvideoV4::Dimensions

Dimensions. Corresponds to the JSON property dimensions



13951
13952
13953
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13951

def dimensions
  @dimensions
end

#file_size_bytesFixnum

Optional. The size of the transcoded file, in bytes. Corresponds to the JSON property fileSizeBytes

Returns:

  • (Fixnum)


13956
13957
13958
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13956

def file_size_bytes
  @file_size_bytes
end

#frame_rateFloat

Optional. The frame rate of the transcoded video, in frames per second. Corresponds to the JSON property frameRate

Returns:

  • (Float)


13961
13962
13963
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13961

def frame_rate
  @frame_rate
end

#mime_typeString

Optional. The MIME type of the transcoded file. Corresponds to the JSON property mimeType

Returns:

  • (String)


13966
13967
13968
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13966

def mime_type
  @mime_type
end

#nameString

Optional. The name of the transcoded file. Corresponds to the JSON property name

Returns:

  • (String)


13971
13972
13973
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13971

def name
  @name
end

#transcodedBoolean Also known as: transcoded?

Optional. Indicates if the transcoding was successful. Corresponds to the JSON property transcoded

Returns:

  • (Boolean)


13976
13977
13978
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13976

def transcoded
  @transcoded
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13984
13985
13986
13987
13988
13989
13990
13991
13992
13993
13994
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 13984

def update!(**args)
  @audio_bit_rate_kbps = args[:audio_bit_rate_kbps] if args.key?(:audio_bit_rate_kbps)
  @audio_sample_rate_hz = args[:audio_sample_rate_hz] if args.key?(:audio_sample_rate_hz)
  @bit_rate_kbps = args[:bit_rate_kbps] if args.key?(:bit_rate_kbps)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @file_size_bytes = args[:file_size_bytes] if args.key?(:file_size_bytes)
  @frame_rate = args[:frame_rate] if args.key?(:frame_rate)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @name = args[:name] if args.key?(:name)
  @transcoded = args[:transcoded] if args.key?(:transcoded)
end