Class: Google::Apis::DisplayvideoV4::UploadAdAssetRequest
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::UploadAdAssetRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A request message for UploadAdAsset.
Instance Attribute Summary collapse
-
#ad_asset_type ⇒ String
Required.
-
#filename ⇒ String
Required.
-
#synthetic_content_attestation_status ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UploadAdAssetRequest
constructor
A new instance of UploadAdAssetRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UploadAdAssetRequest
Returns a new instance of UploadAdAssetRequest.
14931 14932 14933 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_asset_type ⇒ String
Required. The type of the ad asset. Only AD_ASSET_TYPE_IMAGE is supported.
Corresponds to the JSON property adAssetType
14918 14919 14920 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14918 def ad_asset_type @ad_asset_type end |
#filename ⇒ String
Required. The filename of the ad asset, including the file extension. The
filename must be UTF-8 encoded with a maximum size of 240 bytes.
Corresponds to the JSON property filename
14924 14925 14926 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14924 def filename @filename end |
#synthetic_content_attestation_status ⇒ String
Optional. Whether the asset contains synthetic content or was created using AI.
Corresponds to the JSON property syntheticContentAttestationStatus
14929 14930 14931 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14929 def synthetic_content_attestation_status @synthetic_content_attestation_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14936 14937 14938 14939 14940 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14936 def update!(**args) @ad_asset_type = args[:ad_asset_type] if args.key?(:ad_asset_type) @filename = args[:filename] if args.key?(:filename) @synthetic_content_attestation_status = args[:synthetic_content_attestation_status] if args.key?(:synthetic_content_attestation_status) end |