Class: Google::Apis::DisplayvideoV4::VideoAdSequenceStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

The detail of a single step in a VideoAdSequence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoAdSequenceStep

Returns a new instance of VideoAdSequenceStep.



15154
15155
15156
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_group_idFixnum

The ID of the corresponding ad group of the step. Corresponds to the JSON property adGroupId

Returns:

  • (Fixnum)


15136
15137
15138
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15136

def ad_group_id
  @ad_group_id
end

#interaction_typeString

The interaction on the previous step that will lead the viewer to this step. The first step does not have interaction_type. Corresponds to the JSON property interactionType

Returns:

  • (String)


15142
15143
15144
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15142

def interaction_type
  @interaction_type
end

#previous_step_idFixnum

The ID of the previous step. The first step does not have previous step. Corresponds to the JSON property previousStepId

Returns:

  • (Fixnum)


15147
15148
15149
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15147

def previous_step_id
  @previous_step_id
end

#step_idFixnum

The ID of the step. Corresponds to the JSON property stepId

Returns:

  • (Fixnum)


15152
15153
15154
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15152

def step_id
  @step_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15159
15160
15161
15162
15163
15164
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15159

def update!(**args)
  @ad_group_id = args[:ad_group_id] if args.key?(:ad_group_id)
  @interaction_type = args[:interaction_type] if args.key?(:interaction_type)
  @previous_step_id = args[:previous_step_id] if args.key?(:previous_step_id)
  @step_id = args[:step_id] if args.key?(:step_id)
end