Class: Google::Apis::DisplayvideoV4::VideoPerformanceAd

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Details for a video performance ad.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoPerformanceAd

Returns a new instance of VideoPerformanceAd.



14410
14411
14412
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_button_labelsArray<String>

The list of text assets shown on the call-to-action button. Corresponds to the JSON property actionButtonLabels

Returns:

  • (Array<String>)


14353
14354
14355
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14353

def action_button_labels
  @action_button_labels
end

#companion_bannersArray<Google::Apis::DisplayvideoV4::ImageAsset>

The list of companion banners used by this ad. Corresponds to the JSON property companionBanners



14358
14359
14360
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14358

def companion_banners
  @companion_banners
end

#custom_parametersHash<String,String>

The custom parameters and accompanying values to add to the tracking URL. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,String>)


14363
14364
14365
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14363

def custom_parameters
  @custom_parameters
end

#descriptionsArray<String>

The list of descriptions shown on the call-to-action banner. Corresponds to the JSON property descriptions

Returns:

  • (Array<String>)


14368
14369
14370
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14368

def descriptions
  @descriptions
end

#display_url_breadcrumb1String

The first piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb1

Returns:

  • (String)


14373
14374
14375
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14373

def display_url_breadcrumb1
  @display_url_breadcrumb1
end

#display_url_breadcrumb2String

The second piece after the domain in the display URL. Corresponds to the JSON property displayUrlBreadcrumb2

Returns:

  • (String)


14378
14379
14380
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14378

def display_url_breadcrumb2
  @display_url_breadcrumb2
end

#domainString

The domain of the display URL. Corresponds to the JSON property domain

Returns:

  • (String)


14383
14384
14385
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14383

def domain
  @domain
end

#final_urlString

The URL address of the webpage that people reach after they click the ad. Corresponds to the JSON property finalUrl

Returns:

  • (String)


14388
14389
14390
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14388

def final_url
  @final_url
end

#headlinesArray<String>

The list of headlines shown on the call-to-action banner. Corresponds to the JSON property headlines

Returns:

  • (Array<String>)


14393
14394
14395
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14393

def headlines
  @headlines
end

#long_headlinesArray<String>

The list of long headlines shown on the call-to-action banner. Corresponds to the JSON property longHeadlines

Returns:

  • (Array<String>)


14398
14399
14400
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14398

def long_headlines
  @long_headlines
end

#tracking_urlString

The URL address loaded in the background for tracking purposes. Corresponds to the JSON property trackingUrl

Returns:

  • (String)


14403
14404
14405
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14403

def tracking_url
  @tracking_url
end

#videosArray<Google::Apis::DisplayvideoV4::YoutubeVideoDetails>

The list of YouTube video assets used by this ad. Corresponds to the JSON property videos



14408
14409
14410
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14408

def videos
  @videos
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14415
14416
14417
14418
14419
14420
14421
14422
14423
14424
14425
14426
14427
14428
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14415

def update!(**args)
  @action_button_labels = args[:action_button_labels] if args.key?(:action_button_labels)
  @companion_banners = args[:companion_banners] if args.key?(:companion_banners)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @descriptions = args[:descriptions] if args.key?(:descriptions)
  @display_url_breadcrumb1 = args[:display_url_breadcrumb1] if args.key?(:display_url_breadcrumb1)
  @display_url_breadcrumb2 = args[:display_url_breadcrumb2] if args.key?(:display_url_breadcrumb2)
  @domain = args[:domain] if args.key?(:domain)
  @final_url = args[:final_url] if args.key?(:final_url)
  @headlines = args[:headlines] if args.key?(:headlines)
  @long_headlines = args[:long_headlines] if args.key?(:long_headlines)
  @tracking_url = args[:tracking_url] if args.key?(:tracking_url)
  @videos = args[:videos] if args.key?(:videos)
end