Class: Google::Apis::DisplayvideoV4::YoutubeAndPartnersSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

Settings for YouTube and Partners line items.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAndPartnersSettings

Returns a new instance of YoutubeAndPartnersSettings.



14683
14684
14685
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14683

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_categoryString

Output only. The kind of content on which the YouTube and Partners ads will be shown. Warning: This field will be removed in the near future. Use effective_content_category instead. Corresponds to the JSON property contentCategory

Returns:

  • (String)


14622
14623
14624
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14622

def 
  @content_category
end

#effective_content_categoryString

Output only. The content category which takes effect when serving the line item. When content category is set in both line item and advertiser, the stricter one will take effect when serving the line item. New line items will only inherit the advertiser level setting. Corresponds to the JSON property effectiveContentCategory

Returns:

  • (String)


14630
14631
14632
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14630

def 
  @effective_content_category
end

#inventory_source_settingsGoogle::Apis::DisplayvideoV4::YoutubeAndPartnersInventorySourceConfig

Settings that control what YouTube related inventories the YouTube and Partners line item will target. Corresponds to the JSON property inventorySourceSettings



14636
14637
14638
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14636

def inventory_source_settings
  @inventory_source_settings
end

#lead_form_idFixnum

Optional. The ID of the form to generate leads. Corresponds to the JSON property leadFormId

Returns:

  • (Fixnum)


14641
14642
14643
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14641

def lead_form_id
  @lead_form_id
end

#linked_merchant_idFixnum

Optional. The ID of the Merchant Center account used to provide a product feed. This Merchant Center account must already be linked to the advertiser. Corresponds to the JSON property linkedMerchantId

Returns:

  • (Fixnum)


14647
14648
14649
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14647

def linked_merchant_id
  @linked_merchant_id
end

Optional. The IDs of the videos appear below the primary video ad when the ad is playing in the YouTube app on mobile devices. Corresponds to the JSON property relatedVideoIds

Returns:

  • (Array<String>)


14653
14654
14655
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14653

def related_video_ids
  @related_video_ids
end

#target_frequencyGoogle::Apis::DisplayvideoV4::TargetFrequency

Setting that controls the average number of times the ads will show to the same person over a certain period of time. Corresponds to the JSON property targetFrequency



14659
14660
14661
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14659

def target_frequency
  @target_frequency
end

#third_party_measurement_configsGoogle::Apis::DisplayvideoV4::ThirdPartyMeasurementConfigs

Settings that control what third-party vendors are measuring specific line item metrics. Corresponds to the JSON property thirdPartyMeasurementConfigs



14665
14666
14667
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14665

def third_party_measurement_configs
  @third_party_measurement_configs
end

#video_ad_inventory_controlGoogle::Apis::DisplayvideoV4::VideoAdInventoryControl

The video ad inventory control used in certain YouTube line item types. Corresponds to the JSON property videoAdInventoryControl



14670
14671
14672
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14670

def video_ad_inventory_control
  @video_ad_inventory_control
end

#video_ad_sequence_settingsGoogle::Apis::DisplayvideoV4::VideoAdSequenceSettings

Settings related to VideoAdSequence. Corresponds to the JSON property videoAdSequenceSettings



14675
14676
14677
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14675

def video_ad_sequence_settings
  @video_ad_sequence_settings
end

#view_frequency_capGoogle::Apis::DisplayvideoV4::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property viewFrequencyCap



14681
14682
14683
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14681

def view_frequency_cap
  @view_frequency_cap
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14688
14689
14690
14691
14692
14693
14694
14695
14696
14697
14698
14699
14700
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14688

def update!(**args)
  @content_category = args[:content_category] if args.key?(:content_category)
  @effective_content_category = args[:effective_content_category] if args.key?(:effective_content_category)
  @inventory_source_settings = args[:inventory_source_settings] if args.key?(:inventory_source_settings)
  @lead_form_id = args[:lead_form_id] if args.key?(:lead_form_id)
  @linked_merchant_id = args[:linked_merchant_id] if args.key?(:linked_merchant_id)
  @related_video_ids = args[:related_video_ids] if args.key?(:related_video_ids)
  @target_frequency = args[:target_frequency] if args.key?(:target_frequency)
  @third_party_measurement_configs = args[:third_party_measurement_configs] if args.key?(:third_party_measurement_configs)
  @video_ad_inventory_control = args[:video_ad_inventory_control] if args.key?(:video_ad_inventory_control)
  @video_ad_sequence_settings = args[:video_ad_sequence_settings] if args.key?(:video_ad_sequence_settings)
  @view_frequency_cap = args[:view_frequency_cap] if args.key?(:view_frequency_cap)
end