Class: Google::Apis::DisplayvideoV4::YoutubeAssetAssociationAffiliateLocationAssetFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

An asset filter that matches eligible affiliate location assets for serving.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAssetAssociationAffiliateLocationAssetFilter

Returns a new instance of YoutubeAssetAssociationAffiliateLocationAssetFilter.



15679
15680
15681
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affiliate_location_matching_functionGoogle::Apis::DisplayvideoV4::YoutubeAssetAssociationAffiliateLocationAssetFilterAffiliateLocationMatchingFunction

The matching function for an affiliate location asset filter. Corresponds to the JSON property affiliateLocationMatchingFunction



15666
15667
15668
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15666

def affiliate_location_matching_function
  @affiliate_location_matching_function
end

#affiliate_location_matching_typeString

Required. The matching type of this affiliate location asset filter. Corresponds to the JSON property affiliateLocationMatchingType

Returns:

  • (String)


15671
15672
15673
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15671

def affiliate_location_matching_type
  @affiliate_location_matching_type
end

#asset_set_idFixnum

Output only. The ID of the asset set that matches the affiliate location assets eligible for serving. Corresponds to the JSON property assetSetId

Returns:

  • (Fixnum)


15677
15678
15679
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15677

def asset_set_id
  @asset_set_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15684
15685
15686
15687
15688
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15684

def update!(**args)
  @affiliate_location_matching_function = args[:affiliate_location_matching_function] if args.key?(:affiliate_location_matching_function)
  @affiliate_location_matching_type = args[:affiliate_location_matching_type] if args.key?(:affiliate_location_matching_type)
  @asset_set_id = args[:asset_set_id] if args.key?(:asset_set_id)
end