Class: Google::Apis::DisplayvideoV4::YoutubeAssetAssociationAffiliateLocationAssetFilter
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::YoutubeAssetAssociationAffiliateLocationAssetFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
An asset filter that matches eligible affiliate location assets for serving.
Instance Attribute Summary collapse
-
#affiliate_location_matching_function ⇒ Google::Apis::DisplayvideoV4::YoutubeAssetAssociationAffiliateLocationAssetFilterAffiliateLocationMatchingFunction
The matching function for an affiliate location asset filter.
-
#affiliate_location_matching_type ⇒ String
Required.
-
#asset_set_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ YoutubeAssetAssociationAffiliateLocationAssetFilter
constructor
A new instance of YoutubeAssetAssociationAffiliateLocationAssetFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ YoutubeAssetAssociationAffiliateLocationAssetFilter
Returns a new instance of YoutubeAssetAssociationAffiliateLocationAssetFilter.
14756 14757 14758 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affiliate_location_matching_function ⇒ Google::Apis::DisplayvideoV4::YoutubeAssetAssociationAffiliateLocationAssetFilterAffiliateLocationMatchingFunction
The matching function for an affiliate location asset filter.
Corresponds to the JSON property affiliateLocationMatchingFunction
14743 14744 14745 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14743 def affiliate_location_matching_function @affiliate_location_matching_function end |
#affiliate_location_matching_type ⇒ String
Required. The matching type of this affiliate location asset filter.
Corresponds to the JSON property affiliateLocationMatchingType
14748 14749 14750 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14748 def affiliate_location_matching_type @affiliate_location_matching_type end |
#asset_set_id ⇒ Fixnum
Output only. The ID of the asset set that matches the affiliate location
assets eligible for serving.
Corresponds to the JSON property assetSetId
14754 14755 14756 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14754 def asset_set_id @asset_set_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14761 14762 14763 14764 14765 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14761 def update!(**args) @affiliate_location_matching_function = args[:affiliate_location_matching_function] if args.key?(:affiliate_location_matching_function) @affiliate_location_matching_type = args[:affiliate_location_matching_type] if args.key?(:affiliate_location_matching_type) @asset_set_id = args[:asset_set_id] if args.key?(:asset_set_id) end |