Class: Google::Apis::DisplayvideoV4::YoutubeAssetAssociationLinkedYouTubeAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A YouTube asset linked to a resource in a YoutubeAssetAssociation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAssetAssociationLinkedYouTubeAsset

Returns a new instance of YoutubeAssetAssociationLinkedYouTubeAsset.



15749
15750
15751
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affiliate_location_asset_filterGoogle::Apis::DisplayvideoV4::YoutubeAssetAssociationAffiliateLocationAssetFilter

An asset filter that matches eligible affiliate location assets for serving. Corresponds to the JSON property affiliateLocationAssetFilter



15737
15738
15739
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15737

def affiliate_location_asset_filter
  @affiliate_location_asset_filter
end

#location_asset_filterGoogle::Apis::DisplayvideoV4::YoutubeAssetAssociationLocationAssetFilter

An asset filter that matches eligible location assets for serving. Corresponds to the JSON property locationAssetFilter



15742
15743
15744
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15742

def location_asset_filter
  @location_asset_filter
end

A sitelink asset. Corresponds to the JSON property sitelinkAsset



15747
15748
15749
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15747

def sitelink_asset
  @sitelink_asset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15754
15755
15756
15757
15758
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15754

def update!(**args)
  @affiliate_location_asset_filter = args[:affiliate_location_asset_filter] if args.key?(:affiliate_location_asset_filter)
  @location_asset_filter = args[:location_asset_filter] if args.key?(:location_asset_filter)
  @sitelink_asset = args[:sitelink_asset] if args.key?(:sitelink_asset)
end