Class: Google::Apis::DisplayvideoV4::YoutubeAssetAssociationLinkedYouTubeAsset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

A YouTube asset linked to a resource in a YoutubeAssetAssociation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAssetAssociationLinkedYouTubeAsset

Returns a new instance of YoutubeAssetAssociationLinkedYouTubeAsset.



14835
14836
14837
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14835

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affiliate_location_asset_filterGoogle::Apis::DisplayvideoV4::YoutubeAssetAssociationAffiliateLocationAssetFilter

An asset filter that matches eligible affiliate location assets for serving. Corresponds to the JSON property affiliateLocationAssetFilter



14823
14824
14825
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14823

def affiliate_location_asset_filter
  @affiliate_location_asset_filter
end

#location_asset_filterGoogle::Apis::DisplayvideoV4::YoutubeAssetAssociationLocationAssetFilter

An asset filter that matches eligible location assets for serving. Corresponds to the JSON property locationAssetFilter



14828
14829
14830
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14828

def location_asset_filter
  @location_asset_filter
end

A sitelink asset. Corresponds to the JSON property sitelinkAsset



14833
14834
14835
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14833

def sitelink_asset
  @sitelink_asset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14840
14841
14842
14843
14844
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14840

def update!(**args)
  @affiliate_location_asset_filter = args[:affiliate_location_asset_filter] if args.key?(:affiliate_location_asset_filter)
  @location_asset_filter = args[:location_asset_filter] if args.key?(:location_asset_filter)
  @sitelink_asset = args[:sitelink_asset] if args.key?(:sitelink_asset)
end