Class: Google::Apis::DisplayvideoV4::YoutubeAssetAssociationLinkedYouTubeAsset
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV4::YoutubeAssetAssociationLinkedYouTubeAsset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb
Overview
A YouTube asset linked to a resource in a YoutubeAssetAssociation.
Instance Attribute Summary collapse
-
#affiliate_location_asset_filter ⇒ Google::Apis::DisplayvideoV4::YoutubeAssetAssociationAffiliateLocationAssetFilter
An asset filter that matches eligible affiliate location assets for serving.
-
#location_asset_filter ⇒ Google::Apis::DisplayvideoV4::YoutubeAssetAssociationLocationAssetFilter
An asset filter that matches eligible location assets for serving.
-
#sitelink_asset ⇒ Google::Apis::DisplayvideoV4::YoutubeAssetAssociationSitelinkAsset
A sitelink asset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ YoutubeAssetAssociationLinkedYouTubeAsset
constructor
A new instance of YoutubeAssetAssociationLinkedYouTubeAsset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ YoutubeAssetAssociationLinkedYouTubeAsset
Returns a new instance of YoutubeAssetAssociationLinkedYouTubeAsset.
14826 14827 14828 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14826 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affiliate_location_asset_filter ⇒ Google::Apis::DisplayvideoV4::YoutubeAssetAssociationAffiliateLocationAssetFilter
An asset filter that matches eligible affiliate location assets for serving.
Corresponds to the JSON property affiliateLocationAssetFilter
14814 14815 14816 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14814 def affiliate_location_asset_filter @affiliate_location_asset_filter end |
#location_asset_filter ⇒ Google::Apis::DisplayvideoV4::YoutubeAssetAssociationLocationAssetFilter
An asset filter that matches eligible location assets for serving.
Corresponds to the JSON property locationAssetFilter
14819 14820 14821 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14819 def location_asset_filter @location_asset_filter end |
#sitelink_asset ⇒ Google::Apis::DisplayvideoV4::YoutubeAssetAssociationSitelinkAsset
A sitelink asset.
Corresponds to the JSON property sitelinkAsset
14824 14825 14826 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14824 def sitelink_asset @sitelink_asset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14831 14832 14833 14834 14835 |
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14831 def update!(**args) @affiliate_location_asset_filter = args[:affiliate_location_asset_filter] if args.key?(:affiliate_location_asset_filter) @location_asset_filter = args[:location_asset_filter] if args.key?(:location_asset_filter) @sitelink_asset = args[:sitelink_asset] if args.key?(:sitelink_asset) end |