Class: Google::Apis::DisplayvideoV4::YoutubeAssetAssociationLocationAssetFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

An asset filter that matches eligible location assets for serving.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAssetAssociationLocationAssetFilter

Returns a new instance of YoutubeAssetAssociationLocationAssetFilter.



14868
14869
14870
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_set_idFixnum

Output only. The ID of the asset set that matches the location assets eligible for serving. Corresponds to the JSON property assetSetId

Returns:

  • (Fixnum)


14856
14857
14858
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14856

def asset_set_id
  @asset_set_id
end

#location_matching_functionGoogle::Apis::DisplayvideoV4::YoutubeAssetAssociationLocationAssetFilterLocationMatchingFunction

The matching function for a location asset filter. Corresponds to the JSON property locationMatchingFunction



14861
14862
14863
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14861

def location_matching_function
  @location_matching_function
end

#location_matching_typeString

Required. The matching type of this location asset filter. Corresponds to the JSON property locationMatchingType

Returns:

  • (String)


14866
14867
14868
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14866

def location_matching_type
  @location_matching_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14873
14874
14875
14876
14877
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 14873

def update!(**args)
  @asset_set_id = args[:asset_set_id] if args.key?(:asset_set_id)
  @location_matching_function = args[:location_matching_function] if args.key?(:location_matching_function)
  @location_matching_type = args[:location_matching_type] if args.key?(:location_matching_type)
end