Class: Google::Apis::DisplayvideoV4::YoutubeAssetAssociationLocationAssetFilterLocationMatchingFunction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v4/classes.rb,
lib/google/apis/displayvideo_v4/representations.rb,
lib/google/apis/displayvideo_v4/representations.rb

Overview

The matching function for a location asset filter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YoutubeAssetAssociationLocationAssetFilterLocationMatchingFunction

Returns a new instance of YoutubeAssetAssociationLocationAssetFilterLocationMatchingFunction.



15815
15816
15817
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#businessString

Optional. The business name to match with. This field is optional and can only be set if location_matching_type is FILTER. Corresponds to the JSON property business

Returns:

  • (String)


15801
15802
15803
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15801

def business
  @business
end

#labelsArray<String>

Optional. The labels to match with. Labels are logically OR'ed together. This field is optional and can only be set if location_matching_type is FILTER. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


15807
15808
15809
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15807

def labels
  @labels
end

#location_asset_idsArray<Fixnum>

Optional. The selected location asset IDs. This field is required if location_matching_type is SELECTED_ASSETS. Corresponds to the JSON property locationAssetIds

Returns:

  • (Array<Fixnum>)


15813
15814
15815
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15813

def location_asset_ids
  @location_asset_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15820
15821
15822
15823
15824
# File 'lib/google/apis/displayvideo_v4/classes.rb', line 15820

def update!(**args)
  @business = args[:business] if args.key?(:business)
  @labels = args[:labels] if args.key?(:labels)
  @location_asset_ids = args[:location_asset_ids] if args.key?(:location_asset_ids)
end